/* this file is created by mksrc.rb (99/08/04 numa@ees.hokudai.ac.jp) */

#include <ruby.h>
#include <math.h>

struct MC_ARRAY {
    int type;        /* 0: int, 1: float */ 
    int dimension;   /* numbwer of dimension */
    int *size;       /* array size for each dimension */
    int total;       /* total size */
    union {
      int    *i;  /* body of the array; expressed as one-dimensitonal array */
      float  *f;  /* body of the array; expressed as one-dimensitonal array */
      double *d;  /* body of the array; expressed as one-dimensitonal array */
    } ptr;
};

#define MC_SetMCA(x,vx) \
        struct MC_ARRAY* x = (struct MC_ARRAY*)DATA_PTR(vx)

#define MC_SetInt(x,vx) \
        int   x = FIXNUM_P(vx) ? FIX2INT(vx) : (int)RFLOAT(vx)->value

#define MC_SetFloat(x,vx) \
        float x = FIXNUM_P(vx) ? (float)FIX2INT(vx) : (float)RFLOAT(vx)->value

#define MC_SetDouble(x,vx) \
        double x = FIXNUM_P(vx) ? (double)FIX2INT(vx) : RFLOAT(vx)->value

#define MC_SetString(x,vx) \
        char * x = STR2CSTR(vx)

#define MC_SetLogic(x,vx) \
        int x = FIXNUM_P(vx) ? (int)FIX2INT(vx) : \
           TYPE(vx)==T_FALSE || TYPE(vx)==T_NIL ? 0 : 1

#define MC_SetIntArray(x,vx) \
        int   * x = ((struct MC_ARRAY*)DATA_PTR(vx))->ptr.i

#define MC_SetFloatArray(x,vx) \
        float * x = ((struct MC_ARRAY*)DATA_PTR(vx))->ptr.f

#define MC_SetDoubleArray(x,vx) \
        float * x = ((struct MC_ARRAY*)DATA_PTR(vx))->ptr.d


#define MC_GetInt(x,vx) \
	vx = INT2FIX(x)

#define MC_GetFloat(x,vx) \
        vx = rb_float_new(x)

#define MC_GetDouble(x,vx) \
        vx = rb_float_new(x)

#define MC_GetString(x,vx) \
        vx = rb_str_new(x,strlen(x))

#define MC_GetLogic(x,vx) \
        vx = (x) ? Qtrue : Qfalse

#define MC_NewInt(x) \
	INT2FIX(x)

#define MC_NewFloat(x) \
	rb_float_new(x)

#define MC_NewDouble(x) \
	rb_float_new(x)

#define MC_NewChar(x) \
	rb_str_new(&x,1)

#define MC_NewString(x) \
	rb_str_new(x,strlen(x))

#define MC_NewLogic(x) \
	(x) ? Qtrue : Qfalse


static VALUE
dcl_scplu(self,Vn,Vupx,Vupy,Vupz)
    VALUE self,Vn,Vupx,Vupy,Vupz;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetFloatArray(Cupz,Vupz);
  scplu_(&Cn,Cupx,Cupy,Cupz);
  return Qnil;
}

static VALUE
dcl_scplv(self,Vn,Vvpx,Vvpy,Vvpz)
    VALUE self,Vn,Vvpx,Vvpy,Vvpz;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cvpx,Vvpx);
  MC_SetFloatArray(Cvpy,Vvpy);
  MC_SetFloatArray(Cvpz,Vvpz);
  scplv_(&Cn,Cvpx,Cvpy,Cvpz);
  return Qnil;
}

static VALUE
dcl_scspli(self,Vindex)
    VALUE self,Vindex;
{
  MC_SetInt(Cindex,Vindex);
  scspli_(&Cindex);
  return Qnil;
}

static VALUE
dcl_scqpli(self,Vindex)
    VALUE self,Vindex;
{
  int   Cindex;
  scqpli_(&Cindex);
  MC_GetInt(Cindex,Vindex);
  return Qnil;
}

static VALUE
dcl_scplzu(self,Vn,Vupx,Vupy,Vupz,Vindex)
    VALUE self,Vn,Vupx,Vupy,Vupz,Vindex;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetFloatArray(Cupz,Vupz);
  MC_SetInt(Cindex,Vindex);
  scplzu_(&Cn,Cupx,Cupy,Cupz,&Cindex);
  return Qnil;
}

static VALUE
dcl_scplzv(self,Vn,Vvpx,Vvpy,Vvpz,Vindex)
    VALUE self,Vn,Vvpx,Vvpy,Vvpz,Vindex;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cvpx,Vvpx);
  MC_SetFloatArray(Cvpy,Vvpy);
  MC_SetFloatArray(Cvpz,Vvpz);
  MC_SetInt(Cindex,Vindex);
  scplzv_(&Cn,Cvpx,Cvpy,Cvpz,&Cindex);
  return Qnil;
}

static VALUE
dcl_scpmu(self,Vn,Vupx,Vupy,Vupz)
    VALUE self,Vn,Vupx,Vupy,Vupz;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetFloatArray(Cupz,Vupz);
  scpmu_(&Cn,Cupx,Cupy,Cupz);
  return Qnil;
}

static VALUE
dcl_scpmv(self,Vn,Vvpx,Vvpy,Vvpz)
    VALUE self,Vn,Vvpx,Vvpy,Vvpz;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cvpx,Vvpx);
  MC_SetFloatArray(Cvpy,Vvpy);
  MC_SetFloatArray(Cvpz,Vvpz);
  scpmv_(&Cn,Cvpx,Cvpy,Cvpz);
  return Qnil;
}

static VALUE
dcl_scspmt(self,Vitype)
    VALUE self,Vitype;
{
  MC_SetInt(Citype,Vitype);
  scspmt_(&Citype);
  return Qnil;
}

static VALUE
dcl_scqpmt(self,Vitype)
    VALUE self,Vitype;
{
  int   Citype;
  scqpmt_(&Citype);
  MC_GetInt(Citype,Vitype);
  return Qnil;
}

static VALUE
dcl_scspmi(self,Vindex)
    VALUE self,Vindex;
{
  MC_SetInt(Cindex,Vindex);
  scspmi_(&Cindex);
  return Qnil;
}

static VALUE
dcl_scqpmi(self,Vindex)
    VALUE self,Vindex;
{
  int   Cindex;
  scqpmi_(&Cindex);
  MC_GetInt(Cindex,Vindex);
  return Qnil;
}

static VALUE
dcl_scspms(self,Vrsize)
    VALUE self,Vrsize;
{
  MC_SetFloat(Crsize,Vrsize);
  scspms_(&Crsize);
  return Qnil;
}

static VALUE
dcl_scqpms(self,Vrsize)
    VALUE self,Vrsize;
{
  float Crsize;
  scqpms_(&Crsize);
  MC_GetFloat(Crsize,Vrsize);
  return Qnil;
}

static VALUE
dcl_scpmzu(self,Vn,Vupx,Vupy,Vupz,Vitype,Vindex,Vrsize)
    VALUE self,Vn,Vupx,Vupy,Vupz,Vitype,Vindex,Vrsize;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetFloatArray(Cupz,Vupz);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  MC_SetFloat(Crsize,Vrsize);
  scpmzu_(&Cn,Cupx,Cupy,Cupz,&Citype,&Cindex,&Crsize);
  return Qnil;
}

static VALUE
dcl_scpmzv(self,Vn,Vvpx,Vvpy,Vvpz,Vitype,Vindex,Vrsize)
    VALUE self,Vn,Vvpx,Vvpy,Vvpz,Vitype,Vindex,Vrsize;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cvpx,Vvpx);
  MC_SetFloatArray(Cvpy,Vvpy);
  MC_SetFloatArray(Cvpz,Vvpz);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  MC_SetFloat(Crsize,Vrsize);
  scpmzv_(&Cn,Cvpx,Cvpy,Cvpz,&Citype,&Cindex,&Crsize);
  return Qnil;
}

static VALUE
dcl_scseye(self,Vxeye3,Vyeye3,Vzeye3)
    VALUE self,Vxeye3,Vyeye3,Vzeye3;
{
  MC_SetFloat(Cxeye3,Vxeye3);
  MC_SetFloat(Cyeye3,Vyeye3);
  MC_SetFloat(Czeye3,Vzeye3);
  scseye_(&Cxeye3,&Cyeye3,&Czeye3);
  return Qnil;
}

static VALUE
dcl_scqeye(self,Vxeye3,Vyeye3,Vzeye3)
    VALUE self,Vxeye3,Vyeye3,Vzeye3;
{
  float Cxeye3;
  float Cyeye3;
  float Czeye3;
  scqeye_(&Cxeye3,&Cyeye3,&Czeye3);
  MC_GetFloat(Cxeye3,Vxeye3);
  MC_GetFloat(Cyeye3,Vyeye3);
  MC_GetFloat(Czeye3,Vzeye3);
  return Qnil;
}

static VALUE
dcl_scslog(self,Vlxlog3,Vlylog3,Vlzlog3)
    VALUE self,Vlxlog3,Vlylog3,Vlzlog3;
{
  MC_SetLogic(Clxlog3,Vlxlog3);
  MC_SetLogic(Clylog3,Vlylog3);
  MC_SetLogic(Clzlog3,Vlzlog3);
  scslog_(&Clxlog3,&Clylog3,&Clzlog3);
  return Qnil;
}

static VALUE
dcl_scqlog(self,Vlxlog3,Vlylog3,Vlzlog3)
    VALUE self,Vlxlog3,Vlylog3,Vlzlog3;
{
  int    Clxlog3;
  int    Clylog3;
  int    Clzlog3;
  scqlog_(&Clxlog3,&Clylog3,&Clzlog3);
  MC_GetLogic(Clxlog3,Vlxlog3);
  MC_GetLogic(Clylog3,Vlylog3);
  MC_GetLogic(Clzlog3,Vlzlog3);
  return Qnil;
}

static VALUE
dcl_scsobj(self,Vxobj3,Vyobj3,Vzobj3)
    VALUE self,Vxobj3,Vyobj3,Vzobj3;
{
  MC_SetFloat(Cxobj3,Vxobj3);
  MC_SetFloat(Cyobj3,Vyobj3);
  MC_SetFloat(Czobj3,Vzobj3);
  scsobj_(&Cxobj3,&Cyobj3,&Czobj3);
  return Qnil;
}

static VALUE
dcl_scqobj(self,Vxobj3,Vyobj3,Vzobj3)
    VALUE self,Vxobj3,Vyobj3,Vzobj3;
{
  float Cxobj3;
  float Cyobj3;
  float Czobj3;
  scqobj_(&Cxobj3,&Cyobj3,&Czobj3);
  MC_GetFloat(Cxobj3,Vxobj3);
  MC_GetFloat(Cyobj3,Vyobj3);
  MC_GetFloat(Czobj3,Vzobj3);
  return Qnil;
}

static VALUE
dcl_scsorg(self,Vsimfac,Vvxorg3,Vvyorg3,Vvzorg3)
    VALUE self,Vsimfac,Vvxorg3,Vvyorg3,Vvzorg3;
{
  MC_SetFloat(Csimfac,Vsimfac);
  MC_SetFloat(Cvxorg3,Vvxorg3);
  MC_SetFloat(Cvyorg3,Vvyorg3);
  MC_SetFloat(Cvzorg3,Vvzorg3);
  scsorg_(&Csimfac,&Cvxorg3,&Cvyorg3,&Cvzorg3);
  return Qnil;
}

static VALUE
dcl_scqorg(self,Vsimfac,Vvxorg3,Vvyorg3,Vvzorg3)
    VALUE self,Vsimfac,Vvxorg3,Vvyorg3,Vvzorg3;
{
  float Csimfac;
  float Cvxorg3;
  float Cvyorg3;
  float Cvzorg3;
  scqorg_(&Csimfac,&Cvxorg3,&Cvyorg3,&Cvzorg3);
  MC_GetFloat(Csimfac,Vsimfac);
  MC_GetFloat(Cvxorg3,Vvxorg3);
  MC_GetFloat(Cvyorg3,Vvyorg3);
  MC_GetFloat(Cvzorg3,Vvzorg3);
  return Qnil;
}

static VALUE
dcl_scspln(self,Vixax,Viyax,Vsect)
    VALUE self,Vixax,Viyax,Vsect;
{
  MC_SetInt(Cixax,Vixax);
  MC_SetInt(Ciyax,Viyax);
  MC_SetFloat(Csect,Vsect);
  scspln_(&Cixax,&Ciyax,&Csect);
  return Qnil;
}

static VALUE
dcl_scqpln(self,Vixax,Viyax,Vsect)
    VALUE self,Vixax,Viyax,Vsect;
{
  int   Cixax;
  int   Ciyax;
  float Csect;
  scqpln_(&Cixax,&Ciyax,&Csect);
  MC_GetInt(Cixax,Vixax);
  MC_GetInt(Ciyax,Viyax);
  MC_GetFloat(Csect,Vsect);
  return Qnil;
}

static VALUE
dcl_scsprj(self)
    VALUE self;
{
  scsprj_();
  return Qnil;
}

static VALUE
dcl_scstrf(self)
    VALUE self;
{
  scstrf_();
  return Qnil;
}

static VALUE
dcl_scstrn(self,Vitr3)
    VALUE self,Vitr3;
{
  MC_SetInt(Citr3,Vitr3);
  scstrn_(&Citr3);
  return Qnil;
}

static VALUE
dcl_scqtrn(self,Vitr3)
    VALUE self,Vitr3;
{
  int   Citr3;
  scqtrn_(&Citr3);
  MC_GetInt(Citr3,Vitr3);
  return Qnil;
}

static VALUE
dcl_scsvpt(self,Vvxmin,Vvxmax,Vvymin,Vvymax,Vvzmin,Vvzmax)
    VALUE self,Vvxmin,Vvxmax,Vvymin,Vvymax,Vvzmin,Vvzmax;
{
  MC_SetFloat(Cvxmin,Vvxmin);
  MC_SetFloat(Cvxmax,Vvxmax);
  MC_SetFloat(Cvymin,Vvymin);
  MC_SetFloat(Cvymax,Vvymax);
  MC_SetFloat(Cvzmin,Vvzmin);
  MC_SetFloat(Cvzmax,Vvzmax);
  scsvpt_(&Cvxmin,&Cvxmax,&Cvymin,&Cvymax,&Cvzmin,&Cvzmax);
  return Qnil;
}

static VALUE
dcl_scqvpt(self,Vvxmin,Vvxmax,Vvymin,Vvymax,Vvzmin,Vvzmax)
    VALUE self,Vvxmin,Vvxmax,Vvymin,Vvymax,Vvzmin,Vvzmax;
{
  float Cvxmin;
  float Cvxmax;
  float Cvymin;
  float Cvymax;
  float Cvzmin;
  float Cvzmax;
  scqvpt_(&Cvxmin,&Cvxmax,&Cvymin,&Cvymax,&Cvzmin,&Cvzmax);
  MC_GetFloat(Cvxmin,Vvxmin);
  MC_GetFloat(Cvxmax,Vvxmax);
  MC_GetFloat(Cvymin,Vvymin);
  MC_GetFloat(Cvymax,Vvymax);
  MC_GetFloat(Cvzmin,Vvzmin);
  MC_GetFloat(Cvzmax,Vvzmax);
  return Qnil;
}

static VALUE
dcl_scswnd(self,Vuxmin,Vuxmax,Vuymin,Vuymax,Vuzmin,Vuzmax)
    VALUE self,Vuxmin,Vuxmax,Vuymin,Vuymax,Vuzmin,Vuzmax;
{
  MC_SetFloat(Cuxmin,Vuxmin);
  MC_SetFloat(Cuxmax,Vuxmax);
  MC_SetFloat(Cuymin,Vuymin);
  MC_SetFloat(Cuymax,Vuymax);
  MC_SetFloat(Cuzmin,Vuzmin);
  MC_SetFloat(Cuzmax,Vuzmax);
  scswnd_(&Cuxmin,&Cuxmax,&Cuymin,&Cuymax,&Cuzmin,&Cuzmax);
  return Qnil;
}

static VALUE
dcl_scqwnd(self,Vuxmin,Vuxmax,Vuymin,Vuymax,Vuzmin,Vuzmax)
    VALUE self,Vuxmin,Vuxmax,Vuymin,Vuymax,Vuzmin,Vuzmax;
{
  float Cuxmin;
  float Cuxmax;
  float Cuymin;
  float Cuymax;
  float Cuzmin;
  float Cuzmax;
  scqwnd_(&Cuxmin,&Cuxmax,&Cuymin,&Cuymax,&Cuzmin,&Cuzmax);
  MC_GetFloat(Cuxmin,Vuxmin);
  MC_GetFloat(Cuxmax,Vuxmax);
  MC_GetFloat(Cuymin,Vuymin);
  MC_GetFloat(Cuymax,Vuymax);
  MC_GetFloat(Cuzmin,Vuzmin);
  MC_GetFloat(Cuzmax,Vuzmax);
  return Qnil;
}

static VALUE
dcl_sctnu(self,Vupx,Vupy,Vupz)
    VALUE self,Vupx,Vupy,Vupz;
{
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetFloatArray(Cupz,Vupz);
  sctnu_(Cupx,Cupy,Cupz);
  return Qnil;
}

static VALUE
dcl_sctnv(self,Vvpx,Vvpy,Vvpz)
    VALUE self,Vvpx,Vvpy,Vvpz;
{
  MC_SetFloatArray(Cvpx,Vvpx);
  MC_SetFloatArray(Cvpy,Vvpy);
  MC_SetFloatArray(Cvpz,Vvpz);
  sctnv_(Cvpx,Cvpy,Cvpz);
  return Qnil;
}

static VALUE
dcl_scstnp(self,Vitpat1,Vitpat2)
    VALUE self,Vitpat1,Vitpat2;
{
  MC_SetInt(Citpat1,Vitpat1);
  MC_SetInt(Citpat2,Vitpat2);
  scstnp_(&Citpat1,&Citpat2);
  return Qnil;
}

static VALUE
dcl_scqtnp(self,Vitpat1,Vitpat2)
    VALUE self,Vitpat1,Vitpat2;
{
  int   Citpat1;
  int   Citpat2;
  scqtnp_(&Citpat1,&Citpat2);
  MC_GetInt(Citpat1,Vitpat1);
  MC_GetInt(Citpat2,Vitpat2);
  return Qnil;
}

static VALUE
dcl_sctnzu(self,Vupx,Vupy,Vupz,Vitpat1,Vitpat2)
    VALUE self,Vupx,Vupy,Vupz,Vitpat1,Vitpat2;
{
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetFloatArray(Cupz,Vupz);
  MC_SetInt(Citpat1,Vitpat1);
  MC_SetInt(Citpat2,Vitpat2);
  sctnzu_(Cupx,Cupy,Cupz,&Citpat1,&Citpat2);
  return Qnil;
}

static VALUE
dcl_sctnzv(self,Vvpx,Vvpy,Vvpz,Vitpat1,Vitpat2)
    VALUE self,Vvpx,Vvpy,Vvpz,Vitpat1,Vitpat2;
{
  MC_SetFloatArray(Cvpx,Vvpx);
  MC_SetFloatArray(Cvpy,Vvpy);
  MC_SetFloatArray(Cvpz,Vvpz);
  MC_SetInt(Citpat1,Vitpat1);
  MC_SetInt(Citpat2,Vitpat2);
  sctnzv_(Cvpx,Cvpy,Cvpz,&Citpat1,&Citpat2);
  return Qnil;
}

static VALUE
dcl_isgtrc(self,Vctr)
    VALUE self,Vctr;
{
  MC_SetString(Cctr,Vctr);
  int ret;
  int isgtrc_();
  ret = isgtrc_(Cctr,strlen(Cctr));
  return MC_NewInt(ret);;
}

static VALUE
dcl_sglau(self,Vux1,Vuy1,Vux2,Vuy2)
    VALUE self,Vux1,Vuy1,Vux2,Vuy2;
{
  MC_SetFloat(Cux1,Vux1);
  MC_SetFloat(Cuy1,Vuy1);
  MC_SetFloat(Cux2,Vux2);
  MC_SetFloat(Cuy2,Vuy2);
  sglau_(&Cux1,&Cuy1,&Cux2,&Cuy2);
  return Qnil;
}

static VALUE
dcl_sglav(self,Vvx1,Vvy1,Vvx2,Vvy2)
    VALUE self,Vvx1,Vvy1,Vvx2,Vvy2;
{
  MC_SetFloat(Cvx1,Vvx1);
  MC_SetFloat(Cvy1,Vvy1);
  MC_SetFloat(Cvx2,Vvx2);
  MC_SetFloat(Cvy2,Vvy2);
  sglav_(&Cvx1,&Cvy1,&Cvx2,&Cvy2);
  return Qnil;
}

static VALUE
dcl_sglar(self,Vrx1,Vry1,Vrx2,Vry2)
    VALUE self,Vrx1,Vry1,Vrx2,Vry2;
{
  MC_SetFloat(Crx1,Vrx1);
  MC_SetFloat(Cry1,Vry1);
  MC_SetFloat(Crx2,Vrx2);
  MC_SetFloat(Cry2,Vry2);
  sglar_(&Crx1,&Cry1,&Crx2,&Cry2);
  return Qnil;
}

static VALUE
dcl_sgslat(self,Vitype)
    VALUE self,Vitype;
{
  MC_SetInt(Citype,Vitype);
  sgslat_(&Citype);
  return Qnil;
}

static VALUE
dcl_sgqlat(self,Vitype)
    VALUE self,Vitype;
{
  int   Citype;
  sgqlat_(&Citype);
  MC_GetInt(Citype,Vitype);
  return Qnil;
}

static VALUE
dcl_sgslai(self,Vindex)
    VALUE self,Vindex;
{
  MC_SetInt(Cindex,Vindex);
  sgslai_(&Cindex);
  return Qnil;
}

static VALUE
dcl_sgqlai(self,Vindex)
    VALUE self,Vindex;
{
  int   Cindex;
  sgqlai_(&Cindex);
  MC_GetInt(Cindex,Vindex);
  return Qnil;
}

static VALUE
dcl_sglazr(self,Vrx1,Vry1,Vrx2,Vry2,Vitype,Vindex)
    VALUE self,Vrx1,Vry1,Vrx2,Vry2,Vitype,Vindex;
{
  MC_SetFloat(Crx1,Vrx1);
  MC_SetFloat(Cry1,Vry1);
  MC_SetFloat(Crx2,Vrx2);
  MC_SetFloat(Cry2,Vry2);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  sglazr_(&Crx1,&Cry1,&Crx2,&Cry2,&Citype,&Cindex);
  return Qnil;
}

static VALUE
dcl_sglazu(self,Vux1,Vuy1,Vux2,Vuy2,Vitype,Vindex)
    VALUE self,Vux1,Vuy1,Vux2,Vuy2,Vitype,Vindex;
{
  MC_SetFloat(Cux1,Vux1);
  MC_SetFloat(Cuy1,Vuy1);
  MC_SetFloat(Cux2,Vux2);
  MC_SetFloat(Cuy2,Vuy2);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  sglazu_(&Cux1,&Cuy1,&Cux2,&Cuy2,&Citype,&Cindex);
  return Qnil;
}

static VALUE
dcl_sglazv(self,Vvx1,Vvy1,Vvx2,Vvy2,Vitype,Vindex)
    VALUE self,Vvx1,Vvy1,Vvx2,Vvy2,Vitype,Vindex;
{
  MC_SetFloat(Cvx1,Vvx1);
  MC_SetFloat(Cvy1,Vvy1);
  MC_SetFloat(Cvx2,Vvx2);
  MC_SetFloat(Cvy2,Vvy2);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  sglazv_(&Cvx1,&Cvy1,&Cvx2,&Cvy2,&Citype,&Cindex);
  return Qnil;
}

static VALUE
dcl_sglnu(self,Vux1,Vuy1,Vux2,Vuy2)
    VALUE self,Vux1,Vuy1,Vux2,Vuy2;
{
  MC_SetFloat(Cux1,Vux1);
  MC_SetFloat(Cuy1,Vuy1);
  MC_SetFloat(Cux2,Vux2);
  MC_SetFloat(Cuy2,Vuy2);
  sglnu_(&Cux1,&Cuy1,&Cux2,&Cuy2);
  return Qnil;
}

static VALUE
dcl_sglnv(self,Vvx1,Vvy1,Vvx2,Vvy2)
    VALUE self,Vvx1,Vvy1,Vvx2,Vvy2;
{
  MC_SetFloat(Cvx1,Vvx1);
  MC_SetFloat(Cvy1,Vvy1);
  MC_SetFloat(Cvx2,Vvx2);
  MC_SetFloat(Cvy2,Vvy2);
  sglnv_(&Cvx1,&Cvy1,&Cvx2,&Cvy2);
  return Qnil;
}

static VALUE
dcl_sglnr(self,Vrx1,Vry1,Vrx2,Vry2)
    VALUE self,Vrx1,Vry1,Vrx2,Vry2;
{
  MC_SetFloat(Crx1,Vrx1);
  MC_SetFloat(Cry1,Vry1);
  MC_SetFloat(Crx2,Vrx2);
  MC_SetFloat(Cry2,Vry2);
  sglnr_(&Crx1,&Cry1,&Crx2,&Cry2);
  return Qnil;
}

static VALUE
dcl_sgslni(self,Vindex)
    VALUE self,Vindex;
{
  MC_SetInt(Cindex,Vindex);
  sgslni_(&Cindex);
  return Qnil;
}

static VALUE
dcl_sgqlni(self,Vindex)
    VALUE self,Vindex;
{
  int   Cindex;
  sgqlni_(&Cindex);
  MC_GetInt(Cindex,Vindex);
  return Qnil;
}

static VALUE
dcl_sglnzr(self,Vrx1,Vry1,Vrx2,Vry2,Vindex)
    VALUE self,Vrx1,Vry1,Vrx2,Vry2,Vindex;
{
  MC_SetFloat(Crx1,Vrx1);
  MC_SetFloat(Cry1,Vry1);
  MC_SetFloat(Crx2,Vrx2);
  MC_SetFloat(Cry2,Vry2);
  MC_SetInt(Cindex,Vindex);
  sglnzr_(&Crx1,&Cry1,&Crx2,&Cry2,&Cindex);
  return Qnil;
}

static VALUE
dcl_sglnzu(self,Vux1,Vuy1,Vux2,Vuy2,Vindex)
    VALUE self,Vux1,Vuy1,Vux2,Vuy2,Vindex;
{
  MC_SetFloat(Cux1,Vux1);
  MC_SetFloat(Cuy1,Vuy1);
  MC_SetFloat(Cux2,Vux2);
  MC_SetFloat(Cuy2,Vuy2);
  MC_SetInt(Cindex,Vindex);
  sglnzu_(&Cux1,&Cuy1,&Cux2,&Cuy2,&Cindex);
  return Qnil;
}

static VALUE
dcl_sglnzv(self,Vvx1,Vvy1,Vvx2,Vvy2,Vindex)
    VALUE self,Vvx1,Vvy1,Vvx2,Vvy2,Vindex;
{
  MC_SetFloat(Cvx1,Vvx1);
  MC_SetFloat(Cvy1,Vvy1);
  MC_SetFloat(Cvx2,Vvx2);
  MC_SetFloat(Cvy2,Vvy2);
  MC_SetInt(Cindex,Vindex);
  sglnzv_(&Cvx1,&Cvy1,&Cvx2,&Cvy2,&Cindex);
  return Qnil;
}

static VALUE
dcl_sgopn(self,Viws)
    VALUE self,Viws;
{
  MC_SetInt(Ciws,Viws);
  sgopn_(&Ciws);
  return Qnil;
}

static VALUE
dcl_sginit(self)
    VALUE self;
{
  sginit_();
  return Qnil;
}

static VALUE
dcl_sgfrm(self)
    VALUE self;
{
  sgfrm_();
  return Qnil;
}

static VALUE
dcl_sgcls(self)
    VALUE self;
{
  sgcls_();
  return Qnil;
}

static VALUE
dcl_sgpget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  sgpget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_sgiget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  sgiget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_sgrget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  float Cipara;
  sgrget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetFloat(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_sglget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int    Cipara;
  sglget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetLogic(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_sgpset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  sgpset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_sgiset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  sgiset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_sgrset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  sgrset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_sglset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  sglset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_sgpstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  sgpstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_sgistx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  sgistx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_sgrstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  sgrstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_sglstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  sglstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_sgplu(self,Vn,Vupx,Vupy)
    VALUE self,Vn,Vupx,Vupy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  sgplu_(&Cn,Cupx,Cupy);
  return Qnil;
}

static VALUE
dcl_sgplv(self,Vn,Vvpx,Vvpy)
    VALUE self,Vn,Vvpx,Vvpy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cvpx,Vvpx);
  MC_SetFloatArray(Cvpy,Vvpy);
  sgplv_(&Cn,Cvpx,Cvpy);
  return Qnil;
}

static VALUE
dcl_sgplr(self,Vn,Vrpx,Vrpy)
    VALUE self,Vn,Vrpx,Vrpy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Crpx,Vrpx);
  MC_SetFloatArray(Crpy,Vrpy);
  sgplr_(&Cn,Crpx,Crpy);
  return Qnil;
}

static VALUE
dcl_sgsplt(self,Vitype)
    VALUE self,Vitype;
{
  MC_SetInt(Citype,Vitype);
  sgsplt_(&Citype);
  return Qnil;
}

static VALUE
dcl_sgqplt(self,Vitype)
    VALUE self,Vitype;
{
  int   Citype;
  sgqplt_(&Citype);
  MC_GetInt(Citype,Vitype);
  return Qnil;
}

static VALUE
dcl_sgspli(self,Vindex)
    VALUE self,Vindex;
{
  MC_SetInt(Cindex,Vindex);
  sgspli_(&Cindex);
  return Qnil;
}

static VALUE
dcl_sgqpli(self,Vindex)
    VALUE self,Vindex;
{
  int   Cindex;
  sgqpli_(&Cindex);
  MC_GetInt(Cindex,Vindex);
  return Qnil;
}

static VALUE
dcl_sgplzr(self,Vn,Vrpx,Vrpy,Vitype,Vindex)
    VALUE self,Vn,Vrpx,Vrpy,Vitype,Vindex;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Crpx,Vrpx);
  MC_SetFloatArray(Crpy,Vrpy);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  sgplzr_(&Cn,Crpx,Crpy,&Citype,&Cindex);
  return Qnil;
}

static VALUE
dcl_sgplzu(self,Vn,Vupx,Vupy,Vitype,Vindex)
    VALUE self,Vn,Vupx,Vupy,Vitype,Vindex;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  sgplzu_(&Cn,Cupx,Cupy,&Citype,&Cindex);
  return Qnil;
}

static VALUE
dcl_sgplzv(self,Vn,Vvpx,Vvpy,Vitype,Vindex)
    VALUE self,Vn,Vvpx,Vvpy,Vitype,Vindex;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cvpx,Vvpx);
  MC_SetFloatArray(Cvpy,Vvpy);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  sgplzv_(&Cn,Cvpx,Cvpy,&Citype,&Cindex);
  return Qnil;
}

static VALUE
dcl_sgpmu(self,Vn,Vupx,Vupy)
    VALUE self,Vn,Vupx,Vupy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  sgpmu_(&Cn,Cupx,Cupy);
  return Qnil;
}

static VALUE
dcl_sgpmv(self,Vn,Vvpx,Vvpy)
    VALUE self,Vn,Vvpx,Vvpy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cvpx,Vvpx);
  MC_SetFloatArray(Cvpy,Vvpy);
  sgpmv_(&Cn,Cvpx,Cvpy);
  return Qnil;
}

static VALUE
dcl_sgpmr(self,Vn,Vrpx,Vrpy)
    VALUE self,Vn,Vrpx,Vrpy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Crpx,Vrpx);
  MC_SetFloatArray(Crpy,Vrpy);
  sgpmr_(&Cn,Crpx,Crpy);
  return Qnil;
}

static VALUE
dcl_sgspmt(self,Vitype)
    VALUE self,Vitype;
{
  MC_SetInt(Citype,Vitype);
  sgspmt_(&Citype);
  return Qnil;
}

static VALUE
dcl_sgqpmt(self,Vitype)
    VALUE self,Vitype;
{
  int   Citype;
  sgqpmt_(&Citype);
  MC_GetInt(Citype,Vitype);
  return Qnil;
}

static VALUE
dcl_sgspmi(self,Vindex)
    VALUE self,Vindex;
{
  MC_SetInt(Cindex,Vindex);
  sgspmi_(&Cindex);
  return Qnil;
}

static VALUE
dcl_sgqpmi(self,Vindex)
    VALUE self,Vindex;
{
  int   Cindex;
  sgqpmi_(&Cindex);
  MC_GetInt(Cindex,Vindex);
  return Qnil;
}

static VALUE
dcl_sgspms(self,Vrsize)
    VALUE self,Vrsize;
{
  MC_SetFloat(Crsize,Vrsize);
  sgspms_(&Crsize);
  return Qnil;
}

static VALUE
dcl_sgqpms(self,Vrsize)
    VALUE self,Vrsize;
{
  float Crsize;
  sgqpms_(&Crsize);
  MC_GetFloat(Crsize,Vrsize);
  return Qnil;
}

static VALUE
dcl_sgpmzr(self,Vn,Vrpx,Vrpy,Vitype,Vindex,Vrsize)
    VALUE self,Vn,Vrpx,Vrpy,Vitype,Vindex,Vrsize;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Crpx,Vrpx);
  MC_SetFloatArray(Crpy,Vrpy);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  MC_SetFloat(Crsize,Vrsize);
  sgpmzr_(&Cn,Crpx,Crpy,&Citype,&Cindex,&Crsize);
  return Qnil;
}

static VALUE
dcl_sgpmzu(self,Vn,Vupx,Vupy,Vitype,Vindex,Vrsize)
    VALUE self,Vn,Vupx,Vupy,Vitype,Vindex,Vrsize;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  MC_SetFloat(Crsize,Vrsize);
  sgpmzu_(&Cn,Cupx,Cupy,&Citype,&Cindex,&Crsize);
  return Qnil;
}

static VALUE
dcl_sgpmzv(self,Vn,Vvpx,Vvpy,Vitype,Vindex,Vrsize)
    VALUE self,Vn,Vvpx,Vvpy,Vitype,Vindex,Vrsize;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cvpx,Vvpx);
  MC_SetFloatArray(Cvpy,Vvpy);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  MC_SetFloat(Crsize,Vrsize);
  sgpmzv_(&Cn,Cvpx,Cvpy,&Citype,&Cindex,&Crsize);
  return Qnil;
}

static VALUE
dcl_sgpqnp(self,Vncp)
    VALUE self,Vncp;
{
  int   Cncp;
  sgpqnp_(&Cncp);
  MC_GetInt(Cncp,Vncp);
  return Qnil;
}

static VALUE
dcl_sgpqid(self,Vcp,Vidx)
    VALUE self,Vcp,Vidx;
{
  MC_SetString(Ccp,Vcp);
  int   Cidx;
  sgpqid_(Ccp,&Cidx,strlen(Ccp));
  MC_GetInt(Cidx,Vidx);
  return Qnil;
}

static VALUE
dcl_sgpqcp(self,Vidx,Vcp)
    VALUE self,Vidx,Vcp;
{
  MC_SetInt(Cidx,Vidx);
  char * Ccp="                ";
  sgpqcp_(&Cidx,Ccp,strlen(Ccp));
  MC_GetString(Ccp,Vcp);
  return Qnil;
}

static VALUE
dcl_sgpqvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  int   Cipara;
  sgpqvl_(&Cidx,&Cipara);
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_sgpsvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetInt(Cipara,Vipara);
  sgpsvl_(&Cidx,&Cipara);
  return Qnil;
}

static VALUE
dcl_sgpwsn(self)
    VALUE self;
{
  sgpwsn_();
  return Qnil;
}

static VALUE
dcl_sgsmpl(self,Vplx,Vply,Vplrot)
    VALUE self,Vplx,Vply,Vplrot;
{
  MC_SetFloat(Cplx,Vplx);
  MC_SetFloat(Cply,Vply);
  MC_SetFloat(Cplrot,Vplrot);
  sgsmpl_(&Cplx,&Cply,&Cplrot);
  return Qnil;
}

static VALUE
dcl_sgqmpl(self,Vplx,Vply,Vplrot)
    VALUE self,Vplx,Vply,Vplrot;
{
  float Cplx;
  float Cply;
  float Cplrot;
  sgqmpl_(&Cplx,&Cply,&Cplrot);
  MC_GetFloat(Cplx,Vplx);
  MC_GetFloat(Cply,Vply);
  MC_GetFloat(Cplrot,Vplrot);
  return Qnil;
}

static VALUE
dcl_sgsplc(self,Vcharx)
    VALUE self,Vcharx;
{
  MC_SetString(Ccharx,Vcharx);
  sgsplc_(Ccharx,strlen(Ccharx));
  return Qnil;
}

static VALUE
dcl_sgqplc(self,Vcharx)
    VALUE self,Vcharx;
{
  char * Ccharx="                ";
  sgqplc_(Ccharx,strlen(Ccharx));
  MC_GetString(Ccharx,Vcharx);
  return Qnil;
}

static VALUE
dcl_sgspls(self,Vrsize)
    VALUE self,Vrsize;
{
  MC_SetFloat(Crsize,Vrsize);
  sgspls_(&Crsize);
  return Qnil;
}

static VALUE
dcl_sgqpls(self,Vrsize)
    VALUE self,Vrsize;
{
  float Crsize;
  sgqpls_(&Crsize);
  MC_GetFloat(Crsize,Vrsize);
  return Qnil;
}

static VALUE
dcl_sgnplc(self)
    VALUE self;
{
  sgnplc_();
  return Qnil;
}

static VALUE
dcl_sgssim(self,Vsimfac,Vvxoff,Vvyoff)
    VALUE self,Vsimfac,Vvxoff,Vvyoff;
{
  MC_SetFloat(Csimfac,Vsimfac);
  MC_SetFloat(Cvxoff,Vvxoff);
  MC_SetFloat(Cvyoff,Vvyoff);
  sgssim_(&Csimfac,&Cvxoff,&Cvyoff);
  return Qnil;
}

static VALUE
dcl_sgqsim(self,Vsimfac,Vvxoff,Vvyoff)
    VALUE self,Vsimfac,Vvxoff,Vvyoff;
{
  float Csimfac;
  float Cvxoff;
  float Cvyoff;
  sgqsim_(&Csimfac,&Cvxoff,&Cvyoff);
  MC_GetFloat(Csimfac,Vsimfac);
  MC_GetFloat(Cvxoff,Vvxoff);
  MC_GetFloat(Cvyoff,Vvyoff);
  return Qnil;
}

static VALUE
dcl_sgstrf(self)
    VALUE self;
{
  sgstrf_();
  return Qnil;
}

static VALUE
dcl_sgstrn(self,Vitr)
    VALUE self,Vitr;
{
  MC_SetInt(Citr,Vitr);
  sgstrn_(&Citr);
  return Qnil;
}

static VALUE
dcl_sgqtrn(self,Vitr)
    VALUE self,Vitr;
{
  int   Citr;
  sgqtrn_(&Citr);
  MC_GetInt(Citr,Vitr);
  return Qnil;
}

static VALUE
dcl_sgstxy(self,Vtxmin,Vtxmax,Vtymin,Vtymax)
    VALUE self,Vtxmin,Vtxmax,Vtymin,Vtymax;
{
  MC_SetFloat(Ctxmin,Vtxmin);
  MC_SetFloat(Ctxmax,Vtxmax);
  MC_SetFloat(Ctymin,Vtymin);
  MC_SetFloat(Ctymax,Vtymax);
  sgstxy_(&Ctxmin,&Ctxmax,&Ctymin,&Ctymax);
  return Qnil;
}

static VALUE
dcl_sgqtxy(self,Vtxmin,Vtxmax,Vtymin,Vtymax)
    VALUE self,Vtxmin,Vtxmax,Vtymin,Vtymax;
{
  float Ctxmin;
  float Ctxmax;
  float Ctymin;
  float Ctymax;
  sgqtxy_(&Ctxmin,&Ctxmax,&Ctymin,&Ctymax);
  MC_GetFloat(Ctxmin,Vtxmin);
  MC_GetFloat(Ctxmax,Vtxmax);
  MC_GetFloat(Ctymin,Vtymin);
  MC_GetFloat(Ctymax,Vtymax);
  return Qnil;
}

static VALUE
dcl_sgsvpt(self,Vvxmin,Vvxmax,Vvymin,Vvymax)
    VALUE self,Vvxmin,Vvxmax,Vvymin,Vvymax;
{
  MC_SetFloat(Cvxmin,Vvxmin);
  MC_SetFloat(Cvxmax,Vvxmax);
  MC_SetFloat(Cvymin,Vvymin);
  MC_SetFloat(Cvymax,Vvymax);
  sgsvpt_(&Cvxmin,&Cvxmax,&Cvymin,&Cvymax);
  return Qnil;
}

static VALUE
dcl_sgqvpt(self,Vvxmin,Vvxmax,Vvymin,Vvymax)
    VALUE self,Vvxmin,Vvxmax,Vvymin,Vvymax;
{
  float Cvxmin;
  float Cvxmax;
  float Cvymin;
  float Cvymax;
  sgqvpt_(&Cvxmin,&Cvxmax,&Cvymin,&Cvymax);
  MC_GetFloat(Cvxmin,Vvxmin);
  MC_GetFloat(Cvxmax,Vvxmax);
  MC_GetFloat(Cvymin,Vvymin);
  MC_GetFloat(Cvymax,Vvymax);
  return Qnil;
}

static VALUE
dcl_sgswnd(self,Vuxmin,Vuxmax,Vuymin,Vuymax)
    VALUE self,Vuxmin,Vuxmax,Vuymin,Vuymax;
{
  MC_SetFloat(Cuxmin,Vuxmin);
  MC_SetFloat(Cuxmax,Vuxmax);
  MC_SetFloat(Cuymin,Vuymin);
  MC_SetFloat(Cuymax,Vuymax);
  sgswnd_(&Cuxmin,&Cuxmax,&Cuymin,&Cuymax);
  return Qnil;
}

static VALUE
dcl_sgqwnd(self,Vuxmin,Vuxmax,Vuymin,Vuymax)
    VALUE self,Vuxmin,Vuxmax,Vuymin,Vuymax;
{
  float Cuxmin;
  float Cuxmax;
  float Cuymin;
  float Cuymax;
  sgqwnd_(&Cuxmin,&Cuxmax,&Cuymin,&Cuymax);
  MC_GetFloat(Cuxmin,Vuxmin);
  MC_GetFloat(Cuxmax,Vuxmax);
  MC_GetFloat(Cuymin,Vuymin);
  MC_GetFloat(Cuymax,Vuymax);
  return Qnil;
}

static VALUE
dcl_sgtnu(self,Vn,Vupx,Vupy)
    VALUE self,Vn,Vupx,Vupy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  sgtnu_(&Cn,Cupx,Cupy);
  return Qnil;
}

static VALUE
dcl_sgtnv(self,Vn,Vvpx,Vvpy)
    VALUE self,Vn,Vvpx,Vvpy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cvpx,Vvpx);
  MC_SetFloatArray(Cvpy,Vvpy);
  sgtnv_(&Cn,Cvpx,Cvpy);
  return Qnil;
}

static VALUE
dcl_sgtnr(self,Vn,Vrpx,Vrpy)
    VALUE self,Vn,Vrpx,Vrpy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Crpx,Vrpx);
  MC_SetFloatArray(Crpy,Vrpy);
  sgtnr_(&Cn,Crpx,Crpy);
  return Qnil;
}

static VALUE
dcl_sgstnp(self,Vitpat)
    VALUE self,Vitpat;
{
  MC_SetInt(Citpat,Vitpat);
  sgstnp_(&Citpat);
  return Qnil;
}

static VALUE
dcl_sgqtnp(self,Vitpat)
    VALUE self,Vitpat;
{
  int   Citpat;
  sgqtnp_(&Citpat);
  MC_GetInt(Citpat,Vitpat);
  return Qnil;
}

static VALUE
dcl_sgtnzr(self,Vn,Vrpx,Vrpy,Vitpat)
    VALUE self,Vn,Vrpx,Vrpy,Vitpat;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Crpx,Vrpx);
  MC_SetFloatArray(Crpy,Vrpy);
  MC_SetInt(Citpat,Vitpat);
  sgtnzr_(&Cn,Crpx,Crpy,&Citpat);
  return Qnil;
}

static VALUE
dcl_sgtnzu(self,Vn,Vupx,Vupy,Vitpat)
    VALUE self,Vn,Vupx,Vupy,Vitpat;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetInt(Citpat,Vitpat);
  sgtnzu_(&Cn,Cupx,Cupy,&Citpat);
  return Qnil;
}

static VALUE
dcl_sgtnzv(self,Vn,Vvpx,Vvpy,Vitpat)
    VALUE self,Vn,Vvpx,Vvpy,Vitpat;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cvpx,Vvpx);
  MC_SetFloatArray(Cvpy,Vvpy);
  MC_SetInt(Citpat,Vitpat);
  sgtnzv_(&Cn,Cvpx,Cvpy,&Citpat);
  return Qnil;
}

static VALUE
dcl_sgtrqf(self,Vntx,Vltr)
    VALUE self,Vntx,Vltr;
{
  MC_SetInt(Cntx,Vntx);
  int    Cltr;
  sgtrqf_(&Cntx,&Cltr);
  MC_GetLogic(Cltr,Vltr);
  return Qnil;
}

static VALUE
dcl_sgtrsl(self,Vcts,Vctl)
    VALUE self,Vcts,Vctl;
{
  MC_SetString(Ccts,Vcts);
  char * Cctl="                ";
  sgtrsl_(Ccts,Cctl,strlen(Ccts),strlen(Cctl));
  MC_GetString(Cctl,Vctl);
  return Qnil;
}

static VALUE
dcl_sgtrsn(self,Vcts,Vntx)
    VALUE self,Vcts,Vntx;
{
  MC_SetString(Ccts,Vcts);
  int   Cntx;
  sgtrsn_(Ccts,&Cntx,strlen(Ccts));
  MC_GetInt(Cntx,Vntx);
  return Qnil;
}

static VALUE
dcl_sgtrls(self,Vctl,Vcts)
    VALUE self,Vctl,Vcts;
{
  MC_SetString(Cctl,Vctl);
  char * Ccts="                ";
  sgtrls_(Cctl,Ccts,strlen(Cctl),strlen(Ccts));
  MC_GetString(Ccts,Vcts);
  return Qnil;
}

static VALUE
dcl_sgtrln(self,Vctl,Vntx)
    VALUE self,Vctl,Vntx;
{
  MC_SetString(Cctl,Vctl);
  int   Cntx;
  sgtrln_(Cctl,&Cntx,strlen(Cctl));
  MC_GetInt(Cntx,Vntx);
  return Qnil;
}

static VALUE
dcl_sgtrns(self,Vntx,Vcts)
    VALUE self,Vntx,Vcts;
{
  MC_SetInt(Cntx,Vntx);
  char * Ccts="                ";
  sgtrns_(&Cntx,Ccts,strlen(Ccts));
  MC_GetString(Ccts,Vcts);
  return Qnil;
}

static VALUE
dcl_sgtrnl(self,Vntx,Vctl)
    VALUE self,Vntx,Vctl;
{
  MC_SetInt(Cntx,Vntx);
  char * Cctl="                ";
  sgtrnl_(&Cntx,Cctl,strlen(Cctl));
  MC_GetString(Cctl,Vctl);
  return Qnil;
}

static VALUE
dcl_sgtxu(self,Vux,Vuy,Vchars)
    VALUE self,Vux,Vuy,Vchars;
{
  MC_SetFloat(Cux,Vux);
  MC_SetFloat(Cuy,Vuy);
  MC_SetString(Cchars,Vchars);
  sgtxu_(&Cux,&Cuy,Cchars,strlen(Cchars));
  return Qnil;
}

static VALUE
dcl_sgtxv(self,Vvx,Vvy,Vchars)
    VALUE self,Vvx,Vvy,Vchars;
{
  MC_SetFloat(Cvx,Vvx);
  MC_SetFloat(Cvy,Vvy);
  MC_SetString(Cchars,Vchars);
  sgtxv_(&Cvx,&Cvy,Cchars,strlen(Cchars));
  return Qnil;
}

static VALUE
dcl_sgtxr(self,Vrx,Vry,Vchars)
    VALUE self,Vrx,Vry,Vchars;
{
  MC_SetFloat(Crx,Vrx);
  MC_SetFloat(Cry,Vry);
  MC_SetString(Cchars,Vchars);
  sgtxr_(&Crx,&Cry,Cchars,strlen(Cchars));
  return Qnil;
}

static VALUE
dcl_sgstxs(self,Vrsize)
    VALUE self,Vrsize;
{
  MC_SetFloat(Crsize,Vrsize);
  sgstxs_(&Crsize);
  return Qnil;
}

static VALUE
dcl_sgqtxs(self,Vrsize)
    VALUE self,Vrsize;
{
  float Crsize;
  sgqtxs_(&Crsize);
  MC_GetFloat(Crsize,Vrsize);
  return Qnil;
}

static VALUE
dcl_sgstxr(self,Virota)
    VALUE self,Virota;
{
  MC_SetInt(Cirota,Virota);
  sgstxr_(&Cirota);
  return Qnil;
}

static VALUE
dcl_sgqtxr(self,Virota)
    VALUE self,Virota;
{
  int   Cirota;
  sgqtxr_(&Cirota);
  MC_GetInt(Cirota,Virota);
  return Qnil;
}

static VALUE
dcl_sgstxc(self,Vicent)
    VALUE self,Vicent;
{
  MC_SetInt(Cicent,Vicent);
  sgstxc_(&Cicent);
  return Qnil;
}

static VALUE
dcl_sgqtxc(self,Vicent)
    VALUE self,Vicent;
{
  int   Cicent;
  sgqtxc_(&Cicent);
  MC_GetInt(Cicent,Vicent);
  return Qnil;
}

static VALUE
dcl_sgstxi(self,Vindex)
    VALUE self,Vindex;
{
  MC_SetInt(Cindex,Vindex);
  sgstxi_(&Cindex);
  return Qnil;
}

static VALUE
dcl_sgqtxi(self,Vindex)
    VALUE self,Vindex;
{
  int   Cindex;
  sgqtxi_(&Cindex);
  MC_GetInt(Cindex,Vindex);
  return Qnil;
}

static VALUE
dcl_sgtxzr(self,Vrx,Vry,Vchars,Vrsize,Virota,Vicent,Vindex)
    VALUE self,Vrx,Vry,Vchars,Vrsize,Virota,Vicent,Vindex;
{
  MC_SetFloat(Crx,Vrx);
  MC_SetFloat(Cry,Vry);
  MC_SetString(Cchars,Vchars);
  MC_SetFloat(Crsize,Vrsize);
  MC_SetInt(Cirota,Virota);
  MC_SetInt(Cicent,Vicent);
  MC_SetInt(Cindex,Vindex);
  sgtxzr_(&Crx,&Cry,Cchars,&Crsize,&Cirota,&Cicent,&Cindex,strlen(Cchars));
  return Qnil;
}

static VALUE
dcl_sgtxzu(self,Vux,Vuy,Vchars,Vrsize,Virota,Vicent,Vindex)
    VALUE self,Vux,Vuy,Vchars,Vrsize,Virota,Vicent,Vindex;
{
  MC_SetFloat(Cux,Vux);
  MC_SetFloat(Cuy,Vuy);
  MC_SetString(Cchars,Vchars);
  MC_SetFloat(Crsize,Vrsize);
  MC_SetInt(Cirota,Virota);
  MC_SetInt(Cicent,Vicent);
  MC_SetInt(Cindex,Vindex);
  sgtxzu_(&Cux,&Cuy,Cchars,&Crsize,&Cirota,&Cicent,&Cindex,strlen(Cchars));
  return Qnil;
}

static VALUE
dcl_sgtxzv(self,Vvx,Vvy,Vchars,Vrsize,Virota,Vicent,Vindex)
    VALUE self,Vvx,Vvy,Vchars,Vrsize,Virota,Vicent,Vindex;
{
  MC_SetFloat(Cvx,Vvx);
  MC_SetFloat(Cvy,Vvy);
  MC_SetString(Cchars,Vchars);
  MC_SetFloat(Crsize,Vrsize);
  MC_SetInt(Cirota,Virota);
  MC_SetInt(Cicent,Vicent);
  MC_SetInt(Cindex,Vindex);
  sgtxzv_(&Cvx,&Cvy,Cchars,&Crsize,&Cirota,&Cicent,&Cindex,strlen(Cchars));
  return Qnil;
}

static VALUE
dcl_sldiv(self,Vcform,Vix,Viy)
    VALUE self,Vcform,Vix,Viy;
{
  MC_SetString(Ccform,Vcform);
  MC_SetInt(Cix,Vix);
  MC_SetInt(Ciy,Viy);
  sldiv_(Ccform,&Cix,&Ciy,strlen(Ccform));
  return Qnil;
}

static VALUE
dcl_sldivz(self)
    VALUE self;
{
  sldivz_();
  return Qnil;
}

static VALUE
dcl_slinit(self,Vwxmax,Vwymax,Vfact)
    VALUE self,Vwxmax,Vwymax,Vfact;
{
  MC_SetFloat(Cwxmax,Vwxmax);
  MC_SetFloat(Cwymax,Vwymax);
  MC_SetFloat(Cfact,Vfact);
  slinit_(&Cwxmax,&Cwymax,&Cfact);
  return Qnil;
}

static VALUE
dcl_slsize(self,Vcszez)
    VALUE self,Vcszez;
{
  MC_SetString(Ccszez,Vcszez);
  slsize_(Ccszez,strlen(Ccszez));
  return Qnil;
}

static VALUE
dcl_slform(self,Vdxa,Vdya)
    VALUE self,Vdxa,Vdya;
{
  MC_SetFloat(Cdxa,Vdxa);
  MC_SetFloat(Cdya,Vdya);
  slform_(&Cdxa,&Cdya);
  return Qnil;
}

static VALUE
dcl_slmgn(self,Vxl,Vxr,Vyb,Vyt)
    VALUE self,Vxl,Vxr,Vyb,Vyt;
{
  MC_SetFloat(Cxl,Vxl);
  MC_SetFloat(Cxr,Vxr);
  MC_SetFloat(Cyb,Vyb);
  MC_SetFloat(Cyt,Vyt);
  slmgn_(&Cxl,&Cxr,&Cyb,&Cyt);
  return Qnil;
}

static VALUE
dcl_slmgnz(self,Vxamin,Vxamax,Vyamin,Vyamax,Vxl,Vxr,Vyb,Vyt)
    VALUE self,Vxamin,Vxamax,Vyamin,Vyamax,Vxl,Vxr,Vyb,Vyt;
{
  float Cxamin;
  float Cxamax;
  float Cyamin;
  MC_SetFloat(Cyamax,Vyamax);
  MC_SetFloat(Cxl,Vxl);
  MC_SetFloat(Cxr,Vxr);
  MC_SetFloat(Cyb,Vyb);
  MC_SetFloat(Cyt,Vyt);
  slmgnz_(&Cxamin,&Cxamax,&Cyamin,&Cyamax,&Cxl,&Cxr,&Cyb,&Cyt);
  MC_GetFloat(Cxamin,Vxamin);
  MC_GetFloat(Cxamax,Vxamax);
  MC_GetFloat(Cyamin,Vyamin);
  return Qnil;
}

static VALUE
dcl_slpage(self,Vlev,Vifrm,Vipage)
    VALUE self,Vlev,Vifrm,Vipage;
{
  MC_SetInt(Clev,Vlev);
  MC_SetInt(Cifrm,Vifrm);
  int   Cipage;
  slpage_(&Clev,&Cifrm,&Cipage);
  MC_GetInt(Cipage,Vipage);
  return Qnil;
}

static VALUE
dcl_slpcnr(self)
    VALUE self;
{
  slpcnr_();
  return Qnil;
}

static VALUE
dcl_slpvpc(self,Vindex,Vrc)
    VALUE self,Vindex,Vrc;
{
  MC_SetInt(Cindex,Vindex);
  MC_SetFloat(Crc,Vrc);
  slpvpc_(&Cindex,&Crc);
  return Qnil;
}

static VALUE
dcl_slpvpr(self,Vindex)
    VALUE self,Vindex;
{
  MC_SetInt(Cindex,Vindex);
  slpvpr_(&Cindex);
  return Qnil;
}

static VALUE
dcl_slpwvc(self,Vindex,Vrc)
    VALUE self,Vindex,Vrc;
{
  MC_SetInt(Cindex,Vindex);
  MC_SetFloat(Crc,Vrc);
  slpwvc_(&Cindex,&Crc);
  return Qnil;
}

static VALUE
dcl_slpwvr(self,Vindex)
    VALUE self,Vindex;
{
  MC_SetInt(Cindex,Vindex);
  slpwvr_(&Cindex);
  return Qnil;
}

static VALUE
dcl_slpwwc(self,Vindex,Vrc)
    VALUE self,Vindex,Vrc;
{
  MC_SetInt(Cindex,Vindex);
  MC_SetFloat(Crc,Vrc);
  slpwwc_(&Cindex,&Crc);
  return Qnil;
}

static VALUE
dcl_slpwwr(self,Vindex)
    VALUE self,Vindex;
{
  MC_SetInt(Cindex,Vindex);
  slpwwr_(&Cindex);
  return Qnil;
}

static VALUE
dcl_slqrct(self,Vlev,Vifrm,Vxamin,Vxamax,Vyamin,Vyamax)
    VALUE self,Vlev,Vifrm,Vxamin,Vxamax,Vyamin,Vyamax;
{
  MC_SetInt(Clev,Vlev);
  MC_SetInt(Cifrm,Vifrm);
  float Cxamin;
  float Cxamax;
  float Cyamin;
  MC_SetFloat(Cyamax,Vyamax);
  slqrct_(&Clev,&Cifrm,&Cxamin,&Cxamax,&Cyamin,&Cyamax);
  MC_GetFloat(Cxamin,Vxamin);
  MC_GetFloat(Cxamax,Vxamax);
  MC_GetFloat(Cyamin,Vyamin);
  return Qnil;
}

static VALUE
dcl_slqsiz(self,Vcsize,Vdx,Vdy)
    VALUE self,Vcsize,Vdx,Vdy;
{
  MC_SetString(Ccsize,Vcsize);
  float Cdx;
  float Cdy;
  slqsiz_(Ccsize,&Cdx,&Cdy,strlen(Ccsize));
  MC_GetFloat(Cdx,Vdx);
  MC_GetFloat(Cdy,Vdy);
  return Qnil;
}

static VALUE
dcl_slrat(self,Vrx,Vry)
    VALUE self,Vrx,Vry;
{
  MC_SetFloat(Crx,Vrx);
  MC_SetFloat(Cry,Vry);
  slrat_(&Crx,&Cry);
  return Qnil;
}

static VALUE
dcl_slratz(self,Vxamin,Vxamax,Vyamin,Vyamax,Vrx,Vry)
    VALUE self,Vxamin,Vxamax,Vyamin,Vyamax,Vrx,Vry;
{
  MC_SetFloat(Cxamin,Vxamin);
  MC_SetFloat(Cxamax,Vxamax);
  MC_SetFloat(Cyamin,Vyamin);
  MC_SetFloat(Cyamax,Vyamax);
  MC_SetFloat(Crx,Vrx);
  MC_SetFloat(Cry,Vry);
  slratz_(&Cxamin,&Cxamax,&Cyamin,&Cyamax,&Crx,&Cry);
  return Qnil;
}

static VALUE
dcl_slsttl(self,Vcttl,Vcside,Vpx,Vpy,Vht,Vnt)
    VALUE self,Vcttl,Vcside,Vpx,Vpy,Vht,Vnt;
{
  MC_SetString(Ccttl,Vcttl);
  MC_SetString(Ccside,Vcside);
  MC_SetFloat(Cpx,Vpx);
  MC_SetFloat(Cpy,Vpy);
  MC_SetFloat(Cht,Vht);
  MC_SetInt(Cnt,Vnt);
  slsttl_(Ccttl,Ccside,&Cpx,&Cpy,&Cht,&Cnt,strlen(Ccttl),strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_sldttl(self,Vnt)
    VALUE self,Vnt;
{
  MC_SetInt(Cnt,Vnt);
  sldttl_(&Cnt);
  return Qnil;
}

static VALUE
dcl_slpttl(self)
    VALUE self;
{
  slpttl_();
  return Qnil;
}

static VALUE
dcl_sltlcv(self,Vctlin,Vctlout,Vlout)
    VALUE self,Vctlin,Vctlout,Vlout;
{
  MC_SetString(Cctlin,Vctlin);
  char * Cctlout="                ";
  MC_SetInt(Clout,Vlout);
  sltlcv_(Cctlin,Cctlout,&Clout,strlen(Cctlin),strlen(Cctlout));
  MC_GetString(Cctlout,Vctlout);
  return Qnil;
}

static VALUE
dcl_slzttl(self,Vcside,Vcttl,Vpx,Vpy,Vrsize,Vindex)
    VALUE self,Vcside,Vcttl,Vpx,Vpy,Vrsize,Vindex;
{
  MC_SetString(Ccside,Vcside);
  MC_SetString(Ccttl,Vcttl);
  MC_SetFloat(Cpx,Vpx);
  MC_SetFloat(Cpy,Vpy);
  MC_SetFloat(Crsize,Vrsize);
  MC_SetInt(Cindex,Vindex);
  slzttl_(Ccside,Ccttl,&Cpx,&Cpy,&Crsize,&Cindex,strlen(Ccside),strlen(Ccttl));
  return Qnil;
}

static VALUE
dcl_stfpr3(self,Vx,Vy,Vz,Vrx,Vry)
    VALUE self,Vx,Vy,Vz,Vrx,Vry;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  MC_SetFloat(Cz,Vz);
  float Crx;
  float Cry;
  stfpr3_(&Cx,&Cy,&Cz,&Crx,&Cry);
  MC_GetFloat(Crx,Vrx);
  MC_GetFloat(Cry,Vry);
  return Qnil;
}

static VALUE
dcl_stspr3(self)
    VALUE self;
{
  stspr3_();
  return Qnil;
}

static VALUE
dcl_stfpr2(self,Vx,Vy,Vrx,Vry)
    VALUE self,Vx,Vy,Vrx,Vry;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  float Crx;
  float Cry;
  stfpr2_(&Cx,&Cy,&Crx,&Cry);
  MC_GetFloat(Crx,Vrx);
  MC_GetFloat(Cry,Vry);
  return Qnil;
}

static VALUE
dcl_stipr2(self,Vrx,Vry,Vx,Vy)
    VALUE self,Vrx,Vry,Vx,Vy;
{
  MC_SetFloat(Crx,Vrx);
  MC_SetFloat(Cry,Vry);
  float Cx;
  float Cy;
  stipr2_(&Crx,&Cry,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  return Qnil;
}

static VALUE
dcl_stspr2(self,Vix,Viy,Vsect)
    VALUE self,Vix,Viy,Vsect;
{
  MC_SetInt(Cix,Vix);
  MC_SetInt(Ciy,Viy);
  MC_SetFloat(Csect,Vsect);
  stspr2_(&Cix,&Ciy,&Csect);
  return Qnil;
}

static VALUE
dcl_stepr2(self)
    VALUE self;
{
  stepr2_();
  return Qnil;
}

static VALUE
dcl_strpr2(self)
    VALUE self;
{
  strpr2_();
  return Qnil;
}

static VALUE
dcl_stfrad(self,Vx,Vy,Vrx,Vry)
    VALUE self,Vx,Vy,Vrx,Vry;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  float Crx;
  float Cry;
  stfrad_(&Cx,&Cy,&Crx,&Cry);
  MC_GetFloat(Crx,Vrx);
  MC_GetFloat(Cry,Vry);
  return Qnil;
}

static VALUE
dcl_stirad(self,Vrx,Vry,Vx,Vy)
    VALUE self,Vrx,Vry,Vx,Vy;
{
  MC_SetFloat(Crx,Vrx);
  MC_SetFloat(Cry,Vry);
  float Cx;
  float Cy;
  stirad_(&Crx,&Cry,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  return Qnil;
}

static VALUE
dcl_stsrad(self,Vlxdeg,Vlydeg)
    VALUE self,Vlxdeg,Vlydeg;
{
  MC_SetLogic(Clxdeg,Vlxdeg);
  MC_SetLogic(Clydeg,Vlydeg);
  stsrad_(&Clxdeg,&Clydeg);
  return Qnil;
}

static VALUE
dcl_stfrot(self,Vux,Vuy,Vtx,Vty)
    VALUE self,Vux,Vuy,Vtx,Vty;
{
  MC_SetFloat(Cux,Vux);
  MC_SetFloat(Cuy,Vuy);
  MC_SetFloat(Ctx,Vtx);
  float Cty;
  stfrot_(&Cux,&Cuy,&Ctx,&Cty);
  MC_GetFloat(Cty,Vty);
  return Qnil;
}

static VALUE
dcl_stirot(self,Vtx,Vty,Vux,Vuy)
    VALUE self,Vtx,Vty,Vux,Vuy;
{
  MC_SetFloat(Ctx,Vtx);
  MC_SetFloat(Cty,Vty);
  MC_SetFloat(Cux,Vux);
  float Cuy;
  stirot_(&Ctx,&Cty,&Cux,&Cuy);
  MC_GetFloat(Cuy,Vuy);
  return Qnil;
}

static VALUE
dcl_stsrot(self,Vtheta,Vphi,Vpsi)
    VALUE self,Vtheta,Vphi,Vpsi;
{
  MC_SetFloat(Ctheta,Vtheta);
  MC_SetFloat(Cphi,Vphi);
  MC_SetFloat(Cpsi,Vpsi);
  stsrot_(&Ctheta,&Cphi,&Cpsi);
  return Qnil;
}

static VALUE
dcl_stftr3(self,Vux,Vuy,Vuz,Vvx,Vvy,Vvz)
    VALUE self,Vux,Vuy,Vuz,Vvx,Vvy,Vvz;
{
  MC_SetFloat(Cux,Vux);
  MC_SetFloat(Cuy,Vuy);
  MC_SetFloat(Cuz,Vuz);
  float Cvx;
  float Cvy;
  float Cvz;
  stftr3_(&Cux,&Cuy,&Cuz,&Cvx,&Cvy,&Cvz);
  MC_GetFloat(Cvx,Vvx);
  MC_GetFloat(Cvy,Vvy);
  MC_GetFloat(Cvz,Vvz);
  return Qnil;
}

static VALUE
dcl_ststr3(self,Vitr,Vcxa,Vcya,Vcza,Vvxoff,Vvyoff,Vvzoff)
    VALUE self,Vitr,Vcxa,Vcya,Vcza,Vvxoff,Vvyoff,Vvzoff;
{
  MC_SetInt(Citr,Vitr);
  MC_SetFloat(Ccxa,Vcxa);
  MC_SetFloat(Ccya,Vcya);
  MC_SetFloat(Ccza,Vcza);
  MC_SetFloat(Cvxoff,Vvxoff);
  MC_SetFloat(Cvyoff,Vvyoff);
  MC_SetFloat(Cvzoff,Vvzoff);
  ststr3_(&Citr,&Ccxa,&Ccya,&Ccza,&Cvxoff,&Cvyoff,&Cvzoff);
  return Qnil;
}

static VALUE
dcl_stsrd3(self,Vlxrd,Vlyrd,Vlzrd)
    VALUE self,Vlxrd,Vlyrd,Vlzrd;
{
  MC_SetLogic(Clxrd,Vlxrd);
  MC_SetLogic(Clyrd,Vlyrd);
  MC_SetLogic(Clzrd,Vlzrd);
  stsrd3_(&Clxrd,&Clyrd,&Clzrd);
  return Qnil;
}

static VALUE
dcl_stslg3(self,Vlxlg,Vlylg,Vlzlg)
    VALUE self,Vlxlg,Vlylg,Vlzlg;
{
  MC_SetLogic(Clxlg,Vlxlg);
  MC_SetLogic(Clylg,Vlylg);
  MC_SetLogic(Clzlg,Vlzlg);
  stslg3_(&Clxlg,&Clylg,&Clzlg);
  return Qnil;
}

static VALUE
dcl_stftrf(self,Vux,Vuy,Vvx,Vvy)
    VALUE self,Vux,Vuy,Vvx,Vvy;
{
  MC_SetFloat(Cux,Vux);
  MC_SetFloat(Cuy,Vuy);
  float Cvx;
  float Cvy;
  stftrf_(&Cux,&Cuy,&Cvx,&Cvy);
  MC_GetFloat(Cvx,Vvx);
  MC_GetFloat(Cvy,Vvy);
  return Qnil;
}

static VALUE
dcl_stitrf(self,Vvx,Vvy,Vux,Vuy)
    VALUE self,Vvx,Vvy,Vux,Vuy;
{
  MC_SetFloat(Cvx,Vvx);
  MC_SetFloat(Cvy,Vvy);
  float Cux;
  float Cuy;
  stitrf_(&Cvx,&Cvy,&Cux,&Cuy);
  MC_GetFloat(Cux,Vux);
  MC_GetFloat(Cuy,Vuy);
  return Qnil;
}

static VALUE
dcl_stqtrf(self,Vlmapa)
    VALUE self,Vlmapa;
{
  int    Clmapa;
  stqtrf_(&Clmapa);
  MC_GetLogic(Clmapa,Vlmapa);
  return Qnil;
}

static VALUE
dcl_ststrf(self,Vlmapa)
    VALUE self,Vlmapa;
{
  MC_SetLogic(Clmapa,Vlmapa);
  ststrf_(&Clmapa);
  return Qnil;
}

static VALUE
dcl_stftrn(self,Vux,Vuy,Vvx,Vvy)
    VALUE self,Vux,Vuy,Vvx,Vvy;
{
  MC_SetFloat(Cux,Vux);
  MC_SetFloat(Cuy,Vuy);
  float Cvx;
  float Cvy;
  stftrn_(&Cux,&Cuy,&Cvx,&Cvy);
  MC_GetFloat(Cvx,Vvx);
  MC_GetFloat(Cvy,Vvy);
  return Qnil;
}

static VALUE
dcl_stitrn(self,Vvx,Vvy,Vux,Vuy)
    VALUE self,Vvx,Vvy,Vux,Vuy;
{
  MC_SetFloat(Cvx,Vvx);
  MC_SetFloat(Cvy,Vvy);
  float Cux;
  float Cuy;
  stitrn_(&Cvx,&Cvy,&Cux,&Cuy);
  MC_GetFloat(Cux,Vux);
  MC_GetFloat(Cuy,Vuy);
  return Qnil;
}

static VALUE
dcl_ststrn(self,Vitr,Vcxa,Vcya,Vvxoff,Vvyoff)
    VALUE self,Vitr,Vcxa,Vcya,Vvxoff,Vvyoff;
{
  MC_SetInt(Citr,Vitr);
  MC_SetFloat(Ccxa,Vcxa);
  MC_SetFloat(Ccya,Vcya);
  MC_SetFloat(Cvxoff,Vvxoff);
  MC_SetFloat(Cvyoff,Vvyoff);
  ststrn_(&Citr,&Ccxa,&Ccya,&Cvxoff,&Cvyoff);
  return Qnil;
}

static VALUE
dcl_stfusr(self,Vux,Vuy,Vxx,Vyy)
    VALUE self,Vux,Vuy,Vxx,Vyy;
{
  MC_SetFloat(Cux,Vux);
  MC_SetFloat(Cuy,Vuy);
  float Cxx;
  float Cyy;
  stfusr_(&Cux,&Cuy,&Cxx,&Cyy);
  MC_GetFloat(Cxx,Vxx);
  MC_GetFloat(Cyy,Vyy);
  return Qnil;
}

static VALUE
dcl_stiusr(self,Vxx,Vyy,Vux,Vuy)
    VALUE self,Vxx,Vyy,Vux,Vuy;
{
  MC_SetFloat(Cxx,Vxx);
  MC_SetFloat(Cyy,Vyy);
  float Cux;
  float Cuy;
  stiusr_(&Cxx,&Cyy,&Cux,&Cuy);
  MC_GetFloat(Cux,Vux);
  MC_GetFloat(Cuy,Vuy);
  return Qnil;
}

static VALUE
dcl_stsusr(self)
    VALUE self;
{
  stsusr_();
  return Qnil;
}

static VALUE
dcl_stfwtr(self,Vrx,Vry,Vwx,Vwy)
    VALUE self,Vrx,Vry,Vwx,Vwy;
{
  MC_SetFloat(Crx,Vrx);
  MC_SetFloat(Cry,Vry);
  float Cwx;
  float Cwy;
  stfwtr_(&Crx,&Cry,&Cwx,&Cwy);
  MC_GetFloat(Cwx,Vwx);
  MC_GetFloat(Cwy,Vwy);
  return Qnil;
}

static VALUE
dcl_stiwtr(self,Vwx,Vwy,Vrx,Vry)
    VALUE self,Vwx,Vwy,Vrx,Vry;
{
  MC_SetFloat(Cwx,Vwx);
  MC_SetFloat(Cwy,Vwy);
  float Crx;
  float Cry;
  stiwtr_(&Cwx,&Cwy,&Crx,&Cry);
  MC_GetFloat(Crx,Vrx);
  MC_GetFloat(Cry,Vry);
  return Qnil;
}

static VALUE
dcl_stswtr(self)
    VALUE self;
{
  stswtr_();
  return Qnil;
}

static VALUE
dcl_stqwtr(self)
    VALUE self;
{
  stqwtr_();
  return Qnil;
}

static VALUE
dcl_stswrc(self,Vwsxmn,Vwsxmx,Vwsymn,Vwsymx)
    VALUE self,Vwsxmn,Vwsxmx,Vwsymn,Vwsymx;
{
  MC_SetFloat(Cwsxmn,Vwsxmn);
  MC_SetFloat(Cwsxmx,Vwsxmx);
  MC_SetFloat(Cwsymn,Vwsymn);
  MC_SetFloat(Cwsymx,Vwsymx);
  stswrc_(&Cwsxmn,&Cwsxmx,&Cwsymn,&Cwsymx);
  return Qnil;
}

static VALUE
dcl_stqwrc(self,Vwsxmn,Vwsxmx,Vwsymn,Vwsymx)
    VALUE self,Vwsxmn,Vwsxmx,Vwsymn,Vwsymx;
{
  float Cwsxmn;
  float Cwsxmx;
  float Cwsymn;
  float Cwsymx;
  stqwrc_(&Cwsxmn,&Cwsxmx,&Cwsymn,&Cwsymx);
  MC_GetFloat(Cwsxmn,Vwsxmn);
  MC_GetFloat(Cwsxmx,Vwsxmx);
  MC_GetFloat(Cwsymn,Vwsymn);
  MC_GetFloat(Cwsymx,Vwsymx);
  return Qnil;
}

static VALUE
dcl_swcget(self,Vcp,Vcpara)
    VALUE self,Vcp,Vcpara;
{
  MC_SetString(Ccp,Vcp);
  char * Ccpara="                ";
  swcget_(Ccp,Ccpara,strlen(Ccp),strlen(Ccpara));
  MC_GetString(Ccpara,Vcpara);
  return Qnil;
}

static VALUE
dcl_swcset(self,Vcp,Vcpara)
    VALUE self,Vcp,Vcpara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetString(Ccpara,Vcpara);
  swcset_(Ccp,Ccpara,strlen(Ccp),strlen(Ccpara));
  return Qnil;
}

static VALUE
dcl_swcstx(self,Vcp,Vcpara)
    VALUE self,Vcp,Vcpara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetString(Ccpara,Vcpara);
  swcstx_(Ccp,Ccpara,strlen(Ccp),strlen(Ccpara));
  return Qnil;
}

static VALUE
dcl_swcqnp(self,Vncp)
    VALUE self,Vncp;
{
  int   Cncp;
  swcqnp_(&Cncp);
  MC_GetInt(Cncp,Vncp);
  return Qnil;
}

static VALUE
dcl_swcqid(self,Vcp,Vidx)
    VALUE self,Vcp,Vidx;
{
  MC_SetString(Ccp,Vcp);
  int   Cidx;
  swcqid_(Ccp,&Cidx,strlen(Ccp));
  MC_GetInt(Cidx,Vidx);
  return Qnil;
}

static VALUE
dcl_swcqcp(self,Vidx,Vcp)
    VALUE self,Vidx,Vcp;
{
  MC_SetInt(Cidx,Vidx);
  char * Ccp="                ";
  swcqcp_(&Cidx,Ccp,strlen(Ccp));
  MC_GetString(Ccp,Vcp);
  return Qnil;
}

static VALUE
dcl_swcqvl(self,Vidx,Vcval)
    VALUE self,Vidx,Vcval;
{
  MC_SetInt(Cidx,Vidx);
  char * Ccval="                ";
  swcqvl_(&Cidx,Ccval,strlen(Ccval));
  MC_GetString(Ccval,Vcval);
  return Qnil;
}

static VALUE
dcl_swcsvl(self,Vidx,Vcval)
    VALUE self,Vidx,Vcval;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetString(Ccval,Vcval);
  swcsvl_(&Cidx,Ccval,strlen(Ccval));
  return Qnil;
}

static VALUE
dcl_swdopn(self)
    VALUE self;
{
  swdopn_();
  return Qnil;
}

static VALUE
dcl_swdcls(self)
    VALUE self;
{
  swdcls_();
  return Qnil;
}

static VALUE
dcl_swpopn(self)
    VALUE self;
{
  swpopn_();
  return Qnil;
}

static VALUE
dcl_swpcls(self)
    VALUE self;
{
  swpcls_();
  return Qnil;
}

static VALUE
dcl_swoopn(self,Vcobj,Vcomm)
    VALUE self,Vcobj,Vcomm;
{
  MC_SetString(Ccobj,Vcobj);
  MC_SetString(Ccomm,Vcomm);
  swoopn_(Ccobj,Ccomm,strlen(Ccobj),strlen(Ccomm));
  return Qnil;
}

static VALUE
dcl_swocls(self,Vcobj)
    VALUE self,Vcobj;
{
  MC_SetString(Ccobj,Vcobj);
  swocls_(Ccobj,strlen(Ccobj));
  return Qnil;
}

static VALUE
dcl_swswdi(self,Viwdidx)
    VALUE self,Viwdidx;
{
  MC_SetInt(Ciwdidx,Viwdidx);
  swswdi_(&Ciwdidx);
  return Qnil;
}

static VALUE
dcl_swscli(self,Viclidx)
    VALUE self,Viclidx;
{
  MC_SetInt(Ciclidx,Viclidx);
  swscli_(&Ciclidx);
  return Qnil;
}

static VALUE
dcl_swgopn(self)
    VALUE self;
{
  swgopn_();
  return Qnil;
}

static VALUE
dcl_swgmov(self,Vwx,Vwy)
    VALUE self,Vwx,Vwy;
{
  MC_SetFloat(Cwx,Vwx);
  MC_SetFloat(Cwy,Vwy);
  swgmov_(&Cwx,&Cwy);
  return Qnil;
}

static VALUE
dcl_swgplt(self,Vwx,Vwy)
    VALUE self,Vwx,Vwy;
{
  MC_SetFloat(Cwx,Vwx);
  MC_SetFloat(Cwy,Vwy);
  swgplt_(&Cwx,&Cwy);
  return Qnil;
}

static VALUE
dcl_swgcls(self)
    VALUE self;
{
  swgcls_();
  return Qnil;
}

static VALUE
dcl_swgton(self,Vnp,Vwpx,Vwpy,Vitpat)
    VALUE self,Vnp,Vwpx,Vwpy,Vitpat;
{
  MC_SetInt(Cnp,Vnp);
  MC_SetFloatArray(Cwpx,Vwpx);
  MC_SetFloatArray(Cwpy,Vwpy);
  MC_SetInt(Citpat,Vitpat);
  swgton_(&Cnp,Cwpx,Cwpy,&Citpat);
  return Qnil;
}

static VALUE
dcl_swiopn(self,Viwx,Viwy,Vimw,Vimh)
    VALUE self,Viwx,Viwy,Vimw,Vimh;
{
  MC_SetInt(Ciwx,Viwx);
  MC_SetInt(Ciwy,Viwy);
  MC_SetInt(Cimw,Vimw);
  MC_SetInt(Cimh,Vimh);
  swiopn_(&Ciwx,&Ciwy,&Cimw,&Cimh);
  return Qnil;
}

static VALUE
dcl_swidat(self,Vimage,Vnlen)
    VALUE self,Vimage,Vnlen;
{
  MC_SetIntArray(Cimage,Vimage);
  MC_SetInt(Cnlen,Vnlen);
  swidat_(Cimage,&Cnlen);
  return Qnil;
}

static VALUE
dcl_swicls(self)
    VALUE self;
{
  swicls_();
  return Qnil;
}

static VALUE
dcl_swqpnt(self,Vwx,Vwy,Vmb)
    VALUE self,Vwx,Vwy,Vmb;
{
  MC_SetFloat(Cwx,Vwx);
  MC_SetFloat(Cwy,Vwy);
  MC_SetInt(Cmb,Vmb);
  swqpnt_(&Cwx,&Cwy,&Cmb);
  return Qnil;
}

static VALUE
dcl_swfint(self,Vwx,Vwy,Viwx,Viwy)
    VALUE self,Vwx,Vwy,Viwx,Viwy;
{
  MC_SetFloat(Cwx,Vwx);
  MC_SetFloat(Cwy,Vwy);
  MC_SetInt(Ciwx,Viwx);
  MC_SetInt(Ciwy,Viwy);
  swfint_(&Cwx,&Cwy,&Ciwx,&Ciwy);
  return Qnil;
}

static VALUE
dcl_swiint(self,Viwx,Viwy,Vwx,Vwy)
    VALUE self,Viwx,Viwy,Vwx,Vwy;
{
  MC_SetInt(Ciwx,Viwx);
  MC_SetInt(Ciwy,Viwy);
  MC_SetFloat(Cwx,Vwx);
  MC_SetFloat(Cwy,Vwy);
  swiint_(&Ciwx,&Ciwy,&Cwx,&Cwy);
  return Qnil;
}

static VALUE
dcl_swqwdc(self,Vlwdatr)
    VALUE self,Vlwdatr;
{
  MC_SetLogic(Clwdatr,Vlwdatr);
  swqwdc_(&Clwdatr);
  return Qnil;
}

static VALUE
dcl_swqclc(self,Vlclatr)
    VALUE self,Vlclatr;
{
  MC_SetLogic(Clclatr,Vlclatr);
  swqclc_(&Clclatr);
  return Qnil;
}

static VALUE
dcl_swqtnc(self,Vltnatr)
    VALUE self,Vltnatr;
{
  MC_SetLogic(Cltnatr,Vltnatr);
  swqtnc_(&Cltnatr);
  return Qnil;
}

static VALUE
dcl_swqimc(self,Vlimatr)
    VALUE self,Vlimatr;
{
  MC_SetLogic(Climatr,Vlimatr);
  swqimc_(&Climatr);
  return Qnil;
}

static VALUE
dcl_swqptc(self,Vlptatr)
    VALUE self,Vlptatr;
{
  MC_SetLogic(Clptatr,Vlptatr);
  swqptc_(&Clptatr);
  return Qnil;
}

static VALUE
dcl_swqrct(self,Vwsxmn,Vwsxmx,Vwsymn,Vwsymx,Vfact)
    VALUE self,Vwsxmn,Vwsxmx,Vwsymn,Vwsymx,Vfact;
{
  MC_SetFloat(Cwsxmn,Vwsxmn);
  MC_SetFloat(Cwsxmx,Vwsxmx);
  MC_SetFloat(Cwsymn,Vwsymn);
  MC_SetFloat(Cwsymx,Vwsymx);
  MC_SetFloat(Cfact,Vfact);
  swqrct_(&Cwsxmn,&Cwsxmx,&Cwsymn,&Cwsymx,&Cfact);
  return Qnil;
}

static VALUE
dcl_swsrot(self,Viwtrot)
    VALUE self,Viwtrot;
{
  MC_SetInt(Ciwtrot,Viwtrot);
  swsrot_(&Ciwtrot);
  return Qnil;
}

static VALUE
dcl_swpget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  swpget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_swiget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  swiget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_swrget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  float Cipara;
  swrget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetFloat(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_swlget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int    Cipara;
  swlget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetLogic(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_swpset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  swpset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_swiset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  swiset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_swrset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  swrset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_swlset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  swlset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_swpstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  swpstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_swistx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  swistx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_swrstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  swrstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_swlstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  swlstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_swpqnp(self,Vncp)
    VALUE self,Vncp;
{
  int   Cncp;
  swpqnp_(&Cncp);
  MC_GetInt(Cncp,Vncp);
  return Qnil;
}

static VALUE
dcl_swpqid(self,Vcp,Vidx)
    VALUE self,Vcp,Vidx;
{
  MC_SetString(Ccp,Vcp);
  int   Cidx;
  swpqid_(Ccp,&Cidx,strlen(Ccp));
  MC_GetInt(Cidx,Vidx);
  return Qnil;
}

static VALUE
dcl_swpqcp(self,Vidx,Vcp)
    VALUE self,Vidx,Vcp;
{
  MC_SetInt(Cidx,Vidx);
  char * Ccp="                ";
  swpqcp_(&Cidx,Ccp,strlen(Ccp));
  MC_GetString(Ccp,Vcp);
  return Qnil;
}

static VALUE
dcl_swpqvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetInt(Cipara,Vipara);
  swpqvl_(&Cidx,&Cipara);
  return Qnil;
}

static VALUE
dcl_swrqvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetInt(Cipara,Vipara);
  swrqvl_(&Cidx,&Cipara);
  return Qnil;
}

static VALUE
dcl_swiqvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetInt(Cipara,Vipara);
  swiqvl_(&Cidx,&Cipara);
  return Qnil;
}

static VALUE
dcl_swlqvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  int   Cipara;
  swlqvl_(&Cidx,&Cipara);
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_swpsvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetInt(Cipara,Vipara);
  swpsvl_(&Cidx,&Cipara);
  return Qnil;
}

static VALUE
dcl_swrsvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetInt(Cipara,Vipara);
  swrsvl_(&Cidx,&Cipara);
  return Qnil;
}

static VALUE
dcl_swisvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetInt(Cipara,Vipara);
  swisvl_(&Cidx,&Cipara);
  return Qnil;
}

static VALUE
dcl_swlsvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetInt(Cipara,Vipara);
  swlsvl_(&Cidx,&Cipara);
  return Qnil;
}

static VALUE
dcl_swqfnm(self,Vcpara,Vcfname)
    VALUE self,Vcpara,Vcfname;
{
  MC_SetString(Ccpara,Vcpara);
  MC_SetString(Ccfname,Vcfname);
  swqfnm_(Ccpara,Ccfname,strlen(Ccpara),strlen(Ccfname));
  return Qnil;
}

static VALUE
dcl_szcltn(self,Vicpat,Vmaxcli)
    VALUE self,Vicpat,Vmaxcli;
{
  MC_SetIntArray(Cicpat,Vicpat);
  MC_SetInt(Cmaxcli,Vmaxcli);
  szcltn_(Cicpat,&Cmaxcli);
  return Qnil;
}

static VALUE
dcl_szfont(self,Vifont,Viposx,Vnchar,Vckx,Vcky,Vlen)
    VALUE self,Vifont,Viposx,Vnchar,Vckx,Vcky,Vlen;
{
  MC_SetInt(Cifont,Vifont);
  MC_SetIntArray(Ciposx,Viposx);
  MC_SetInt(Cnchar,Vnchar);
  MC_SetString(Cckx,Vckx);
  MC_SetString(Ccky,Vcky);
  MC_SetInt(Clen,Vlen);
  szfont_(&Cifont,Ciposx,&Cnchar,&Cckx,&Ccky,&Clen);
  return Qnil;
}

static VALUE
dcl_szl3op(self,Vindex)
    VALUE self,Vindex;
{
  MC_SetInt(Cindex,Vindex);
  szl3op_(&Cindex);
  return Qnil;
}

static VALUE
dcl_szl3cl(self)
    VALUE self;
{
  szl3cl_();
  return Qnil;
}

static VALUE
dcl_szl3zu(self,Vn,Vu3x,Vu3y,Vu3z)
    VALUE self,Vn,Vu3x,Vu3y,Vu3z;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cu3x,Vu3x);
  MC_SetFloatArray(Cu3y,Vu3y);
  MC_SetFloatArray(Cu3z,Vu3z);
  szl3zu_(&Cn,Cu3x,Cu3y,Cu3z);
  return Qnil;
}

static VALUE
dcl_szl3zv(self,Vn,Vv3x,Vv3y,Vv3z)
    VALUE self,Vn,Vv3x,Vv3y,Vv3z;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cv3x,Vv3x);
  MC_SetFloatArray(Cv3y,Vv3y);
  MC_SetFloatArray(Cv3z,Vv3z);
  szl3zv_(&Cn,Cv3x,Cv3y,Cv3z);
  return Qnil;
}

static VALUE
dcl_szlaop(self,Vitype,Vindex)
    VALUE self,Vitype,Vindex;
{
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  szlaop_(&Citype,&Cindex);
  return Qnil;
}

static VALUE
dcl_szlacl(self)
    VALUE self;
{
  szlacl_();
  return Qnil;
}

static VALUE
dcl_szlazr(self,Vrx1,Vry1,Vrx2,Vry2)
    VALUE self,Vrx1,Vry1,Vrx2,Vry2;
{
  MC_SetFloat(Crx1,Vrx1);
  MC_SetFloat(Cry1,Vry1);
  MC_SetFloat(Crx2,Vrx2);
  MC_SetFloat(Cry2,Vry2);
  szlazr_(&Crx1,&Cry1,&Crx2,&Cry2);
  return Qnil;
}

static VALUE
dcl_szlazu(self,Vux1,Vuy1,Vux2,Vuy2)
    VALUE self,Vux1,Vuy1,Vux2,Vuy2;
{
  MC_SetFloat(Cux1,Vux1);
  MC_SetFloat(Cuy1,Vuy1);
  MC_SetFloat(Cux2,Vux2);
  MC_SetFloat(Cuy2,Vuy2);
  szlazu_(&Cux1,&Cuy1,&Cux2,&Cuy2);
  return Qnil;
}

static VALUE
dcl_szlazv(self,Vvx1,Vvy1,Vvx2,Vvy2)
    VALUE self,Vvx1,Vvy1,Vvx2,Vvy2;
{
  MC_SetFloat(Cvx1,Vvx1);
  MC_SetFloat(Cvy1,Vvy1);
  MC_SetFloat(Cvx2,Vvx2);
  MC_SetFloat(Cvy2,Vvy2);
  szlazv_(&Cvx1,&Cvy1,&Cvx2,&Cvy2);
  return Qnil;
}

static VALUE
dcl_szlnop(self,Vindex)
    VALUE self,Vindex;
{
  MC_SetInt(Cindex,Vindex);
  szlnop_(&Cindex);
  return Qnil;
}

static VALUE
dcl_szlncl(self)
    VALUE self;
{
  szlncl_();
  return Qnil;
}

static VALUE
dcl_szlnzr(self,Vrx1,Vry1,Vrx2,Vry2)
    VALUE self,Vrx1,Vry1,Vrx2,Vry2;
{
  MC_SetFloat(Crx1,Vrx1);
  MC_SetFloat(Cry1,Vry1);
  MC_SetFloat(Crx2,Vrx2);
  MC_SetFloat(Cry2,Vry2);
  szlnzr_(&Crx1,&Cry1,&Crx2,&Cry2);
  return Qnil;
}

static VALUE
dcl_szlnzu(self,Vux1,Vuy1,Vux2,Vuy2)
    VALUE self,Vux1,Vuy1,Vux2,Vuy2;
{
  MC_SetFloat(Cux1,Vux1);
  MC_SetFloat(Cuy1,Vuy1);
  MC_SetFloat(Cux2,Vux2);
  MC_SetFloat(Cuy2,Vuy2);
  szlnzu_(&Cux1,&Cuy1,&Cux2,&Cuy2);
  return Qnil;
}

static VALUE
dcl_szlnzv(self,Vvx1,Vvy1,Vvx2,Vvy2)
    VALUE self,Vvx1,Vvy1,Vvx2,Vvy2;
{
  MC_SetFloat(Cvx1,Vvx1);
  MC_SetFloat(Cvy1,Vvy1);
  MC_SetFloat(Cvx2,Vvx2);
  MC_SetFloat(Cvy2,Vvy2);
  szlnzv_(&Cvx1,&Cvy1,&Cvx2,&Cvy2);
  return Qnil;
}

static VALUE
dcl_szm3op(self,Vitype,Vindex,Vrsize)
    VALUE self,Vitype,Vindex,Vrsize;
{
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  MC_SetFloat(Crsize,Vrsize);
  szm3op_(&Citype,&Cindex,&Crsize);
  return Qnil;
}

static VALUE
dcl_szm3cl(self)
    VALUE self;
{
  szm3cl_();
  return Qnil;
}

static VALUE
dcl_szm3zu(self,Vn,Vupx,Vupy,Vupz)
    VALUE self,Vn,Vupx,Vupy,Vupz;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetFloatArray(Cupz,Vupz);
  szm3zu_(&Cn,Cupx,Cupy,Cupz);
  return Qnil;
}

static VALUE
dcl_szm3zv(self,Vn,Vvpx,Vvpy,Vvpz)
    VALUE self,Vn,Vvpx,Vvpy,Vvpz;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cvpx,Vvpx);
  MC_SetFloatArray(Cvpy,Vvpy);
  MC_SetFloatArray(Cvpz,Vvpz);
  szm3zv_(&Cn,Cvpx,Cvpy,Cvpz);
  return Qnil;
}

static VALUE
dcl_szopl3(self)
    VALUE self;
{
  szopl3_();
  return Qnil;
}

static VALUE
dcl_szmvl3(self,Vsx,Vsy,Vsz)
    VALUE self,Vsx,Vsy,Vsz;
{
  MC_SetFloat(Csx,Vsx);
  MC_SetFloat(Csy,Vsy);
  MC_SetFloat(Csz,Vsz);
  szmvl3_(&Csx,&Csy,&Csz);
  return Qnil;
}

static VALUE
dcl_szpll3(self,Vsx,Vsy,Vsz)
    VALUE self,Vsx,Vsy,Vsz;
{
  MC_SetFloat(Csx,Vsx);
  MC_SetFloat(Csy,Vsy);
  MC_SetFloat(Csz,Vsz);
  szpll3_(&Csx,&Csy,&Csz);
  return Qnil;
}

static VALUE
dcl_szcll3(self)
    VALUE self;
{
  szcll3_();
  return Qnil;
}

static VALUE
dcl_szoplc(self)
    VALUE self;
{
  szoplc_();
  return Qnil;
}

static VALUE
dcl_szmvlc(self,Vvx,Vvy)
    VALUE self,Vvx,Vvy;
{
  MC_SetFloat(Cvx,Vvx);
  MC_SetFloat(Cvy,Vvy);
  szmvlc_(&Cvx,&Cvy);
  return Qnil;
}

static VALUE
dcl_szpllc(self,Vvx,Vvy)
    VALUE self,Vvx,Vvy;
{
  MC_SetFloat(Cvx,Vvx);
  MC_SetFloat(Cvy,Vvy);
  szpllc_(&Cvx,&Cvy);
  return Qnil;
}

static VALUE
dcl_szcllc(self)
    VALUE self;
{
  szcllc_();
  return Qnil;
}

static VALUE
dcl_szschz(self,Vch,Vh)
    VALUE self,Vch,Vh;
{
  MC_SetString(Cch,Vch);
  MC_SetFloat(Ch,Vh);
  szschz_(Cch,&Ch,strlen(Cch));
  return Qnil;
}

static VALUE
dcl_szqchz(self,Vch,Vh)
    VALUE self,Vch,Vh;
{
  char * Cch="                ";
  float Ch;
  szqchz_(Cch,&Ch,strlen(Cch));
  MC_GetString(Cch,Vch);
  MC_GetFloat(Ch,Vh);
  return Qnil;
}

static VALUE
dcl_szcrst(self)
    VALUE self;
{
  szcrst_();
  return Qnil;
}

static VALUE
dcl_szopld(self)
    VALUE self;
{
  szopld_();
  return Qnil;
}

static VALUE
dcl_szmvld(self,Vvx,Vvy)
    VALUE self,Vvx,Vvy;
{
  MC_SetFloat(Cvx,Vvx);
  MC_SetFloat(Cvy,Vvy);
  szmvld_(&Cvx,&Cvy);
  return Qnil;
}

static VALUE
dcl_szplld(self,Vvx,Vvy)
    VALUE self,Vvx,Vvy;
{
  MC_SetFloat(Cvx,Vvx);
  MC_SetFloat(Cvy,Vvy);
  szplld_(&Cvx,&Cvy);
  return Qnil;
}

static VALUE
dcl_szclld(self)
    VALUE self;
{
  szclld_();
  return Qnil;
}

static VALUE
dcl_szstyz(self,Vipat)
    VALUE self,Vipat;
{
  MC_SetInt(Cipat,Vipat);
  szstyz_(&Cipat);
  return Qnil;
}

static VALUE
dcl_szqtyz(self,Vipat)
    VALUE self,Vipat;
{
  int   Cipat;
  szqtyz_(&Cipat);
  MC_GetInt(Cipat,Vipat);
  return Qnil;
}

static VALUE
dcl_szoplp(self)
    VALUE self;
{
  szoplp_();
  return Qnil;
}

static VALUE
dcl_szmvlp(self,Vvx,Vvy)
    VALUE self,Vvx,Vvy;
{
  MC_SetFloat(Cvx,Vvx);
  MC_SetFloat(Cvy,Vvy);
  szmvlp_(&Cvx,&Cvy);
  return Qnil;
}

static VALUE
dcl_szpllp(self,Vvx,Vvy)
    VALUE self,Vvx,Vvy;
{
  MC_SetFloat(Cvx,Vvx);
  MC_SetFloat(Cvy,Vvy);
  szpllp_(&Cvx,&Cvy);
  return Qnil;
}

static VALUE
dcl_szcllp(self)
    VALUE self;
{
  szcllp_();
  return Qnil;
}

static VALUE
dcl_szoplr(self)
    VALUE self;
{
  szoplr_();
  return Qnil;
}

static VALUE
dcl_szmvlr(self,Vrx,Vry)
    VALUE self,Vrx,Vry;
{
  MC_SetFloat(Crx,Vrx);
  MC_SetFloat(Cry,Vry);
  szmvlr_(&Crx,&Cry);
  return Qnil;
}

static VALUE
dcl_szpllr(self,Vrx,Vry)
    VALUE self,Vrx,Vry;
{
  MC_SetFloat(Crx,Vrx);
  MC_SetFloat(Cry,Vry);
  szpllr_(&Crx,&Cry);
  return Qnil;
}

static VALUE
dcl_szcllr(self)
    VALUE self;
{
  szcllr_();
  return Qnil;
}

static VALUE
dcl_szoplt(self)
    VALUE self;
{
  szoplt_();
  return Qnil;
}

static VALUE
dcl_szmvlt(self,Vtx,Vty)
    VALUE self,Vtx,Vty;
{
  MC_SetFloat(Ctx,Vtx);
  MC_SetFloat(Cty,Vty);
  szmvlt_(&Ctx,&Cty);
  return Qnil;
}

static VALUE
dcl_szpllt(self,Vtx,Vty)
    VALUE self,Vtx,Vty;
{
  MC_SetFloat(Ctx,Vtx);
  MC_SetFloat(Cty,Vty);
  szpllt_(&Ctx,&Cty);
  return Qnil;
}

static VALUE
dcl_szcllt(self)
    VALUE self;
{
  szcllt_();
  return Qnil;
}

static VALUE
dcl_szoplu(self)
    VALUE self;
{
  szoplu_();
  return Qnil;
}

static VALUE
dcl_szmvlu(self,Vux,Vuy)
    VALUE self,Vux,Vuy;
{
  MC_SetFloat(Cux,Vux);
  MC_SetFloat(Cuy,Vuy);
  szmvlu_(&Cux,&Cuy);
  return Qnil;
}

static VALUE
dcl_szpllu(self,Vux,Vuy)
    VALUE self,Vux,Vuy;
{
  MC_SetFloat(Cux,Vux);
  MC_SetFloat(Cuy,Vuy);
  szpllu_(&Cux,&Cuy);
  return Qnil;
}

static VALUE
dcl_szcllu(self)
    VALUE self;
{
  szcllu_();
  return Qnil;
}

static VALUE
dcl_szoplv(self)
    VALUE self;
{
  szoplv_();
  return Qnil;
}

static VALUE
dcl_szmvlv(self,Vvx,Vvy)
    VALUE self,Vvx,Vvy;
{
  MC_SetFloat(Cvx,Vvx);
  MC_SetFloat(Cvy,Vvy);
  szmvlv_(&Cvx,&Cvy);
  return Qnil;
}

static VALUE
dcl_szpllv(self,Vvx,Vvy)
    VALUE self,Vvx,Vvy;
{
  MC_SetFloat(Cvx,Vvx);
  MC_SetFloat(Cvy,Vvy);
  szpllv_(&Cvx,&Cvy);
  return Qnil;
}

static VALUE
dcl_szcllv(self)
    VALUE self;
{
  szcllv_();
  return Qnil;
}

static VALUE
dcl_szoplz(self)
    VALUE self;
{
  szoplz_();
  return Qnil;
}

static VALUE
dcl_szmvlz(self,Vrx,Vry)
    VALUE self,Vrx,Vry;
{
  MC_SetFloat(Crx,Vrx);
  MC_SetFloat(Cry,Vry);
  szmvlz_(&Crx,&Cry);
  return Qnil;
}

static VALUE
dcl_szpllz(self,Vrx,Vry)
    VALUE self,Vrx,Vry;
{
  MC_SetFloat(Crx,Vrx);
  MC_SetFloat(Cry,Vry);
  szpllz_(&Crx,&Cry);
  return Qnil;
}

static VALUE
dcl_szcllz(self)
    VALUE self;
{
  szcllz_();
  return Qnil;
}

static VALUE
dcl_szopsv(self)
    VALUE self;
{
  szopsv_();
  return Qnil;
}

static VALUE
dcl_szmvsv(self,Vvx,Vvy)
    VALUE self,Vvx,Vvy;
{
  MC_SetFloat(Cvx,Vvx);
  MC_SetFloat(Cvy,Vvy);
  szmvsv_(&Cvx,&Cvy);
  return Qnil;
}

static VALUE
dcl_szplsv(self,Vvx,Vvy)
    VALUE self,Vvx,Vvy;
{
  MC_SetFloat(Cvx,Vvx);
  MC_SetFloat(Cvy,Vvy);
  szplsv_(&Cvx,&Cvy);
  return Qnil;
}

static VALUE
dcl_szclsv(self)
    VALUE self;
{
  szclsv_();
  return Qnil;
}

static VALUE
dcl_szoptp(self)
    VALUE self;
{
  szoptp_();
  return Qnil;
}

static VALUE
dcl_szsttp(self,Vvx,Vvy)
    VALUE self,Vvx,Vvy;
{
  MC_SetFloat(Cvx,Vvx);
  MC_SetFloat(Cvy,Vvy);
  szsttp_(&Cvx,&Cvy);
  return Qnil;
}

static VALUE
dcl_szcltp(self)
    VALUE self;
{
  szcltp_();
  return Qnil;
}

static VALUE
dcl_szstmd(self,Vlhard)
    VALUE self,Vlhard;
{
  MC_SetLogic(Clhard,Vlhard);
  szstmd_(&Clhard);
  return Qnil;
}

static VALUE
dcl_szqtmd(self,Vlhard)
    VALUE self,Vlhard;
{
  int    Clhard;
  szqtmd_(&Clhard);
  MC_GetLogic(Clhard,Vlhard);
  return Qnil;
}

static VALUE
dcl_szoptr(self)
    VALUE self;
{
  szoptr_();
  return Qnil;
}

static VALUE
dcl_szsttr(self,Vrx,Vry)
    VALUE self,Vrx,Vry;
{
  MC_SetFloat(Crx,Vrx);
  MC_SetFloat(Cry,Vry);
  szsttr_(&Crx,&Cry);
  return Qnil;
}

static VALUE
dcl_szcltr(self)
    VALUE self;
{
  szcltr_();
  return Qnil;
}

static VALUE
dcl_szopts(self)
    VALUE self;
{
  szopts_();
  return Qnil;
}

static VALUE
dcl_szstts(self,Vvx,Vvy)
    VALUE self,Vvx,Vvy;
{
  MC_SetFloat(Cvx,Vvx);
  MC_SetFloat(Cvy,Vvy);
  szstts_(&Cvx,&Cvy);
  return Qnil;
}

static VALUE
dcl_szclts(self)
    VALUE self;
{
  szclts_();
  return Qnil;
}

static VALUE
dcl_sztits(self,Vitpat)
    VALUE self,Vitpat;
{
  MC_SetInt(Citpat,Vitpat);
  sztits_(&Citpat);
  return Qnil;
}

static VALUE
dcl_szoptt(self)
    VALUE self;
{
  szoptt_();
  return Qnil;
}

static VALUE
dcl_szsttt(self,Vtx,Vty)
    VALUE self,Vtx,Vty;
{
  MC_SetFloat(Ctx,Vtx);
  MC_SetFloat(Cty,Vty);
  szsttt_(&Ctx,&Cty);
  return Qnil;
}

static VALUE
dcl_szcltt(self)
    VALUE self;
{
  szcltt_();
  return Qnil;
}

static VALUE
dcl_szoptu(self)
    VALUE self;
{
  szoptu_();
  return Qnil;
}

static VALUE
dcl_szsttu(self,Vux,Vuy)
    VALUE self,Vux,Vuy;
{
  MC_SetFloat(Cux,Vux);
  MC_SetFloat(Cuy,Vuy);
  szsttu_(&Cux,&Cuy);
  return Qnil;
}

static VALUE
dcl_szcltu(self)
    VALUE self;
{
  szcltu_();
  return Qnil;
}

static VALUE
dcl_szoptv(self)
    VALUE self;
{
  szoptv_();
  return Qnil;
}

static VALUE
dcl_szsttv(self,Vvx,Vvy)
    VALUE self,Vvx,Vvy;
{
  MC_SetFloat(Cvx,Vvx);
  MC_SetFloat(Cvy,Vvy);
  szsttv_(&Cvx,&Cvy);
  return Qnil;
}

static VALUE
dcl_szcltv(self)
    VALUE self;
{
  szcltv_();
  return Qnil;
}

static VALUE
dcl_szoptz(self)
    VALUE self;
{
  szoptz_();
  return Qnil;
}

static VALUE
dcl_szsttz(self,Vrx,Vry)
    VALUE self,Vrx,Vry;
{
  MC_SetFloat(Crx,Vrx);
  MC_SetFloat(Cry,Vry);
  szsttz_(&Crx,&Cry);
  return Qnil;
}

static VALUE
dcl_szcltz(self)
    VALUE self;
{
  szcltz_();
  return Qnil;
}

static VALUE
dcl_sztitz(self,Vitpat)
    VALUE self,Vitpat;
{
  MC_SetInt(Citpat,Vitpat);
  sztitz_(&Citpat);
  return Qnil;
}

static VALUE
dcl_szpcll(self,Vvx0,Vvy0,Vvx1,Vvy1,Vlvalid,Vii)
    VALUE self,Vvx0,Vvy0,Vvx1,Vvy1,Vlvalid,Vii;
{
  MC_SetFloat(Cvx0,Vvx0);
  MC_SetFloat(Cvy0,Vvy0);
  MC_SetFloat(Cvx1,Vvx1);
  MC_SetFloat(Cvy1,Vvy1);
  int    Clvalid;
  MC_SetInt(Cii,Vii);
  szpcll_(&Cvx0,&Cvy0,&Cvx1,&Cvy1,&Clvalid,&Cii);
  MC_GetLogic(Clvalid,Vlvalid);
  return Qnil;
}

static VALUE
dcl_szgcll(self,Vxx,Vyy,Vlcont,Vlmove,Vii)
    VALUE self,Vxx,Vyy,Vlcont,Vlmove,Vii;
{
  float Cxx;
  float Cyy;
  int    Clcont;
  int    Clmove;
  MC_SetInt(Cii,Vii);
  szgcll_(&Cxx,&Cyy,&Clcont,&Clmove,&Cii);
  MC_GetFloat(Cxx,Vxx);
  MC_GetFloat(Cyy,Vyy);
  MC_GetLogic(Clcont,Vlcont);
  MC_GetLogic(Clmove,Vlmove);
  return Qnil;
}

static VALUE
dcl_szscll(self,Vvxmin,Vvxmax,Vvymin,Vvymax,Vii)
    VALUE self,Vvxmin,Vvxmax,Vvymin,Vvymax,Vii;
{
  MC_SetFloat(Cvxmin,Vvxmin);
  MC_SetFloat(Cvxmax,Vvxmax);
  MC_SetFloat(Cvymin,Vvymin);
  MC_SetFloat(Cvymax,Vvymax);
  MC_SetInt(Cii,Vii);
  szscll_(&Cvxmin,&Cvxmax,&Cvymin,&Cvymax,&Cii);
  return Qnil;
}

static VALUE
dcl_szqcll(self,Vvxmin,Vvxmax,Vvymin,Vvymax,Vii)
    VALUE self,Vvxmin,Vvxmax,Vvymin,Vvymax,Vii;
{
  float Cvxmin;
  float Cvxmax;
  float Cvymin;
  float Cvymax;
  MC_SetInt(Cii,Vii);
  szqcll_(&Cvxmin,&Cvxmax,&Cvymin,&Cvymax,&Cii);
  MC_GetFloat(Cvxmin,Vvxmin);
  MC_GetFloat(Cvxmax,Vvxmax);
  MC_GetFloat(Cvymin,Vvymin);
  MC_GetFloat(Cvymax,Vvymax);
  return Qnil;
}

static VALUE
dcl_szpclx(self,Vtx0,Vty0,Vtx1,Vty1,Vlvalid,Vlbound)
    VALUE self,Vtx0,Vty0,Vtx1,Vty1,Vlvalid,Vlbound;
{
  MC_SetFloat(Ctx0,Vtx0);
  MC_SetFloat(Cty0,Vty0);
  MC_SetFloat(Ctx1,Vtx1);
  MC_SetFloat(Cty1,Vty1);
  int    Clvalid;
  MC_SetInt(Clbound,Vlbound);
  szpclx_(&Ctx0,&Cty0,&Ctx1,&Cty1,&Clvalid,&Clbound);
  MC_GetLogic(Clvalid,Vlvalid);
  return Qnil;
}

static VALUE
dcl_szgclx(self,Vtx,Vty,Vlcont,Vlmove)
    VALUE self,Vtx,Vty,Vlcont,Vlmove;
{
  float Ctx;
  float Cty;
  int    Clcont;
  int    Clmove;
  szgclx_(&Ctx,&Cty,&Clcont,&Clmove);
  MC_GetFloat(Ctx,Vtx);
  MC_GetFloat(Cty,Vty);
  MC_GetLogic(Clcont,Vlcont);
  MC_GetLogic(Clmove,Vlmove);
  return Qnil;
}

static VALUE
dcl_szsclx(self,Vxbnd1,Vxbnd2)
    VALUE self,Vxbnd1,Vxbnd2;
{
  MC_SetFloat(Cxbnd1,Vxbnd1);
  MC_SetFloat(Cxbnd2,Vxbnd2);
  szsclx_(&Cxbnd1,&Cxbnd2);
  return Qnil;
}

static VALUE
dcl_szqclx(self,Vxbnd1,Vxbnd2)
    VALUE self,Vxbnd1,Vxbnd2;
{
  float Cxbnd1;
  float Cxbnd2;
  szqclx_(&Cxbnd1,&Cxbnd2);
  MC_GetFloat(Cxbnd1,Vxbnd1);
  MC_GetFloat(Cxbnd2,Vxbnd2);
  return Qnil;
}

static VALUE
dcl_szpcly(self,Vtx0,Vty0,Vtx1,Vty1,Vlvalid,Vlbound)
    VALUE self,Vtx0,Vty0,Vtx1,Vty1,Vlvalid,Vlbound;
{
  MC_SetFloat(Ctx0,Vtx0);
  MC_SetFloat(Cty0,Vty0);
  MC_SetFloat(Ctx1,Vtx1);
  MC_SetFloat(Cty1,Vty1);
  int    Clvalid;
  MC_SetLogic(Clbound,Vlbound);
  szpcly_(&Ctx0,&Cty0,&Ctx1,&Cty1,&Clvalid,&Clbound);
  MC_GetLogic(Clvalid,Vlvalid);
  return Qnil;
}

static VALUE
dcl_szgcly(self,Vtx,Vty,Vlcont)
    VALUE self,Vtx,Vty,Vlcont;
{
  float Ctx;
  float Cty;
  int    Clcont;
  szgcly_(&Ctx,&Cty,&Clcont);
  MC_GetFloat(Ctx,Vtx);
  MC_GetFloat(Cty,Vty);
  MC_GetLogic(Clcont,Vlcont);
  return Qnil;
}

static VALUE
dcl_szscly(self,Vybnd1,Vybnd2)
    VALUE self,Vybnd1,Vybnd2;
{
  MC_SetFloat(Cybnd1,Vybnd1);
  MC_SetFloat(Cybnd2,Vybnd2);
  szscly_(&Cybnd1,&Cybnd2);
  return Qnil;
}

static VALUE
dcl_szqcly(self,Vybnd1,Vybnd2)
    VALUE self,Vybnd1,Vybnd2;
{
  float Cybnd1;
  float Cybnd2;
  szqcly_(&Cybnd1,&Cybnd2);
  MC_GetFloat(Cybnd1,Vybnd1);
  MC_GetFloat(Cybnd2,Vybnd2);
  return Qnil;
}

static VALUE
dcl_szpipl(self,Vx0,Vy0,Vx1,Vy1,Vmode)
    VALUE self,Vx0,Vy0,Vx1,Vy1,Vmode;
{
  MC_SetFloat(Cx0,Vx0);
  MC_SetFloat(Cy0,Vy0);
  MC_SetFloat(Cx1,Vx1);
  MC_SetFloat(Cy1,Vy1);
  MC_SetInt(Cmode,Vmode);
  szpipl_(&Cx0,&Cy0,&Cx1,&Cy1,&Cmode);
  return Qnil;
}

static VALUE
dcl_szgipl(self,Vx,Vy,Vlcont)
    VALUE self,Vx,Vy,Vlcont;
{
  float Cx;
  float Cy;
  int    Clcont;
  szgipl_(&Cx,&Cy,&Clcont);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  MC_GetLogic(Clcont,Vlcont);
  return Qnil;
}

static VALUE
dcl_szpipt(self,Vtx0,Vty0,Vtx1,Vty1,Vmode)
    VALUE self,Vtx0,Vty0,Vtx1,Vty1,Vmode;
{
  MC_SetFloat(Ctx0,Vtx0);
  MC_SetFloat(Cty0,Vty0);
  MC_SetFloat(Ctx1,Vtx1);
  MC_SetFloat(Cty1,Vty1);
  MC_SetInt(Cmode,Vmode);
  szpipt_(&Ctx0,&Cty0,&Ctx1,&Cty1,&Cmode);
  return Qnil;
}

static VALUE
dcl_szgipt(self,Vtx,Vty,Vlcont)
    VALUE self,Vtx,Vty,Vlcont;
{
  float Ctx;
  float Cty;
  int    Clcont;
  szgipt_(&Ctx,&Cty,&Clcont);
  MC_GetFloat(Ctx,Vtx);
  MC_GetFloat(Cty,Vty);
  MC_GetLogic(Clcont,Vlcont);
  return Qnil;
}

static VALUE
dcl_szpipz(self,Vuxp0,Vuyp0,Vuxp1,Vuyp1,Vnn)
    VALUE self,Vuxp0,Vuyp0,Vuxp1,Vuyp1,Vnn;
{
  MC_SetFloat(Cuxp0,Vuxp0);
  MC_SetFloat(Cuyp0,Vuyp0);
  MC_SetFloat(Cuxp1,Vuxp1);
  MC_SetFloat(Cuyp1,Vuyp1);
  int   Cnn;
  szpipz_(&Cuxp0,&Cuyp0,&Cuxp1,&Cuyp1,&Cnn);
  MC_GetInt(Cnn,Vnn);
  return Qnil;
}

static VALUE
dcl_szgipz(self,Vuxg0,Vuyg0,Vuxg1,Vuyg1,Vn0)
    VALUE self,Vuxg0,Vuyg0,Vuxg1,Vuyg1,Vn0;
{
  MC_SetFloat(Cuxg0,Vuxg0);
  MC_SetFloat(Cuyg0,Vuyg0);
  MC_SetFloat(Cuxg1,Vuxg1);
  MC_SetFloat(Cuyg1,Vuyg1);
  MC_SetInt(Cn0,Vn0);
  szgipz_(&Cuxg0,&Cuyg0,&Cuxg1,&Cuyg1,&Cn0);
  return Qnil;
}

static VALUE
dcl_szplop(self,Vitype,Vindex)
    VALUE self,Vitype,Vindex;
{
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  szplop_(&Citype,&Cindex);
  return Qnil;
}

static VALUE
dcl_szplcl(self)
    VALUE self;
{
  szplcl_();
  return Qnil;
}

static VALUE
dcl_szplzr(self,Vn,Vrpx,Vrpy)
    VALUE self,Vn,Vrpx,Vrpy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Crpx,Vrpx);
  MC_SetFloatArray(Crpy,Vrpy);
  szplzr_(&Cn,Crpx,Crpy);
  return Qnil;
}

static VALUE
dcl_szplzu(self,Vn,Vupx,Vupy)
    VALUE self,Vn,Vupx,Vupy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  szplzu_(&Cn,Cupx,Cupy);
  return Qnil;
}

static VALUE
dcl_szplzv(self,Vn,Vvpx,Vvpy)
    VALUE self,Vn,Vvpx,Vvpy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cvpx,Vvpx);
  MC_SetFloatArray(Cvpy,Vvpy);
  szplzv_(&Cn,Cvpx,Cvpy);
  return Qnil;
}

static VALUE
dcl_szpmop(self,Vitype,Vindex,Vrsize)
    VALUE self,Vitype,Vindex,Vrsize;
{
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  MC_SetFloat(Crsize,Vrsize);
  szpmop_(&Citype,&Cindex,&Crsize);
  return Qnil;
}

static VALUE
dcl_szpmcl(self)
    VALUE self;
{
  szpmcl_();
  return Qnil;
}

static VALUE
dcl_szpmzr(self,Vn,Vrpx,Vrpy)
    VALUE self,Vn,Vrpx,Vrpy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Crpx,Vrpx);
  MC_SetFloatArray(Crpy,Vrpy);
  szpmzr_(&Cn,Crpx,Crpy);
  return Qnil;
}

static VALUE
dcl_szpmzu(self,Vn,Vupx,Vupy)
    VALUE self,Vn,Vupx,Vupy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  szpmzu_(&Cn,Cupx,Cupy);
  return Qnil;
}

static VALUE
dcl_szpmzv(self,Vn,Vvpx,Vvpy)
    VALUE self,Vn,Vvpx,Vvpy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cvpx,Vvpx);
  MC_SetFloatArray(Cvpy,Vvpy);
  szpmzv_(&Cn,Cvpx,Cvpy);
  return Qnil;
}

static VALUE
dcl_szqtxw(self,Vchars,Vnc,Vwxch,Vwych)
    VALUE self,Vchars,Vnc,Vwxch,Vwych;
{
  MC_SetString(Cchars,Vchars);
  int   Cnc;
  float Cwxch;
  float Cwych;
  szqtxw_(Cchars,&Cnc,&Cwxch,&Cwych,strlen(Cchars));
  MC_GetInt(Cnc,Vnc);
  MC_GetFloat(Cwxch,Vwxch);
  MC_GetFloat(Cwych,Vwych);
  return Qnil;
}

static VALUE
dcl_szsgcl(self,Vtx0,Vty0,Vtx1,Vty1)
    VALUE self,Vtx0,Vty0,Vtx1,Vty1;
{
  MC_SetFloat(Ctx0,Vtx0);
  MC_SetFloat(Cty0,Vty0);
  MC_SetFloat(Ctx1,Vtx1);
  MC_SetFloat(Cty1,Vty1);
  szsgcl_(&Ctx0,&Cty0,&Ctx1,&Cty1);
  return Qnil;
}

static VALUE
dcl_szqgcy(self,Vtx,Vty)
    VALUE self,Vtx,Vty;
{
  MC_SetFloat(Ctx,Vtx);
  float Cty;
  szqgcy_(&Ctx,&Cty);
  MC_GetFloat(Cty,Vty);
  return Qnil;
}

static VALUE
dcl_szqgcx(self,Vty,Vtx)
    VALUE self,Vty,Vtx;
{
  MC_SetFloat(Cty,Vty);
  float Ctx;
  szqgcx_(&Cty,&Ctx);
  MC_GetFloat(Ctx,Vtx);
  return Qnil;
}

static VALUE
dcl_szsidx(self,Vindex)
    VALUE self,Vindex;
{
  MC_SetInt(Cindex,Vindex);
  szsidx_(&Cindex);
  return Qnil;
}

static VALUE
dcl_szqidx(self,Vindex)
    VALUE self,Vindex;
{
  int   Cindex;
  szqidx_(&Cindex);
  MC_GetInt(Cindex,Vindex);
  return Qnil;
}

static VALUE
dcl_szslti(self,Vitype,Vindex)
    VALUE self,Vitype,Vindex;
{
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  szslti_(&Citype,&Cindex);
  return Qnil;
}

static VALUE
dcl_szstni(self,Vitpat)
    VALUE self,Vitpat;
{
  MC_SetInt(Citpat,Vitpat);
  szstni_(&Citpat);
  return Qnil;
}

static VALUE
dcl_szqtni(self,Vitpat)
    VALUE self,Vitpat;
{
  int   Citpat;
  szqtni_(&Citpat);
  MC_GetInt(Citpat,Vitpat);
  return Qnil;
}

static VALUE
dcl_szstyp(self,Vitype)
    VALUE self,Vitype;
{
  MC_SetInt(Citype,Vitype);
  szstyp_(&Citype);
  return Qnil;
}

static VALUE
dcl_szqtyp(self,Vitype)
    VALUE self,Vitype;
{
  int   Citype;
  szqtyp_(&Citype);
  MC_GetInt(Citype,Vitype);
  return Qnil;
}

static VALUE
dcl_szt3op(self,Vitpat1,Vitpat2)
    VALUE self,Vitpat1,Vitpat2;
{
  MC_SetInt(Citpat1,Vitpat1);
  MC_SetInt(Citpat2,Vitpat2);
  szt3op_(&Citpat1,&Citpat2);
  return Qnil;
}

static VALUE
dcl_szt3cl(self)
    VALUE self;
{
  szt3cl_();
  return Qnil;
}

static VALUE
dcl_szt3zu(self,Vupx,Vupy,Vupz)
    VALUE self,Vupx,Vupy,Vupz;
{
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetFloatArray(Cupz,Vupz);
  szt3zu_(Cupx,Cupy,Cupz);
  return Qnil;
}

static VALUE
dcl_szt3zv(self,Vvpx,Vvpy,Vvpz)
    VALUE self,Vvpx,Vvpy,Vvpz;
{
  MC_SetFloatArray(Cvpx,Vvpx);
  MC_SetFloatArray(Cvpy,Vvpy);
  MC_SetFloatArray(Cvpz,Vvpz);
  szt3zv_(Cvpx,Cvpy,Cvpz);
  return Qnil;
}

static VALUE
dcl_sztnop(self,Vitpat)
    VALUE self,Vitpat;
{
  MC_SetInt(Citpat,Vitpat);
  sztnop_(&Citpat);
  return Qnil;
}

static VALUE
dcl_sztncl(self)
    VALUE self;
{
  sztncl_();
  return Qnil;
}

static VALUE
dcl_sztnsv(self,Vn,Vvpx,Vvpy,Virota,Vrspce,Vitype,Vindex)
    VALUE self,Vn,Vvpx,Vvpy,Virota,Vrspce,Vitype,Vindex;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cvpx,Vvpx);
  MC_SetFloatArray(Cvpy,Vvpy);
  MC_SetInt(Cirota,Virota);
  MC_SetFloat(Crspce,Vrspce);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  sztnsv_(&Cn,Cvpx,Cvpy,&Cirota,&Crspce,&Citype,&Cindex);
  return Qnil;
}

static VALUE
dcl_sztnzr(self,Vn,Vrpx,Vrpy)
    VALUE self,Vn,Vrpx,Vrpy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Crpx,Vrpx);
  MC_SetFloatArray(Crpy,Vrpy);
  sztnzr_(&Cn,Crpx,Crpy);
  return Qnil;
}

static VALUE
dcl_sztnzu(self,Vn,Vupx,Vupy)
    VALUE self,Vn,Vupx,Vupy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  sztnzu_(&Cn,Cupx,Cupy);
  return Qnil;
}

static VALUE
dcl_sztnzv(self,Vn,Vvpx,Vvpy)
    VALUE self,Vn,Vvpx,Vvpy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cvpx,Vvpx);
  MC_SetFloatArray(Cvpy,Vvpy);
  sztnzv_(&Cn,Cvpx,Cvpy);
  return Qnil;
}

static VALUE
dcl_sztxop(self,Vrsize,Virota,Vicent,Vindex)
    VALUE self,Vrsize,Virota,Vicent,Vindex;
{
  MC_SetFloat(Crsize,Vrsize);
  MC_SetInt(Cirota,Virota);
  MC_SetInt(Cicent,Vicent);
  MC_SetInt(Cindex,Vindex);
  sztxop_(&Crsize,&Cirota,&Cicent,&Cindex);
  return Qnil;
}

static VALUE
dcl_sztxcl(self)
    VALUE self;
{
  sztxcl_();
  return Qnil;
}

static VALUE
dcl_sztxwv(self,Vvx,Vvy,Vchars)
    VALUE self,Vvx,Vvy,Vchars;
{
  MC_SetFloat(Cvx,Vvx);
  MC_SetFloat(Cvy,Vvy);
  MC_SetString(Cchars,Vchars);
  sztxwv_(&Cvx,&Cvy,Cchars,strlen(Cchars));
  return Qnil;
}

static VALUE
dcl_sztxzr(self,Vrx,Vry,Vchars)
    VALUE self,Vrx,Vry,Vchars;
{
  MC_SetFloat(Crx,Vrx);
  MC_SetFloat(Cry,Vry);
  MC_SetString(Cchars,Vchars);
  sztxzr_(&Crx,&Cry,Cchars,strlen(Cchars));
  return Qnil;
}

static VALUE
dcl_sztxzu(self,Vux,Vuy,Vchars)
    VALUE self,Vux,Vuy,Vchars;
{
  MC_SetFloat(Cux,Vux);
  MC_SetFloat(Cuy,Vuy);
  MC_SetString(Cchars,Vchars);
  sztxzu_(&Cux,&Cuy,Cchars,strlen(Cchars));
  return Qnil;
}

static VALUE
dcl_sztxzv(self,Vvx,Vvy,Vchars)
    VALUE self,Vvx,Vvy,Vchars;
{
  MC_SetFloat(Cvx,Vvx);
  MC_SetFloat(Cvy,Vvy);
  MC_SetString(Cchars,Vchars);
  sztxzv_(&Cvx,&Cvy,Cchars,strlen(Cchars));
  return Qnil;
}

static VALUE
dcl_szxmod(self,Vx)
    VALUE self,Vx;
{
  MC_SetFloat(Cx,Vx);
  float ret;
  float szxmod_();
  ret = szxmod_(&Cx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_grinit(self)
    VALUE self;
{
  grinit_();
  return Qnil;
}

static VALUE
dcl_gropn(self,Viws)
    VALUE self,Viws;
{
  MC_SetInt(Ciws,Viws);
  gropn_(&Ciws);
  return Qnil;
}

static VALUE
dcl_grfrm(self)
    VALUE self;
{
  grfrm_();
  return Qnil;
}

static VALUE
dcl_grfig(self)
    VALUE self;
{
  grfig_();
  return Qnil;
}

static VALUE
dcl_grcls(self)
    VALUE self;
{
  grcls_();
  return Qnil;
}

static VALUE
dcl_grsmpl(self,Vplx,Vply,Vplrot)
    VALUE self,Vplx,Vply,Vplrot;
{
  MC_SetFloat(Cplx,Vplx);
  MC_SetFloat(Cply,Vply);
  MC_SetFloat(Cplrot,Vplrot);
  grsmpl_(&Cplx,&Cply,&Cplrot);
  return Qnil;
}

static VALUE
dcl_grssim(self,Vsimfac,Vvxoff,Vvyoff)
    VALUE self,Vsimfac,Vvxoff,Vvyoff;
{
  MC_SetFloat(Csimfac,Vsimfac);
  MC_SetFloat(Cvxoff,Vvxoff);
  MC_SetFloat(Cvyoff,Vvyoff);
  grssim_(&Csimfac,&Cvxoff,&Cvyoff);
  return Qnil;
}

static VALUE
dcl_grstrf(self)
    VALUE self;
{
  grstrf_();
  return Qnil;
}

static VALUE
dcl_grstrn(self,Vitr)
    VALUE self,Vitr;
{
  MC_SetInt(Citr,Vitr);
  grstrn_(&Citr);
  return Qnil;
}

static VALUE
dcl_grstxy(self,Vtxmin,Vtxmax,Vtymin,Vtymax)
    VALUE self,Vtxmin,Vtxmax,Vtymin,Vtymax;
{
  MC_SetFloat(Ctxmin,Vtxmin);
  MC_SetFloat(Ctxmax,Vtxmax);
  MC_SetFloat(Ctymin,Vtymin);
  MC_SetFloat(Ctymax,Vtymax);
  grstxy_(&Ctxmin,&Ctxmax,&Ctymin,&Ctymax);
  return Qnil;
}

static VALUE
dcl_grsvpt(self,Vvxmin,Vvxmax,Vvymin,Vvymax)
    VALUE self,Vvxmin,Vvxmax,Vvymin,Vvymax;
{
  MC_SetFloat(Cvxmin,Vvxmin);
  MC_SetFloat(Cvxmax,Vvxmax);
  MC_SetFloat(Cvymin,Vvymin);
  MC_SetFloat(Cvymax,Vvymax);
  grsvpt_(&Cvxmin,&Cvxmax,&Cvymin,&Cvymax);
  return Qnil;
}

static VALUE
dcl_grswnd(self,Vuxmin,Vuxmax,Vuymin,Vuymax)
    VALUE self,Vuxmin,Vuxmax,Vuymin,Vuymax;
{
  MC_SetFloat(Cuxmin,Vuxmin);
  MC_SetFloat(Cuxmax,Vuxmax);
  MC_SetFloat(Cuymin,Vuymin);
  MC_SetFloat(Cuymax,Vuymax);
  grswnd_(&Cuxmin,&Cuxmax,&Cuymin,&Cuymax);
  return Qnil;
}

static VALUE
dcl_nucchr(self,Vcs,Vnd)
    VALUE self,Vcs,Vnd;
{
  MC_SetString(Ccs,Vcs);
  MC_SetInt(Cnd,Vnd);
  int ret;
  int nucchr_();
  ret = nucchr_(Ccs,&Cnd,strlen(Ccs));
  return MC_NewInt(ret);;
}

static VALUE
dcl_nucday(self,Vcs,Vnd)
    VALUE self,Vcs,Vnd;
{
  MC_SetString(Ccs,Vcs);
  MC_SetInt(Cnd,Vnd);
  int ret;
  int nucday_();
  ret = nucday_(Ccs,&Cnd,strlen(Ccs));
  return MC_NewInt(ret);;
}

static VALUE
dcl_ucpget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  ucpget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uciget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  uciget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_ucrget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  float Cipara;
  ucrget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetFloat(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uclget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int    Cipara;
  uclget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetLogic(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_ucpset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  ucpset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uciset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  uciset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ucrset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  ucrset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uclset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  uclset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ucpstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  ucpstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ucistx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  ucistx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ucrstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  ucrstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uclstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  uclstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ucpqnp(self,Vncp)
    VALUE self,Vncp;
{
  int   Cncp;
  ucpqnp_(&Cncp);
  MC_GetInt(Cncp,Vncp);
  return Qnil;
}

static VALUE
dcl_ucpqid(self,Vcp,Vidx)
    VALUE self,Vcp,Vidx;
{
  MC_SetString(Ccp,Vcp);
  int   Cidx;
  ucpqid_(Ccp,&Cidx,strlen(Ccp));
  MC_GetInt(Cidx,Vidx);
  return Qnil;
}

static VALUE
dcl_ucpqcp(self,Vidx,Vcp)
    VALUE self,Vidx,Vcp;
{
  MC_SetInt(Cidx,Vidx);
  char * Ccp="                ";
  ucpqcp_(&Cidx,Ccp,strlen(Ccp));
  MC_GetString(Ccp,Vcp);
  return Qnil;
}

static VALUE
dcl_ucpqvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  int   Cipara;
  ucpqvl_(&Cidx,&Cipara);
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_ucpsvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetInt(Cipara,Vipara);
  ucpsvl_(&Cidx,&Cipara);
  return Qnil;
}

static VALUE
dcl_ucxacl(self,Vcside,Vjd0,Vnd)
    VALUE self,Vcside,Vjd0,Vnd;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cjd0,Vjd0);
  MC_SetInt(Cnd,Vnd);
  ucxacl_(Ccside,&Cjd0,&Cnd,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_ucxady(self,Vcside,Vjd0,Vnd)
    VALUE self,Vcside,Vjd0,Vnd;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cjd0,Vjd0);
  MC_SetInt(Cnd,Vnd);
  ucxady_(Ccside,&Cjd0,&Cnd,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_ucxamn(self,Vcside,Vjd0,Vnd)
    VALUE self,Vcside,Vjd0,Vnd;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cjd0,Vjd0);
  MC_SetInt(Cnd,Vnd);
  ucxamn_(Ccside,&Cjd0,&Cnd,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_ucxayr(self,Vcside,Vjd0,Vnd)
    VALUE self,Vcside,Vjd0,Vnd;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cjd0,Vjd0);
  MC_SetInt(Cnd,Vnd);
  ucxayr_(Ccside,&Cjd0,&Cnd,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_ucyacl(self,Vcside,Vjd0,Vnd)
    VALUE self,Vcside,Vjd0,Vnd;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cjd0,Vjd0);
  MC_SetInt(Cnd,Vnd);
  ucyacl_(Ccside,&Cjd0,&Cnd,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_ucyady(self,Vcside,Vjd0,Vnd)
    VALUE self,Vcside,Vjd0,Vnd;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cjd0,Vjd0);
  MC_SetInt(Cnd,Vnd);
  ucyady_(Ccside,&Cjd0,&Cnd,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_ucyamn(self,Vcside,Vjd0,Vnd)
    VALUE self,Vcside,Vjd0,Vnd;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cjd0,Vjd0);
  MC_SetInt(Cnd,Vnd);
  ucyamn_(Ccside,&Cjd0,&Cnd,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_ucyayr(self,Vcside,Vjd0,Vnd)
    VALUE self,Vcside,Vjd0,Vnd;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cjd0,Vjd0);
  MC_SetInt(Cnd,Vnd);
  ucyayr_(Ccside,&Cjd0,&Cnd,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_ludchk(self,Vi,Vj,Vk,Vl,Vibr)
    VALUE self,Vi,Vj,Vk,Vl,Vibr;
{
  MC_SetInt(Ci,Vi);
  MC_SetInt(Cj,Vj);
  MC_SetInt(Ck,Vk);
  MC_SetInt(Cl,Vl);
  MC_SetIntArray(Cibr,Vibr);
  int ret;
  int ludchk_();
  ret = ludchk_(&Ci,&Cj,&Ck,&Cl,Cibr);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_rudlev(self,Vnlev)
    VALUE self,Vnlev;
{
  MC_SetInt(Cnlev,Vnlev);
  float ret;
  float rudlev_();
  ret = rudlev_(&Cnlev);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rudval(self,Vzz,Vcz)
    VALUE self,Vzz,Vcz;
{
  MC_SetFloat(Czz,Vzz);
  MC_SetFloat(Ccz,Vcz);
  float ret;
  float rudval_();
  ret = rudval_(&Czz,&Ccz);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_udbclr(self,Vi,Vj,Vk,Vl,Vibr)
    VALUE self,Vi,Vj,Vk,Vl,Vibr;
{
  MC_SetInt(Ci,Vi);
  MC_SetInt(Cj,Vj);
  MC_SetInt(Ck,Vk);
  MC_SetInt(Cl,Vl);
  MC_SetIntArray(Cibr,Vibr);
  udbclr_(&Ci,&Cj,&Ck,&Cl,Cibr);
  return Qnil;
}

static VALUE
dcl_udbset(self,Vi,Vj,Vk,Vl,Vibr)
    VALUE self,Vi,Vj,Vk,Vl,Vibr;
{
  MC_SetInt(Ci,Vi);
  MC_SetInt(Cj,Vj);
  MC_SetInt(Ck,Vk);
  MC_SetInt(Cl,Vl);
  MC_SetIntArray(Cibr,Vibr);
  udbset_(&Ci,&Cj,&Ck,&Cl,Cibr);
  return Qnil;
}

static VALUE
dcl_udcntr(self,Vz,Vmx,Vnx,Vny)
    VALUE self,Vz,Vmx,Vnx,Vny;
{
  MC_SetFloatArray(Cz,Vz);
  MC_SetInt(Cmx,Vmx);
  MC_SetInt(Cnx,Vnx);
  MC_SetInt(Cny,Vny);
  udcntr_(Cz,&Cmx,&Cnx,&Cny);
  return Qnil;
}

static VALUE
dcl_udcntz(self,Vz,Vmx,Vnx,Vny,Vibr,Vnbr2)
    VALUE self,Vz,Vmx,Vnx,Vny,Vibr,Vnbr2;
{
  MC_SetFloatArray(Cz,Vz);
  MC_SetInt(Cmx,Vmx);
  MC_SetInt(Cnx,Vnx);
  MC_SetInt(Cny,Vny);
  MC_SetIntArray(Cibr,Vibr);
  MC_SetInt(Cnbr2,Vnbr2);
  udcntz_(Cz,&Cmx,&Cnx,&Cny,Cibr,&Cnbr2);
  return Qnil;
}

static VALUE
dcl_udgcla(self,Vxmin,Vxmax,Vdx)
    VALUE self,Vxmin,Vxmax,Vdx;
{
  MC_SetFloat(Cxmin,Vxmin);
  MC_SetFloat(Cxmax,Vxmax);
  MC_SetFloat(Cdx,Vdx);
  udgcla_(&Cxmin,&Cxmax,&Cdx);
  return Qnil;
}

static VALUE
dcl_udgclb(self,Vz,Vmx,Vnx,Vny,Vdx)
    VALUE self,Vz,Vmx,Vnx,Vny,Vdx;
{
  MC_SetFloatArray(Cz,Vz);
  MC_SetInt(Cmx,Vmx);
  MC_SetInt(Cnx,Vnx);
  MC_SetInt(Cny,Vny);
  MC_SetFloat(Cdx,Vdx);
  udgclb_(Cz,&Cmx,&Cnx,&Cny,&Cdx);
  return Qnil;
}

static VALUE
dcl_udgrdn(self,Vmode,Vix,Viy,Vk,Vjx,Vjy,Vjk)
    VALUE self,Vmode,Vix,Viy,Vk,Vjx,Vjy,Vjk;
{
  MC_SetInt(Cmode,Vmode);
  MC_SetInt(Cix,Vix);
  MC_SetInt(Ciy,Viy);
  MC_SetInt(Ck,Vk);
  MC_SetIntArray(Cjx,Vjx);
  MC_SetIntArray(Cjy,Vjy);
  MC_SetIntArray(Cjk,Vjk);
  udgrdn_(&Cmode,&Cix,&Ciy,&Ck,Cjx,Cjy,Cjk);
  return Qnil;
}

static VALUE
dcl_udiclr(self,Vix,Vn)
    VALUE self,Vix,Vn;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  udiclr_(Cix,&Cn);
  return Qnil;
}

static VALUE
dcl_udiclv(self)
    VALUE self;
{
  udiclv_();
  return Qnil;
}

static VALUE
dcl_udsclv(self,Vzlev,Vindx,Vityp,Vclv,Vhl)
    VALUE self,Vzlev,Vindx,Vityp,Vclv,Vhl;
{
  MC_SetFloat(Czlev,Vzlev);
  MC_SetInt(Cindx,Vindx);
  MC_SetInt(Cityp,Vityp);
  MC_SetString(Cclv,Vclv);
  MC_SetFloat(Chl,Vhl);
  udsclv_(&Czlev,&Cindx,&Cityp,Cclv,&Chl,strlen(Cclv));
  return Qnil;
}

static VALUE
dcl_udqclv(self,Vzlev,Vindx,Vityp,Vclv,Vhl,Vnlev)
    VALUE self,Vzlev,Vindx,Vityp,Vclv,Vhl,Vnlev;
{
  float Czlev;
  int   Cindx;
  int   Cityp;
  char * Cclv="                ";
  float Chl;
  MC_SetInt(Cnlev,Vnlev);
  udqclv_(&Czlev,&Cindx,&Cityp,Cclv,&Chl,&Cnlev,strlen(Cclv));
  MC_GetFloat(Czlev,Vzlev);
  MC_GetInt(Cindx,Vindx);
  MC_GetInt(Cityp,Vityp);
  MC_GetString(Cclv,Vclv);
  MC_GetFloat(Chl,Vhl);
  return Qnil;
}

static VALUE
dcl_udqcln(self,Vnlev)
    VALUE self,Vnlev;
{
  int   Cnlev;
  udqcln_(&Cnlev);
  MC_GetInt(Cnlev,Vnlev);
  return Qnil;
}

static VALUE
dcl_uddclv(self,Vzlev)
    VALUE self,Vzlev;
{
  MC_SetFloat(Czlev,Vzlev);
  uddclv_(&Czlev);
  return Qnil;
}

static VALUE
dcl_udsclz(self,Vlset)
    VALUE self,Vlset;
{
  MC_SetLogic(Clset,Vlset);
  udsclz_(&Clset);
  return Qnil;
}

static VALUE
dcl_udqclz(self,Vlset)
    VALUE self,Vlset;
{
  int    Clset;
  udqclz_(&Clset);
  MC_GetLogic(Clset,Vlset);
  return Qnil;
}

static VALUE
dcl_udlabl(self,Vval,Vcval)
    VALUE self,Vval,Vcval;
{
  MC_SetFloat(Cval,Vval);
  MC_SetString(Ccval,Vcval);
  udlabl_(&Cval,Ccval,strlen(Ccval));
  return Qnil;
}

static VALUE
dcl_udsfmt(self,Vcfmt)
    VALUE self,Vcfmt;
{
  MC_SetString(Ccfmt,Vcfmt);
  udsfmt_(Ccfmt,strlen(Ccfmt));
  return Qnil;
}

static VALUE
dcl_udqfmt(self,Vcfmt)
    VALUE self,Vcfmt;
{
  char * Ccfmt="                ";
  udqfmt_(Ccfmt,strlen(Ccfmt));
  MC_GetString(Ccfmt,Vcfmt);
  return Qnil;
}

static VALUE
dcl_udline(self,Vz,Vmx,Vkx,Vky,Vkk,Vcx,Vlopen,Vibr)
    VALUE self,Vz,Vmx,Vkx,Vky,Vkk,Vcx,Vlopen,Vibr;
{
  MC_SetFloatArray(Cz,Vz);
  MC_SetInt(Cmx,Vmx);
  MC_SetInt(Ckx,Vkx);
  MC_SetInt(Cky,Vky);
  MC_SetInt(Ckk,Vkk);
  MC_SetFloat(Ccx,Vcx);
  MC_SetLogic(Clopen,Vlopen);
  MC_SetIntArray(Cibr,Vibr);
  udline_(Cz,&Cmx,&Ckx,&Cky,&Ckk,&Ccx,&Clopen,Cibr);
  return Qnil;
}

static VALUE
dcl_udpget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  udpget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_udiget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  udiget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_udrget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  float Cipara;
  udrget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetFloat(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_udlget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int    Cipara;
  udlget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetLogic(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_udpset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  udpset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_udiset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  udiset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_udrset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  udrset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_udlset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  udlset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_udpstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  udpstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_udistx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  udistx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_udrstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  udrstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_udlstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  udlstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_udpqnp(self,Vncp)
    VALUE self,Vncp;
{
  int   Cncp;
  udpqnp_(&Cncp);
  MC_GetInt(Cncp,Vncp);
  return Qnil;
}

static VALUE
dcl_udpqid(self,Vcp,Vidx)
    VALUE self,Vcp,Vidx;
{
  MC_SetString(Ccp,Vcp);
  int   Cidx;
  udpqid_(Ccp,&Cidx,strlen(Ccp));
  MC_GetInt(Cidx,Vidx);
  return Qnil;
}

static VALUE
dcl_udpqcp(self,Vidx,Vcp)
    VALUE self,Vidx,Vcp;
{
  MC_SetInt(Cidx,Vidx);
  char * Ccp="                ";
  udpqcp_(&Cidx,Ccp,strlen(Ccp));
  MC_GetString(Ccp,Vcp);
  return Qnil;
}

static VALUE
dcl_udpqvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  int   Cipara;
  udpqvl_(&Cidx,&Cipara);
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_udpsvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetInt(Cipara,Vipara);
  udpsvl_(&Cidx,&Cipara);
  return Qnil;
}

static VALUE
dcl_uduxuy(self,Vz,Vmx,Vix,Viy,Vk,Vcx,Vux,Vuy)
    VALUE self,Vz,Vmx,Vix,Viy,Vk,Vcx,Vux,Vuy;
{
  MC_SetFloatArray(Cz,Vz);
  MC_SetInt(Cmx,Vmx);
  MC_SetInt(Cix,Vix);
  MC_SetInt(Ciy,Viy);
  MC_SetInt(Ck,Vk);
  MC_SetFloat(Ccx,Vcx);
  float Cux;
  MC_SetFloat(Cuy,Vuy);
  uduxuy_(Cz,&Cmx,&Cix,&Ciy,&Ck,&Ccx,&Cux,&Cuy);
  MC_GetFloat(Cux,Vux);
  return Qnil;
}

static VALUE
dcl_iueton(self,Vzlev)
    VALUE self,Vzlev;
{
  MC_SetFloat(Czlev,Vzlev);
  int ret;
  int iueton_();
  ret = iueton_(&Czlev);
  return MC_NewInt(ret);;
}

static VALUE
dcl_uearea(self,Vxp,Vyp,Vzp,Vvlvm,Vax,Vay,Vnp,Vni,Vng)
    VALUE self,Vxp,Vyp,Vzp,Vvlvm,Vax,Vay,Vnp,Vni,Vng;
{
  MC_SetFloatArray(Cxp,Vxp);
  MC_SetFloatArray(Cyp,Vyp);
  MC_SetFloatArray(Czp,Vzp);
  MC_SetFloatArray(Cvlvm,Vvlvm);
  MC_SetFloatArray(Cax,Vax);
  MC_SetFloatArray(Cay,Vay);
  MC_SetIntArray(Cnp,Vnp);
  MC_SetIntArray(Cni,Vni);
  int   Cng;
  uearea_(Cxp,Cyp,Czp,Cvlvm,Cax,Cay,Cnp,Cni,&Cng);
  MC_GetInt(Cng,Vng);
  return Qnil;
}

static VALUE
dcl_ueaint(self)
    VALUE self;
{
  ueaint_();
  return Qnil;
}

static VALUE
dcl_uegtla(self,Vxmin,Vxmax,Vdx)
    VALUE self,Vxmin,Vxmax,Vdx;
{
  MC_SetFloat(Cxmin,Vxmin);
  MC_SetFloat(Cxmax,Vxmax);
  MC_SetFloat(Cdx,Vdx);
  uegtla_(&Cxmin,&Cxmax,&Cdx);
  return Qnil;
}

static VALUE
dcl_uegtlb(self,Vz,Vmx,Vnx,Vny,Vdx)
    VALUE self,Vz,Vmx,Vnx,Vny,Vdx;
{
  MC_SetFloatArray(Cz,Vz);
  MC_SetInt(Cmx,Vmx);
  MC_SetInt(Cnx,Vnx);
  MC_SetInt(Cny,Vny);
  MC_SetFloat(Cdx,Vdx);
  uegtlb_(Cz,&Cmx,&Cnx,&Cny,&Cdx);
  return Qnil;
}

static VALUE
dcl_ueitlv(self)
    VALUE self;
{
  ueitlv_();
  return Qnil;
}

static VALUE
dcl_uestlv(self,Vtlev1,Vtlev2,Vipat)
    VALUE self,Vtlev1,Vtlev2,Vipat;
{
  MC_SetFloat(Ctlev1,Vtlev1);
  MC_SetFloat(Ctlev2,Vtlev2);
  MC_SetInt(Cipat,Vipat);
  uestlv_(&Ctlev1,&Ctlev2,&Cipat);
  return Qnil;
}

static VALUE
dcl_ueqtlv(self,Vtlev1,Vtlev2,Vipat,Viton)
    VALUE self,Vtlev1,Vtlev2,Vipat,Viton;
{
  float Ctlev1;
  float Ctlev2;
  int   Cipat;
  MC_SetInt(Citon,Viton);
  ueqtlv_(&Ctlev1,&Ctlev2,&Cipat,&Citon);
  MC_GetFloat(Ctlev1,Vtlev1);
  MC_GetFloat(Ctlev2,Vtlev2);
  MC_GetInt(Cipat,Vipat);
  return Qnil;
}

static VALUE
dcl_ueqntl(self,Vnton)
    VALUE self,Vnton;
{
  int   Cnton;
  ueqntl_(&Cnton);
  MC_GetInt(Cnton,Vnton);
  return Qnil;
}

static VALUE
dcl_uestlz(self,Vlset)
    VALUE self,Vlset;
{
  MC_SetLogic(Clset,Vlset);
  uestlz_(&Clset);
  return Qnil;
}

static VALUE
dcl_ueqtlz(self,Vlset)
    VALUE self,Vlset;
{
  int    Clset;
  ueqtlz_(&Clset);
  MC_GetLogic(Clset,Vlset);
  return Qnil;
}

static VALUE
dcl_uepget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  uepget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_ueiget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  ueiget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uerget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  float Cipara;
  uerget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetFloat(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uelget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int    Cipara;
  uelget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetLogic(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uepset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  uepset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ueiset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  ueiset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uerset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  uerset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uelset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  uelset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uepstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  uepstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ueistx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  ueistx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uerstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  uerstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uelstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  uelstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uepqnp(self,Vncp)
    VALUE self,Vncp;
{
  int   Cncp;
  uepqnp_(&Cncp);
  MC_GetInt(Cncp,Vncp);
  return Qnil;
}

static VALUE
dcl_uepqid(self,Vcp,Vidx)
    VALUE self,Vcp,Vidx;
{
  MC_SetString(Ccp,Vcp);
  int   Cidx;
  uepqid_(Ccp,&Cidx,strlen(Ccp));
  MC_GetInt(Cidx,Vidx);
  return Qnil;
}

static VALUE
dcl_uepqcp(self,Vidx,Vcp)
    VALUE self,Vidx,Vcp;
{
  MC_SetInt(Cidx,Vidx);
  char * Ccp="                ";
  uepqcp_(&Cidx,Ccp,strlen(Ccp));
  MC_GetString(Ccp,Vcp);
  return Qnil;
}

static VALUE
dcl_uepqvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  int   Cipara;
  uepqvl_(&Cidx,&Cipara);
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uepsvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetInt(Cipara,Vipara);
  uepsvl_(&Cidx,&Cipara);
  return Qnil;
}

static VALUE
dcl_uestln(self,Vtlevn,Vipatn,Vnton)
    VALUE self,Vtlevn,Vipatn,Vnton;
{
  MC_SetFloatArray(Ctlevn,Vtlevn);
  MC_SetIntArray(Cipatn,Vipatn);
  MC_SetInt(Cnton,Vnton);
  uestln_(Ctlevn,Cipatn,&Cnton);
  return Qnil;
}

static VALUE
dcl_uetonc(self,Vz,Vmx,Vnx,Vny)
    VALUE self,Vz,Vmx,Vnx,Vny;
{
  MC_SetFloatArray(Cz,Vz);
  MC_SetInt(Cmx,Vmx);
  MC_SetInt(Cnx,Vnx);
  MC_SetInt(Cny,Vny);
  uetonc_(Cz,&Cmx,&Cnx,&Cny);
  return Qnil;
}

static VALUE
dcl_uetone(self,Vz,Vmx,Vnx,Vny)
    VALUE self,Vz,Vmx,Vnx,Vny;
{
  MC_SetFloatArray(Cz,Vz);
  MC_SetInt(Cmx,Vmx);
  MC_SetInt(Cnx,Vnx);
  MC_SetInt(Cny,Vny);
  uetone_(Cz,&Cmx,&Cnx,&Cny);
  return Qnil;
}

static VALUE
dcl_uetonf(self,Vz,Vmx,Vnx,Vny)
    VALUE self,Vz,Vmx,Vnx,Vny;
{
  MC_SetFloatArray(Cz,Vz);
  MC_SetInt(Cmx,Vmx);
  MC_SetInt(Cnx,Vnx);
  MC_SetInt(Cny,Vny);
  uetonf_(Cz,&Cmx,&Cnx,&Cny);
  return Qnil;
}

static VALUE
dcl_uezchk(self,Vz,Vmx,Vnx,Vny,Vcname,Vistat)
    VALUE self,Vz,Vmx,Vnx,Vny,Vcname,Vistat;
{
  MC_SetFloatArray(Cz,Vz);
  MC_SetInt(Cmx,Vmx);
  MC_SetInt(Cnx,Vnx);
  MC_SetInt(Cny,Vny);
  MC_SetString(Ccname,Vcname);
  int   Cistat;
  uezchk_(Cz,&Cmx,&Cnx,&Cny,Ccname,&Cistat,strlen(Ccname));
  MC_GetInt(Cistat,Vistat);
  return Qnil;
}

static VALUE
dcl_ugpget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  ugpget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_ugiget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  ugiget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_ugrget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  float Cipara;
  ugrget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetFloat(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uglget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int    Cipara;
  uglget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetLogic(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_ugpset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  ugpset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ugiset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  ugiset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ugrset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  ugrset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uglset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  uglset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ugpstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  ugpstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ugistx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  ugistx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ugrstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  ugrstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uglstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  uglstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ugpqnp(self,Vncp)
    VALUE self,Vncp;
{
  int   Cncp;
  ugpqnp_(&Cncp);
  MC_GetInt(Cncp,Vncp);
  return Qnil;
}

static VALUE
dcl_ugpqid(self,Vcp,Vidx)
    VALUE self,Vcp,Vidx;
{
  MC_SetString(Ccp,Vcp);
  int   Cidx;
  ugpqid_(Ccp,&Cidx,strlen(Ccp));
  MC_GetInt(Cidx,Vidx);
  return Qnil;
}

static VALUE
dcl_ugpqcp(self,Vidx,Vcp)
    VALUE self,Vidx,Vcp;
{
  MC_SetInt(Cidx,Vidx);
  char * Ccp="                ";
  ugpqcp_(&Cidx,Ccp,strlen(Ccp));
  MC_GetString(Ccp,Vcp);
  return Qnil;
}

static VALUE
dcl_ugpqvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  int   Cipara;
  ugpqvl_(&Cidx,&Cipara);
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_ugpsvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetInt(Cipara,Vipara);
  ugpsvl_(&Cidx,&Cipara);
  return Qnil;
}

static VALUE
dcl_ugsut(self,Vcside,Vcttl)
    VALUE self,Vcside,Vcttl;
{
  MC_SetString(Ccside,Vcside);
  MC_SetString(Ccttl,Vcttl);
  ugsut_(Ccside,Ccttl,strlen(Ccside),strlen(Ccttl));
  return Qnil;
}

static VALUE
dcl_ugdut(self)
    VALUE self;
{
  ugdut_();
  return Qnil;
}

static VALUE
dcl_ugunit(self)
    VALUE self;
{
  ugunit_();
  return Qnil;
}

static VALUE
dcl_ugvect(self,Vu,Vmu,Vv,Vmv,Vnx,Vny)
    VALUE self,Vu,Vmu,Vv,Vmv,Vnx,Vny;
{
  MC_SetFloatArray(Cu,Vu);
  MC_SetInt(Cmu,Vmu);
  MC_SetFloatArray(Cv,Vv);
  MC_SetInt(Cmv,Vmv);
  MC_SetInt(Cnx,Vnx);
  MC_SetInt(Cny,Vny);
  ugvect_(Cu,&Cmu,Cv,&Cmv,&Cnx,&Cny);
  return Qnil;
}

static VALUE
dcl_uhbra(self,Vn,Vupx1,Vupx2,Vupy)
    VALUE self,Vn,Vupx1,Vupx2,Vupy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx1,Vupx1);
  MC_SetFloatArray(Cupx2,Vupx2);
  MC_SetFloatArray(Cupy,Vupy);
  uhbra_(&Cn,Cupx1,Cupx2,Cupy);
  return Qnil;
}

static VALUE
dcl_uhbraz(self,Vn,Vupx1,Vupx2,Vupy,Vitpat1,Vitpat2,Vrsize)
    VALUE self,Vn,Vupx1,Vupx2,Vupy,Vitpat1,Vitpat2,Vrsize;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx1,Vupx1);
  MC_SetFloatArray(Cupx2,Vupx2);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetInt(Citpat1,Vitpat1);
  MC_SetInt(Citpat2,Vitpat2);
  MC_SetFloat(Crsize,Vrsize);
  uhbraz_(&Cn,Cupx1,Cupx2,Cupy,&Citpat1,&Citpat2,&Crsize);
  return Qnil;
}

static VALUE
dcl_uhbrf(self,Vn,Vupx1,Vupx2,Vupy)
    VALUE self,Vn,Vupx1,Vupx2,Vupy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx1,Vupx1);
  MC_SetFloatArray(Cupx2,Vupx2);
  MC_SetFloatArray(Cupy,Vupy);
  uhbrf_(&Cn,Cupx1,Cupx2,Cupy);
  return Qnil;
}

static VALUE
dcl_uhbrfz(self,Vn,Vupx1,Vupx2,Vupy,Vitype,Vindex,Vrsize)
    VALUE self,Vn,Vupx1,Vupx2,Vupy,Vitype,Vindex,Vrsize;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx1,Vupx1);
  MC_SetFloatArray(Cupx2,Vupx2);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  MC_SetFloat(Crsize,Vrsize);
  uhbrfz_(&Cn,Cupx1,Cupx2,Cupy,&Citype,&Cindex,&Crsize);
  return Qnil;
}

static VALUE
dcl_uhbrl(self,Vn,Vupx,Vupy)
    VALUE self,Vn,Vupx,Vupy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  uhbrl_(&Cn,Cupx,Cupy);
  return Qnil;
}

static VALUE
dcl_uhbrlz(self,Vn,Vupx,Vupy,Vitype,Vindex,Vrsize)
    VALUE self,Vn,Vupx,Vupy,Vitype,Vindex,Vrsize;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  MC_SetFloat(Crsize,Vrsize);
  uhbrlz_(&Cn,Cupx,Cupy,&Citype,&Cindex,&Crsize);
  return Qnil;
}

static VALUE
dcl_uhbxa(self,Vn,Vupx1,Vupx2,Vupy)
    VALUE self,Vn,Vupx1,Vupx2,Vupy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx1,Vupx1);
  MC_SetFloatArray(Cupx2,Vupx2);
  MC_SetFloatArray(Cupy,Vupy);
  uhbxa_(&Cn,Cupx1,Cupx2,Cupy);
  return Qnil;
}

static VALUE
dcl_uhbxaz(self,Vn,Vupx1,Vupx2,Vupy,Vitpat1,Vitpat2)
    VALUE self,Vn,Vupx1,Vupx2,Vupy,Vitpat1,Vitpat2;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx1,Vupx1);
  MC_SetFloatArray(Cupx2,Vupx2);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetInt(Citpat1,Vitpat1);
  MC_SetInt(Citpat2,Vitpat2);
  uhbxaz_(&Cn,Cupx1,Cupx2,Cupy,&Citpat1,&Citpat2);
  return Qnil;
}

static VALUE
dcl_uhbxf(self,Vn,Vupx1,Vupx2,Vupy)
    VALUE self,Vn,Vupx1,Vupx2,Vupy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx1,Vupx1);
  MC_SetFloatArray(Cupx2,Vupx2);
  MC_SetFloatArray(Cupy,Vupy);
  uhbxf_(&Cn,Cupx1,Cupx2,Cupy);
  return Qnil;
}

static VALUE
dcl_uhbxfz(self,Vn,Vupx1,Vupx2,Vupy,Vitype,Vindex)
    VALUE self,Vn,Vupx1,Vupx2,Vupy,Vitype,Vindex;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx1,Vupx1);
  MC_SetFloatArray(Cupx2,Vupx2);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  uhbxfz_(&Cn,Cupx1,Cupx2,Cupy,&Citype,&Cindex);
  return Qnil;
}

static VALUE
dcl_uhbxl(self,Vn,Vupx,Vupy)
    VALUE self,Vn,Vupx,Vupy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  uhbxl_(&Cn,Cupx,Cupy);
  return Qnil;
}

static VALUE
dcl_uhbxlz(self,Vn,Vupx,Vupy,Vitype,Vindex)
    VALUE self,Vn,Vupx,Vupy,Vitype,Vindex;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  uhbxlz_(&Cn,Cupx,Cupy,&Citype,&Cindex);
  return Qnil;
}

static VALUE
dcl_uhdif(self,Vn,Vupx1,Vupx2,Vupy)
    VALUE self,Vn,Vupx1,Vupx2,Vupy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx1,Vupx1);
  MC_SetFloatArray(Cupx2,Vupx2);
  MC_SetFloatArray(Cupy,Vupy);
  uhdif_(&Cn,Cupx1,Cupx2,Cupy);
  return Qnil;
}

static VALUE
dcl_uhdifz(self,Vn,Vupx1,Vupx2,Vupy,Vitpat1,Vitpat2)
    VALUE self,Vn,Vupx1,Vupx2,Vupy,Vitpat1,Vitpat2;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx1,Vupx1);
  MC_SetFloatArray(Cupx2,Vupx2);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetInt(Citpat1,Vitpat1);
  MC_SetInt(Citpat2,Vitpat2);
  uhdifz_(&Cn,Cupx1,Cupx2,Cupy,&Citpat1,&Citpat2);
  return Qnil;
}

static VALUE
dcl_uherb(self,Vn,Vupx1,Vupx2,Vupy)
    VALUE self,Vn,Vupx1,Vupx2,Vupy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx1,Vupx1);
  MC_SetFloatArray(Cupx2,Vupx2);
  MC_SetFloatArray(Cupy,Vupy);
  uherb_(&Cn,Cupx1,Cupx2,Cupy);
  return Qnil;
}

static VALUE
dcl_uherbz(self,Vn,Vupx1,Vupx2,Vupy,Vitype,Vindex,Vrsize)
    VALUE self,Vn,Vupx1,Vupx2,Vupy,Vitype,Vindex,Vrsize;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx1,Vupx1);
  MC_SetFloatArray(Cupx2,Vupx2);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  MC_SetFloat(Crsize,Vrsize);
  uherbz_(&Cn,Cupx1,Cupx2,Cupy,&Citype,&Cindex,&Crsize);
  return Qnil;
}

static VALUE
dcl_ulpget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  ulpget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uliget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  uliget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_ulrget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  float Cipara;
  ulrget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetFloat(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_ullget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int    Cipara;
  ullget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetLogic(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_ulpset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  ulpset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uliset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  uliset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ulrset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  ulrset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ullset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  ullset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ulpstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  ulpstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ulistx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  ulistx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ulrstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  ulrstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ullstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  ullstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_ulpqnp(self,Vncp)
    VALUE self,Vncp;
{
  int   Cncp;
  ulpqnp_(&Cncp);
  MC_GetInt(Cncp,Vncp);
  return Qnil;
}

static VALUE
dcl_ulpqid(self,Vcp,Vidx)
    VALUE self,Vcp,Vidx;
{
  MC_SetString(Ccp,Vcp);
  int   Cidx;
  ulpqid_(Ccp,&Cidx,strlen(Ccp));
  MC_GetInt(Cidx,Vidx);
  return Qnil;
}

static VALUE
dcl_ulpqcp(self,Vidx,Vcp)
    VALUE self,Vidx,Vcp;
{
  MC_SetInt(Cidx,Vidx);
  char * Ccp="                ";
  ulpqcp_(&Cidx,Ccp,strlen(Ccp));
  MC_GetString(Ccp,Vcp);
  return Qnil;
}

static VALUE
dcl_ulpqvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  int   Cipara;
  ulpqvl_(&Cidx,&Cipara);
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_ulpsvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetInt(Cipara,Vipara);
  ulpsvl_(&Cidx,&Cipara);
  return Qnil;
}

static VALUE
dcl_ulxlbl(self,Vbl,Vnbl,Vinum)
    VALUE self,Vbl,Vnbl,Vinum;
{
  float Cbl;
  int   Cnbl;
  MC_SetInt(Cinum,Vinum);
  ulxlbl_(&Cbl,&Cnbl,&Cinum);
  MC_GetFloat(Cbl,Vbl);
  MC_GetInt(Cnbl,Vnbl);
  return Qnil;
}

static VALUE
dcl_ulsxbl(self,Vbl,Vnbl)
    VALUE self,Vbl,Vnbl;
{
  MC_SetFloat(Cbl,Vbl);
  MC_SetInt(Cnbl,Vnbl);
  ulsxbl_(&Cbl,&Cnbl);
  return Qnil;
}

static VALUE
dcl_ulqxbl(self,Vbl,Vnbl)
    VALUE self,Vbl,Vnbl;
{
  float Cbl;
  int   Cnbl;
  ulqxbl_(&Cbl,&Cnbl);
  MC_GetFloat(Cbl,Vbl);
  MC_GetInt(Cnbl,Vnbl);
  return Qnil;
}

static VALUE
dcl_ulxlog(self,Vcside,Vnlbl,Vnticks)
    VALUE self,Vcside,Vnlbl,Vnticks;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cnlbl,Vnlbl);
  MC_SetInt(Cnticks,Vnticks);
  ulxlog_(Ccside,&Cnlbl,&Cnticks,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_ulxsfm(self,Vcxfmt)
    VALUE self,Vcxfmt;
{
  MC_SetString(Ccxfmt,Vcxfmt);
  ulxsfm_(Ccxfmt,strlen(Ccxfmt));
  return Qnil;
}

static VALUE
dcl_ulxqfm(self,Vcxfmt)
    VALUE self,Vcxfmt;
{
  char * Ccxfmt="                ";
  ulxqfm_(Ccxfmt,strlen(Ccxfmt));
  MC_GetString(Ccxfmt,Vcxfmt);
  return Qnil;
}

static VALUE
dcl_ulylbl(self,Vbl,Vnbl,Vinum)
    VALUE self,Vbl,Vnbl,Vinum;
{
  float Cbl;
  int   Cnbl;
  MC_SetInt(Cinum,Vinum);
  ulylbl_(&Cbl,&Cnbl,&Cinum);
  MC_GetFloat(Cbl,Vbl);
  MC_GetInt(Cnbl,Vnbl);
  return Qnil;
}

static VALUE
dcl_ulsybl(self,Vbl,Vnbl)
    VALUE self,Vbl,Vnbl;
{
  MC_SetFloat(Cbl,Vbl);
  MC_SetInt(Cnbl,Vnbl);
  ulsybl_(&Cbl,&Cnbl);
  return Qnil;
}

static VALUE
dcl_ulqybl(self,Vbl,Vnbl)
    VALUE self,Vbl,Vnbl;
{
  float Cbl;
  int   Cnbl;
  ulqybl_(&Cbl,&Cnbl);
  MC_GetFloat(Cbl,Vbl);
  MC_GetInt(Cnbl,Vnbl);
  return Qnil;
}

static VALUE
dcl_ulylog(self,Vcside,Vnlbl,Vnticks)
    VALUE self,Vcside,Vnlbl,Vnticks;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cnlbl,Vnlbl);
  MC_SetInt(Cnticks,Vnticks);
  ulylog_(Ccside,&Cnlbl,&Cnticks,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_ulysfm(self,Vcyfmt)
    VALUE self,Vcyfmt;
{
  MC_SetString(Ccyfmt,Vcyfmt);
  ulysfm_(Ccyfmt,strlen(Ccyfmt));
  return Qnil;
}

static VALUE
dcl_ulyqfm(self,Vcyfmt)
    VALUE self,Vcyfmt;
{
  char * Ccyfmt="                ";
  ulyqfm_(Ccyfmt,strlen(Ccyfmt));
  MC_GetString(Ccyfmt,Vcyfmt);
  return Qnil;
}

static VALUE
dcl_umbndc(self,Vxmin,Vxmax,Vymin,Vymax)
    VALUE self,Vxmin,Vxmax,Vymin,Vymax;
{
  float Cxmin;
  float Cxmax;
  float Cymin;
  float Cymax;
  umbndc_(&Cxmin,&Cxmax,&Cymin,&Cymax);
  MC_GetFloat(Cxmin,Vxmin);
  MC_GetFloat(Cxmax,Vxmax);
  MC_GetFloat(Cymin,Vymin);
  MC_GetFloat(Cymax,Vymax);
  return Qnil;
}

static VALUE
dcl_umbndp(self,Vvxmin,Vvxmax,Vvymin,Vvymax)
    VALUE self,Vvxmin,Vvxmax,Vvymin,Vvymax;
{
  float Cvxmin;
  float Cvxmax;
  float Cvymin;
  float Cvymax;
  umbndp_(&Cvxmin,&Cvxmax,&Cvymin,&Cvymax);
  MC_GetFloat(Cvxmin,Vvxmin);
  MC_GetFloat(Cvxmax,Vvxmax);
  MC_GetFloat(Cvymin,Vvymin);
  MC_GetFloat(Cvymax,Vvymax);
  return Qnil;
}

static VALUE
dcl_umbndr(self)
    VALUE self;
{
  umbndr_();
  return Qnil;
}

static VALUE
dcl_uminit(self)
    VALUE self;
{
  uminit_();
  return Qnil;
}

static VALUE
dcl_umpfit(self)
    VALUE self;
{
  umpfit_();
  return Qnil;
}

static VALUE
dcl_umpget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  umpget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_umiget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  umiget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_umrget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  float Cipara;
  umrget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetFloat(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_umlget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int    Cipara;
  umlget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetLogic(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_umpset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  umpset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_umiset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  umiset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_umrset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  umrset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_umlset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  umlset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_umpstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  umpstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_umistx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  umistx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_umrstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  umrstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_umlstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  umlstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_umpglb(self)
    VALUE self;
{
  umpglb_();
  return Qnil;
}

static VALUE
dcl_umpgrd(self)
    VALUE self;
{
  umpgrd_();
  return Qnil;
}

static VALUE
dcl_umplim(self)
    VALUE self;
{
  umplim_();
  return Qnil;
}

static VALUE
dcl_umpmap(self,Vcdsn)
    VALUE self,Vcdsn;
{
  MC_SetString(Ccdsn,Vcdsn);
  umpmap_(Ccdsn,strlen(Ccdsn));
  return Qnil;
}

static VALUE
dcl_umpqnp(self,Vncp)
    VALUE self,Vncp;
{
  int   Cncp;
  umpqnp_(&Cncp);
  MC_GetInt(Cncp,Vncp);
  return Qnil;
}

static VALUE
dcl_umpqid(self,Vcp,Vidx)
    VALUE self,Vcp,Vidx;
{
  MC_SetString(Ccp,Vcp);
  int   Cidx;
  umpqid_(Ccp,&Cidx,strlen(Ccp));
  MC_GetInt(Cidx,Vidx);
  return Qnil;
}

static VALUE
dcl_umpqcp(self,Vidx,Vcp)
    VALUE self,Vidx,Vcp;
{
  MC_SetInt(Cidx,Vidx);
  char * Ccp="                ";
  umpqcp_(&Cidx,Ccp,strlen(Ccp));
  MC_GetString(Ccp,Vcp);
  return Qnil;
}

static VALUE
dcl_umpqvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  int   Cipara;
  umpqvl_(&Cidx,&Cipara);
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_umpsvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetInt(Cipara,Vipara);
  umpsvl_(&Cidx,&Cipara);
  return Qnil;
}

static VALUE
dcl_umqfnm(self,Vcpara,Vcfname)
    VALUE self,Vcpara,Vcfname;
{
  MC_SetString(Ccpara,Vcpara);
  MC_SetString(Ccfname,Vcfname);
  umqfnm_(Ccpara,Ccfname,strlen(Ccpara),strlen(Ccfname));
  return Qnil;
}

static VALUE
dcl_umqtxy(self,Vtxminz,Vtxmaxz,Vtyminz,Vtymaxz)
    VALUE self,Vtxminz,Vtxmaxz,Vtyminz,Vtymaxz;
{
  MC_SetFloat(Ctxminz,Vtxminz);
  MC_SetFloat(Ctxmaxz,Vtxmaxz);
  float Ctyminz;
  float Ctymaxz;
  umqtxy_(&Ctxminz,&Ctxmaxz,&Ctyminz,&Ctymaxz);
  MC_GetFloat(Ctyminz,Vtyminz);
  MC_GetFloat(Ctymaxz,Vtymaxz);
  return Qnil;
}

static VALUE
dcl_umscnt(self,Vxcnt,Vycnt,Vrot)
    VALUE self,Vxcnt,Vycnt,Vrot;
{
  MC_SetFloat(Cxcnt,Vxcnt);
  MC_SetFloat(Cycnt,Vycnt);
  MC_SetFloat(Crot,Vrot);
  umscnt_(&Cxcnt,&Cycnt,&Crot);
  return Qnil;
}

static VALUE
dcl_umqcnt(self,Vxcnt,Vycnt,Vrot)
    VALUE self,Vxcnt,Vycnt,Vrot;
{
  float Cxcnt;
  float Cycnt;
  float Crot;
  umqcnt_(&Cxcnt,&Cycnt,&Crot);
  MC_GetFloat(Cxcnt,Vxcnt);
  MC_GetFloat(Cycnt,Vycnt);
  MC_GetFloat(Crot,Vrot);
  return Qnil;
}

static VALUE
dcl_umscom(self)
    VALUE self;
{
  umscom_();
  return Qnil;
}

static VALUE
dcl_umscwd(self,Vxcntr,Vycntr,Vr)
    VALUE self,Vxcntr,Vycntr,Vr;
{
  MC_SetFloat(Cxcntr,Vxcntr);
  MC_SetFloat(Cycntr,Vycntr);
  MC_SetFloat(Cr,Vr);
  umscwd_(&Cxcntr,&Cycntr,&Cr);
  return Qnil;
}

static VALUE
dcl_umqcwd(self,Vxcntr,Vycntr,Vr)
    VALUE self,Vxcntr,Vycntr,Vr;
{
  float Cxcntr;
  float Cycntr;
  float Cr;
  umqcwd_(&Cxcntr,&Cycntr,&Cr);
  MC_GetFloat(Cxcntr,Vxcntr);
  MC_GetFloat(Cycntr,Vycntr);
  MC_GetFloat(Cr,Vr);
  return Qnil;
}

static VALUE
dcl_umsgrd(self)
    VALUE self;
{
  umsgrd_();
  return Qnil;
}

static VALUE
dcl_umspct(self)
    VALUE self;
{
  umspct_();
  return Qnil;
}

static VALUE
dcl_umspcw(self)
    VALUE self;
{
  umspcw_();
  return Qnil;
}

static VALUE
dcl_umspdf(self)
    VALUE self;
{
  umspdf_();
  return Qnil;
}

static VALUE
dcl_umspnt(self,Vn,Vux,Vuy)
    VALUE self,Vn,Vux,Vuy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cux,Vux);
  MC_SetFloatArray(Cuy,Vuy);
  umspnt_(&Cn,Cux,Cuy);
  return Qnil;
}

static VALUE
dcl_umqpnt(self,Vn,Vuxa,Vuya)
    VALUE self,Vn,Vuxa,Vuya;
{
  MC_SetInt(Cn,Vn);
  float Cuxa;
  float Cuya;
  umqpnt_(&Cn,&Cuxa,&Cuya);
  MC_GetFloat(Cuxa,Vuxa);
  MC_GetFloat(Cuya,Vuya);
  return Qnil;
}

static VALUE
dcl_umqptn(self,Vn)
    VALUE self,Vn;
{
  int   Cn;
  umqptn_(&Cn);
  MC_GetInt(Cn,Vn);
  return Qnil;
}

static VALUE
dcl_umrpnt(self)
    VALUE self;
{
  umrpnt_();
  return Qnil;
}

static VALUE
dcl_umsppt(self)
    VALUE self;
{
  umsppt_();
  return Qnil;
}

static VALUE
dcl_umspwd(self)
    VALUE self;
{
  umspwd_();
  return Qnil;
}

static VALUE
dcl_umstvz(self)
    VALUE self;
{
  umstvz_();
  return Qnil;
}

static VALUE
dcl_csblbl(self,Vufac,Vuoff,Vcunit)
    VALUE self,Vufac,Vuoff,Vcunit;
{
  MC_SetFloat(Cufac,Vufac);
  MC_SetFloat(Cuoff,Vuoff);
  MC_SetString(Ccunit,Vcunit);
  char * ret;
  char * csblbl_();
  ret = csblbl_(&Cufac,&Cuoff,Ccunit,strlen(Ccunit));
  return MC_NewString(ret);;
}

static VALUE
dcl_uscget(self,Vcp,Vcpara)
    VALUE self,Vcp,Vcpara;
{
  MC_SetString(Ccp,Vcp);
  char * Ccpara="                ";
  uscget_(Ccp,Ccpara,strlen(Ccp),strlen(Ccpara));
  MC_GetString(Ccpara,Vcpara);
  return Qnil;
}

static VALUE
dcl_uscset(self,Vcp,Vcpara)
    VALUE self,Vcp,Vcpara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetString(Ccpara,Vcpara);
  uscset_(Ccp,Ccpara,strlen(Ccp),strlen(Ccpara));
  return Qnil;
}

static VALUE
dcl_uscstx(self,Vcp,Vcpara)
    VALUE self,Vcp,Vcpara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetString(Ccpara,Vcpara);
  uscstx_(Ccp,Ccpara,strlen(Ccp),strlen(Ccpara));
  return Qnil;
}

static VALUE
dcl_uschvl(self,Vx,Vchx)
    VALUE self,Vx,Vchx;
{
  MC_SetFloat(Cx,Vx);
  char * Cchx="                ";
  uschvl_(&Cx,Cchx,strlen(Cchx));
  MC_GetString(Cchx,Vchx);
  return Qnil;
}

static VALUE
dcl_uscqnp(self,Vncp)
    VALUE self,Vncp;
{
  int   Cncp;
  uscqnp_(&Cncp);
  MC_GetInt(Cncp,Vncp);
  return Qnil;
}

static VALUE
dcl_uscqid(self,Vcp,Vidx)
    VALUE self,Vcp,Vidx;
{
  MC_SetString(Ccp,Vcp);
  int   Cidx;
  uscqid_(Ccp,&Cidx,strlen(Ccp));
  MC_GetInt(Cidx,Vidx);
  return Qnil;
}

static VALUE
dcl_uscqcp(self,Vidx,Vcp)
    VALUE self,Vidx,Vcp;
{
  MC_SetInt(Cidx,Vidx);
  char * Ccp="                ";
  uscqcp_(&Cidx,Ccp,strlen(Ccp));
  MC_GetString(Ccp,Vcp);
  return Qnil;
}

static VALUE
dcl_uscqvl(self,Vidx,Vcval)
    VALUE self,Vidx,Vcval;
{
  MC_SetInt(Cidx,Vidx);
  char * Ccval="                ";
  uscqvl_(&Cidx,Ccval,strlen(Ccval));
  MC_GetString(Ccval,Vcval);
  return Qnil;
}

static VALUE
dcl_uscsvl(self,Vidx,Vcval)
    VALUE self,Vidx,Vcval;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetString(Ccval,Vcval);
  uscsvl_(&Cidx,Ccval,strlen(Ccval));
  return Qnil;
}

static VALUE
dcl_usdaxs(self)
    VALUE self;
{
  usdaxs_();
  return Qnil;
}

static VALUE
dcl_usgrph(self,Vn,Vx,Vy)
    VALUE self,Vn,Vx,Vy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cx,Vx);
  MC_SetFloatArray(Cy,Vy);
  usgrph_(&Cn,Cx,Cy);
  return Qnil;
}

static VALUE
dcl_usinit(self)
    VALUE self;
{
  usinit_();
  return Qnil;
}

static VALUE
dcl_uspfit(self)
    VALUE self;
{
  uspfit_();
  return Qnil;
}

static VALUE
dcl_uspget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  uspget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_usiget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  usiget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_usrget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  float Cipara;
  usrget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetFloat(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uslget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int    Cipara;
  uslget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetLogic(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uspset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  uspset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_usiset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  usiset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_usrset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  usrset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uslset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  uslset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uspstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  uspstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_usistx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  usistx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_usrstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  usrstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uslstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  uslstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uspqnp(self,Vncp)
    VALUE self,Vncp;
{
  int   Cncp;
  uspqnp_(&Cncp);
  MC_GetInt(Cncp,Vncp);
  return Qnil;
}

static VALUE
dcl_uspqid(self,Vcp,Vidx)
    VALUE self,Vcp,Vidx;
{
  MC_SetString(Ccp,Vcp);
  int   Cidx;
  uspqid_(Ccp,&Cidx,strlen(Ccp));
  MC_GetInt(Cidx,Vidx);
  return Qnil;
}

static VALUE
dcl_uspqcp(self,Vidx,Vcp)
    VALUE self,Vidx,Vcp;
{
  MC_SetInt(Cidx,Vidx);
  char * Ccp="                ";
  uspqcp_(&Cidx,Ccp,strlen(Ccp));
  MC_GetString(Ccp,Vcp);
  return Qnil;
}

static VALUE
dcl_uspqvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  int   Cipara;
  uspqvl_(&Cidx,&Cipara);
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uspsvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetInt(Cipara,Vipara);
  uspsvl_(&Cidx,&Cipara);
  return Qnil;
}

static VALUE
dcl_usspnt(self,Vn,Vx,Vy)
    VALUE self,Vn,Vx,Vy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cx,Vx);
  MC_SetFloatArray(Cy,Vy);
  usspnt_(&Cn,Cx,Cy);
  return Qnil;
}

static VALUE
dcl_ussttl(self,Vcxttl,Vcxunit,Vcyttl,Vcyunit)
    VALUE self,Vcxttl,Vcxunit,Vcyttl,Vcyunit;
{
  MC_SetString(Ccxttl,Vcxttl);
  MC_SetString(Ccxunit,Vcxunit);
  MC_SetString(Ccyttl,Vcyttl);
  MC_SetString(Ccyunit,Vcyunit);
  ussttl_(Ccxttl,Ccxunit,Ccyttl,Ccyunit,strlen(Ccxttl),strlen(Ccxunit),strlen(Ccyttl),strlen(Ccyunit));
  return Qnil;
}

static VALUE
dcl_usurdl(self,Vumin,Vumax,Vvmin,Vvmax)
    VALUE self,Vumin,Vumax,Vvmin,Vvmax;
{
  float Cumin;
  float Cumax;
  MC_SetFloat(Cvmin,Vvmin);
  MC_SetFloat(Cvmax,Vvmax);
  usurdl_(&Cumin,&Cumax,&Cvmin,&Cvmax);
  MC_GetFloat(Cumin,Vumin);
  MC_GetFloat(Cumax,Vumax);
  return Qnil;
}

static VALUE
dcl_usurdt(self,Vumin,Vumax,Vvmin,Vvmax,Vdut)
    VALUE self,Vumin,Vumax,Vvmin,Vvmax,Vdut;
{
  float Cumin;
  float Cumax;
  MC_SetFloat(Cvmin,Vvmin);
  MC_SetFloat(Cvmax,Vvmax);
  float Cdut;
  usurdt_(&Cumin,&Cumax,&Cvmin,&Cvmax,&Cdut);
  MC_GetFloat(Cumin,Vumin);
  MC_GetFloat(Cumax,Vumax);
  MC_GetFloat(Cdut,Vdut);
  return Qnil;
}

static VALUE
dcl_ususcl(self,Vcaxis,Vumin,Vumax,Vvmin,Vvmax)
    VALUE self,Vcaxis,Vumin,Vumax,Vvmin,Vvmax;
{
  MC_SetString(Ccaxis,Vcaxis);
  MC_SetFloat(Cumin,Vumin);
  MC_SetFloat(Cumax,Vumax);
  MC_SetFloat(Cvmin,Vvmin);
  MC_SetFloat(Cvmax,Vvmax);
  ususcl_(Ccaxis,&Cumin,&Cumax,&Cvmin,&Cvmax,strlen(Ccaxis));
  return Qnil;
}

static VALUE
dcl_ususcu(self,Vcaxis,Vumin,Vumax,Vvmin,Vvmax,Vmode)
    VALUE self,Vcaxis,Vumin,Vumax,Vvmin,Vvmax,Vmode;
{
  MC_SetString(Ccaxis,Vcaxis);
  MC_SetFloat(Cumin,Vumin);
  MC_SetFloat(Cumax,Vumax);
  MC_SetFloat(Cvmin,Vvmin);
  MC_SetFloat(Cvmax,Vvmax);
  MC_SetInt(Cmode,Vmode);
  ususcu_(Ccaxis,&Cumin,&Cumax,&Cvmin,&Cvmax,&Cmode,strlen(Ccaxis));
  return Qnil;
}

static VALUE
dcl_uswapz(self,Vx1,Vx2,Vn)
    VALUE self,Vx1,Vx2,Vn;
{
  MC_SetFloatArray(Cx1,Vx1);
  MC_SetFloatArray(Cx2,Vx2);
  MC_SetInt(Cn,Vn);
  uswapz_(Cx1,Cx2,&Cn);
  return Qnil;
}

static VALUE
dcl_usxaxl(self,Vcxs)
    VALUE self,Vcxs;
{
  MC_SetString(Ccxs,Vcxs);
  usxaxl_(Ccxs,strlen(Ccxs));
  return Qnil;
}

static VALUE
dcl_usxaxs(self,Vcside)
    VALUE self,Vcside;
{
  MC_SetString(Ccside,Vcside);
  usxaxs_(Ccside,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_usxaxu(self,Vcxs)
    VALUE self,Vcxs;
{
  MC_SetString(Ccxs,Vcxs);
  usxaxu_(Ccxs,strlen(Ccxs));
  return Qnil;
}

static VALUE
dcl_usxoff(self,Vcxs)
    VALUE self,Vcxs;
{
  MC_SetString(Ccxs,Vcxs);
  usxoff_(&Ccxs);
  return Qnil;
}

static VALUE
dcl_usxsub(self,Vcxa,Vcya,Vclabel,Vrlbl)
    VALUE self,Vcxa,Vcya,Vclabel,Vrlbl;
{
  MC_SetString(Ccxa,Vcxa);
  MC_SetString(Ccya,Vcya);
  MC_SetString(Cclabel,Vclabel);
  MC_SetFloat(Crlbl,Vrlbl);
  usxsub_(Ccxa,Ccya,Cclabel,&Crlbl,strlen(Ccxa),strlen(Ccya),strlen(Cclabel));
  return Qnil;
}

static VALUE
dcl_usyaxl(self,Vcys)
    VALUE self,Vcys;
{
  MC_SetString(Ccys,Vcys);
  usyaxl_(Ccys,strlen(Ccys));
  return Qnil;
}

static VALUE
dcl_usyaxs(self,Vcside)
    VALUE self,Vcside;
{
  MC_SetString(Ccside,Vcside);
  usyaxs_(Ccside,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_usyaxu(self,Vcys)
    VALUE self,Vcys;
{
  MC_SetString(Ccys,Vcys);
  usyaxu_(Ccys,strlen(Ccys));
  return Qnil;
}

static VALUE
dcl_usyoff(self,Vcys)
    VALUE self,Vcys;
{
  MC_SetString(Ccys,Vcys);
  usyoff_(&Ccys);
  return Qnil;
}

static VALUE
dcl_usysub(self,Vcya,Vcxa,Vclabel,Vrlbl)
    VALUE self,Vcya,Vcxa,Vclabel,Vrlbl;
{
  MC_SetString(Ccya,Vcya);
  MC_SetString(Ccxa,Vcxa);
  MC_SetString(Cclabel,Vclabel);
  MC_SetFloat(Crlbl,Vrlbl);
  usysub_(Ccya,Ccxa,Cclabel,&Crlbl,strlen(Ccya),strlen(Ccxa),strlen(Cclabel));
  return Qnil;
}

static VALUE
dcl_uszdgt(self)
    VALUE self;
{
  uszdgt_();
  return Qnil;
}

static VALUE
dcl_uuinit(self)
    VALUE self;
{
  uuinit_();
  return Qnil;
}

static VALUE
dcl_uulin(self,Vn,Vupx,Vupy)
    VALUE self,Vn,Vupx,Vupy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  uulin_(&Cn,Cupx,Cupy);
  return Qnil;
}

static VALUE
dcl_uulinz(self,Vn,Vupx,Vupy,Vitype,Vindex)
    VALUE self,Vn,Vupx,Vupy,Vitype,Vindex;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  uulinz_(&Cn,Cupx,Cupy,&Citype,&Cindex);
  return Qnil;
}

static VALUE
dcl_uumrk(self,Vn,Vupx,Vupy)
    VALUE self,Vn,Vupx,Vupy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  uumrk_(&Cn,Cupx,Cupy);
  return Qnil;
}

static VALUE
dcl_uumrkz(self,Vn,Vupx,Vupy,Vitype,Vindex,Vrsize)
    VALUE self,Vn,Vupx,Vupy,Vitype,Vindex,Vrsize;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  MC_SetFloat(Crsize,Vrsize);
  uumrkz_(&Cn,Cupx,Cupy,&Citype,&Cindex,&Crsize);
  return Qnil;
}

static VALUE
dcl_uupget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  uupget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uuiget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  uuiget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uurget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  float Cipara;
  uurget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetFloat(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uulget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int    Cipara;
  uulget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetLogic(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uupset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  uupset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uuiset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  uuiset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uurset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  uurset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uulset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  uulset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uupstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  uupstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uuistx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  uuistx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uurstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  uurstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uulstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  uulstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uupqnp(self,Vncp)
    VALUE self,Vncp;
{
  int   Cncp;
  uupqnp_(&Cncp);
  MC_GetInt(Cncp,Vncp);
  return Qnil;
}

static VALUE
dcl_uupqid(self,Vcp,Vidx)
    VALUE self,Vcp,Vidx;
{
  MC_SetString(Ccp,Vcp);
  int   Cidx;
  uupqid_(Ccp,&Cidx,strlen(Ccp));
  MC_GetInt(Cidx,Vidx);
  return Qnil;
}

static VALUE
dcl_uupqcp(self,Vidx,Vcp)
    VALUE self,Vidx,Vcp;
{
  MC_SetInt(Cidx,Vidx);
  char * Ccp="                ";
  uupqcp_(&Cidx,Ccp,strlen(Ccp));
  MC_GetString(Ccp,Vcp);
  return Qnil;
}

static VALUE
dcl_uupqvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  int   Cipara;
  uupqvl_(&Cidx,&Cipara);
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uupsvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetInt(Cipara,Vipara);
  uupsvl_(&Cidx,&Cipara);
  return Qnil;
}

static VALUE
dcl_uusarp(self,Vitpt1,Vitpt2)
    VALUE self,Vitpt1,Vitpt2;
{
  MC_SetInt(Citpt1,Vitpt1);
  MC_SetInt(Citpt2,Vitpt2);
  uusarp_(&Citpt1,&Citpt2);
  return Qnil;
}

static VALUE
dcl_uuqarp(self,Vitpt1,Vitpt2)
    VALUE self,Vitpt1,Vitpt2;
{
  int   Citpt1;
  int   Citpt2;
  uuqarp_(&Citpt1,&Citpt2);
  MC_GetInt(Citpt1,Vitpt1);
  MC_GetInt(Citpt2,Vitpt2);
  return Qnil;
}

static VALUE
dcl_uusbrs(self,Vrsize)
    VALUE self,Vrsize;
{
  MC_SetFloat(Crsize,Vrsize);
  uusbrs_(&Crsize);
  return Qnil;
}

static VALUE
dcl_uuqbrs(self,Vrsize)
    VALUE self,Vrsize;
{
  float Crsize;
  uuqbrs_(&Crsize);
  MC_GetFloat(Crsize,Vrsize);
  return Qnil;
}

static VALUE
dcl_uusebt(self,Vitype)
    VALUE self,Vitype;
{
  MC_SetInt(Citype,Vitype);
  uusebt_(&Citype);
  return Qnil;
}

static VALUE
dcl_uuqebt(self,Vitype)
    VALUE self,Vitype;
{
  int   Citype;
  uuqebt_(&Citype);
  MC_GetInt(Citype,Vitype);
  return Qnil;
}

static VALUE
dcl_uusebi(self,Vindex)
    VALUE self,Vindex;
{
  MC_SetInt(Cindex,Vindex);
  uusebi_(&Cindex);
  return Qnil;
}

static VALUE
dcl_uuqebi(self,Vindex)
    VALUE self,Vindex;
{
  int   Cindex;
  uuqebi_(&Cindex);
  MC_GetInt(Cindex,Vindex);
  return Qnil;
}

static VALUE
dcl_uusebs(self,Vrsize)
    VALUE self,Vrsize;
{
  MC_SetFloat(Crsize,Vrsize);
  uusebs_(&Crsize);
  return Qnil;
}

static VALUE
dcl_uuqebs(self,Vrsize)
    VALUE self,Vrsize;
{
  float Crsize;
  uuqebs_(&Crsize);
  MC_GetFloat(Crsize,Vrsize);
  return Qnil;
}

static VALUE
dcl_uusfrt(self,Vitype)
    VALUE self,Vitype;
{
  MC_SetInt(Citype,Vitype);
  uusfrt_(&Citype);
  return Qnil;
}

static VALUE
dcl_uuqfrt(self,Vitype)
    VALUE self,Vitype;
{
  int   Citype;
  uuqfrt_(&Citype);
  MC_GetInt(Citype,Vitype);
  return Qnil;
}

static VALUE
dcl_uusfri(self,Vindex)
    VALUE self,Vindex;
{
  MC_SetInt(Cindex,Vindex);
  uusfri_(&Cindex);
  return Qnil;
}

static VALUE
dcl_uuqfri(self,Vindex)
    VALUE self,Vindex;
{
  int   Cindex;
  uuqfri_(&Cindex);
  MC_GetInt(Cindex,Vindex);
  return Qnil;
}

static VALUE
dcl_uusidv(self,Vumin,Vumax)
    VALUE self,Vumin,Vumax;
{
  MC_SetFloat(Cumin,Vumin);
  MC_SetFloat(Cumax,Vumax);
  uusidv_(&Cumin,&Cumax);
  return Qnil;
}

static VALUE
dcl_uuqidv(self,Vumin,Vumax)
    VALUE self,Vumin,Vumax;
{
  float Cumin;
  float Cumax;
  uuqidv_(&Cumin,&Cumax);
  MC_GetFloat(Cumin,Vumin);
  MC_GetFloat(Cumax,Vumax);
  return Qnil;
}

static VALUE
dcl_uuslnt(self,Vitype)
    VALUE self,Vitype;
{
  MC_SetInt(Citype,Vitype);
  uuslnt_(&Citype);
  return Qnil;
}

static VALUE
dcl_uuqlnt(self,Vitype)
    VALUE self,Vitype;
{
  int   Citype;
  uuqlnt_(&Citype);
  MC_GetInt(Citype,Vitype);
  return Qnil;
}

static VALUE
dcl_uuslni(self,Vindex)
    VALUE self,Vindex;
{
  MC_SetInt(Cindex,Vindex);
  uuslni_(&Cindex);
  return Qnil;
}

static VALUE
dcl_uuqlni(self,Vindex)
    VALUE self,Vindex;
{
  int   Cindex;
  uuqlni_(&Cindex);
  MC_GetInt(Cindex,Vindex);
  return Qnil;
}

static VALUE
dcl_uusmkt(self,Vitype)
    VALUE self,Vitype;
{
  MC_SetInt(Citype,Vitype);
  uusmkt_(&Citype);
  return Qnil;
}

static VALUE
dcl_uuqmkt(self,Vitype)
    VALUE self,Vitype;
{
  int   Citype;
  uuqmkt_(&Citype);
  MC_GetInt(Citype,Vitype);
  return Qnil;
}

static VALUE
dcl_uusmki(self,Vindex)
    VALUE self,Vindex;
{
  MC_SetInt(Cindex,Vindex);
  uusmki_(&Cindex);
  return Qnil;
}

static VALUE
dcl_uuqmki(self,Vindex)
    VALUE self,Vindex;
{
  int   Cindex;
  uuqmki_(&Cindex);
  MC_GetInt(Cindex,Vindex);
  return Qnil;
}

static VALUE
dcl_uusmks(self,Vrsize)
    VALUE self,Vrsize;
{
  MC_SetFloat(Crsize,Vrsize);
  uusmks_(&Crsize);
  return Qnil;
}

static VALUE
dcl_uuqmks(self,Vrsize)
    VALUE self,Vrsize;
{
  float Crsize;
  uuqmks_(&Crsize);
  MC_GetFloat(Crsize,Vrsize);
  return Qnil;
}

static VALUE
dcl_uvbra(self,Vn,Vupx,Vupy1,Vupy2)
    VALUE self,Vn,Vupx,Vupy1,Vupy2;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy1,Vupy1);
  MC_SetFloatArray(Cupy2,Vupy2);
  uvbra_(&Cn,Cupx,Cupy1,Cupy2);
  return Qnil;
}

static VALUE
dcl_uvbraz(self,Vn,Vupx,Vupy1,Vupy2,Vitpat1,Vitpat2,Vrsize)
    VALUE self,Vn,Vupx,Vupy1,Vupy2,Vitpat1,Vitpat2,Vrsize;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy1,Vupy1);
  MC_SetFloatArray(Cupy2,Vupy2);
  MC_SetInt(Citpat1,Vitpat1);
  MC_SetInt(Citpat2,Vitpat2);
  MC_SetFloat(Crsize,Vrsize);
  uvbraz_(&Cn,Cupx,Cupy1,Cupy2,&Citpat1,&Citpat2,&Crsize);
  return Qnil;
}

static VALUE
dcl_uvbrf(self,Vn,Vupx,Vupy1,Vupy2)
    VALUE self,Vn,Vupx,Vupy1,Vupy2;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy1,Vupy1);
  MC_SetFloatArray(Cupy2,Vupy2);
  uvbrf_(&Cn,Cupx,Cupy1,Cupy2);
  return Qnil;
}

static VALUE
dcl_uvbrfz(self,Vn,Vupx,Vupy1,Vupy2,Vitype,Vindex,Vrsize)
    VALUE self,Vn,Vupx,Vupy1,Vupy2,Vitype,Vindex,Vrsize;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy1,Vupy1);
  MC_SetFloatArray(Cupy2,Vupy2);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  MC_SetFloat(Crsize,Vrsize);
  uvbrfz_(&Cn,Cupx,Cupy1,Cupy2,&Citype,&Cindex,&Crsize);
  return Qnil;
}

static VALUE
dcl_uvbrl(self,Vn,Vupx,Vupy)
    VALUE self,Vn,Vupx,Vupy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  uvbrl_(&Cn,Cupx,Cupy);
  return Qnil;
}

static VALUE
dcl_uvbrlz(self,Vn,Vupx,Vupy,Vitype,Vindex,Vrsize)
    VALUE self,Vn,Vupx,Vupy,Vitype,Vindex,Vrsize;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  MC_SetFloat(Crsize,Vrsize);
  uvbrlz_(&Cn,Cupx,Cupy,&Citype,&Cindex,&Crsize);
  return Qnil;
}

static VALUE
dcl_uvbxa(self,Vn,Vupx,Vupy1,Vupy2)
    VALUE self,Vn,Vupx,Vupy1,Vupy2;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy1,Vupy1);
  MC_SetFloatArray(Cupy2,Vupy2);
  uvbxa_(&Cn,Cupx,Cupy1,Cupy2);
  return Qnil;
}

static VALUE
dcl_uvbxaz(self,Vn,Vupx,Vupy1,Vupy2,Vitpat1,Vitpat2)
    VALUE self,Vn,Vupx,Vupy1,Vupy2,Vitpat1,Vitpat2;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy1,Vupy1);
  MC_SetFloatArray(Cupy2,Vupy2);
  MC_SetInt(Citpat1,Vitpat1);
  MC_SetInt(Citpat2,Vitpat2);
  uvbxaz_(&Cn,Cupx,Cupy1,Cupy2,&Citpat1,&Citpat2);
  return Qnil;
}

static VALUE
dcl_uvbxf(self,Vn,Vupx,Vupy1,Vupy2)
    VALUE self,Vn,Vupx,Vupy1,Vupy2;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy1,Vupy1);
  MC_SetFloatArray(Cupy2,Vupy2);
  uvbxf_(&Cn,Cupx,Cupy1,Cupy2);
  return Qnil;
}

static VALUE
dcl_uvbxfz(self,Vn,Vupx,Vupy1,Vupy2,Vitype,Vindex)
    VALUE self,Vn,Vupx,Vupy1,Vupy2,Vitype,Vindex;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy1,Vupy1);
  MC_SetFloatArray(Cupy2,Vupy2);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  uvbxfz_(&Cn,Cupx,Cupy1,Cupy2,&Citype,&Cindex);
  return Qnil;
}

static VALUE
dcl_uvbxl(self,Vn,Vupx,Vupy)
    VALUE self,Vn,Vupx,Vupy;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  uvbxl_(&Cn,Cupx,Cupy);
  return Qnil;
}

static VALUE
dcl_uvbxlz(self,Vn,Vupx,Vupy,Vitype,Vindex)
    VALUE self,Vn,Vupx,Vupy,Vitype,Vindex;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy,Vupy);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  uvbxlz_(&Cn,Cupx,Cupy,&Citype,&Cindex);
  return Qnil;
}

static VALUE
dcl_uvdif(self,Vn,Vupx,Vupy1,Vupy2)
    VALUE self,Vn,Vupx,Vupy1,Vupy2;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy1,Vupy1);
  MC_SetFloatArray(Cupy2,Vupy2);
  uvdif_(&Cn,Cupx,Cupy1,Cupy2);
  return Qnil;
}

static VALUE
dcl_uvdifz(self,Vn,Vupx,Vupy1,Vupy2,Vitpat1,Vitpat2)
    VALUE self,Vn,Vupx,Vupy1,Vupy2,Vitpat1,Vitpat2;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy1,Vupy1);
  MC_SetFloatArray(Cupy2,Vupy2);
  MC_SetInt(Citpat1,Vitpat1);
  MC_SetInt(Citpat2,Vitpat2);
  uvdifz_(&Cn,Cupx,Cupy1,Cupy2,&Citpat1,&Citpat2);
  return Qnil;
}

static VALUE
dcl_uverb(self,Vn,Vupx,Vupy1,Vupy2)
    VALUE self,Vn,Vupx,Vupy1,Vupy2;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy1,Vupy1);
  MC_SetFloatArray(Cupy2,Vupy2);
  uverb_(&Cn,Cupx,Cupy1,Cupy2);
  return Qnil;
}

static VALUE
dcl_uverbz(self,Vn,Vupx,Vupy1,Vupy2,Vitype,Vindex,Vrsize)
    VALUE self,Vn,Vupx,Vupy1,Vupy2,Vitype,Vindex,Vrsize;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloatArray(Cupx,Vupx);
  MC_SetFloatArray(Cupy1,Vupy1);
  MC_SetFloatArray(Cupy2,Vupy2);
  MC_SetInt(Citype,Vitype);
  MC_SetInt(Cindex,Vindex);
  MC_SetFloat(Crsize,Vrsize);
  uverbz_(&Cn,Cupx,Cupy1,Cupy2,&Citype,&Cindex,&Crsize);
  return Qnil;
}

static VALUE
dcl_iuwgx(self,Vux)
    VALUE self,Vux;
{
  MC_SetFloat(Cux,Vux);
  int ret;
  int iuwgx_();
  ret = iuwgx_(&Cux);
  return MC_NewInt(ret);;
}

static VALUE
dcl_iuwgy(self,Vuy)
    VALUE self,Vuy;
{
  MC_SetFloat(Cuy,Vuy);
  int ret;
  int iuwgy_();
  ret = iuwgy_(&Cuy);
  return MC_NewInt(ret);;
}

static VALUE
dcl_ruwgx(self,Vix)
    VALUE self,Vix;
{
  MC_SetInt(Cix,Vix);
  float ret;
  float ruwgx_();
  ret = ruwgx_(&Cix);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_ruwgy(self,Viy)
    VALUE self,Viy;
{
  MC_SetInt(Ciy,Viy);
  float ret;
  float ruwgy_();
  ret = ruwgy_(&Ciy);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_uwdflt(self,Vnx,Vny)
    VALUE self,Vnx,Vny;
{
  MC_SetInt(Cnx,Vnx);
  MC_SetInt(Cny,Vny);
  uwdflt_(&Cnx,&Cny);
  return Qnil;
}

static VALUE
dcl_uwqgxi(self,Vux,Viux,Vfrac)
    VALUE self,Vux,Viux,Vfrac;
{
  MC_SetFloat(Cux,Vux);
  int   Ciux;
  float Cfrac;
  uwqgxi_(&Cux,&Ciux,&Cfrac);
  MC_GetInt(Ciux,Viux);
  MC_GetFloat(Cfrac,Vfrac);
  return Qnil;
}

static VALUE
dcl_uwigxi(self)
    VALUE self;
{
  uwigxi_();
  return Qnil;
}

static VALUE
dcl_uwqgyi(self,Vuy,Viuy,Vfrac)
    VALUE self,Vuy,Viuy,Vfrac;
{
  MC_SetFloat(Cuy,Vuy);
  int   Ciuy;
  float Cfrac;
  uwqgyi_(&Cuy,&Ciuy,&Cfrac);
  MC_GetInt(Ciuy,Viuy);
  MC_GetFloat(Cfrac,Vfrac);
  return Qnil;
}

static VALUE
dcl_uwigyi(self)
    VALUE self;
{
  uwigyi_();
  return Qnil;
}

static VALUE
dcl_uwsgxa(self,Vxp,Vnx)
    VALUE self,Vxp,Vnx;
{
  MC_SetFloatArray(Cxp,Vxp);
  MC_SetInt(Cnx,Vnx);
  uwsgxa_(Cxp,&Cnx);
  return Qnil;
}

static VALUE
dcl_uwqgxa(self,Vxp,Vnx)
    VALUE self,Vxp,Vnx;
{
  MC_SetFloatArray(Cxp,Vxp);
  int   Cnx;
  uwqgxa_(Cxp,&Cnx);
  MC_GetInt(Cnx,Vnx);
  return Qnil;
}

static VALUE
dcl_uwsgxb(self,Vuxmin,Vuxmax,Vnx)
    VALUE self,Vuxmin,Vuxmax,Vnx;
{
  MC_SetFloat(Cuxmin,Vuxmin);
  MC_SetFloat(Cuxmax,Vuxmax);
  MC_SetInt(Cnx,Vnx);
  uwsgxb_(&Cuxmin,&Cuxmax,&Cnx);
  return Qnil;
}

static VALUE
dcl_uwqgxb(self,Vuxmin,Vuxmax,Vnx)
    VALUE self,Vuxmin,Vuxmax,Vnx;
{
  float Cuxmin;
  float Cuxmax;
  int   Cnx;
  uwqgxb_(&Cuxmin,&Cuxmax,&Cnx);
  MC_GetFloat(Cuxmin,Vuxmin);
  MC_GetFloat(Cuxmax,Vuxmax);
  MC_GetInt(Cnx,Vnx);
  return Qnil;
}

static VALUE
dcl_uwsgxz(self,Vlsetx)
    VALUE self,Vlsetx;
{
  MC_SetLogic(Clsetx,Vlsetx);
  uwsgxz_(&Clsetx);
  return Qnil;
}

static VALUE
dcl_uwqgxz(self,Vlsetx)
    VALUE self,Vlsetx;
{
  int    Clsetx;
  uwqgxz_(&Clsetx);
  MC_GetLogic(Clsetx,Vlsetx);
  return Qnil;
}

static VALUE
dcl_uwsgya(self,Vyp,Vny)
    VALUE self,Vyp,Vny;
{
  MC_SetFloatArray(Cyp,Vyp);
  MC_SetInt(Cny,Vny);
  uwsgya_(Cyp,&Cny);
  return Qnil;
}

static VALUE
dcl_uwqgya(self,Vyp,Vny)
    VALUE self,Vyp,Vny;
{
  MC_SetFloatArray(Cyp,Vyp);
  int   Cny;
  uwqgya_(Cyp,&Cny);
  MC_GetInt(Cny,Vny);
  return Qnil;
}

static VALUE
dcl_uwsgyb(self,Vuymin,Vuymax,Vny)
    VALUE self,Vuymin,Vuymax,Vny;
{
  MC_SetFloat(Cuymin,Vuymin);
  MC_SetFloat(Cuymax,Vuymax);
  MC_SetInt(Cny,Vny);
  uwsgyb_(&Cuymin,&Cuymax,&Cny);
  return Qnil;
}

static VALUE
dcl_uwqgyb(self,Vuymin,Vuymax,Vny)
    VALUE self,Vuymin,Vuymax,Vny;
{
  float Cuymin;
  float Cuymax;
  int   Cny;
  uwqgyb_(&Cuymin,&Cuymax,&Cny);
  MC_GetFloat(Cuymin,Vuymin);
  MC_GetFloat(Cuymax,Vuymax);
  MC_GetInt(Cny,Vny);
  return Qnil;
}

static VALUE
dcl_uwsgyz(self,Vlsety)
    VALUE self,Vlsety;
{
  MC_SetLogic(Clsety,Vlsety);
  uwsgyz_(&Clsety);
  return Qnil;
}

static VALUE
dcl_uwqgyz(self,Vlsety)
    VALUE self,Vlsety;
{
  int    Clsety;
  uwqgyz_(&Clsety);
  MC_GetLogic(Clsety,Vlsety);
  return Qnil;
}

static VALUE
dcl_luxchk(self,Vcside)
    VALUE self,Vcside;
{
  MC_SetString(Ccside,Vcside);
  int ret;
  int luxchk_();
  ret = luxchk_(Ccside,strlen(Ccside));
  return MC_NewLogic(ret);;
}

static VALUE
dcl_uxaxdv(self,Vcside,Vdx1,Vdx2)
    VALUE self,Vcside,Vdx1,Vdx2;
{
  MC_SetString(Ccside,Vcside);
  MC_SetFloat(Cdx1,Vdx1);
  MC_SetFloat(Cdx2,Vdx2);
  uxaxdv_(Ccside,&Cdx1,&Cdx2,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_uxaxlb(self,Vcside,Vux1,Vn1,Vux2,Vch,Vnc,Vn2)
    VALUE self,Vcside,Vux1,Vn1,Vux2,Vch,Vnc,Vn2;
{
  MC_SetString(Ccside,Vcside);
  MC_SetFloatArray(Cux1,Vux1);
  MC_SetInt(Cn1,Vn1);
  MC_SetFloatArray(Cux2,Vux2);
  MC_SetString(Cch,Vch);
  MC_SetInt(Cnc,Vnc);
  MC_SetInt(Cn2,Vn2);
  uxaxlb_(Ccside,Cux1,&Cn1,Cux2,&Cch,&Cnc,&Cn2,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_uxaxnm(self,Vcside,Vux1,Vn1,Vux2,Vn2)
    VALUE self,Vcside,Vux1,Vn1,Vux2,Vn2;
{
  MC_SetString(Ccside,Vcside);
  MC_SetFloatArray(Cux1,Vux1);
  MC_SetInt(Cn1,Vn1);
  MC_SetFloatArray(Cux2,Vux2);
  MC_SetInt(Cn2,Vn2);
  uxaxnm_(Ccside,Cux1,&Cn1,Cux2,&Cn2,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_uxmttl(self,Vcside,Vcttl,Vpx)
    VALUE self,Vcside,Vcttl,Vpx;
{
  MC_SetString(Ccside,Vcside);
  MC_SetString(Ccttl,Vcttl);
  MC_SetFloat(Cpx,Vpx);
  uxmttl_(Ccside,Ccttl,&Cpx,strlen(Ccside),strlen(Ccttl));
  return Qnil;
}

static VALUE
dcl_uxpaxs(self,Vcside,Vislct)
    VALUE self,Vcside,Vislct;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cislct,Vislct);
  uxpaxs_(Ccside,&Cislct,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_uxplba(self,Vux,Vch,Vnc,Vn,Vupy,Vroffx,Vrsize,Virota,Vicent,Vindex)
    VALUE self,Vux,Vch,Vnc,Vn,Vupy,Vroffx,Vrsize,Virota,Vicent,Vindex;
{
  MC_SetFloatArray(Cux,Vux);
  MC_SetString(Cch,Vch);
  MC_SetInt(Cnc,Vnc);
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cupy,Vupy);
  MC_SetFloat(Croffx,Vroffx);
  MC_SetFloat(Crsize,Vrsize);
  MC_SetInt(Cirota,Virota);
  MC_SetInt(Cicent,Vicent);
  MC_SetInt(Cindex,Vindex);
  uxplba_(Cux,&Cch,&Cnc,&Cn,&Cupy,&Croffx,&Crsize,&Cirota,&Cicent,&Cindex);
  return Qnil;
}

static VALUE
dcl_uxplbb(self)
    VALUE self;
{
  uxplbb_();
  return Qnil;
}

static VALUE
dcl_uxplbl(self,Vcside,Vislct,Vux,Vch,Vnc,Vn)
    VALUE self,Vcside,Vislct,Vux,Vch,Vnc,Vn;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cislct,Vislct);
  MC_SetFloatArray(Cux,Vux);
  MC_SetString(Cch,Vch);
  MC_SetInt(Cnc,Vnc);
  MC_SetInt(Cn,Vn);
  uxplbl_(Ccside,&Cislct,Cux,&Cch,&Cnc,&Cn,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_uxpnum(self,Vcside,Vislct,Vux,Vn)
    VALUE self,Vcside,Vislct,Vux,Vn;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cislct,Vislct);
  MC_SetFloatArray(Cux,Vux);
  MC_SetInt(Cn,Vn);
  uxpnum_(Ccside,&Cislct,Cux,&Cn,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_uxsfmt(self,Vcfmt)
    VALUE self,Vcfmt;
{
  MC_SetString(Ccfmt,Vcfmt);
  uxsfmt_(Ccfmt,strlen(Ccfmt));
  return Qnil;
}

static VALUE
dcl_uxqfmt(self,Vcfmt)
    VALUE self,Vcfmt;
{
  char * Ccfmt="                ";
  uxqfmt_(Ccfmt,strlen(Ccfmt));
  MC_GetString(Ccfmt,Vcfmt);
  return Qnil;
}

static VALUE
dcl_uxptmk(self,Vcside,Vislct,Vux,Vn)
    VALUE self,Vcside,Vislct,Vux,Vn;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cislct,Vislct);
  MC_SetFloatArray(Cux,Vux);
  MC_SetInt(Cn,Vn);
  uxptmk_(Ccside,&Cislct,Cux,&Cn,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_uxptmz(self,Vux,Vn,Vupy,Vroffx,Vrtick,Vindex)
    VALUE self,Vux,Vn,Vupy,Vroffx,Vrtick,Vindex;
{
  MC_SetFloatArray(Cux,Vux);
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cupy,Vupy);
  MC_SetFloat(Croffx,Vroffx);
  MC_SetFloat(Crtick,Vrtick);
  MC_SetInt(Cindex,Vindex);
  uxptmz_(Cux,&Cn,&Cupy,&Croffx,&Crtick,&Cindex);
  return Qnil;
}

static VALUE
dcl_uxpttl(self,Vcside,Vislct,Vcttl,Vpx)
    VALUE self,Vcside,Vislct,Vcttl,Vpx;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cislct,Vislct);
  MC_SetString(Ccttl,Vcttl);
  MC_SetFloat(Cpx,Vpx);
  uxpttl_(Ccside,&Cislct,Ccttl,&Cpx,strlen(Ccside),strlen(Ccttl));
  return Qnil;
}

static VALUE
dcl_uxsaxs(self,Vcside)
    VALUE self,Vcside;
{
  MC_SetString(Ccside,Vcside);
  uxsaxs_(Ccside,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_uxsaxz(self,Vcside,Vroffx)
    VALUE self,Vcside,Vroffx;
{
  MC_SetString(Ccside,Vcside);
  MC_SetFloat(Croffx,Vroffx);
  uxsaxz_(Ccside,&Croffx,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_uxsoff(self)
    VALUE self;
{
  uxsoff_();
  return Qnil;
}

static VALUE
dcl_uxroff(self)
    VALUE self;
{
  uxroff_();
  return Qnil;
}

static VALUE
dcl_uxsttl(self,Vcside,Vcttl,Vpx)
    VALUE self,Vcside,Vcttl,Vpx;
{
  MC_SetString(Ccside,Vcside);
  MC_SetString(Ccttl,Vcttl);
  MC_SetFloat(Cpx,Vpx);
  uxsttl_(Ccside,Ccttl,&Cpx,strlen(Ccside),strlen(Ccttl));
  return Qnil;
}

static VALUE
dcl_luychk(self,Vcside)
    VALUE self,Vcside;
{
  MC_SetString(Ccside,Vcside);
  int ret;
  int luychk_();
  ret = luychk_(Ccside,strlen(Ccside));
  return MC_NewLogic(ret);;
}

static VALUE
dcl_uyaxdv(self,Vcside,Vdy1,Vdy2)
    VALUE self,Vcside,Vdy1,Vdy2;
{
  MC_SetString(Ccside,Vcside);
  MC_SetFloat(Cdy1,Vdy1);
  MC_SetFloat(Cdy2,Vdy2);
  uyaxdv_(Ccside,&Cdy1,&Cdy2,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_uyaxlb(self,Vcside,Vuy1,Vn1,Vuy2,Vch,Vnc,Vn2)
    VALUE self,Vcside,Vuy1,Vn1,Vuy2,Vch,Vnc,Vn2;
{
  MC_SetString(Ccside,Vcside);
  MC_SetFloatArray(Cuy1,Vuy1);
  MC_SetInt(Cn1,Vn1);
  MC_SetFloatArray(Cuy2,Vuy2);
  MC_SetString(Cch,Vch);
  MC_SetInt(Cnc,Vnc);
  MC_SetInt(Cn2,Vn2);
  uyaxlb_(Ccside,Cuy1,&Cn1,Cuy2,&Cch,&Cnc,&Cn2,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_uyaxnm(self,Vcside,Vuy1,Vn1,Vuy2,Vn2)
    VALUE self,Vcside,Vuy1,Vn1,Vuy2,Vn2;
{
  MC_SetString(Ccside,Vcside);
  MC_SetFloatArray(Cuy1,Vuy1);
  MC_SetInt(Cn1,Vn1);
  MC_SetFloatArray(Cuy2,Vuy2);
  MC_SetInt(Cn2,Vn2);
  uyaxnm_(Ccside,Cuy1,&Cn1,Cuy2,&Cn2,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_uymttl(self,Vcside,Vcttl,Vpx)
    VALUE self,Vcside,Vcttl,Vpx;
{
  MC_SetString(Ccside,Vcside);
  MC_SetString(Ccttl,Vcttl);
  MC_SetFloat(Cpx,Vpx);
  uymttl_(Ccside,Ccttl,&Cpx,strlen(Ccside),strlen(Ccttl));
  return Qnil;
}

static VALUE
dcl_uypaxs(self,Vcside,Vislct)
    VALUE self,Vcside,Vislct;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cislct,Vislct);
  uypaxs_(Ccside,&Cislct,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_uyplba(self,Vuy,Vch,Vnc,Vn,Vupx,Vroffy,Vrsize,Virota,Vicent,Vindex)
    VALUE self,Vuy,Vch,Vnc,Vn,Vupx,Vroffy,Vrsize,Virota,Vicent,Vindex;
{
  MC_SetFloatArray(Cuy,Vuy);
  MC_SetString(Cch,Vch);
  MC_SetInt(Cnc,Vnc);
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cupx,Vupx);
  MC_SetFloat(Croffy,Vroffy);
  MC_SetFloat(Crsize,Vrsize);
  MC_SetInt(Cirota,Virota);
  MC_SetInt(Cicent,Vicent);
  MC_SetInt(Cindex,Vindex);
  uyplba_(Cuy,&Cch,&Cnc,&Cn,&Cupx,&Croffy,&Crsize,&Cirota,&Cicent,&Cindex);
  return Qnil;
}

static VALUE
dcl_uyplbb(self)
    VALUE self;
{
  uyplbb_();
  return Qnil;
}

static VALUE
dcl_uyplbl(self,Vcside,Vislct,Vuy,Vch,Vnc,Vn)
    VALUE self,Vcside,Vislct,Vuy,Vch,Vnc,Vn;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cislct,Vislct);
  MC_SetFloatArray(Cuy,Vuy);
  MC_SetString(Cch,Vch);
  MC_SetInt(Cnc,Vnc);
  MC_SetInt(Cn,Vn);
  uyplbl_(Ccside,&Cislct,Cuy,&Cch,&Cnc,&Cn,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_uypnum(self,Vcside,Vislct,Vuy,Vn)
    VALUE self,Vcside,Vislct,Vuy,Vn;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cislct,Vislct);
  MC_SetFloatArray(Cuy,Vuy);
  MC_SetInt(Cn,Vn);
  uypnum_(Ccside,&Cislct,Cuy,&Cn,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_uysfmt(self,Vcfmt)
    VALUE self,Vcfmt;
{
  MC_SetString(Ccfmt,Vcfmt);
  uysfmt_(Ccfmt,strlen(Ccfmt));
  return Qnil;
}

static VALUE
dcl_uyqfmt(self,Vcfmt)
    VALUE self,Vcfmt;
{
  char * Ccfmt="                ";
  uyqfmt_(Ccfmt,strlen(Ccfmt));
  MC_GetString(Ccfmt,Vcfmt);
  return Qnil;
}

static VALUE
dcl_uyptmk(self,Vcside,Vislct,Vuy,Vn)
    VALUE self,Vcside,Vislct,Vuy,Vn;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cislct,Vislct);
  MC_SetFloatArray(Cuy,Vuy);
  MC_SetInt(Cn,Vn);
  uyptmk_(Ccside,&Cislct,Cuy,&Cn,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_uyptmz(self,Vuy,Vn,Vupx,Vroffy,Vrtick,Vindex)
    VALUE self,Vuy,Vn,Vupx,Vroffy,Vrtick,Vindex;
{
  MC_SetFloatArray(Cuy,Vuy);
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cupx,Vupx);
  MC_SetFloat(Croffy,Vroffy);
  MC_SetFloat(Crtick,Vrtick);
  MC_SetInt(Cindex,Vindex);
  uyptmz_(Cuy,&Cn,&Cupx,&Croffy,&Crtick,&Cindex);
  return Qnil;
}

static VALUE
dcl_uypttl(self,Vcside,Vislct,Vcttl,Vpx)
    VALUE self,Vcside,Vislct,Vcttl,Vpx;
{
  MC_SetString(Ccside,Vcside);
  MC_SetInt(Cislct,Vislct);
  MC_SetString(Ccttl,Vcttl);
  MC_SetFloat(Cpx,Vpx);
  uypttl_(Ccside,&Cislct,Ccttl,&Cpx,strlen(Ccside),strlen(Ccttl));
  return Qnil;
}

static VALUE
dcl_uysaxs(self,Vcside)
    VALUE self,Vcside;
{
  MC_SetString(Ccside,Vcside);
  uysaxs_(Ccside,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_uysaxz(self,Vcside,Vroffy)
    VALUE self,Vcside,Vroffy;
{
  MC_SetString(Ccside,Vcside);
  MC_SetFloat(Croffy,Vroffy);
  uysaxz_(Ccside,&Croffy,strlen(Ccside));
  return Qnil;
}

static VALUE
dcl_uysoff(self)
    VALUE self;
{
  uysoff_();
  return Qnil;
}

static VALUE
dcl_uyroff(self)
    VALUE self;
{
  uyroff_();
  return Qnil;
}

static VALUE
dcl_uysttl(self,Vcside,Vcttl,Vpx)
    VALUE self,Vcside,Vcttl,Vpx;
{
  MC_SetString(Ccside,Vcside);
  MC_SetString(Ccttl,Vcttl);
  MC_SetFloat(Cpx,Vpx);
  uysttl_(Ccside,Ccttl,&Cpx,strlen(Ccside),strlen(Ccttl));
  return Qnil;
}

static VALUE
dcl_uzfact(self,Vrfact)
    VALUE self,Vrfact;
{
  MC_SetFloat(Crfact,Vrfact);
  uzfact_(&Crfact);
  return Qnil;
}

static VALUE
dcl_uzinit(self)
    VALUE self;
{
  uzinit_();
  return Qnil;
}

static VALUE
dcl_uzpget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  uzpget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uziget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  uziget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uzrget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  float Cipara;
  uzrget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetFloat(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uzlget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int    Cipara;
  uzlget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetLogic(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uzpset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  uzpset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uziset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  uziset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uzrset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  uzrset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uzlset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  uzlset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uzpstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  uzpstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uzistx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  uzistx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uzrstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  uzrstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uzlstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  uzlstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_uzpqnp(self,Vncp)
    VALUE self,Vncp;
{
  int   Cncp;
  uzpqnp_(&Cncp);
  MC_GetInt(Cncp,Vncp);
  return Qnil;
}

static VALUE
dcl_uzpqid(self,Vcp,Vidx)
    VALUE self,Vcp,Vidx;
{
  MC_SetString(Ccp,Vcp);
  int   Cidx;
  uzpqid_(Ccp,&Cidx,strlen(Ccp));
  MC_GetInt(Cidx,Vidx);
  return Qnil;
}

static VALUE
dcl_uzpqcp(self,Vidx,Vcp)
    VALUE self,Vidx,Vcp;
{
  MC_SetInt(Cidx,Vidx);
  char * Ccp="                ";
  uzpqcp_(&Cidx,Ccp,strlen(Ccp));
  MC_GetString(Ccp,Vcp);
  return Qnil;
}

static VALUE
dcl_uzpqvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  int   Cipara;
  uzpqvl_(&Cidx,&Cipara);
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_uzpsvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetInt(Cipara,Vipara);
  uzpsvl_(&Cidx,&Cipara);
  return Qnil;
}

static VALUE
dcl_uzpsav(self)
    VALUE self;
{
  uzpsav_();
  return Qnil;
}

static VALUE
dcl_uzprst(self)
    VALUE self;
{
  uzprst_();
  return Qnil;
}

static VALUE
dcl_iblkge(self,Vrx,Vn,Vrr)
    VALUE self,Vrx,Vn,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Crr,Vrr);
  int ret;
  int iblkge_();
  ret = iblkge_(Crx,&Cn,&Crr);
  return MC_NewInt(ret);;
}

static VALUE
dcl_iblkgt(self,Vrx,Vn,Vrr)
    VALUE self,Vrx,Vn,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Crr,Vrr);
  int ret;
  int iblkgt_();
  ret = iblkgt_(Crx,&Cn,&Crr);
  return MC_NewInt(ret);;
}

static VALUE
dcl_iblkle(self,Vrx,Vn,Vrr)
    VALUE self,Vrx,Vn,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Crr,Vrr);
  int ret;
  int iblkle_();
  ret = iblkle_(Crx,&Cn,&Crr);
  return MC_NewInt(ret);;
}

static VALUE
dcl_iblklt(self,Vrx,Vn,Vrr)
    VALUE self,Vrx,Vn,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Crr,Vrr);
  int ret;
  int iblklt_();
  ret = iblklt_(Crx,&Cn,&Crr);
  return MC_NewInt(ret);;
}

static VALUE
dcl_cladj(self,Vchr)
    VALUE self,Vchr;
{
  char * Cchr="                ";
  cladj_(Cchr,strlen(Cchr));
  MC_GetString(Cchr,Vchr);
  return Qnil;
}

static VALUE
dcl_cradj(self,Vchr)
    VALUE self,Vchr;
{
  char * Cchr="                ";
  cradj_(Cchr,strlen(Cchr));
  MC_GetString(Cchr,Vchr);
  return Qnil;
}

static VALUE
dcl_crvrs(self,Vchr)
    VALUE self,Vchr;
{
  char * Cchr="                ";
  crvrs_(Cchr,strlen(Cchr));
  MC_GetString(Cchr,Vchr);
  return Qnil;
}

static VALUE
dcl_lenb(self,Vc)
    VALUE self,Vc;
{
  MC_SetString(Cc,Vc);
  int ret;
  int lenb_();
  ret = lenb_(Cc,strlen(Cc));
  return MC_NewInt(ret);;
}

static VALUE
dcl_lenc(self,Vc)
    VALUE self,Vc;
{
  MC_SetString(Cc,Vc);
  int ret;
  int lenc_();
  ret = lenc_(Cc,strlen(Cc));
  return MC_NewInt(ret);;
}

static VALUE
dcl_leny(self,Vc)
    VALUE self,Vc;
{
  MC_SetString(Cc,Vc);
  int ret;
  int leny_();
  ret = leny_(Cc,strlen(Cc));
  return MC_NewInt(ret);;
}

static VALUE
dcl_lenz(self,Vc)
    VALUE self,Vc;
{
  MC_SetString(Cc,Vc);
  int ret;
  int lenz_();
  ret = lenz_(Cc,strlen(Cc));
  return MC_NewInt(ret);;
}

static VALUE
dcl_cr2c(self,Vtheta,Vx0,Vy0,Vx1,Vy1)
    VALUE self,Vtheta,Vx0,Vy0,Vx1,Vy1;
{
  MC_SetFloat(Ctheta,Vtheta);
  MC_SetFloat(Cx0,Vx0);
  MC_SetFloat(Cy0,Vy0);
  float Cx1;
  MC_SetFloat(Cy1,Vy1);
  cr2c_(&Ctheta,&Cx0,&Cy0,&Cx1,&Cy1);
  MC_GetFloat(Cx1,Vx1);
  return Qnil;
}

static VALUE
dcl_cr3c(self,Vtheta,Vphi,Vpsi,Vx0,Vy0,Vz0,Vx1,Vy1,Vz1)
    VALUE self,Vtheta,Vphi,Vpsi,Vx0,Vy0,Vz0,Vx1,Vy1,Vz1;
{
  MC_SetFloat(Ctheta,Vtheta);
  MC_SetFloat(Cphi,Vphi);
  MC_SetFloat(Cpsi,Vpsi);
  MC_SetFloat(Cx0,Vx0);
  MC_SetFloat(Cy0,Vy0);
  MC_SetFloat(Cz0,Vz0);
  MC_SetFloat(Cx1,Vx1);
  MC_SetFloat(Cy1,Vy1);
  MC_SetFloat(Cz1,Vz1);
  cr3c_(&Ctheta,&Cphi,&Cpsi,&Cx0,&Cy0,&Cz0,&Cx1,&Cy1,&Cz1);
  return Qnil;
}

static VALUE
dcl_cr3s(self,Vtheta,Vphi,Vpsi,Vtheta0,Vphi0,Vtheta1,Vphi1)
    VALUE self,Vtheta,Vphi,Vpsi,Vtheta0,Vphi0,Vtheta1,Vphi1;
{
  MC_SetFloat(Ctheta,Vtheta);
  MC_SetFloat(Cphi,Vphi);
  MC_SetFloat(Cpsi,Vpsi);
  MC_SetFloat(Ctheta0,Vtheta0);
  MC_SetFloat(Cphi0,Vphi0);
  float Ctheta1;
  float Cphi1;
  cr3s_(&Ctheta,&Cphi,&Cpsi,&Ctheta0,&Cphi0,&Ctheta1,&Cphi1);
  MC_GetFloat(Ctheta1,Vtheta1);
  MC_GetFloat(Cphi1,Vphi1);
  return Qnil;
}

static VALUE
dcl_ct2bc(self,Vu,Vv,Vx,Vy)
    VALUE self,Vu,Vv,Vx,Vy;
{
  MC_SetFloat(Cu,Vu);
  MC_SetFloat(Cv,Vv);
  float Cx;
  float Cy;
  ct2bc_(&Cu,&Cv,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  return Qnil;
}

static VALUE
dcl_ct2ch(self,Vx,Vy,Vu,Vv)
    VALUE self,Vx,Vy,Vu,Vv;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  float Cu;
  MC_SetFloat(Cv,Vv);
  ct2ch_(&Cx,&Cy,&Cu,&Cv);
  MC_GetFloat(Cu,Vu);
  return Qnil;
}

static VALUE
dcl_ct2cp(self,Vx,Vy,Vr,Vtheta)
    VALUE self,Vx,Vy,Vr,Vtheta;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  float Cr;
  MC_SetFloat(Ctheta,Vtheta);
  ct2cp_(&Cx,&Cy,&Cr,&Ctheta);
  MC_GetFloat(Cr,Vr);
  return Qnil;
}

static VALUE
dcl_ct2ec(self,Vu,Vv,Vx,Vy)
    VALUE self,Vu,Vv,Vx,Vy;
{
  MC_SetFloat(Cu,Vu);
  MC_SetFloat(Cv,Vv);
  float Cx;
  MC_SetFloat(Cy,Vy);
  ct2ec_(&Cu,&Cv,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  return Qnil;
}

static VALUE
dcl_ct2hc(self,Vu,Vv,Vx,Vy)
    VALUE self,Vu,Vv,Vx,Vy;
{
  MC_SetFloat(Cu,Vu);
  MC_SetFloat(Cv,Vv);
  float Cx;
  MC_SetFloat(Cy,Vy);
  ct2hc_(&Cu,&Cv,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  return Qnil;
}

static VALUE
dcl_ct2pc(self,Vr,Vtheta,Vx,Vy)
    VALUE self,Vr,Vtheta,Vx,Vy;
{
  MC_SetFloat(Cr,Vr);
  MC_SetFloat(Ctheta,Vtheta);
  float Cx;
  MC_SetFloat(Cy,Vy);
  ct2pc_(&Cr,&Ctheta,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  return Qnil;
}

static VALUE
dcl_ct3cs(self,Vx,Vy,Vz,Vr,Vtheta,Vphi)
    VALUE self,Vx,Vy,Vz,Vr,Vtheta,Vphi;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  MC_SetFloat(Cz,Vz);
  float Cr;
  MC_SetFloat(Ctheta,Vtheta);
  float Cphi;
  ct3cs_(&Cx,&Cy,&Cz,&Cr,&Ctheta,&Cphi);
  MC_GetFloat(Cr,Vr);
  MC_GetFloat(Cphi,Vphi);
  return Qnil;
}

static VALUE
dcl_ct3sc(self,Vr,Vtheta,Vphi,Vx,Vy,Vz)
    VALUE self,Vr,Vtheta,Vphi,Vx,Vy,Vz;
{
  MC_SetFloat(Cr,Vr);
  MC_SetFloat(Ctheta,Vtheta);
  MC_SetFloat(Cphi,Vphi);
  float Cx;
  float Cy;
  MC_SetFloat(Cz,Vz);
  ct3sc_(&Cr,&Ctheta,&Cphi,&Cx,&Cy,&Cz);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  return Qnil;
}

static VALUE
dcl_igus(self,Vrx)
    VALUE self,Vrx;
{
  MC_SetFloat(Crx,Vrx);
  int ret;
  int igus_();
  ret = igus_(&Crx);
  return MC_NewInt(ret);;
}

static VALUE
dcl_imod(self,Vix,Vid)
    VALUE self,Vix,Vid;
{
  MC_SetInt(Cix,Vix);
  MC_SetInt(Cid,Vid);
  int ret;
  int imod_();
  ret = imod_(&Cix,&Cid);
  return MC_NewInt(ret);;
}

static VALUE
dcl_rd2r(self,Vx)
    VALUE self,Vx;
{
  MC_SetFloat(Cx,Vx);
  float ret;
  float rd2r_();
  ret = rd2r_(&Cx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rexp(self,Vrx,Vib,Vie)
    VALUE self,Vrx,Vib,Vie;
{
  MC_SetFloat(Crx,Vrx);
  MC_SetInt(Cib,Vib);
  MC_SetInt(Cie,Vie);
  float ret;
  float rexp_();
  ret = rexp_(&Crx,&Cib,&Cie);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rfpi(self,V)
    VALUE self,V;
{
  float ret;
  float rfpi_();
  ret = rfpi_();
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rmod(self,Vrx,Vrd)
    VALUE self,Vrx,Vrd;
{
  MC_SetFloat(Crx,Vrx);
  MC_SetFloat(Crd,Vrd);
  float ret;
  float rmod_();
  ret = rmod_(&Crx,&Crd);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rr2d(self,Vx)
    VALUE self,Vx;
{
  MC_SetFloat(Cx,Vx);
  float ret;
  float rr2d_();
  ret = rr2d_(&Cx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_gnsave(self)
    VALUE self;
{
  gnsave_();
  return Qnil;
}

static VALUE
dcl_gnrset(self)
    VALUE self;
{
  gnrset_();
  return Qnil;
}

static VALUE
dcl_gnsblk(self,Vxb,Vnb)
    VALUE self,Vxb,Vnb;
{
  MC_SetFloatArray(Cxb,Vxb);
  MC_SetInt(Cnb,Vnb);
  gnsblk_(Cxb,&Cnb);
  return Qnil;
}

static VALUE
dcl_gnqblk(self,Vxb,Vnb)
    VALUE self,Vxb,Vnb;
{
  MC_SetFloatArray(Cxb,Vxb);
  int   Cnb;
  gnqblk_(Cxb,&Cnb);
  MC_GetInt(Cnb,Vnb);
  return Qnil;
}

static VALUE
dcl_gnlt(self,Vrx,Vbx,Vip)
    VALUE self,Vrx,Vbx,Vip;
{
  MC_SetFloat(Crx,Vrx);
  float Cbx;
  int   Cip;
  gnlt_(&Crx,&Cbx,&Cip);
  MC_GetFloat(Cbx,Vbx);
  MC_GetInt(Cip,Vip);
  return Qnil;
}

static VALUE
dcl_gnle(self,Vrx,Vbx,Vip)
    VALUE self,Vrx,Vbx,Vip;
{
  MC_SetFloat(Crx,Vrx);
  float Cbx;
  int   Cip;
  gnle_(&Crx,&Cbx,&Cip);
  MC_GetFloat(Cbx,Vbx);
  MC_GetInt(Cip,Vip);
  return Qnil;
}

static VALUE
dcl_gngt(self,Vrx,Vbx,Vip)
    VALUE self,Vrx,Vbx,Vip;
{
  MC_SetFloat(Crx,Vrx);
  float Cbx;
  int   Cip;
  gngt_(&Crx,&Cbx,&Cip);
  MC_GetFloat(Cbx,Vbx);
  MC_GetInt(Cip,Vip);
  return Qnil;
}

static VALUE
dcl_gnge(self,Vrx,Vbx,Vip)
    VALUE self,Vrx,Vbx,Vip;
{
  MC_SetFloat(Crx,Vrx);
  float Cbx;
  int   Cip;
  gnge_(&Crx,&Cbx,&Cip);
  MC_GetFloat(Cbx,Vbx);
  MC_GetInt(Cip,Vip);
  return Qnil;
}

static VALUE
dcl_rgnge(self,Vrx)
    VALUE self,Vrx;
{
  MC_SetFloat(Crx,Vrx);
  float ret;
  float rgnge_();
  ret = rgnge_(&Crx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rgngt(self,Vrx)
    VALUE self,Vrx;
{
  MC_SetFloat(Crx,Vrx);
  float ret;
  float rgngt_();
  ret = rgngt_(&Crx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rgnle(self,Vrx)
    VALUE self,Vrx;
{
  MC_SetFloat(Crx,Vrx);
  float ret;
  float rgnle_();
  ret = rgnle_(&Crx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rgnlt(self,Vrx)
    VALUE self,Vrx;
{
  MC_SetFloat(Crx,Vrx);
  float ret;
  float rgnlt_();
  ret = rgnlt_(&Crx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_imax(self,Vix,Vn,Vjx)
    VALUE self,Vix,Vn,Vjx;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  int ret;
  int imax_();
  ret = imax_(Cix,&Cn,&Cjx);
  return MC_NewInt(ret);;
}

static VALUE
dcl_imax0(self,Vix,Vn,Vjx)
    VALUE self,Vix,Vn,Vjx;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  int ret;
  int imax0_();
  ret = imax0_(Cix,&Cn,&Cjx);
  return MC_NewInt(ret);;
}

static VALUE
dcl_imax1(self,Vix,Vn,Vjx)
    VALUE self,Vix,Vn,Vjx;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  int ret;
  int imax1_();
  ret = imax1_(Cix,&Cn,&Cjx);
  return MC_NewInt(ret);;
}

static VALUE
dcl_imin(self,Vix,Vn,Vjx)
    VALUE self,Vix,Vn,Vjx;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  int ret;
  int imin_();
  ret = imin_(Cix,&Cn,&Cjx);
  return MC_NewInt(ret);;
}

static VALUE
dcl_imin0(self,Vix,Vn,Vjx)
    VALUE self,Vix,Vn,Vjx;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  int ret;
  int imin0_();
  ret = imin0_(Cix,&Cn,&Cjx);
  return MC_NewInt(ret);;
}

static VALUE
dcl_imin1(self,Vix,Vn,Vjx)
    VALUE self,Vix,Vn,Vjx;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  int ret;
  int imin1_();
  ret = imin1_(Cix,&Cn,&Cjx);
  return MC_NewInt(ret);;
}

static VALUE
dcl_isum(self,Vix,Vn,Vjx)
    VALUE self,Vix,Vn,Vjx;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  int ret;
  int isum_();
  ret = isum_(Cix,&Cn,&Cjx);
  return MC_NewInt(ret);;
}

static VALUE
dcl_isum0(self,Vix,Vn,Vjx)
    VALUE self,Vix,Vn,Vjx;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  int ret;
  int isum0_();
  ret = isum0_(Cix,&Cn,&Cjx);
  return MC_NewInt(ret);;
}

static VALUE
dcl_isum1(self,Vix,Vn,Vjx)
    VALUE self,Vix,Vn,Vjx;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  int ret;
  int isum1_();
  ret = isum1_(Cix,&Cn,&Cjx);
  return MC_NewInt(ret);;
}

static VALUE
dcl_indxcf(self,Vcx,Vn,Vjd,Vch)
    VALUE self,Vcx,Vn,Vjd,Vch;
{
  MC_SetString(Ccx,Vcx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjd,Vjd);
  MC_SetString(Cch,Vch);
  int ret;
  int indxcf_();
  ret = indxcf_(&Ccx,&Cn,&Cjd,Cch,strlen(Cch));
  return MC_NewInt(ret);;
}

static VALUE
dcl_indxcl(self,Vcx,Vn,Vjd,Vch)
    VALUE self,Vcx,Vn,Vjd,Vch;
{
  MC_SetString(Ccx,Vcx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjd,Vjd);
  MC_SetString(Cch,Vch);
  int ret;
  int indxcl_();
  ret = indxcl_(&Ccx,&Cn,&Cjd,Cch,strlen(Cch));
  return MC_NewInt(ret);;
}

static VALUE
dcl_indxif(self,Vix,Vn,Vjd,Vii)
    VALUE self,Vix,Vn,Vjd,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjd,Vjd);
  MC_SetInt(Cii,Vii);
  int ret;
  int indxif_();
  ret = indxif_(Cix,&Cn,&Cjd,&Cii);
  return MC_NewInt(ret);;
}

static VALUE
dcl_indxil(self,Vix,Vn,Vjd,Vii)
    VALUE self,Vix,Vn,Vjd,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjd,Vjd);
  MC_SetInt(Cii,Vii);
  int ret;
  int indxil_();
  ret = indxil_(Cix,&Cn,&Cjd,&Cii);
  return MC_NewInt(ret);;
}

static VALUE
dcl_indxmf(self,Vcx,Vn,Vjd,Vch)
    VALUE self,Vcx,Vn,Vjd,Vch;
{
  MC_SetString(Ccx,Vcx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjd,Vjd);
  MC_SetString(Cch,Vch);
  int ret;
  int indxmf_();
  ret = indxmf_(Ccx,&Cn,&Cjd,Cch,strlen(Ccx),strlen(Cch));
  return MC_NewInt(ret);;
}

static VALUE
dcl_indxml(self,Vcx,Vn,Vjd,Vch)
    VALUE self,Vcx,Vn,Vjd,Vch;
{
  MC_SetString(Ccx,Vcx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjd,Vjd);
  MC_SetString(Cch,Vch);
  int ret;
  int indxml_();
  ret = indxml_(Ccx,&Cn,&Cjd,Cch,strlen(Ccx),strlen(Cch));
  return MC_NewInt(ret);;
}

static VALUE
dcl_indxnf(self,Vcx,Vn,Vjd,Vch)
    VALUE self,Vcx,Vn,Vjd,Vch;
{
  MC_SetString(Ccx,Vcx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjd,Vjd);
  MC_SetString(Cch,Vch);
  int ret;
  int indxnf_();
  ret = indxnf_(Ccx,&Cn,&Cjd,Cch,strlen(Ccx),strlen(Cch));
  return MC_NewInt(ret);;
}

static VALUE
dcl_indxnl(self,Vcx,Vn,Vjd,Vch)
    VALUE self,Vcx,Vn,Vjd,Vch;
{
  MC_SetString(Ccx,Vcx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjd,Vjd);
  MC_SetString(Cch,Vch);
  int ret;
  int indxnl_();
  ret = indxnl_(Ccx,&Cn,&Cjd,Cch,strlen(Ccx),strlen(Cch));
  return MC_NewInt(ret);;
}

static VALUE
dcl_indxrf(self,Vrx,Vn,Vjd,Vrr)
    VALUE self,Vrx,Vn,Vjd,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjd,Vjd);
  MC_SetFloat(Crr,Vrr);
  int ret;
  int indxrf_();
  ret = indxrf_(Crx,&Cn,&Cjd,&Crr);
  return MC_NewInt(ret);;
}

static VALUE
dcl_indxrl(self,Vrx,Vn,Vjd,Vrr)
    VALUE self,Vrx,Vn,Vjd,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjd,Vjd);
  MC_SetFloat(Crr,Vrr);
  int ret;
  int indxrl_();
  ret = indxrl_(Crx,&Cn,&Cjd,&Crr);
  return MC_NewInt(ret);;
}

static VALUE
dcl_nindxc(self,Vcx,Vn,Vjd,Vch)
    VALUE self,Vcx,Vn,Vjd,Vch;
{
  MC_SetString(Ccx,Vcx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjd,Vjd);
  MC_SetString(Cch,Vch);
  int ret;
  int nindxc_();
  ret = nindxc_(&Ccx,&Cn,&Cjd,Cch,strlen(Cch));
  return MC_NewInt(ret);;
}

static VALUE
dcl_nindxi(self,Vix,Vn,Vjd,Vii)
    VALUE self,Vix,Vn,Vjd,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjd,Vjd);
  MC_SetInt(Cii,Vii);
  int ret;
  int nindxi_();
  ret = nindxi_(Cix,&Cn,&Cjd,&Cii);
  return MC_NewInt(ret);;
}

static VALUE
dcl_nindxm(self,Vcx,Vn,Vjd,Vch)
    VALUE self,Vcx,Vn,Vjd,Vch;
{
  MC_SetString(Ccx,Vcx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjd,Vjd);
  MC_SetString(Cch,Vch);
  int ret;
  int nindxm_();
  ret = nindxm_(Ccx,&Cn,&Cjd,Cch,strlen(Ccx),strlen(Cch));
  return MC_NewInt(ret);;
}

static VALUE
dcl_nindxn(self,Vcx,Vn,Vjd,Vch)
    VALUE self,Vcx,Vn,Vjd,Vch;
{
  MC_SetString(Ccx,Vcx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjd,Vjd);
  MC_SetString(Cch,Vch);
  int ret;
  int nindxn_();
  ret = nindxn_(Ccx,&Cn,&Cjd,Cch,strlen(Ccx),strlen(Cch));
  return MC_NewInt(ret);;
}

static VALUE
dcl_nindxr(self,Vrx,Vn,Vjd,Vrr)
    VALUE self,Vrx,Vn,Vjd,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjd,Vjd);
  MC_SetFloat(Crr,Vrr);
  int ret;
  int nindxr_();
  ret = nindxr_(Crx,&Cn,&Cjd,&Crr);
  return MC_NewInt(ret);;
}

static VALUE
dcl_irge(self,Vrx)
    VALUE self,Vrx;
{
  MC_SetFloatArray(Crx,Vrx);
  int ret;
  int irge_();
  ret = irge_(Crx);
  return MC_NewInt(ret);;
}

static VALUE
dcl_irgt(self,Vrx)
    VALUE self,Vrx;
{
  MC_SetFloatArray(Crx,Vrx);
  int ret;
  int irgt_();
  ret = irgt_(Crx);
  return MC_NewInt(ret);;
}

static VALUE
dcl_irle(self,Vrx)
    VALUE self,Vrx;
{
  MC_SetFloatArray(Crx,Vrx);
  int ret;
  int irle_();
  ret = irle_(Crx);
  return MC_NewInt(ret);;
}

static VALUE
dcl_irlt(self,Vrx)
    VALUE self,Vrx;
{
  MC_SetFloatArray(Crx,Vrx);
  int ret;
  int irlt_();
  ret = irlt_(Crx);
  return MC_NewInt(ret);;
}

static VALUE
dcl_lreq(self,Vx,Vy)
    VALUE self,Vx,Vy;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  int ret;
  int lreq_();
  ret = lreq_(&Cx,&Cy);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lreq0(self,Vx,Vy)
    VALUE self,Vx,Vy;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  int ret;
  int lreq0_();
  ret = lreq0_(&Cx,&Cy);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lreq1(self,Vx,Vy)
    VALUE self,Vx,Vy;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  int ret;
  int lreq1_();
  ret = lreq1_(&Cx,&Cy);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lreqa(self,Vx,Vy,Vepsl)
    VALUE self,Vx,Vy,Vepsl;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  MC_SetFloat(Cepsl,Vepsl);
  int ret;
  int lreqa_();
  ret = lreqa_(&Cx,&Cy,&Cepsl);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrge(self,Vx,Vy)
    VALUE self,Vx,Vy;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  int ret;
  int lrge_();
  ret = lrge_(&Cx,&Cy);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrge0(self,Vx,Vy)
    VALUE self,Vx,Vy;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  int ret;
  int lrge0_();
  ret = lrge0_(&Cx,&Cy);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrge1(self,Vx,Vy)
    VALUE self,Vx,Vy;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  int ret;
  int lrge1_();
  ret = lrge1_(&Cx,&Cy);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrgea(self,Vx,Vy,Vepsl)
    VALUE self,Vx,Vy,Vepsl;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  MC_SetFloat(Cepsl,Vepsl);
  int ret;
  int lrgea_();
  ret = lrgea_(&Cx,&Cy,&Cepsl);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrgt(self,Vx,Vy)
    VALUE self,Vx,Vy;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  int ret;
  int lrgt_();
  ret = lrgt_(&Cx,&Cy);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrgt0(self,Vx,Vy)
    VALUE self,Vx,Vy;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  int ret;
  int lrgt0_();
  ret = lrgt0_(&Cx,&Cy);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrgt1(self,Vx,Vy)
    VALUE self,Vx,Vy;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  int ret;
  int lrgt1_();
  ret = lrgt1_(&Cx,&Cy);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrgta(self,Vx,Vy,Vepsl)
    VALUE self,Vx,Vy,Vepsl;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  MC_SetFloat(Cepsl,Vepsl);
  int ret;
  int lrgta_();
  ret = lrgta_(&Cx,&Cy,&Cepsl);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrle(self,Vx,Vy)
    VALUE self,Vx,Vy;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  int ret;
  int lrle_();
  ret = lrle_(&Cx,&Cy);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrle0(self,Vx,Vy)
    VALUE self,Vx,Vy;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  int ret;
  int lrle0_();
  ret = lrle0_(&Cx,&Cy);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrle1(self,Vx,Vy)
    VALUE self,Vx,Vy;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  int ret;
  int lrle1_();
  ret = lrle1_(&Cx,&Cy);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrlea(self,Vx,Vy,Vepsl)
    VALUE self,Vx,Vy,Vepsl;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  MC_SetFloat(Cepsl,Vepsl);
  int ret;
  int lrlea_();
  ret = lrlea_(&Cx,&Cy,&Cepsl);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrlt(self,Vx,Vy)
    VALUE self,Vx,Vy;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  int ret;
  int lrlt_();
  ret = lrlt_(&Cx,&Cy);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrlt0(self,Vx,Vy)
    VALUE self,Vx,Vy;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  int ret;
  int lrlt0_();
  ret = lrlt0_(&Cx,&Cy);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrlt1(self,Vx,Vy)
    VALUE self,Vx,Vy;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  int ret;
  int lrlt1_();
  ret = lrlt1_(&Cx,&Cy);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrlta(self,Vx,Vy,Vepsl)
    VALUE self,Vx,Vy,Vepsl;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  MC_SetFloat(Cepsl,Vepsl);
  int ret;
  int lrlta_();
  ret = lrlta_(&Cx,&Cy,&Cepsl);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrne(self,Vx,Vy)
    VALUE self,Vx,Vy;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  int ret;
  int lrne_();
  ret = lrne_(&Cx,&Cy);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrne0(self,Vx,Vy)
    VALUE self,Vx,Vy;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  int ret;
  int lrne0_();
  ret = lrne0_(&Cx,&Cy);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrne1(self,Vx,Vy)
    VALUE self,Vx,Vy;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  int ret;
  int lrne1_();
  ret = lrne1_(&Cx,&Cy);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lrnea(self,Vx,Vy,Vepsl)
    VALUE self,Vx,Vy,Vepsl;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  MC_SetFloat(Cepsl,Vepsl);
  int ret;
  int lrnea_();
  ret = lrnea_(&Cx,&Cy,&Cepsl);
  return MC_NewLogic(ret);;
}

static VALUE
dcl_mpfaza(self,Vxlon,Vylat,Vx,Vy)
    VALUE self,Vxlon,Vylat,Vx,Vy;
{
  MC_SetFloat(Cxlon,Vxlon);
  MC_SetFloat(Cylat,Vylat);
  float Cx;
  float Cy;
  mpfaza_(&Cxlon,&Cylat,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  return Qnil;
}

static VALUE
dcl_mpiaza(self,Vx,Vy,Vxlon,Vylat)
    VALUE self,Vx,Vy,Vxlon,Vylat;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  float Cxlon;
  float Cylat;
  mpiaza_(&Cx,&Cy,&Cxlon,&Cylat);
  MC_GetFloat(Cxlon,Vxlon);
  MC_GetFloat(Cylat,Vylat);
  return Qnil;
}

static VALUE
dcl_mpfazm(self,Vxlon,Vylat,Vx,Vy)
    VALUE self,Vxlon,Vylat,Vx,Vy;
{
  MC_SetFloat(Cxlon,Vxlon);
  MC_SetFloat(Cylat,Vylat);
  float Cx;
  float Cy;
  mpfazm_(&Cxlon,&Cylat,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  return Qnil;
}

static VALUE
dcl_mpiazm(self,Vx,Vy,Vxlon,Vylat)
    VALUE self,Vx,Vy,Vxlon,Vylat;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  float Cxlon;
  float Cylat;
  mpiazm_(&Cx,&Cy,&Cxlon,&Cylat);
  MC_GetFloat(Cxlon,Vxlon);
  MC_GetFloat(Cylat,Vylat);
  return Qnil;
}

static VALUE
dcl_mpfbon(self,Vxlon,Vylat,Vx,Vy)
    VALUE self,Vxlon,Vylat,Vx,Vy;
{
  MC_SetFloat(Cxlon,Vxlon);
  MC_SetFloat(Cylat,Vylat);
  float Cx;
  float Cy;
  mpfbon_(&Cxlon,&Cylat,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  return Qnil;
}

static VALUE
dcl_mpibon(self,Vx,Vy,Vxlon,Vylat)
    VALUE self,Vx,Vy,Vxlon,Vylat;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  float Cxlon;
  float Cylat;
  mpibon_(&Cx,&Cy,&Cxlon,&Cylat);
  MC_GetFloat(Cxlon,Vxlon);
  MC_GetFloat(Cylat,Vylat);
  return Qnil;
}

static VALUE
dcl_mpsbon(self,Vylat0)
    VALUE self,Vylat0;
{
  MC_SetFloat(Cylat0,Vylat0);
  mpsbon_(&Cylat0);
  return Qnil;
}

static VALUE
dcl_mpfcoa(self,Vxlon,Vylat,Vx,Vy)
    VALUE self,Vxlon,Vylat,Vx,Vy;
{
  MC_SetFloat(Cxlon,Vxlon);
  MC_SetFloat(Cylat,Vylat);
  float Cx;
  float Cy;
  mpfcoa_(&Cxlon,&Cylat,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  return Qnil;
}

static VALUE
dcl_mpicoa(self,Vx,Vy,Vxlon,Vylat)
    VALUE self,Vx,Vy,Vxlon,Vylat;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  float Cxlon;
  float Cylat;
  mpicoa_(&Cx,&Cy,&Cxlon,&Cylat);
  MC_GetFloat(Cxlon,Vxlon);
  MC_GetFloat(Cylat,Vylat);
  return Qnil;
}

static VALUE
dcl_mpscoa(self,Vylat0)
    VALUE self,Vylat0;
{
  MC_SetFloat(Cylat0,Vylat0);
  mpscoa_(&Cylat0);
  return Qnil;
}

static VALUE
dcl_mpfcoc(self,Vxlon,Vylat,Vx,Vy)
    VALUE self,Vxlon,Vylat,Vx,Vy;
{
  MC_SetFloat(Cxlon,Vxlon);
  MC_SetFloat(Cylat,Vylat);
  float Cx;
  float Cy;
  mpfcoc_(&Cxlon,&Cylat,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  return Qnil;
}

static VALUE
dcl_mpicoc(self,Vx,Vy,Vxlon,Vylat)
    VALUE self,Vx,Vy,Vxlon,Vylat;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  float Cxlon;
  float Cylat;
  mpicoc_(&Cx,&Cy,&Cxlon,&Cylat);
  MC_GetFloat(Cxlon,Vxlon);
  MC_GetFloat(Cylat,Vylat);
  return Qnil;
}

static VALUE
dcl_mpscoc(self,Vylat1,Vylat2)
    VALUE self,Vylat1,Vylat2;
{
  MC_SetFloat(Cylat1,Vylat1);
  MC_SetFloat(Cylat2,Vylat2);
  mpscoc_(&Cylat1,&Cylat2);
  return Qnil;
}

static VALUE
dcl_mpfcon(self,Vxlon,Vylat,Vx,Vy)
    VALUE self,Vxlon,Vylat,Vx,Vy;
{
  MC_SetFloat(Cxlon,Vxlon);
  MC_SetFloat(Cylat,Vylat);
  float Cx;
  float Cy;
  mpfcon_(&Cxlon,&Cylat,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  return Qnil;
}

static VALUE
dcl_mpicon(self,Vx,Vy,Vxlon,Vylat)
    VALUE self,Vx,Vy,Vxlon,Vylat;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  float Cxlon;
  float Cylat;
  mpicon_(&Cx,&Cy,&Cxlon,&Cylat);
  MC_GetFloat(Cxlon,Vxlon);
  MC_GetFloat(Cylat,Vylat);
  return Qnil;
}

static VALUE
dcl_mpscon(self,Vylat0)
    VALUE self,Vylat0;
{
  MC_SetFloat(Cylat0,Vylat0);
  mpscon_(&Cylat0);
  return Qnil;
}

static VALUE
dcl_mpfcyl(self,Vxlon,Vylat,Vx,Vy)
    VALUE self,Vxlon,Vylat,Vx,Vy;
{
  MC_SetFloat(Cxlon,Vxlon);
  MC_SetFloat(Cylat,Vylat);
  float Cx;
  float Cy;
  mpfcyl_(&Cxlon,&Cylat,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  return Qnil;
}

static VALUE
dcl_mpicyl(self,Vx,Vy,Vxlon,Vylat)
    VALUE self,Vx,Vy,Vxlon,Vylat;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  float Cxlon;
  float Cylat;
  mpicyl_(&Cx,&Cy,&Cxlon,&Cylat);
  MC_GetFloat(Cxlon,Vxlon);
  MC_GetFloat(Cylat,Vylat);
  return Qnil;
}

static VALUE
dcl_mpfek6(self,Vxlon,Vylat,Vx,Vy)
    VALUE self,Vxlon,Vylat,Vx,Vy;
{
  MC_SetFloat(Cxlon,Vxlon);
  MC_SetFloat(Cylat,Vylat);
  float Cx;
  float Cy;
  mpfek6_(&Cxlon,&Cylat,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  return Qnil;
}

static VALUE
dcl_mpiek6(self,Vx,Vy,Vxlon,Vylat)
    VALUE self,Vx,Vy,Vxlon,Vylat;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  float Cxlon;
  float Cylat;
  mpiek6_(&Cx,&Cy,&Cxlon,&Cylat);
  MC_GetFloat(Cxlon,Vxlon);
  MC_GetFloat(Cylat,Vylat);
  return Qnil;
}

static VALUE
dcl_mpfhmr(self,Vxlon,Vylat,Vx,Vy)
    VALUE self,Vxlon,Vylat,Vx,Vy;
{
  MC_SetFloat(Cxlon,Vxlon);
  MC_SetFloat(Cylat,Vylat);
  float Cx;
  float Cy;
  mpfhmr_(&Cxlon,&Cylat,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  return Qnil;
}

static VALUE
dcl_mpihmr(self,Vx,Vy,Vxlon,Vylat)
    VALUE self,Vx,Vy,Vxlon,Vylat;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  float Cxlon;
  float Cylat;
  mpihmr_(&Cx,&Cy,&Cxlon,&Cylat);
  MC_GetFloat(Cxlon,Vxlon);
  MC_GetFloat(Cylat,Vylat);
  return Qnil;
}

static VALUE
dcl_mpfktd(self,Vxlon,Vylat,Vx,Vy)
    VALUE self,Vxlon,Vylat,Vx,Vy;
{
  MC_SetFloat(Cxlon,Vxlon);
  MC_SetFloat(Cylat,Vylat);
  float Cx;
  float Cy;
  mpfktd_(&Cxlon,&Cylat,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  return Qnil;
}

static VALUE
dcl_mpiktd(self,Vx,Vy,Vxlon,Vylat)
    VALUE self,Vx,Vy,Vxlon,Vylat;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  float Cxlon;
  float Cylat;
  mpiktd_(&Cx,&Cy,&Cxlon,&Cylat);
  MC_GetFloat(Cxlon,Vxlon);
  MC_GetFloat(Cylat,Vylat);
  return Qnil;
}

static VALUE
dcl_mpfmer(self,Vxlon,Vylat,Vx,Vy)
    VALUE self,Vxlon,Vylat,Vx,Vy;
{
  MC_SetFloat(Cxlon,Vxlon);
  MC_SetFloat(Cylat,Vylat);
  float Cx;
  float Cy;
  mpfmer_(&Cxlon,&Cylat,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  return Qnil;
}

static VALUE
dcl_mpimer(self,Vx,Vy,Vxlon,Vylat)
    VALUE self,Vx,Vy,Vxlon,Vylat;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  float Cxlon;
  float Cylat;
  mpimer_(&Cx,&Cy,&Cxlon,&Cylat);
  MC_GetFloat(Cxlon,Vxlon);
  MC_GetFloat(Cylat,Vylat);
  return Qnil;
}

static VALUE
dcl_mpfmwd(self,Vxlon,Vylat,Vx,Vy)
    VALUE self,Vxlon,Vylat,Vx,Vy;
{
  MC_SetFloat(Cxlon,Vxlon);
  MC_SetFloat(Cylat,Vylat);
  float Cx;
  float Cy;
  mpfmwd_(&Cxlon,&Cylat,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  return Qnil;
}

static VALUE
dcl_mpimwd(self,Vx,Vy,Vxlon,Vylat)
    VALUE self,Vx,Vy,Vxlon,Vylat;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  float Cxlon;
  float Cylat;
  mpimwd_(&Cx,&Cy,&Cxlon,&Cylat);
  MC_GetFloat(Cxlon,Vxlon);
  MC_GetFloat(Cylat,Vylat);
  return Qnil;
}

static VALUE
dcl_mpfmwl(self,Vxlon,Vylat,Vx,Vy)
    VALUE self,Vxlon,Vylat,Vx,Vy;
{
  MC_SetFloat(Cxlon,Vxlon);
  MC_SetFloat(Cylat,Vylat);
  float Cx;
  float Cy;
  mpfmwl_(&Cxlon,&Cylat,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  return Qnil;
}

static VALUE
dcl_mpimwl(self,Vx,Vy,Vxlon,Vylat)
    VALUE self,Vx,Vy,Vxlon,Vylat;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  float Cxlon;
  float Cylat;
  mpimwl_(&Cx,&Cy,&Cxlon,&Cylat);
  MC_GetFloat(Cxlon,Vxlon);
  MC_GetFloat(Cylat,Vylat);
  return Qnil;
}

static VALUE
dcl_mpfotg(self,Vxlon,Vylat,Vx,Vy)
    VALUE self,Vxlon,Vylat,Vx,Vy;
{
  MC_SetFloat(Cxlon,Vxlon);
  MC_SetFloat(Cylat,Vylat);
  float Cx;
  float Cy;
  mpfotg_(&Cxlon,&Cylat,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  return Qnil;
}

static VALUE
dcl_mpiotg(self,Vx,Vy,Vxlon,Vylat)
    VALUE self,Vx,Vy,Vxlon,Vylat;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  float Cxlon;
  float Cylat;
  mpiotg_(&Cx,&Cy,&Cxlon,&Cylat);
  MC_GetFloat(Cxlon,Vxlon);
  MC_GetFloat(Cylat,Vylat);
  return Qnil;
}

static VALUE
dcl_mpsotg(self,Vr0)
    VALUE self,Vr0;
{
  MC_SetFloat(Cr0,Vr0);
  mpsotg_(&Cr0);
  return Qnil;
}

static VALUE
dcl_mpfpst(self,Vxlon,Vylat,Vx,Vy)
    VALUE self,Vxlon,Vylat,Vx,Vy;
{
  MC_SetFloat(Cxlon,Vxlon);
  MC_SetFloat(Cylat,Vylat);
  float Cx;
  float Cy;
  mpfpst_(&Cxlon,&Cylat,&Cx,&Cy);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cy,Vy);
  return Qnil;
}

static VALUE
dcl_mpipst(self,Vx,Vy,Vxlon,Vylat)
    VALUE self,Vx,Vy,Vxlon,Vylat;
{
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cy,Vy);
  float Cxlon;
  float Cylat;
  mpipst_(&Cx,&Cy,&Cxlon,&Cylat);
  MC_GetFloat(Cxlon,Vxlon);
  MC_GetFloat(Cylat,Vylat);
  return Qnil;
}

static VALUE
dcl_mpzek6(self,Vphi,Valpha,Vf,Vdf)
    VALUE self,Vphi,Valpha,Vf,Vdf;
{
  MC_SetFloat(Cphi,Vphi);
  MC_SetFloat(Calpha,Valpha);
  float Cf;
  MC_SetFloat(Cdf,Vdf);
  mpzek6_(&Cphi,&Calpha,&Cf,&Cdf);
  MC_GetFloat(Cf,Vf);
  return Qnil;
}

static VALUE
dcl_mpzktd(self,Vphi,Valpha,Vf,Vdf)
    VALUE self,Vphi,Valpha,Vf,Vdf;
{
  MC_SetFloat(Cphi,Vphi);
  MC_SetFloat(Calpha,Valpha);
  float Cf;
  MC_SetFloat(Cdf,Vdf);
  mpzktd_(&Cphi,&Calpha,&Cf,&Cdf);
  MC_GetFloat(Cf,Vf);
  return Qnil;
}

static VALUE
dcl_mpzmwd(self,Vphi,Valpha,Vf,Vdf)
    VALUE self,Vphi,Valpha,Vf,Vdf;
{
  MC_SetFloat(Cphi,Vphi);
  MC_SetFloat(Calpha,Valpha);
  float Cf;
  MC_SetFloat(Cdf,Vdf);
  mpzmwd_(&Cphi,&Calpha,&Cf,&Cdf);
  MC_GetFloat(Cf,Vf);
  return Qnil;
}

static VALUE
dcl_mpznwt(self,Vfunc,Vphi,Valpha)
    VALUE self,Vfunc,Vphi,Valpha;
{
  MC_SetFloat(Cfunc,Vfunc);
  MC_SetFloat(Cphi,Vphi);
  float Calpha;
  mpznwt_(&Cfunc,&Cphi,&Calpha);
  MC_GetFloat(Calpha,Valpha);
  return Qnil;
}

static VALUE
dcl_xmplon(self,Vxlon)
    VALUE self,Vxlon;
{
  MC_SetFloat(Cxlon,Vxlon);
  float ret;
  float xmplon_();
  ret = xmplon_(&Cxlon);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_ramp(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float ramp_();
  ret = ramp_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_ramp0(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float ramp0_();
  ret = ramp0_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_ramp1(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float ramp1_();
  ret = ramp1_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rave(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rave_();
  ret = rave_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rave0(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rave0_();
  ret = rave0_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rave1(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rave1_();
  ret = rave1_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rmax(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rmax_();
  ret = rmax_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rmax0(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rmax0_();
  ret = rmax0_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rmax1(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rmax1_();
  ret = rmax1_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rmin(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rmin_();
  ret = rmin_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rmin0(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rmin0_();
  ret = rmin0_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rmin1(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rmin1_();
  ret = rmin1_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rrms(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rrms_();
  ret = rrms_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rrms0(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rrms0_();
  ret = rrms0_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rrms1(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rrms1_();
  ret = rrms1_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rstd(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rstd_();
  ret = rstd_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rstd0(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rstd0_();
  ret = rstd0_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rstd1(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rstd1_();
  ret = rstd1_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rsum(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rsum_();
  ret = rsum_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rsum0(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rsum0_();
  ret = rsum0_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rsum1(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rsum1_();
  ret = rsum1_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rvar(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rvar_();
  ret = rvar_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rvar0(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rvar0_();
  ret = rvar0_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rvar1(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  float ret;
  float rvar1_();
  ret = rvar1_(Crx,&Cn,&Cjx);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rvmax(self,Vrx,Vns,Vnp,Vnq,Vnd)
    VALUE self,Vrx,Vns,Vnp,Vnq,Vnd;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetIntArray(Cns,Vns);
  MC_SetIntArray(Cnp,Vnp);
  MC_SetIntArray(Cnq,Vnq);
  MC_SetInt(Cnd,Vnd);
  float ret;
  float rvmax_();
  ret = rvmax_(Crx,Cns,Cnp,Cnq,&Cnd);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rvmax0(self,Vrx,Vns,Vnp,Vnq,Vnd)
    VALUE self,Vrx,Vns,Vnp,Vnq,Vnd;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetIntArray(Cns,Vns);
  MC_SetIntArray(Cnp,Vnp);
  MC_SetIntArray(Cnq,Vnq);
  MC_SetInt(Cnd,Vnd);
  float ret;
  float rvmax0_();
  ret = rvmax0_(Crx,Cns,Cnp,Cnq,&Cnd);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rvmax1(self,Vrx,Vns,Vnp,Vnq,Vnd)
    VALUE self,Vrx,Vns,Vnp,Vnq,Vnd;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetIntArray(Cns,Vns);
  MC_SetIntArray(Cnp,Vnp);
  MC_SetIntArray(Cnq,Vnq);
  MC_SetInt(Cnd,Vnd);
  float ret;
  float rvmax1_();
  ret = rvmax1_(Crx,Cns,Cnp,Cnq,&Cnd);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rvmin(self,Vrx,Vns,Vnp,Vnq,Vnd)
    VALUE self,Vrx,Vns,Vnp,Vnq,Vnd;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetIntArray(Cns,Vns);
  MC_SetIntArray(Cnp,Vnp);
  MC_SetIntArray(Cnq,Vnq);
  MC_SetInt(Cnd,Vnd);
  float ret;
  float rvmin_();
  ret = rvmin_(Crx,Cns,Cnp,Cnq,&Cnd);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rvmin0(self,Vrx,Vns,Vnp,Vnq,Vnd)
    VALUE self,Vrx,Vns,Vnp,Vnq,Vnd;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetIntArray(Cns,Vns);
  MC_SetIntArray(Cnp,Vnp);
  MC_SetIntArray(Cnq,Vnq);
  MC_SetInt(Cnd,Vnd);
  float ret;
  float rvmin0_();
  ret = rvmin0_(Crx,Cns,Cnp,Cnq,&Cnd);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rvmin1(self,Vrx,Vns,Vnp,Vnq,Vnd)
    VALUE self,Vrx,Vns,Vnp,Vnq,Vnd;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetIntArray(Cns,Vns);
  MC_SetIntArray(Cnp,Vnp);
  MC_SetIntArray(Cnq,Vnq);
  MC_SetInt(Cnd,Vnd);
  float ret;
  float rvmin1_();
  ret = rvmin1_(Crx,Cns,Cnp,Cnq,&Cnd);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rcor(self,Vrx,Vry,Vn,Vjx,Vjy)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  float ret;
  float rcor_();
  ret = rcor_(Crx,Cry,&Cn,&Cjx,&Cjy);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rcov(self,Vrx,Vry,Vn,Vjx,Vjy)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  float ret;
  float rcov_();
  ret = rcov_(Crx,Cry,&Cn,&Cjx,&Cjy);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rprd(self,Vrx,Vry,Vn,Vjx,Vjy)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  float ret;
  float rprd_();
  ret = rprd_(Crx,Cry,&Cn,&Cjx,&Cjy);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_dxfloc(self,Vnd,Vns,Vnp,Vncp)
    VALUE self,Vnd,Vns,Vnp,Vncp;
{
  MC_SetInt(Cnd,Vnd);
  MC_SetIntArray(Cns,Vns);
  MC_SetIntArray(Cnp,Vnp);
  int   Cncp;
  dxfloc_(&Cnd,Cns,Cnp,&Cncp);
  MC_GetInt(Cncp,Vncp);
  return Qnil;
}

static VALUE
dcl_dxiloc(self,Vnd,Vns,Vnp,Vncp)
    VALUE self,Vnd,Vns,Vnp,Vncp;
{
  MC_SetInt(Cnd,Vnd);
  MC_SetIntArray(Cns,Vns);
  MC_SetIntArray(Cnp,Vnp);
  MC_SetInt(Cncp,Vncp);
  dxiloc_(&Cnd,Cns,Cnp,&Cncp);
  return Qnil;
}

static VALUE
dcl_vignn(self,Vix,Vn,Vjx)
    VALUE self,Vix,Vn,Vjx;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  vignn_(Cix,&Cn,&Cjx);
  return Qnil;
}

static VALUE
dcl_vrgnn(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  vrgnn_(Crx,&Cn,&Cjx);
  return Qnil;
}

static VALUE
dcl_cfsrch(self,Vcplist,Vnp,Vcflist,Vnf,Vcfname)
    VALUE self,Vcplist,Vnp,Vcflist,Vnf,Vcfname;
{
  MC_SetString(Ccplist,Vcplist);
  MC_SetInt(Cnp,Vnp);
  MC_SetString(Ccflist,Vcflist);
  MC_SetInt(Cnf,Vnf);
  char * Ccfname="                ";
  cfsrch_(&Ccplist,&Cnp,&Ccflist,&Cnf,Ccfname,strlen(Ccfname));
  MC_GetString(Ccfname,Vcfname);
  return Qnil;
}

static VALUE
dcl_glcget(self,Vcp,Vcpara)
    VALUE self,Vcp,Vcpara;
{
  MC_SetString(Ccp,Vcp);
  char * Ccpara="                ";
  glcget_(Ccp,Ccpara,strlen(Ccp),strlen(Ccpara));
  MC_GetString(Ccpara,Vcpara);
  return Qnil;
}

static VALUE
dcl_glcset(self,Vcp,Vcpara)
    VALUE self,Vcp,Vcpara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetString(Ccpara,Vcpara);
  glcset_(Ccp,Ccpara,strlen(Ccp),strlen(Ccpara));
  return Qnil;
}

static VALUE
dcl_glcstx(self,Vcp,Vcpara)
    VALUE self,Vcp,Vcpara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetString(Ccpara,Vcpara);
  glcstx_(Ccp,Ccpara,strlen(Ccp),strlen(Ccpara));
  return Qnil;
}

static VALUE
dcl_glpget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  glpget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_gliget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  gliget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_glrget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  float Cipara;
  glrget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetFloat(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_gllget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int    Cipara;
  gllget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetLogic(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_glpset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  glpset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_gliset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  gliset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_glrset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  glrset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_gllset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  gllset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_glpstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  glpstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_glistx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  glistx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_glrstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  glrstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_gllstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  gllstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_glqfnm(self,Vcpara,Vcfname)
    VALUE self,Vcpara,Vcfname;
{
  MC_SetString(Ccpara,Vcpara);
  MC_SetString(Ccfname,Vcfname);
  glqfnm_(Ccpara,Ccfname,strlen(Ccpara),strlen(Ccfname));
  return Qnil;
}

static VALUE
dcl_iufopn(self,V)
    VALUE self,V;
{
  int ret;
  int iufopn_();
  ret = iufopn_();
  return MC_NewInt(ret);;
}

static VALUE
dcl_lchreq(self,Vch1,Vch2)
    VALUE self,Vch1,Vch2;
{
  MC_SetString(Cch1,Vch1);
  MC_SetString(Cch2,Vch2);
  int ret;
  int lchreq_();
  ret = lchreq_(Cch1,Cch2,strlen(Cch1),strlen(Cch2));
  return MC_NewLogic(ret);;
}

static VALUE
dcl_msgdmp(self,Vclev,Vcsub,Vcmsg)
    VALUE self,Vclev,Vcsub,Vcmsg;
{
  MC_SetString(Cclev,Vclev);
  MC_SetString(Ccsub,Vcsub);
  MC_SetString(Ccmsg,Vcmsg);
  msgdmp_(Cclev,Ccsub,Ccmsg,strlen(Cclev),strlen(Ccsub),strlen(Ccmsg));
  return Qnil;
}

static VALUE
dcl_mszdmp(self,Vcmsg,Viunit,Vlnsize)
    VALUE self,Vcmsg,Viunit,Vlnsize;
{
  MC_SetString(Ccmsg,Vcmsg);
  MC_SetInt(Ciunit,Viunit);
  MC_SetInt(Clnsize,Vlnsize);
  mszdmp_(Ccmsg,&Ciunit,&Clnsize,strlen(Ccmsg));
  return Qnil;
}

static VALUE
dcl_rtcenv(self,Vcpfix,Vcp,Vcval)
    VALUE self,Vcpfix,Vcp,Vcval;
{
  MC_SetString(Ccpfix,Vcpfix);
  MC_SetString(Ccp,Vcp);
  char * Ccval="                ";
  rtcenv_(Ccpfix,Ccp,Ccval,strlen(Ccpfix),strlen(Ccp),strlen(Ccval));
  MC_GetString(Ccval,Vcval);
  return Qnil;
}

static VALUE
dcl_rtcget(self,Vcpfix,Vcp,Vcpara,Vmax)
    VALUE self,Vcpfix,Vcp,Vcpara,Vmax;
{
  MC_SetString(Ccpfix,Vcpfix);
  MC_SetString(Ccp,Vcp);
  MC_SetString(Ccpara,Vcpara);
  MC_SetInt(Cmax,Vmax);
  rtcget_(Ccpfix,&Ccp,&Ccpara,&Cmax,strlen(Ccpfix));
  return Qnil;
}

static VALUE
dcl_rtcopt(self,Vcpfix,Vcp,Vcval)
    VALUE self,Vcpfix,Vcp,Vcval;
{
  MC_SetString(Ccpfix,Vcpfix);
  MC_SetString(Ccp,Vcp);
  char * Ccval="                ";
  rtcopt_(Ccpfix,Ccp,Ccval,strlen(Ccpfix),strlen(Ccp),strlen(Ccval));
  MC_GetString(Ccval,Vcval);
  return Qnil;
}

static VALUE
dcl_rtcxfl(self,Vcpfix,Vcp,Vcval)
    VALUE self,Vcpfix,Vcp,Vcval;
{
  MC_SetString(Ccpfix,Vcpfix);
  MC_SetString(Ccp,Vcp);
  char * Ccval="                ";
  rtcxfl_(Ccpfix,Ccp,Ccval,strlen(Ccpfix),strlen(Ccp),strlen(Ccval));
  MC_GetString(Ccval,Vcval);
  return Qnil;
}

static VALUE
dcl_rtpenv(self,Vcpfix,Vcp,Vipara)
    VALUE self,Vcpfix,Vcp,Vipara;
{
  MC_SetString(Ccpfix,Vcpfix);
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  rtpenv_(Ccpfix,Ccp,&Cipara,strlen(Ccpfix),strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_rtpget(self,Vcpfix,Vcp,Vipara,Vmax)
    VALUE self,Vcpfix,Vcp,Vipara,Vmax;
{
  MC_SetString(Ccpfix,Vcpfix);
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  MC_SetInt(Cmax,Vmax);
  rtpget_(Ccpfix,&Ccp,&Cipara,&Cmax,strlen(Ccpfix));
  return Qnil;
}

static VALUE
dcl_rtpopt(self,Vcpfix,Vcp,Vipara)
    VALUE self,Vcpfix,Vcp,Vipara;
{
  MC_SetString(Ccpfix,Vcpfix);
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  rtpopt_(Ccpfix,Ccp,&Cipara,strlen(Ccpfix),strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_rtpxfl(self,Vcpfix,Vcp,Vipara)
    VALUE self,Vcpfix,Vcp,Vipara;
{
  MC_SetString(Ccpfix,Vcpfix);
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  rtpxfl_(Ccpfix,Ccp,&Cipara,strlen(Ccpfix),strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_iadd(self,Vix,Vn,Vjx,Vii)
    VALUE self,Vix,Vn,Vjx,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cii,Vii);
  iadd_(Cix,&Cn,&Cjx,&Cii);
  return Qnil;
}

static VALUE
dcl_iadd0(self,Vix,Vn,Vjx,Vii)
    VALUE self,Vix,Vn,Vjx,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cii,Vii);
  iadd0_(Cix,&Cn,&Cjx,&Cii);
  return Qnil;
}

static VALUE
dcl_iadd1(self,Vix,Vn,Vjx,Vii)
    VALUE self,Vix,Vn,Vjx,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cii,Vii);
  iadd1_(Cix,&Cn,&Cjx,&Cii);
  return Qnil;
}

static VALUE
dcl_imlt(self,Vix,Vn,Vjx,Vii)
    VALUE self,Vix,Vn,Vjx,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cii,Vii);
  imlt_(Cix,&Cn,&Cjx,&Cii);
  return Qnil;
}

static VALUE
dcl_imlt0(self,Vix,Vn,Vjx,Vii)
    VALUE self,Vix,Vn,Vjx,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cii,Vii);
  imlt0_(Cix,&Cn,&Cjx,&Cii);
  return Qnil;
}

static VALUE
dcl_imlt1(self,Vix,Vn,Vjx,Vii)
    VALUE self,Vix,Vn,Vjx,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cii,Vii);
  imlt1_(Cix,&Cn,&Cjx,&Cii);
  return Qnil;
}

static VALUE
dcl_iset(self,Vix,Vn,Vjx,Vii)
    VALUE self,Vix,Vn,Vjx,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cii,Vii);
  iset_(Cix,&Cn,&Cjx,&Cii);
  return Qnil;
}

static VALUE
dcl_iset0(self,Vix,Vn,Vjx,Vii)
    VALUE self,Vix,Vn,Vjx,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cii,Vii);
  iset0_(Cix,&Cn,&Cjx,&Cii);
  return Qnil;
}

static VALUE
dcl_iset1(self,Vix,Vn,Vjx,Vii)
    VALUE self,Vix,Vn,Vjx,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cii,Vii);
  iset1_(Cix,&Cn,&Cjx,&Cii);
  return Qnil;
}

static VALUE
dcl_vicon(self,Vix,Viy,Vn,Vjx,Vjy,Vii)
    VALUE self,Vix,Viy,Vn,Vjx,Vjy,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cii,Vii);
  vicon_(Cix,Ciy,&Cn,&Cjx,&Cjy,&Cii);
  return Qnil;
}

static VALUE
dcl_vicon0(self,Vix,Viy,Vn,Vjx,Vjy,Vii)
    VALUE self,Vix,Viy,Vn,Vjx,Vjy,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cii,Vii);
  vicon0_(Cix,Ciy,&Cn,&Cjx,&Cjy,&Cii);
  return Qnil;
}

static VALUE
dcl_vicon1(self,Vix,Viy,Vn,Vjx,Vjy,Vii)
    VALUE self,Vix,Viy,Vn,Vjx,Vjy,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cii,Vii);
  vicon1_(Cix,Ciy,&Cn,&Cjx,&Cjy,&Cii);
  return Qnil;
}

static VALUE
dcl_vifct(self,Vix,Viy,Vn,Vjx,Vjy,Vii)
    VALUE self,Vix,Viy,Vn,Vjx,Vjy,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cii,Vii);
  vifct_(Cix,Ciy,&Cn,&Cjx,&Cjy,&Cii);
  return Qnil;
}

static VALUE
dcl_vifct0(self,Vix,Viy,Vn,Vjx,Vjy,Vii)
    VALUE self,Vix,Viy,Vn,Vjx,Vjy,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cii,Vii);
  vifct0_(Cix,Ciy,&Cn,&Cjx,&Cjy,&Cii);
  return Qnil;
}

static VALUE
dcl_vifct1(self,Vix,Viy,Vn,Vjx,Vjy,Vii)
    VALUE self,Vix,Viy,Vn,Vjx,Vjy,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cii,Vii);
  vifct1_(Cix,Ciy,&Cn,&Cjx,&Cjy,&Cii);
  return Qnil;
}

static VALUE
dcl_vifna(self,Vix,Viy,Vn,Vjx,Vjy,Vifna)
    VALUE self,Vix,Viy,Vn,Vjx,Vjy,Vifna;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cifna,Vifna);
  vifna_(Cix,Ciy,&Cn,&Cjx,&Cjy,&Cifna);
  return Qnil;
}

static VALUE
dcl_vifna0(self,Vix,Viy,Vn,Vjx,Vjy,Vifna)
    VALUE self,Vix,Viy,Vn,Vjx,Vjy,Vifna;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cifna,Vifna);
  vifna0_(Cix,Ciy,&Cn,&Cjx,&Cjy,&Cifna);
  return Qnil;
}

static VALUE
dcl_vifna1(self,Vix,Viy,Vn,Vjx,Vjy,Vifna)
    VALUE self,Vix,Viy,Vn,Vjx,Vjy,Vifna;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cifna,Vifna);
  vifna1_(Cix,Ciy,&Cn,&Cjx,&Cjy,&Cifna);
  return Qnil;
}

static VALUE
dcl_viinc(self,Vix,Viy,Vn,Vjx,Vjy,Vii)
    VALUE self,Vix,Viy,Vn,Vjx,Vjy,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cii,Vii);
  viinc_(Cix,Ciy,&Cn,&Cjx,&Cjy,&Cii);
  return Qnil;
}

static VALUE
dcl_viinc0(self,Vix,Viy,Vn,Vjx,Vjy,Vii)
    VALUE self,Vix,Viy,Vn,Vjx,Vjy,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cii,Vii);
  viinc0_(Cix,Ciy,&Cn,&Cjx,&Cjy,&Cii);
  return Qnil;
}

static VALUE
dcl_viinc1(self,Vix,Viy,Vn,Vjx,Vjy,Vii)
    VALUE self,Vix,Viy,Vn,Vjx,Vjy,Vii;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cii,Vii);
  viinc1_(Cix,Ciy,&Cn,&Cjx,&Cjy,&Cii);
  return Qnil;
}

static VALUE
dcl_viset(self,Vix,Viy,Vn,Vjx,Vjy)
    VALUE self,Vix,Viy,Vn,Vjx,Vjy;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  viset_(Cix,Ciy,&Cn,&Cjx,&Cjy);
  return Qnil;
}

static VALUE
dcl_viset0(self,Vix,Viy,Vn,Vjx,Vjy)
    VALUE self,Vix,Viy,Vn,Vjx,Vjy;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  viset0_(Cix,Ciy,&Cn,&Cjx,&Cjy);
  return Qnil;
}

static VALUE
dcl_viset1(self,Vix,Viy,Vn,Vjx,Vjy)
    VALUE self,Vix,Viy,Vn,Vjx,Vjy;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  viset1_(Cix,Ciy,&Cn,&Cjx,&Cjy);
  return Qnil;
}

static VALUE
dcl_viadd(self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetIntArray(Ciz,Viz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  viadd_(Cix,Ciy,Ciz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_viadd0(self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetIntArray(Ciz,Viz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  viadd0_(Cix,Ciy,Ciz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_viadd1(self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetIntArray(Ciz,Viz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  viadd1_(Cix,Ciy,Ciz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_vidiv(self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetIntArray(Ciz,Viz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  vidiv_(Cix,Ciy,Ciz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_vidiv0(self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetIntArray(Ciz,Viz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  vidiv0_(Cix,Ciy,Ciz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_vidiv1(self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetIntArray(Ciz,Viz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  vidiv1_(Cix,Ciy,Ciz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_vifnb(self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz,Vifnb)
    VALUE self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz,Vifnb;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetIntArray(Ciz,Viz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  MC_SetInt(Cifnb,Vifnb);
  vifnb_(Cix,Ciy,Ciz,&Cn,&Cjx,&Cjy,&Cjz,&Cifnb);
  return Qnil;
}

static VALUE
dcl_vifnb0(self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz,Vifnb)
    VALUE self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz,Vifnb;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetIntArray(Ciz,Viz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  MC_SetInt(Cifnb,Vifnb);
  vifnb0_(Cix,Ciy,Ciz,&Cn,&Cjx,&Cjy,&Cjz,&Cifnb);
  return Qnil;
}

static VALUE
dcl_vifnb1(self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz,Vifnb)
    VALUE self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz,Vifnb;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetIntArray(Ciz,Viz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  MC_SetInt(Cifnb,Vifnb);
  vifnb1_(Cix,Ciy,Ciz,&Cn,&Cjx,&Cjy,&Cjz,&Cifnb);
  return Qnil;
}

static VALUE
dcl_vimlt(self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetIntArray(Ciz,Viz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  vimlt_(Cix,Ciy,Ciz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_vimlt0(self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetIntArray(Ciz,Viz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  vimlt0_(Cix,Ciy,Ciz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_vimlt1(self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetIntArray(Ciz,Viz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  vimlt1_(Cix,Ciy,Ciz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_visub(self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetIntArray(Ciz,Viz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  visub_(Cix,Ciy,Ciz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_visub0(self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetIntArray(Ciz,Viz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  visub0_(Cix,Ciy,Ciz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_visub1(self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vix,Viy,Viz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetIntArray(Cix,Vix);
  MC_SetIntArray(Ciy,Viy);
  MC_SetIntArray(Ciz,Viz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  visub1_(Cix,Ciy,Ciz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_radd(self,Vrx,Vn,Vjx,Vrr)
    VALUE self,Vrx,Vn,Vjx,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetFloat(Crr,Vrr);
  radd_(Crx,&Cn,&Cjx,&Crr);
  return Qnil;
}

static VALUE
dcl_radd0(self,Vrx,Vn,Vjx,Vrr)
    VALUE self,Vrx,Vn,Vjx,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetFloat(Crr,Vrr);
  radd0_(Crx,&Cn,&Cjx,&Crr);
  return Qnil;
}

static VALUE
dcl_radd1(self,Vrx,Vn,Vjx,Vrr)
    VALUE self,Vrx,Vn,Vjx,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetFloat(Crr,Vrr);
  radd1_(Crx,&Cn,&Cjx,&Crr);
  return Qnil;
}

static VALUE
dcl_rmlt(self,Vrx,Vn,Vjx,Vrr)
    VALUE self,Vrx,Vn,Vjx,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetFloat(Crr,Vrr);
  rmlt_(Crx,&Cn,&Cjx,&Crr);
  return Qnil;
}

static VALUE
dcl_rmlt0(self,Vrx,Vn,Vjx,Vrr)
    VALUE self,Vrx,Vn,Vjx,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetFloat(Crr,Vrr);
  rmlt0_(Crx,&Cn,&Cjx,&Crr);
  return Qnil;
}

static VALUE
dcl_rmlt1(self,Vrx,Vn,Vjx,Vrr)
    VALUE self,Vrx,Vn,Vjx,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetFloat(Crr,Vrr);
  rmlt1_(Crx,&Cn,&Cjx,&Crr);
  return Qnil;
}

static VALUE
dcl_rset(self,Vrx,Vn,Vjx,Vrr)
    VALUE self,Vrx,Vn,Vjx,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetFloat(Crr,Vrr);
  rset_(Crx,&Cn,&Cjx,&Crr);
  return Qnil;
}

static VALUE
dcl_rset0(self,Vrx,Vn,Vjx,Vrr)
    VALUE self,Vrx,Vn,Vjx,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetFloat(Crr,Vrr);
  rset0_(Crx,&Cn,&Cjx,&Crr);
  return Qnil;
}

static VALUE
dcl_rset1(self,Vrx,Vn,Vjx,Vrr)
    VALUE self,Vrx,Vn,Vjx,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetFloat(Crr,Vrr);
  rset1_(Crx,&Cn,&Cjx,&Crr);
  return Qnil;
}

static VALUE
dcl_vrcon(self,Vrx,Vry,Vn,Vjx,Vjy,Vrr)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetFloat(Crr,Vrr);
  vrcon_(Crx,Cry,&Cn,&Cjx,&Cjy,&Crr);
  return Qnil;
}

static VALUE
dcl_vrcon0(self,Vrx,Vry,Vn,Vjx,Vjy,Vrr)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetFloat(Crr,Vrr);
  vrcon0_(Crx,Cry,&Cn,&Cjx,&Cjy,&Crr);
  return Qnil;
}

static VALUE
dcl_vrcon1(self,Vrx,Vry,Vn,Vjx,Vjy,Vrr)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetFloat(Crr,Vrr);
  vrcon1_(Crx,Cry,&Cn,&Cjx,&Cjy,&Crr);
  return Qnil;
}

static VALUE
dcl_vrfct(self,Vrx,Vry,Vn,Vjx,Vjy,Vrr)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetFloat(Crr,Vrr);
  vrfct_(Crx,Cry,&Cn,&Cjx,&Cjy,&Crr);
  return Qnil;
}

static VALUE
dcl_vrfct0(self,Vrx,Vry,Vn,Vjx,Vjy,Vrr)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetFloat(Crr,Vrr);
  vrfct0_(Crx,Cry,&Cn,&Cjx,&Cjy,&Crr);
  return Qnil;
}

static VALUE
dcl_vrfct1(self,Vrx,Vry,Vn,Vjx,Vjy,Vrr)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetFloat(Crr,Vrr);
  vrfct1_(Crx,Cry,&Cn,&Cjx,&Cjy,&Crr);
  return Qnil;
}

static VALUE
dcl_vrfna(self,Vrx,Vry,Vn,Vjx,Vjy,Vrfna)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy,Vrfna;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetFloat(Crfna,Vrfna);
  vrfna_(Crx,Cry,&Cn,&Cjx,&Cjy,&Crfna);
  return Qnil;
}

static VALUE
dcl_vrfna0(self,Vrx,Vry,Vn,Vjx,Vjy,Vrfna)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy,Vrfna;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetFloat(Crfna,Vrfna);
  vrfna0_(Crx,Cry,&Cn,&Cjx,&Cjy,&Crfna);
  return Qnil;
}

static VALUE
dcl_vrfna1(self,Vrx,Vry,Vn,Vjx,Vjy,Vrfna)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy,Vrfna;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetFloat(Crfna,Vrfna);
  vrfna1_(Crx,Cry,&Cn,&Cjx,&Cjy,&Crfna);
  return Qnil;
}

static VALUE
dcl_vrinc(self,Vrx,Vry,Vn,Vjx,Vjy,Vrr)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetFloat(Crr,Vrr);
  vrinc_(Crx,Cry,&Cn,&Cjx,&Cjy,&Crr);
  return Qnil;
}

static VALUE
dcl_vrinc0(self,Vrx,Vry,Vn,Vjx,Vjy,Vrr)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetFloat(Crr,Vrr);
  vrinc0_(Crx,Cry,&Cn,&Cjx,&Cjy,&Crr);
  return Qnil;
}

static VALUE
dcl_vrinc1(self,Vrx,Vry,Vn,Vjx,Vjy,Vrr)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy,Vrr;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetFloat(Crr,Vrr);
  vrinc1_(Crx,Cry,&Cn,&Cjx,&Cjy,&Crr);
  return Qnil;
}

static VALUE
dcl_vrset(self,Vrx,Vry,Vn,Vjx,Vjy)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  vrset_(Crx,Cry,&Cn,&Cjx,&Cjy);
  return Qnil;
}

static VALUE
dcl_vrset0(self,Vrx,Vry,Vn,Vjx,Vjy)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  vrset0_(Crx,Cry,&Cn,&Cjx,&Cjy);
  return Qnil;
}

static VALUE
dcl_vrset1(self,Vrx,Vry,Vn,Vjx,Vjy)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  vrset1_(Crx,Cry,&Cn,&Cjx,&Cjy);
  return Qnil;
}

static VALUE
dcl_vradd(self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetFloatArray(Crz,Vrz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  vradd_(Crx,Cry,Crz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_vradd0(self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetFloatArray(Crz,Vrz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  vradd0_(Crx,Cry,Crz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_vradd1(self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetFloatArray(Crz,Vrz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  vradd1_(Crx,Cry,Crz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_vrdiv(self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetFloatArray(Crz,Vrz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  vrdiv_(Crx,Cry,Crz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_vrdiv0(self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetFloatArray(Crz,Vrz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  vrdiv0_(Crx,Cry,Crz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_vrdiv1(self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetFloatArray(Crz,Vrz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  vrdiv1_(Crx,Cry,Crz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_vrfnb(self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz,Vrfnb)
    VALUE self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz,Vrfnb;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetFloatArray(Crz,Vrz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  MC_SetFloat(Crfnb,Vrfnb);
  vrfnb_(Crx,Cry,Crz,&Cn,&Cjx,&Cjy,&Cjz,&Crfnb);
  return Qnil;
}

static VALUE
dcl_vrfnb0(self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz,Vrfnb)
    VALUE self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz,Vrfnb;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetFloatArray(Crz,Vrz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  MC_SetFloat(Crfnb,Vrfnb);
  vrfnb0_(Crx,Cry,Crz,&Cn,&Cjx,&Cjy,&Cjz,&Crfnb);
  return Qnil;
}

static VALUE
dcl_vrfnb1(self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz,Vrfnb)
    VALUE self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz,Vrfnb;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetFloatArray(Crz,Vrz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  MC_SetFloat(Crfnb,Vrfnb);
  vrfnb1_(Crx,Cry,Crz,&Cn,&Cjx,&Cjy,&Cjz,&Crfnb);
  return Qnil;
}

static VALUE
dcl_vrmlt(self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetFloatArray(Crz,Vrz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  vrmlt_(Crx,Cry,Crz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_vrmlt0(self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetFloatArray(Crz,Vrz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  vrmlt0_(Crx,Cry,Crz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_vrmlt1(self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetFloatArray(Crz,Vrz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  vrmlt1_(Crx,Cry,Crz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_vrsub(self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetFloatArray(Crz,Vrz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  vrsub_(Crx,Cry,Crz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_vrsub0(self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetFloatArray(Crz,Vrz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  vrsub0_(Crx,Cry,Crz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_vrsub1(self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz)
    VALUE self,Vrx,Vry,Vrz,Vn,Vjx,Vjy,Vjz;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetFloatArray(Crz,Vrz);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cjz,Vjz);
  vrsub1_(Crx,Cry,Crz,&Cn,&Cjx,&Cjy,&Cjz);
  return Qnil;
}

static VALUE
dcl_ffromc(self,Vcx)
    VALUE self,Vcx;
{
  MC_SetString(Ccx,Vcx);
  float ret;
  float ffromc_();
  ret = ffromc_(Ccx,strlen(Ccx));
  return MC_NewFloat(ret);;
}

static VALUE
dcl_ifromc(self,Vcx)
    VALUE self,Vcx;
{
  MC_SetString(Ccx,Vcx);
  int ret;
  int ifromc_();
  ret = ifromc_(Ccx,strlen(Ccx));
  return MC_NewInt(ret);;
}

static VALUE
dcl_jfromc(self,Vcx)
    VALUE self,Vcx;
{
  MC_SetString(Ccx,Vcx);
  int ret;
  int jfromc_();
  ret = jfromc_(Ccx,strlen(Ccx));
  return MC_NewInt(ret);;
}

static VALUE
dcl_lfromc(self,Vcx)
    VALUE self,Vcx;
{
  MC_SetString(Ccx,Vcx);
  int ret;
  int lfromc_();
  ret = lfromc_(Ccx,strlen(Ccx));
  return MC_NewLogic(ret);;
}

static VALUE
dcl_rfromc(self,Vcx)
    VALUE self,Vcx;
{
  MC_SetString(Ccx,Vcx);
  float ret;
  float rfromc_();
  ret = rfromc_(Ccx,strlen(Ccx));
  return MC_NewFloat(ret);;
}

static VALUE
dcl_cfftb(self,Vn,Vc,Vwsave)
    VALUE self,Vn,Vc,Vwsave;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cc,Vc);
  MC_SetFloat(Cwsave,Vwsave);
  cfftb_(&Cn,&Cc,&Cwsave);
  return Qnil;
}

static VALUE
dcl_cfftb1(self,Vn,Vc,Vch,Vwa,Vifac)
    VALUE self,Vn,Vc,Vch,Vwa,Vifac;
{
  MC_SetInt(Cn,Vn);
  float Cc;
  MC_SetFloat(Cch,Vch);
  MC_SetFloat(Cwa,Vwa);
  MC_SetInt(Cifac,Vifac);
  cfftb1_(&Cn,&Cc,&Cch,&Cwa,&Cifac);
  MC_GetFloat(Cc,Vc);
  return Qnil;
}

static VALUE
dcl_cfftf(self,Vn,Vc,Vwsave)
    VALUE self,Vn,Vc,Vwsave;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cc,Vc);
  MC_SetFloat(Cwsave,Vwsave);
  cfftf_(&Cn,&Cc,&Cwsave);
  return Qnil;
}

static VALUE
dcl_cfftf1(self,Vn,Vc,Vch,Vwa,Vifac)
    VALUE self,Vn,Vc,Vch,Vwa,Vifac;
{
  MC_SetInt(Cn,Vn);
  float Cc;
  MC_SetFloat(Cch,Vch);
  MC_SetFloat(Cwa,Vwa);
  MC_SetInt(Cifac,Vifac);
  cfftf1_(&Cn,&Cc,&Cch,&Cwa,&Cifac);
  MC_GetFloat(Cc,Vc);
  return Qnil;
}

static VALUE
dcl_cffti(self,Vn,Vwsave)
    VALUE self,Vn,Vwsave;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cwsave,Vwsave);
  cffti_(&Cn,&Cwsave);
  return Qnil;
}

static VALUE
dcl_cffti1(self,Vn,Vwa,Vifac)
    VALUE self,Vn,Vwa,Vifac;
{
  MC_SetInt(Cn,Vn);
  float Cwa;
  int   Cifac;
  cffti1_(&Cn,&Cwa,&Cifac);
  MC_GetFloat(Cwa,Vwa);
  MC_GetInt(Cifac,Vifac);
  return Qnil;
}

static VALUE
dcl_cosqb(self,Vn,Vx,Vwsave)
    VALUE self,Vn,Vx,Vwsave;
{
  MC_SetInt(Cn,Vn);
  float Cx;
  MC_SetFloat(Cwsave,Vwsave);
  cosqb_(&Cn,&Cx,&Cwsave);
  MC_GetFloat(Cx,Vx);
  return Qnil;
}

static VALUE
dcl_cosqb1(self,Vn,Vx,Vw,Vxh)
    VALUE self,Vn,Vx,Vw,Vxh;
{
  MC_SetInt(Cn,Vn);
  float Cx;
  MC_SetFloat(Cw,Vw);
  float Cxh;
  cosqb1_(&Cn,&Cx,&Cw,&Cxh);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cxh,Vxh);
  return Qnil;
}

static VALUE
dcl_cosqf(self,Vn,Vx,Vwsave)
    VALUE self,Vn,Vx,Vwsave;
{
  MC_SetInt(Cn,Vn);
  float Cx;
  MC_SetFloat(Cwsave,Vwsave);
  cosqf_(&Cn,&Cx,&Cwsave);
  MC_GetFloat(Cx,Vx);
  return Qnil;
}

static VALUE
dcl_cosqf1(self,Vn,Vx,Vw,Vxh)
    VALUE self,Vn,Vx,Vw,Vxh;
{
  MC_SetInt(Cn,Vn);
  float Cx;
  MC_SetFloat(Cw,Vw);
  float Cxh;
  cosqf1_(&Cn,&Cx,&Cw,&Cxh);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cxh,Vxh);
  return Qnil;
}

static VALUE
dcl_cosqi(self,Vn,Vwsave)
    VALUE self,Vn,Vwsave;
{
  MC_SetInt(Cn,Vn);
  float Cwsave;
  cosqi_(&Cn,&Cwsave);
  MC_GetFloat(Cwsave,Vwsave);
  return Qnil;
}

static VALUE
dcl_cost(self,Vn,Vx,Vwsave)
    VALUE self,Vn,Vx,Vwsave;
{
  MC_SetInt(Cn,Vn);
  float Cx;
  MC_SetFloat(Cwsave,Vwsave);
  cost_(&Cn,&Cx,&Cwsave);
  MC_GetFloat(Cx,Vx);
  return Qnil;
}

static VALUE
dcl_costi(self,Vn,Vwsave)
    VALUE self,Vn,Vwsave;
{
  MC_SetInt(Cn,Vn);
  float Cwsave;
  costi_(&Cn,&Cwsave);
  MC_GetFloat(Cwsave,Vwsave);
  return Qnil;
}

static VALUE
dcl_ezfft1(self,Vn,Vwa,Vifac)
    VALUE self,Vn,Vwa,Vifac;
{
  MC_SetInt(Cn,Vn);
  float Cwa;
  int   Cifac;
  ezfft1_(&Cn,&Cwa,&Cifac);
  MC_GetFloat(Cwa,Vwa);
  MC_GetInt(Cifac,Vifac);
  return Qnil;
}

static VALUE
dcl_ezfftb(self,Vn,Vr,Vazero,Va,Vb,Vwsave)
    VALUE self,Vn,Vr,Vazero,Va,Vb,Vwsave;
{
  MC_SetInt(Cn,Vn);
  float Cr;
  MC_SetFloat(Cazero,Vazero);
  MC_SetFloat(Ca,Va);
  MC_SetFloat(Cb,Vb);
  MC_SetFloat(Cwsave,Vwsave);
  ezfftb_(&Cn,&Cr,&Cazero,&Ca,&Cb,&Cwsave);
  MC_GetFloat(Cr,Vr);
  return Qnil;
}

static VALUE
dcl_ezfftf(self,Vn,Vr,Vazero,Va,Vb,Vwsave)
    VALUE self,Vn,Vr,Vazero,Va,Vb,Vwsave;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cr,Vr);
  float Cazero;
  float Ca;
  float Cb;
  float Cwsave;
  ezfftf_(&Cn,&Cr,&Cazero,&Ca,&Cb,&Cwsave);
  MC_GetFloat(Cazero,Vazero);
  MC_GetFloat(Ca,Va);
  MC_GetFloat(Cb,Vb);
  MC_GetFloat(Cwsave,Vwsave);
  return Qnil;
}

static VALUE
dcl_ezffti(self,Vn,Vwsave)
    VALUE self,Vn,Vwsave;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cwsave,Vwsave);
  ezffti_(&Cn,&Cwsave);
  return Qnil;
}

static VALUE
dcl_passb(self,Vnac,Vido,Vip,Vl1,Vidl1,Vcc,Vc1,Vc2,Vch,Vch2,Vwa)
    VALUE self,Vnac,Vido,Vip,Vl1,Vidl1,Vcc,Vc1,Vc2,Vch,Vch2,Vwa;
{
  int   Cnac;
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cip,Vip);
  MC_SetInt(Cl1,Vl1);
  MC_SetInt(Cidl1,Vidl1);
  MC_SetFloat(Ccc,Vcc);
  float Cc1;
  float Cc2;
  float Cch;
  float Cch2;
  MC_SetFloat(Cwa,Vwa);
  passb_(&Cnac,&Cido,&Cip,&Cl1,&Cidl1,&Ccc,&Cc1,&Cc2,&Cch,&Cch2,&Cwa);
  MC_GetInt(Cnac,Vnac);
  MC_GetFloat(Cc1,Vc1);
  MC_GetFloat(Cc2,Vc2);
  MC_GetFloat(Cch,Vch);
  MC_GetFloat(Cch2,Vch2);
  return Qnil;
}

static VALUE
dcl_passb2(self,Vido,Vl1,Vcc,Vch,Vwa1)
    VALUE self,Vido,Vl1,Vcc,Vch,Vwa1;
{
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cl1,Vl1);
  MC_SetFloat(Ccc,Vcc);
  float Cch;
  MC_SetFloat(Cwa1,Vwa1);
  passb2_(&Cido,&Cl1,&Ccc,&Cch,&Cwa1);
  MC_GetFloat(Cch,Vch);
  return Qnil;
}

static VALUE
dcl_passb3(self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2)
    VALUE self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2;
{
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cl1,Vl1);
  MC_SetFloat(Ccc,Vcc);
  float Cch;
  MC_SetFloat(Cwa1,Vwa1);
  MC_SetFloat(Cwa2,Vwa2);
  passb3_(&Cido,&Cl1,&Ccc,&Cch,&Cwa1,&Cwa2);
  MC_GetFloat(Cch,Vch);
  return Qnil;
}

static VALUE
dcl_passb4(self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2,Vwa3)
    VALUE self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2,Vwa3;
{
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cl1,Vl1);
  MC_SetFloat(Ccc,Vcc);
  float Cch;
  MC_SetFloat(Cwa1,Vwa1);
  MC_SetFloat(Cwa2,Vwa2);
  MC_SetFloat(Cwa3,Vwa3);
  passb4_(&Cido,&Cl1,&Ccc,&Cch,&Cwa1,&Cwa2,&Cwa3);
  MC_GetFloat(Cch,Vch);
  return Qnil;
}

static VALUE
dcl_passb5(self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2,Vwa3,Vwa4)
    VALUE self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2,Vwa3,Vwa4;
{
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cl1,Vl1);
  MC_SetFloat(Ccc,Vcc);
  float Cch;
  MC_SetFloat(Cwa1,Vwa1);
  MC_SetFloat(Cwa2,Vwa2);
  MC_SetFloat(Cwa3,Vwa3);
  MC_SetFloat(Cwa4,Vwa4);
  passb5_(&Cido,&Cl1,&Ccc,&Cch,&Cwa1,&Cwa2,&Cwa3,&Cwa4);
  MC_GetFloat(Cch,Vch);
  return Qnil;
}

static VALUE
dcl_passf(self,Vnac,Vido,Vip,Vl1,Vidl1,Vcc,Vc1,Vc2,Vch,Vch2,Vwa)
    VALUE self,Vnac,Vido,Vip,Vl1,Vidl1,Vcc,Vc1,Vc2,Vch,Vch2,Vwa;
{
  int   Cnac;
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cip,Vip);
  MC_SetInt(Cl1,Vl1);
  MC_SetInt(Cidl1,Vidl1);
  MC_SetFloat(Ccc,Vcc);
  float Cc1;
  float Cc2;
  float Cch;
  float Cch2;
  MC_SetFloat(Cwa,Vwa);
  passf_(&Cnac,&Cido,&Cip,&Cl1,&Cidl1,&Ccc,&Cc1,&Cc2,&Cch,&Cch2,&Cwa);
  MC_GetInt(Cnac,Vnac);
  MC_GetFloat(Cc1,Vc1);
  MC_GetFloat(Cc2,Vc2);
  MC_GetFloat(Cch,Vch);
  MC_GetFloat(Cch2,Vch2);
  return Qnil;
}

static VALUE
dcl_passf2(self,Vido,Vl1,Vcc,Vch,Vwa1)
    VALUE self,Vido,Vl1,Vcc,Vch,Vwa1;
{
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cl1,Vl1);
  MC_SetFloat(Ccc,Vcc);
  float Cch;
  MC_SetFloat(Cwa1,Vwa1);
  passf2_(&Cido,&Cl1,&Ccc,&Cch,&Cwa1);
  MC_GetFloat(Cch,Vch);
  return Qnil;
}

static VALUE
dcl_passf3(self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2)
    VALUE self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2;
{
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cl1,Vl1);
  MC_SetFloat(Ccc,Vcc);
  float Cch;
  MC_SetFloat(Cwa1,Vwa1);
  MC_SetFloat(Cwa2,Vwa2);
  passf3_(&Cido,&Cl1,&Ccc,&Cch,&Cwa1,&Cwa2);
  MC_GetFloat(Cch,Vch);
  return Qnil;
}

static VALUE
dcl_passf4(self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2,Vwa3)
    VALUE self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2,Vwa3;
{
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cl1,Vl1);
  MC_SetFloat(Ccc,Vcc);
  float Cch;
  MC_SetFloat(Cwa1,Vwa1);
  MC_SetFloat(Cwa2,Vwa2);
  MC_SetFloat(Cwa3,Vwa3);
  passf4_(&Cido,&Cl1,&Ccc,&Cch,&Cwa1,&Cwa2,&Cwa3);
  MC_GetFloat(Cch,Vch);
  return Qnil;
}

static VALUE
dcl_passf5(self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2,Vwa3,Vwa4)
    VALUE self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2,Vwa3,Vwa4;
{
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cl1,Vl1);
  MC_SetFloat(Ccc,Vcc);
  float Cch;
  MC_SetFloat(Cwa1,Vwa1);
  MC_SetFloat(Cwa2,Vwa2);
  MC_SetFloat(Cwa3,Vwa3);
  MC_SetFloat(Cwa4,Vwa4);
  passf5_(&Cido,&Cl1,&Ccc,&Cch,&Cwa1,&Cwa2,&Cwa3,&Cwa4);
  MC_GetFloat(Cch,Vch);
  return Qnil;
}

static VALUE
dcl_radb2(self,Vido,Vl1,Vcc,Vch,Vwa1)
    VALUE self,Vido,Vl1,Vcc,Vch,Vwa1;
{
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cl1,Vl1);
  MC_SetFloat(Ccc,Vcc);
  float Cch;
  MC_SetFloat(Cwa1,Vwa1);
  radb2_(&Cido,&Cl1,&Ccc,&Cch,&Cwa1);
  MC_GetFloat(Cch,Vch);
  return Qnil;
}

static VALUE
dcl_radb3(self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2)
    VALUE self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2;
{
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cl1,Vl1);
  MC_SetFloat(Ccc,Vcc);
  float Cch;
  MC_SetFloat(Cwa1,Vwa1);
  MC_SetFloat(Cwa2,Vwa2);
  radb3_(&Cido,&Cl1,&Ccc,&Cch,&Cwa1,&Cwa2);
  MC_GetFloat(Cch,Vch);
  return Qnil;
}

static VALUE
dcl_radb4(self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2,Vwa3)
    VALUE self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2,Vwa3;
{
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cl1,Vl1);
  MC_SetFloat(Ccc,Vcc);
  float Cch;
  MC_SetFloat(Cwa1,Vwa1);
  MC_SetFloat(Cwa2,Vwa2);
  MC_SetFloat(Cwa3,Vwa3);
  radb4_(&Cido,&Cl1,&Ccc,&Cch,&Cwa1,&Cwa2,&Cwa3);
  MC_GetFloat(Cch,Vch);
  return Qnil;
}

static VALUE
dcl_radb5(self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2,Vwa3,Vwa4)
    VALUE self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2,Vwa3,Vwa4;
{
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cl1,Vl1);
  MC_SetFloat(Ccc,Vcc);
  float Cch;
  MC_SetFloat(Cwa1,Vwa1);
  MC_SetFloat(Cwa2,Vwa2);
  MC_SetFloat(Cwa3,Vwa3);
  MC_SetFloat(Cwa4,Vwa4);
  radb5_(&Cido,&Cl1,&Ccc,&Cch,&Cwa1,&Cwa2,&Cwa3,&Cwa4);
  MC_GetFloat(Cch,Vch);
  return Qnil;
}

static VALUE
dcl_radbg(self,Vido,Vip,Vl1,Vidl1,Vcc,Vc1,Vc2,Vch,Vch2,Vwa)
    VALUE self,Vido,Vip,Vl1,Vidl1,Vcc,Vc1,Vc2,Vch,Vch2,Vwa;
{
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cip,Vip);
  MC_SetInt(Cl1,Vl1);
  MC_SetInt(Cidl1,Vidl1);
  MC_SetFloat(Ccc,Vcc);
  float Cc1;
  float Cc2;
  float Cch;
  float Cch2;
  MC_SetFloat(Cwa,Vwa);
  radbg_(&Cido,&Cip,&Cl1,&Cidl1,&Ccc,&Cc1,&Cc2,&Cch,&Cch2,&Cwa);
  MC_GetFloat(Cc1,Vc1);
  MC_GetFloat(Cc2,Vc2);
  MC_GetFloat(Cch,Vch);
  MC_GetFloat(Cch2,Vch2);
  return Qnil;
}

static VALUE
dcl_radf2(self,Vido,Vl1,Vcc,Vch,Vwa1)
    VALUE self,Vido,Vl1,Vcc,Vch,Vwa1;
{
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cl1,Vl1);
  MC_SetFloat(Ccc,Vcc);
  float Cch;
  MC_SetFloat(Cwa1,Vwa1);
  radf2_(&Cido,&Cl1,&Ccc,&Cch,&Cwa1);
  MC_GetFloat(Cch,Vch);
  return Qnil;
}

static VALUE
dcl_radf3(self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2)
    VALUE self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2;
{
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cl1,Vl1);
  MC_SetFloat(Ccc,Vcc);
  float Cch;
  MC_SetFloat(Cwa1,Vwa1);
  MC_SetFloat(Cwa2,Vwa2);
  radf3_(&Cido,&Cl1,&Ccc,&Cch,&Cwa1,&Cwa2);
  MC_GetFloat(Cch,Vch);
  return Qnil;
}

static VALUE
dcl_radf4(self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2,Vwa3)
    VALUE self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2,Vwa3;
{
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cl1,Vl1);
  MC_SetFloat(Ccc,Vcc);
  float Cch;
  MC_SetFloat(Cwa1,Vwa1);
  MC_SetFloat(Cwa2,Vwa2);
  MC_SetFloat(Cwa3,Vwa3);
  radf4_(&Cido,&Cl1,&Ccc,&Cch,&Cwa1,&Cwa2,&Cwa3);
  MC_GetFloat(Cch,Vch);
  return Qnil;
}

static VALUE
dcl_radf5(self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2,Vwa3,Vwa4)
    VALUE self,Vido,Vl1,Vcc,Vch,Vwa1,Vwa2,Vwa3,Vwa4;
{
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cl1,Vl1);
  MC_SetFloat(Ccc,Vcc);
  float Cch;
  MC_SetFloat(Cwa1,Vwa1);
  MC_SetFloat(Cwa2,Vwa2);
  MC_SetFloat(Cwa3,Vwa3);
  MC_SetFloat(Cwa4,Vwa4);
  radf5_(&Cido,&Cl1,&Ccc,&Cch,&Cwa1,&Cwa2,&Cwa3,&Cwa4);
  MC_GetFloat(Cch,Vch);
  return Qnil;
}

static VALUE
dcl_radfg(self,Vido,Vip,Vl1,Vidl1,Vcc,Vc1,Vc2,Vch,Vch2,Vwa)
    VALUE self,Vido,Vip,Vl1,Vidl1,Vcc,Vc1,Vc2,Vch,Vch2,Vwa;
{
  MC_SetInt(Cido,Vido);
  MC_SetInt(Cip,Vip);
  MC_SetInt(Cl1,Vl1);
  MC_SetInt(Cidl1,Vidl1);
  float Ccc;
  float Cc1;
  float Cc2;
  float Cch;
  float Cch2;
  MC_SetFloat(Cwa,Vwa);
  radfg_(&Cido,&Cip,&Cl1,&Cidl1,&Ccc,&Cc1,&Cc2,&Cch,&Cch2,&Cwa);
  MC_GetFloat(Ccc,Vcc);
  MC_GetFloat(Cc1,Vc1);
  MC_GetFloat(Cc2,Vc2);
  MC_GetFloat(Cch,Vch);
  MC_GetFloat(Cch2,Vch2);
  return Qnil;
}

static VALUE
dcl_rfftb(self,Vn,Vr,Vwsave)
    VALUE self,Vn,Vr,Vwsave;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cr,Vr);
  MC_SetFloat(Cwsave,Vwsave);
  rfftb_(&Cn,&Cr,&Cwsave);
  return Qnil;
}

static VALUE
dcl_rfftb1(self,Vn,Vc,Vch,Vwa,Vifac)
    VALUE self,Vn,Vc,Vch,Vwa,Vifac;
{
  MC_SetInt(Cn,Vn);
  float Cc;
  MC_SetFloat(Cch,Vch);
  MC_SetFloat(Cwa,Vwa);
  MC_SetInt(Cifac,Vifac);
  rfftb1_(&Cn,&Cc,&Cch,&Cwa,&Cifac);
  MC_GetFloat(Cc,Vc);
  return Qnil;
}

static VALUE
dcl_rfftf(self,Vn,Vr,Vwsave)
    VALUE self,Vn,Vr,Vwsave;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cr,Vr);
  MC_SetFloat(Cwsave,Vwsave);
  rfftf_(&Cn,&Cr,&Cwsave);
  return Qnil;
}

static VALUE
dcl_rfftf1(self,Vn,Vc,Vch,Vwa,Vifac)
    VALUE self,Vn,Vc,Vch,Vwa,Vifac;
{
  MC_SetInt(Cn,Vn);
  float Cc;
  MC_SetFloat(Cch,Vch);
  MC_SetFloat(Cwa,Vwa);
  MC_SetInt(Cifac,Vifac);
  rfftf1_(&Cn,&Cc,&Cch,&Cwa,&Cifac);
  MC_GetFloat(Cc,Vc);
  return Qnil;
}

static VALUE
dcl_rffti(self,Vn,Vwsave)
    VALUE self,Vn,Vwsave;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cwsave,Vwsave);
  rffti_(&Cn,&Cwsave);
  return Qnil;
}

static VALUE
dcl_rffti1(self,Vn,Vwa,Vifac)
    VALUE self,Vn,Vwa,Vifac;
{
  MC_SetInt(Cn,Vn);
  float Cwa;
  int   Cifac;
  rffti1_(&Cn,&Cwa,&Cifac);
  MC_GetFloat(Cwa,Vwa);
  MC_GetInt(Cifac,Vifac);
  return Qnil;
}

static VALUE
dcl_sinqb(self,Vn,Vx,Vwsave)
    VALUE self,Vn,Vx,Vwsave;
{
  MC_SetInt(Cn,Vn);
  float Cx;
  MC_SetFloat(Cwsave,Vwsave);
  sinqb_(&Cn,&Cx,&Cwsave);
  MC_GetFloat(Cx,Vx);
  return Qnil;
}

static VALUE
dcl_sinqf(self,Vn,Vx,Vwsave)
    VALUE self,Vn,Vx,Vwsave;
{
  MC_SetInt(Cn,Vn);
  float Cx;
  MC_SetFloat(Cwsave,Vwsave);
  sinqf_(&Cn,&Cx,&Cwsave);
  MC_GetFloat(Cx,Vx);
  return Qnil;
}

static VALUE
dcl_sinqi(self,Vn,Vwsave)
    VALUE self,Vn,Vwsave;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cwsave,Vwsave);
  sinqi_(&Cn,&Cwsave);
  return Qnil;
}

static VALUE
dcl_sint(self,Vn,Vx,Vwsave)
    VALUE self,Vn,Vx,Vwsave;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cwsave,Vwsave);
  sint_(&Cn,&Cx,&Cwsave);
  return Qnil;
}

static VALUE
dcl_sint1(self,Vn,Vwar,Vwas,Vxh,Vx,Vifac)
    VALUE self,Vn,Vwar,Vwas,Vxh,Vx,Vifac;
{
  MC_SetInt(Cn,Vn);
  float Cwar;
  MC_SetFloat(Cwas,Vwas);
  float Cxh;
  float Cx;
  MC_SetInt(Cifac,Vifac);
  sint1_(&Cn,&Cwar,&Cwas,&Cxh,&Cx,&Cifac);
  MC_GetFloat(Cwar,Vwar);
  MC_GetFloat(Cxh,Vxh);
  MC_GetFloat(Cx,Vx);
  return Qnil;
}

static VALUE
dcl_sinti(self,Vn,Vwsave)
    VALUE self,Vn,Vwsave;
{
  MC_SetInt(Cn,Vn);
  float Cwsave;
  sinti_(&Cn,&Cwsave);
  MC_GetFloat(Cwsave,Vwsave);
  return Qnil;
}

static VALUE
dcl_vcintr(self,Vcx,Vn,Vjx)
    VALUE self,Vcx,Vn,Vjx;
{
  MC_SetFloat(Ccx,Vcx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  vcintr_(&Ccx,&Cn,&Cjx);
  return Qnil;
}

static VALUE
dcl_vrintr(self,Vrx,Vn,Vjx)
    VALUE self,Vrx,Vn,Vjx;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  vrintr_(Crx,&Cn,&Cjx);
  return Qnil;
}

static VALUE
dcl_odpget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  odpget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_odiget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int   Cipara;
  odiget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_odrget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  float Cipara;
  odrget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetFloat(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_odlget(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  int    Cipara;
  odlget_(Ccp,&Cipara,strlen(Ccp));
  MC_GetLogic(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_odpset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  odpset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_odiset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  odiset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_odrset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  odrset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_odlset(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  odlset_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_odpstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  odpstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_odistx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetInt(Cipara,Vipara);
  odistx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_odrstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetFloat(Cipara,Vipara);
  odrstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_odlstx(self,Vcp,Vipara)
    VALUE self,Vcp,Vipara;
{
  MC_SetString(Ccp,Vcp);
  MC_SetLogic(Cipara,Vipara);
  odlstx_(Ccp,&Cipara,strlen(Ccp));
  return Qnil;
}

static VALUE
dcl_odpqnp(self,Vncp)
    VALUE self,Vncp;
{
  int   Cncp;
  odpqnp_(&Cncp);
  MC_GetInt(Cncp,Vncp);
  return Qnil;
}

static VALUE
dcl_odpqid(self,Vcp,Vidx)
    VALUE self,Vcp,Vidx;
{
  MC_SetString(Ccp,Vcp);
  int   Cidx;
  odpqid_(Ccp,&Cidx,strlen(Ccp));
  MC_GetInt(Cidx,Vidx);
  return Qnil;
}

static VALUE
dcl_odpqcp(self,Vidx,Vcp)
    VALUE self,Vidx,Vcp;
{
  MC_SetInt(Cidx,Vidx);
  char * Ccp="                ";
  odpqcp_(&Cidx,Ccp,strlen(Ccp));
  MC_GetString(Ccp,Vcp);
  return Qnil;
}

static VALUE
dcl_odpqvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  int   Cipara;
  odpqvl_(&Cidx,&Cipara);
  MC_GetInt(Cipara,Vipara);
  return Qnil;
}

static VALUE
dcl_odpsvl(self,Vidx,Vipara)
    VALUE self,Vidx,Vipara;
{
  MC_SetInt(Cidx,Vidx);
  MC_SetInt(Cipara,Vipara);
  odpsvl_(&Cidx,&Cipara);
  return Qnil;
}

static VALUE
dcl_odrk1(self,Vn,Vfcn,Vt,Vdt,Vx,Vdx,Vxout,Vwork)
    VALUE self,Vn,Vfcn,Vt,Vdt,Vx,Vdx,Vxout,Vwork;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cfcn,Vfcn);
  MC_SetFloat(Ct,Vt);
  MC_SetFloat(Cdt,Vdt);
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cdx,Vdx);
  float Cxout;
  MC_SetFloat(Cwork,Vwork);
  odrk1_(&Cn,&Cfcn,&Ct,&Cdt,&Cx,&Cdx,&Cxout,&Cwork);
  MC_GetFloat(Cxout,Vxout);
  return Qnil;
}

static VALUE
dcl_odrk2(self,Vn,Vfcn,Vt,Vdt,Vx,Vdx,Vxout,Vwork)
    VALUE self,Vn,Vfcn,Vt,Vdt,Vx,Vdx,Vxout,Vwork;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cfcn,Vfcn);
  MC_SetFloat(Ct,Vt);
  MC_SetFloat(Cdt,Vdt);
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cdx,Vdx);
  float Cxout;
  MC_SetFloat(Cwork,Vwork);
  odrk2_(&Cn,&Cfcn,&Ct,&Cdt,&Cx,&Cdx,&Cxout,&Cwork);
  MC_GetFloat(Cxout,Vxout);
  return Qnil;
}

static VALUE
dcl_odrk4(self,Vn,Vfcn,Vt,Vdt,Vx,Vdx,Vxout,Vwork)
    VALUE self,Vn,Vfcn,Vt,Vdt,Vx,Vdx,Vxout,Vwork;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cfcn,Vfcn);
  MC_SetFloat(Ct,Vt);
  MC_SetFloat(Cdt,Vdt);
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cdx,Vdx);
  float Cxout;
  float Cwork;
  odrk4_(&Cn,&Cfcn,&Ct,&Cdt,&Cx,&Cdx,&Cxout,&Cwork);
  MC_GetFloat(Cxout,Vxout);
  MC_GetFloat(Cwork,Vwork);
  return Qnil;
}

static VALUE
dcl_odrk4r(self,Vn,Vfcn,Vt,Vdt,Vepsl,Vx,Vwork)
    VALUE self,Vn,Vfcn,Vt,Vdt,Vepsl,Vx,Vwork;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cfcn,Vfcn);
  float Ct;
  float Cdt;
  MC_SetFloat(Cepsl,Vepsl);
  float Cx;
  float Cwork;
  odrk4r_(&Cn,&Cfcn,&Ct,&Cdt,&Cepsl,&Cx,&Cwork);
  MC_GetFloat(Ct,Vt);
  MC_GetFloat(Cdt,Vdt);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cwork,Vwork);
  return Qnil;
}

static VALUE
dcl_odrk4s(self,Vn,Vfcn,Vt,Vdt,Vepsl,Vx,Vwork)
    VALUE self,Vn,Vfcn,Vt,Vdt,Vepsl,Vx,Vwork;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cfcn,Vfcn);
  float Ct;
  float Cdt;
  MC_SetFloat(Cepsl,Vepsl);
  MC_SetFloat(Cx,Vx);
  float Cwork;
  odrk4s_(&Cn,&Cfcn,&Ct,&Cdt,&Cepsl,&Cx,&Cwork);
  MC_GetFloat(Ct,Vt);
  MC_GetFloat(Cdt,Vdt);
  MC_GetFloat(Cwork,Vwork);
  return Qnil;
}

static VALUE
dcl_odrkdu(self,Vn,Valgr,Vfcn,Vt,Vtend,Vistep,Vx,Vwork)
    VALUE self,Vn,Valgr,Vfcn,Vt,Vtend,Vistep,Vx,Vwork;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Calgr,Valgr);
  MC_SetFloat(Cfcn,Vfcn);
  float Ct;
  MC_SetFloat(Ctend,Vtend);
  MC_SetInt(Cistep,Vistep);
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cwork,Vwork);
  odrkdu_(&Cn,&Calgr,&Cfcn,&Ct,&Ctend,&Cistep,&Cx,&Cwork);
  MC_GetFloat(Ct,Vt);
  return Qnil;
}

static VALUE
dcl_odrkdv(self,Vn,Vsteper,Vfcn,Vt,Vtend,Vdt,Vx,Vwork)
    VALUE self,Vn,Vsteper,Vfcn,Vt,Vtend,Vdt,Vx,Vwork;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Csteper,Vsteper);
  MC_SetFloat(Cfcn,Vfcn);
  MC_SetFloat(Ct,Vt);
  MC_SetFloat(Ctend,Vtend);
  float Cdt;
  MC_SetFloat(Cx,Vx);
  MC_SetFloat(Cwork,Vwork);
  odrkdv_(&Cn,&Csteper,&Cfcn,&Ct,&Ctend,&Cdt,&Cx,&Cwork);
  MC_GetFloat(Cdt,Vdt);
  return Qnil;
}

static VALUE
dcl_odrkg(self,Vn,Vfcn,Vt,Vdt,Vx,Vdx,Vxout,Vwork)
    VALUE self,Vn,Vfcn,Vt,Vdt,Vx,Vdx,Vxout,Vwork;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cfcn,Vfcn);
  MC_SetFloat(Ct,Vt);
  MC_SetFloat(Cdt,Vdt);
  MC_SetFloat(Cx,Vx);
  float Cdx;
  float Cxout;
  MC_SetFloat(Cwork,Vwork);
  odrkg_(&Cn,&Cfcn,&Ct,&Cdt,&Cx,&Cdx,&Cxout,&Cwork);
  MC_GetFloat(Cdx,Vdx);
  MC_GetFloat(Cxout,Vxout);
  return Qnil;
}

static VALUE
dcl_odrkgr(self,Vn,Vfcn,Vt,Vdt,Vepsl,Vx,Vwork)
    VALUE self,Vn,Vfcn,Vt,Vdt,Vepsl,Vx,Vwork;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cfcn,Vfcn);
  float Ct;
  float Cdt;
  MC_SetFloat(Cepsl,Vepsl);
  float Cx;
  float Cwork;
  odrkgr_(&Cn,&Cfcn,&Ct,&Cdt,&Cepsl,&Cx,&Cwork);
  MC_GetFloat(Ct,Vt);
  MC_GetFloat(Cdt,Vdt);
  MC_GetFloat(Cx,Vx);
  MC_GetFloat(Cwork,Vwork);
  return Qnil;
}

static VALUE
dcl_odrkgs(self,Vn,Vfcn,Vt,Vdt,Vepsl,Vx,Vwork)
    VALUE self,Vn,Vfcn,Vt,Vdt,Vepsl,Vx,Vwork;
{
  MC_SetInt(Cn,Vn);
  MC_SetFloat(Cfcn,Vfcn);
  float Ct;
  float Cdt;
  MC_SetFloat(Cepsl,Vepsl);
  MC_SetFloat(Cx,Vx);
  float Cwork;
  odrkgs_(&Cn,&Cfcn,&Ct,&Cdt,&Cepsl,&Cx,&Cwork);
  MC_GetFloat(Ct,Vt);
  MC_GetFloat(Cdt,Vdt);
  MC_GetFloat(Cwork,Vwork);
  return Qnil;
}

static VALUE
dcl_vrrnm(self,Vrx,Vry,Vn,Vjx,Vjy,Vnb)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy,Vnb;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cnb,Vnb);
  vrrnm_(Crx,Cry,&Cn,&Cjx,&Cjy,&Cnb);
  return Qnil;
}

static VALUE
dcl_vrrnm0(self,Vrx,Vry,Vn,Vjx,Vjy,Vnb)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy,Vnb;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cnb,Vnb);
  vrrnm0_(Crx,Cry,&Cn,&Cjx,&Cjy,&Cnb);
  return Qnil;
}

static VALUE
dcl_vrrnm1(self,Vrx,Vry,Vn,Vjx,Vjy,Vnb)
    VALUE self,Vrx,Vry,Vn,Vjx,Vjy,Vnb;
{
  MC_SetFloatArray(Crx,Vrx);
  MC_SetFloatArray(Cry,Vry);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cjx,Vjx);
  MC_SetInt(Cjy,Vjy);
  MC_SetInt(Cnb,Vnb);
  vrrnm1_(Crx,Cry,&Cn,&Cjx,&Cjy,&Cnb);
  return Qnil;
}

static VALUE
dcl_shfftb(self,Vnfft,Vxfft,Vwfft)
    VALUE self,Vnfft,Vxfft,Vwfft;
{
  MC_SetInt(Cnfft,Vnfft);
  MC_SetFloatArray(Cxfft,Vxfft);
  MC_SetFloatArray(Cwfft,Vwfft);
  shfftb_(&Cnfft,Cxfft,Cwfft);
  return Qnil;
}

static VALUE
dcl_shfftf(self,Vnfft,Vxfft,Vwfft)
    VALUE self,Vnfft,Vxfft,Vwfft;
{
  MC_SetInt(Cnfft,Vnfft);
  MC_SetFloatArray(Cxfft,Vxfft);
  MC_SetFloatArray(Cwfft,Vwfft);
  shfftf_(&Cnfft,Cxfft,Cwfft);
  return Qnil;
}

static VALUE
dcl_shfg2w(self,Vmm,Vjm,Vim,Vg,Vw,Vh,Vwfft)
    VALUE self,Vmm,Vjm,Vim,Vg,Vw,Vh,Vwfft;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cim,Vim);
  MC_SetFloatArray(Cg,Vg);
  MC_SetFloatArray(Cw,Vw);
  MC_SetFloatArray(Ch,Vh);
  MC_SetFloatArray(Cwfft,Vwfft);
  shfg2w_(&Cmm,&Cjm,&Cim,Cg,Cw,Ch,Cwfft);
  return Qnil;
}

static VALUE
dcl_shfw2g(self,Vmm,Vjm,Vim,Vw,Vg,Vh,Vwfft)
    VALUE self,Vmm,Vjm,Vim,Vw,Vg,Vh,Vwfft;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cim,Vim);
  MC_SetFloatArray(Cw,Vw);
  MC_SetFloatArray(Cg,Vg);
  MC_SetFloatArray(Ch,Vh);
  MC_SetFloatArray(Cwfft,Vwfft);
  shfw2g_(&Cmm,&Cjm,&Cim,Cw,Cg,Ch,Cwfft);
  return Qnil;
}

static VALUE
dcl_shfwga(self,Vmm,Vjm,Vim,Vm1,Vm2,Vw,Vg,Vh,Vwfft)
    VALUE self,Vmm,Vjm,Vim,Vm1,Vm2,Vw,Vg,Vh,Vwfft;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cm1,Vm1);
  MC_SetInt(Cm2,Vm2);
  MC_SetFloatArray(Cw,Vw);
  MC_SetFloatArray(Cg,Vg);
  MC_SetFloatArray(Ch,Vh);
  MC_SetFloatArray(Cwfft,Vwfft);
  shfwga_(&Cmm,&Cjm,&Cim,&Cm1,&Cm2,Cw,Cg,Ch,Cwfft);
  return Qnil;
}

static VALUE
dcl_shfwgj(self,Vmm,Vim,Vm1,Vm2,Vwj,Vgj,Vh,Vwfft)
    VALUE self,Vmm,Vim,Vm1,Vm2,Vwj,Vgj,Vh,Vwfft;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cm1,Vm1);
  MC_SetInt(Cm2,Vm2);
  MC_SetFloatArray(Cwj,Vwj);
  MC_SetFloatArray(Cgj,Vgj);
  MC_SetFloatArray(Ch,Vh);
  MC_SetFloatArray(Cwfft,Vwfft);
  shfwgj_(&Cmm,&Cim,&Cm1,&Cm2,Cwj,Cgj,Ch,Cwfft);
  return Qnil;
}

static VALUE
dcl_shfwgm(self,Vjm,Vim,Vm,Vwr,Vwi,Vg,Vh,Vwfft)
    VALUE self,Vjm,Vim,Vm,Vwr,Vwi,Vg,Vh,Vwfft;
{
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cm,Vm);
  MC_SetFloatArray(Cwr,Vwr);
  MC_SetFloatArray(Cwi,Vwi);
  MC_SetFloatArray(Cg,Vg);
  MC_SetFloatArray(Ch,Vh);
  MC_SetFloatArray(Cwfft,Vwfft);
  shfwgm_(&Cjm,&Cim,&Cm,Cwr,Cwi,Cg,Ch,Cwfft);
  return Qnil;
}

static VALUE
dcl_shfwgz(self,Vjm,Vim,Vwz,Vg)
    VALUE self,Vjm,Vim,Vwz,Vg;
{
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cim,Vim);
  MC_SetFloatArray(Cwz,Vwz);
  MC_SetFloatArray(Cg,Vg);
  shfwgz_(&Cjm,&Cim,Cwz,Cg);
  return Qnil;
}

static VALUE
dcl_shinic(self,Vmm,Vjm,Vxw,Vpx)
    VALUE self,Vmm,Vjm,Vxw,Vpx;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetFloatArray(Cxw,Vxw);
  MC_SetFloatArray(Cpx,Vpx);
  shinic_(&Cmm,&Cjm,Cxw,Cpx);
  return Qnil;
}

static VALUE
dcl_shinif(self,Vnfft,Vwfft)
    VALUE self,Vnfft,Vwfft;
{
  MC_SetInt(Cnfft,Vnfft);
  MC_SetFloatArray(Cwfft,Vwfft);
  shinif_(&Cnfft,Cwfft);
  return Qnil;
}

static VALUE
dcl_shinip(self,Vmm,Vjm,Vys,Vyc,Vpy)
    VALUE self,Vmm,Vjm,Vys,Vyc,Vpy;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetFloatArray(Cys,Vys);
  MC_SetFloatArray(Cyc,Vyc);
  MC_SetFloatArray(Cpy,Vpy);
  shinip_(&Cmm,&Cjm,Cys,Cyc,Cpy);
  return Qnil;
}

static VALUE
dcl_shinir(self,Vmm,Vr)
    VALUE self,Vmm,Vr;
{
  MC_SetInt(Cmm,Vmm);
  float Cr;
  shinir_(&Cmm,&Cr);
  MC_GetFloat(Cr,Vr);
  return Qnil;
}

static VALUE
dcl_shinit(self,Vmm,Vjm,Vim,Vy,Vys,Vyc,Vx,Vxs,Vxc,Vxw,Vz,Vpy,Vpx,Vr,Vwfft)
    VALUE self,Vmm,Vjm,Vim,Vy,Vys,Vyc,Vx,Vxs,Vxc,Vxw,Vz,Vpy,Vpx,Vr,Vwfft;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cim,Vim);
  MC_SetFloatArray(Cy,Vy);
  MC_SetFloatArray(Cys,Vys);
  MC_SetFloatArray(Cyc,Vyc);
  MC_SetFloatArray(Cx,Vx);
  MC_SetFloatArray(Cxs,Vxs);
  MC_SetFloatArray(Cxc,Vxc);
  MC_SetFloatArray(Cxw,Vxw);
  MC_SetFloatArray(Cz,Vz);
  MC_SetFloatArray(Cpy,Vpy);
  MC_SetFloatArray(Cpx,Vpx);
  MC_SetFloat(Cr,Vr);
  MC_SetFloatArray(Cwfft,Vwfft);
  shinit_(&Cmm,&Cjm,&Cim,Cy,Cys,Cyc,Cx,Cxs,Cxc,Cxw,Cz,Cpy,Cpx,&Cr,Cwfft);
  return Qnil;
}

static VALUE
dcl_shinix(self,Vjm,Vx,Vxs,Vxc,Vxw)
    VALUE self,Vjm,Vx,Vxs,Vxc,Vxw;
{
  MC_SetInt(Cjm,Vjm);
  MC_SetFloatArray(Cx,Vx);
  MC_SetFloatArray(Cxs,Vxs);
  MC_SetFloatArray(Cxc,Vxc);
  MC_SetFloatArray(Cxw,Vxw);
  shinix_(&Cjm,Cx,Cxs,Cxc,Cxw);
  return Qnil;
}

static VALUE
dcl_shiniy(self,Vjm,Vy,Vys,Vyc)
    VALUE self,Vjm,Vy,Vys,Vyc;
{
  MC_SetInt(Cjm,Vjm);
  MC_SetFloatArray(Cy,Vy);
  MC_SetFloatArray(Cys,Vys);
  MC_SetFloatArray(Cyc,Vyc);
  shiniy_(&Cjm,Cy,Cys,Cyc);
  return Qnil;
}

static VALUE
dcl_shiniz(self,Vjm,Vx,Vy,Vz)
    VALUE self,Vjm,Vx,Vy,Vz;
{
  MC_SetInt(Cjm,Vjm);
  MC_SetFloatArray(Cx,Vx);
  MC_SetFloatArray(Cy,Vy);
  MC_SetFloatArray(Cz,Vz);
  shiniz_(&Cjm,Cx,Cy,Cz);
  return Qnil;
}

static VALUE
dcl_shlbwj(self,Vmm,Vjm,Vm,Vj,Visw,Vsm,Vwmj,Vsd,Vpmj,Vyc,Vr)
    VALUE self,Vmm,Vjm,Vm,Vj,Visw,Vsm,Vwmj,Vsd,Vpmj,Vyc,Vr;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cm,Vm);
  MC_SetInt(Cj,Vj);
  MC_SetInt(Cisw,Visw);
  MC_SetFloatArray(Csm,Vsm);
  float Cwmj;
  MC_SetFloatArray(Csd,Vsd);
  MC_SetFloatArray(Cpmj,Vpmj);
  MC_SetFloatArray(Cyc,Vyc);
  MC_SetFloat(Cr,Vr);
  shlbwj_(&Cmm,&Cjm,&Cm,&Cj,&Cisw,Csm,&Cwmj,Csd,Cpmj,Cyc,&Cr);
  MC_GetFloat(Cwmj,Vwmj);
  return Qnil;
}

static VALUE
dcl_shlbwl(self,Vmm,Vm,Vsd,Vws,Vwa,Vpmj)
    VALUE self,Vmm,Vm,Vsd,Vws,Vwa,Vpmj;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cm,Vm);
  MC_SetFloatArray(Csd,Vsd);
  float Cws;
  MC_SetFloat(Cwa,Vwa);
  MC_SetFloatArray(Cpmj,Vpmj);
  shlbwl_(&Cmm,&Cm,Csd,&Cws,&Cwa,Cpmj);
  MC_GetFloat(Cws,Vws);
  return Qnil;
}

static VALUE
dcl_shlbwm(self,Vmm,Vjm,Vm,Visw,Vsm,Vwm,Vsd,Vpm,Vyc,Vr)
    VALUE self,Vmm,Vjm,Vm,Visw,Vsm,Vwm,Vsd,Vpm,Vyc,Vr;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cm,Vm);
  MC_SetInt(Cisw,Visw);
  MC_SetFloatArray(Csm,Vsm);
  MC_SetFloatArray(Cwm,Vwm);
  MC_SetFloatArray(Csd,Vsd);
  MC_SetFloatArray(Cpm,Vpm);
  MC_SetFloatArray(Cyc,Vyc);
  MC_SetFloat(Cr,Vr);
  shlbwm_(&Cmm,&Cjm,&Cm,&Cisw,Csm,Cwm,Csd,Cpm,Cyc,&Cr);
  return Qnil;
}

static VALUE
dcl_shlbwu(self,Vmm,Vjm,Vm,Visw,Vsm,Vwm,Vsd,Vpm,Vys,Vyc,Vpy,Vr)
    VALUE self,Vmm,Vjm,Vm,Visw,Vsm,Vwm,Vsd,Vpm,Vys,Vyc,Vpy,Vr;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cm,Vm);
  MC_SetInt(Cisw,Visw);
  MC_SetFloatArray(Csm,Vsm);
  MC_SetFloatArray(Cwm,Vwm);
  MC_SetFloatArray(Csd,Vsd);
  MC_SetFloatArray(Cpm,Vpm);
  MC_SetFloatArray(Cys,Vys);
  MC_SetFloatArray(Cyc,Vyc);
  MC_SetFloatArray(Cpy,Vpy);
  MC_SetFloat(Cr,Vr);
  shlbwu_(&Cmm,&Cjm,&Cm,&Cisw,Csm,Cwm,Csd,Cpm,Cys,Cyc,Cpy,&Cr);
  return Qnil;
}

static VALUE
dcl_shlfwl(self,Vmm,Vjm,Vn,Vm,Vwx,Vsd,Vpm)
    VALUE self,Vmm,Vjm,Vn,Vm,Vwx,Vsd,Vpm;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cm,Vm);
  MC_SetFloatArray(Cwx,Vwx);
  MC_SetFloat(Csd,Vsd);
  MC_SetFloatArray(Cpm,Vpm);
  shlfwl_(&Cmm,&Cjm,&Cn,&Cm,Cwx,&Csd,Cpm);
  return Qnil;
}

static VALUE
dcl_shlfwm(self,Vmm,Vjm,Vm,Visw,Vwm,Vsm,Vsd,Vxc,Vpm,Vwy,Vwx,Vr,Vz)
    VALUE self,Vmm,Vjm,Vm,Visw,Vwm,Vsm,Vsd,Vxc,Vpm,Vwy,Vwx,Vr,Vz;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cm,Vm);
  MC_SetInt(Cisw,Visw);
  MC_SetFloatArray(Cwm,Vwm);
  MC_SetFloatArray(Csm,Vsm);
  MC_SetFloatArray(Csd,Vsd);
  MC_SetFloatArray(Cxc,Vxc);
  MC_SetFloatArray(Cpm,Vpm);
  MC_SetFloatArray(Cwy,Vwy);
  MC_SetFloatArray(Cwx,Vwx);
  MC_SetFloat(Cr,Vr);
  MC_SetFloatArray(Cz,Vz);
  shlfwm_(&Cmm,&Cjm,&Cm,&Cisw,Cwm,Csm,Csd,Cxc,Cpm,Cwy,Cwx,&Cr,Cz);
  return Qnil;
}

static VALUE
dcl_shlfwu(self,Vmm,Vjm,Vm,Visw,Vwm,Vsm,Vsd,Vxs,Vxc,Vpm,Vwy,Vwx,Vpx,Vr,Vz)
    VALUE self,Vmm,Vjm,Vm,Visw,Vwm,Vsm,Vsd,Vxs,Vxc,Vpm,Vwy,Vwx,Vpx,Vr,Vz;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cm,Vm);
  MC_SetInt(Cisw,Visw);
  MC_SetFloatArray(Cwm,Vwm);
  MC_SetFloatArray(Csm,Vsm);
  MC_SetFloatArray(Csd,Vsd);
  MC_SetFloatArray(Cxs,Vxs);
  MC_SetFloatArray(Cxc,Vxc);
  MC_SetFloatArray(Cpm,Vpm);
  MC_SetFloatArray(Cwy,Vwy);
  MC_SetFloatArray(Cwx,Vwx);
  MC_SetFloatArray(Cpx,Vpx);
  MC_SetFloat(Cr,Vr);
  MC_SetFloatArray(Cz,Vz);
  shlfwu_(&Cmm,&Cjm,&Cm,&Cisw,Cwm,Csm,Csd,Cxs,Cxc,Cpm,Cwy,Cwx,Cpx,&Cr,Cz);
  return Qnil;
}

static VALUE
dcl_shlsds(self,Vmm,Vm,Visw,Vsd,Vsm,Vr)
    VALUE self,Vmm,Vm,Visw,Vsd,Vsm,Vr;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cm,Vm);
  MC_SetInt(Cisw,Visw);
  MC_SetFloatArray(Csd,Vsd);
  MC_SetFloatArray(Csm,Vsm);
  MC_SetFloat(Cr,Vr);
  shlsds_(&Cmm,&Cm,&Cisw,Csd,Csm,&Cr);
  return Qnil;
}

static VALUE
dcl_shlssd(self,Vmm,Vm,Visw,Vsm,Vsd,Vr)
    VALUE self,Vmm,Vm,Visw,Vsm,Vsd,Vr;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cm,Vm);
  MC_SetInt(Cisw,Visw);
  MC_SetFloatArray(Csm,Vsm);
  MC_SetFloatArray(Csd,Vsd);
  MC_SetFloat(Cr,Vr);
  shlssd_(&Cmm,&Cm,&Cisw,Csm,Csd,&Cr);
  return Qnil;
}

static VALUE
dcl_shly2x(self,Vjm,Vm,Visw,Vwm,Vwx,Vwy,Vz)
    VALUE self,Vjm,Vm,Visw,Vwm,Vwx,Vwy,Vz;
{
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cm,Vm);
  MC_SetInt(Cisw,Visw);
  MC_SetFloatArray(Cwm,Vwm);
  MC_SetFloatArray(Cwx,Vwx);
  MC_SetFloatArray(Cwy,Vwy);
  MC_SetFloatArray(Cz,Vz);
  shly2x_(&Cjm,&Cm,&Cisw,Cwm,Cwx,Cwy,Cz);
  return Qnil;
}

static VALUE
dcl_shmdxj(self,Vwrd,Vwid)
    VALUE self,Vwrd,Vwid;
{
  float Cwrd;
  MC_SetFloat(Cwid,Vwid);
  shmdxj_(&Cwrd,&Cwid);
  MC_GetFloat(Cwrd,Vwrd);
  return Qnil;
}

static VALUE
dcl_shmdxm(self,Vjm,Vwr,Vwi)
    VALUE self,Vjm,Vwr,Vwi;
{
  MC_SetInt(Cjm,Vjm);
  MC_SetFloatArray(Cwr,Vwr);
  MC_SetFloatArray(Cwi,Vwi);
  shmdxm_(&Cjm,Cwr,Cwi);
  return Qnil;
}

static VALUE
dcl_shms2w(self,Vmm,Vjm,Visw,Vs,Vw,Vsd,Vpm,Vys,Vyc,Vpy,Vr)
    VALUE self,Vmm,Vjm,Visw,Vs,Vw,Vsd,Vpm,Vys,Vyc,Vpy,Vr;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cisw,Visw);
  MC_SetFloat(Cs,Vs);
  MC_SetFloatArray(Cw,Vw);
  MC_SetFloatArray(Csd,Vsd);
  MC_SetFloatArray(Cpm,Vpm);
  MC_SetFloatArray(Cys,Vys);
  MC_SetFloatArray(Cyc,Vyc);
  MC_SetFloatArray(Cpy,Vpy);
  MC_SetFloat(Cr,Vr);
  shms2w_(&Cmm,&Cjm,&Cisw,&Cs,Cw,Csd,Cpm,Cys,Cyc,Cpy,&Cr);
  return Qnil;
}

static VALUE
dcl_shmsri(self,Vmm,Vm,Vsr,Vsi)
    VALUE self,Vmm,Vm,Vsr,Vsi;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cm,Vm);
  MC_SetFloatArray(Csr,Vsr);
  MC_SetFloatArray(Csi,Vsi);
  shmsri_(&Cmm,&Cm,Csr,Csi);
  return Qnil;
}

static VALUE
dcl_shmswa(self,Vmm,Vjm,Visw,Vm1,Vm2,Vs,Vw,Vsd,Vpm,Vys,Vyc,Vpy,Vr)
    VALUE self,Vmm,Vjm,Visw,Vm1,Vm2,Vs,Vw,Vsd,Vpm,Vys,Vyc,Vpy,Vr;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cisw,Visw);
  MC_SetInt(Cm1,Vm1);
  MC_SetInt(Cm2,Vm2);
  MC_SetFloat(Cs,Vs);
  MC_SetFloatArray(Cw,Vw);
  MC_SetFloatArray(Csd,Vsd);
  MC_SetFloatArray(Cpm,Vpm);
  MC_SetFloatArray(Cys,Vys);
  MC_SetFloatArray(Cyc,Vyc);
  MC_SetFloatArray(Cpy,Vpy);
  MC_SetFloat(Cr,Vr);
  shmswa_(&Cmm,&Cjm,&Cisw,&Cm1,&Cm2,&Cs,Cw,Csd,Cpm,Cys,Cyc,Cpy,&Cr);
  return Qnil;
}

static VALUE
dcl_shmswj(self,Vmm,Vjm,Visw,Vj,Vm1,Vm2,Vs,Vwj,Vsd,Vpmj,Vys,Vyc,Vpy,Vr)
    VALUE self,Vmm,Vjm,Visw,Vj,Vm1,Vm2,Vs,Vwj,Vsd,Vpmj,Vys,Vyc,Vpy,Vr;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cisw,Visw);
  MC_SetInt(Cj,Vj);
  MC_SetInt(Cm1,Vm1);
  MC_SetInt(Cm2,Vm2);
  MC_SetFloat(Cs,Vs);
  MC_SetFloatArray(Cwj,Vwj);
  MC_SetFloatArray(Csd,Vsd);
  MC_SetFloatArray(Cpmj,Vpmj);
  MC_SetFloatArray(Cys,Vys);
  MC_SetFloatArray(Cyc,Vyc);
  MC_SetFloatArray(Cpy,Vpy);
  MC_SetFloat(Cr,Vr);
  shmswj_(&Cmm,&Cjm,&Cisw,&Cj,&Cm1,&Cm2,&Cs,Cwj,Csd,Cpmj,Cys,Cyc,Cpy,&Cr);
  return Qnil;
}

static VALUE
dcl_shmswm(self,Vmm,Vjm,Vm,Visw,Vs,Vwr,Vwi,Vsd,Vpm,Vys,Vyc,Vpy,Vr)
    VALUE self,Vmm,Vjm,Vm,Visw,Vs,Vwr,Vwi,Vsd,Vpm,Vys,Vyc,Vpy,Vr;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cm,Vm);
  MC_SetInt(Cisw,Visw);
  MC_SetFloat(Cs,Vs);
  MC_SetFloatArray(Cwr,Vwr);
  MC_SetFloatArray(Cwi,Vwi);
  MC_SetFloatArray(Csd,Vsd);
  MC_SetFloatArray(Cpm,Vpm);
  MC_SetFloatArray(Cys,Vys);
  MC_SetFloatArray(Cyc,Vyc);
  MC_SetFloatArray(Cpy,Vpy);
  MC_SetFloat(Cr,Vr);
  shmswm_(&Cmm,&Cjm,&Cm,&Cisw,&Cs,Cwr,Cwi,Csd,Cpm,Cys,Cyc,Cpy,&Cr);
  return Qnil;
}

static VALUE
dcl_shmswz(self,Vmm,Vjm,Visw,Vs,Vwz,Vsd,Vpm,Vys,Vyc,Vpy,Vr)
    VALUE self,Vmm,Vjm,Visw,Vs,Vwz,Vsd,Vpm,Vys,Vyc,Vpy,Vr;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cisw,Visw);
  MC_SetFloat(Cs,Vs);
  MC_SetFloatArray(Cwz,Vwz);
  MC_SetFloatArray(Csd,Vsd);
  MC_SetFloatArray(Cpm,Vpm);
  MC_SetFloatArray(Cys,Vys);
  MC_SetFloatArray(Cyc,Vyc);
  MC_SetFloatArray(Cpy,Vpy);
  MC_SetFloat(Cr,Vr);
  shmswz_(&Cmm,&Cjm,&Cisw,&Cs,Cwz,Csd,Cpm,Cys,Cyc,Cpy,&Cr);
  return Qnil;
}

static VALUE
dcl_shmw2s(self,Vmm,Vjm,Visw,Vw,Vs,Vsd,Vpm,Vxs,Vxc,Vpx,Vwy,Vwx,Vr,Vz)
    VALUE self,Vmm,Vjm,Visw,Vw,Vs,Vsd,Vpm,Vxs,Vxc,Vpx,Vwy,Vwx,Vr,Vz;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cisw,Visw);
  MC_SetFloatArray(Cw,Vw);
  float Cs;
  MC_SetFloatArray(Csd,Vsd);
  MC_SetFloatArray(Cpm,Vpm);
  MC_SetFloatArray(Cxs,Vxs);
  MC_SetFloatArray(Cxc,Vxc);
  MC_SetFloatArray(Cpx,Vpx);
  MC_SetFloatArray(Cwy,Vwy);
  MC_SetFloatArray(Cwx,Vwx);
  MC_SetFloat(Cr,Vr);
  MC_SetFloatArray(Cz,Vz);
  shmw2s_(&Cmm,&Cjm,&Cisw,Cw,&Cs,Csd,Cpm,Cxs,Cxc,Cpx,Cwy,Cwx,&Cr,Cz);
  MC_GetFloat(Cs,Vs);
  return Qnil;
}

static VALUE
dcl_shmwjm(self,Vmm,Vjm,Visw,Vj,Vm,Vs,Vwjr,Vwji,Vsd,Vpmj,Vys,Vyc,Vpy,Vr)
    VALUE self,Vmm,Vjm,Visw,Vj,Vm,Vs,Vwjr,Vwji,Vsd,Vpmj,Vys,Vyc,Vpy,Vr;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cisw,Visw);
  MC_SetInt(Cj,Vj);
  MC_SetInt(Cm,Vm);
  MC_SetFloat(Cs,Vs);
  MC_SetFloat(Cwjr,Vwjr);
  MC_SetFloat(Cwji,Vwji);
  MC_SetFloatArray(Csd,Vsd);
  MC_SetFloatArray(Cpmj,Vpmj);
  MC_SetFloatArray(Cys,Vys);
  MC_SetFloatArray(Cyc,Vyc);
  MC_SetFloatArray(Cpy,Vpy);
  MC_SetFloat(Cr,Vr);
  shmwjm_(&Cmm,&Cjm,&Cisw,&Cj,&Cm,&Cs,&Cwjr,&Cwji,Csd,Cpmj,Cys,Cyc,Cpy,&Cr);
  return Qnil;
}

static VALUE
dcl_shmwjz(self,Vmm,Vjm,Visw,Vj,Vs,Vwjd,Vsd,Vpmj,Vys,Vyc,Vpy,Vr)
    VALUE self,Vmm,Vjm,Visw,Vj,Vs,Vwjd,Vsd,Vpmj,Vys,Vyc,Vpy,Vr;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cisw,Visw);
  MC_SetInt(Cj,Vj);
  MC_SetFloat(Cs,Vs);
  float Cwjd;
  MC_SetFloatArray(Csd,Vsd);
  MC_SetFloatArray(Cpmj,Vpmj);
  MC_SetFloatArray(Cys,Vys);
  MC_SetFloatArray(Cyc,Vyc);
  MC_SetFloatArray(Cpy,Vpy);
  MC_SetFloat(Cr,Vr);
  shmwjz_(&Cmm,&Cjm,&Cisw,&Cj,&Cs,&Cwjd,Csd,Cpmj,Cys,Cyc,Cpy,&Cr);
  MC_GetFloat(Cwjd,Vwjd);
  return Qnil;
}

static VALUE
dcl_shnm2l(self,Vmm,Vn,Vm,Vlr,Vli)
    VALUE self,Vmm,Vn,Vm,Vlr,Vli;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cm,Vm);
  int   Clr;
  int   Cli;
  shnm2l_(&Cmm,&Cn,&Cm,&Clr,&Cli);
  MC_GetInt(Clr,Vlr);
  MC_GetInt(Cli,Vli);
  return Qnil;
}

static VALUE
dcl_sholap(self,Vmm,Vind,Va,Vb)
    VALUE self,Vmm,Vind,Va,Vb;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cind,Vind);
  MC_SetFloat(Ca,Va);
  float Cb;
  sholap_(&Cmm,&Cind,&Ca,&Cb);
  MC_GetFloat(Cb,Vb);
  return Qnil;
}

static VALUE
dcl_shpfun(self,Vmm,Vjm,Vm,Vfun,Vpm,Vys,Vyc,Vpy,Vr)
    VALUE self,Vmm,Vjm,Vm,Vfun,Vpm,Vys,Vyc,Vpy,Vr;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cm,Vm);
  MC_SetFloatArray(Cfun,Vfun);
  MC_SetFloatArray(Cpm,Vpm);
  MC_SetFloatArray(Cys,Vys);
  MC_SetFloatArray(Cyc,Vyc);
  MC_SetFloatArray(Cpy,Vpy);
  MC_SetFloat(Cr,Vr);
  shpfun_(&Cmm,&Cjm,&Cm,Cfun,Cpm,Cys,Cyc,Cpy,&Cr);
  return Qnil;
}

static VALUE
dcl_shppma(self,Vmm,Vjm,Vm,Vpm,Vys,Vpy,Vr)
    VALUE self,Vmm,Vjm,Vm,Vpm,Vys,Vpy,Vr;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cm,Vm);
  MC_SetFloatArray(Cpm,Vpm);
  MC_SetFloatArray(Cys,Vys);
  MC_SetFloatArray(Cpy,Vpy);
  MC_SetFloat(Cr,Vr);
  shppma_(&Cmm,&Cjm,&Cm,Cpm,Cys,Cpy,&Cr);
  return Qnil;
}

static VALUE
dcl_shppmj(self,Vmm,Vjm,Vm,Vj,Vpmj,Vys,Vpy,Vr)
    VALUE self,Vmm,Vjm,Vm,Vj,Vpmj,Vys,Vpy,Vr;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cm,Vm);
  MC_SetInt(Cj,Vj);
  MC_SetFloatArray(Cpmj,Vpmj);
  MC_SetFloatArray(Cys,Vys);
  MC_SetFloatArray(Cpy,Vpy);
  MC_SetFloat(Cr,Vr);
  shppmj_(&Cmm,&Cjm,&Cm,&Cj,Cpmj,Cys,Cpy,&Cr);
  return Qnil;
}

static VALUE
dcl_shtlib(self)
    VALUE self;
{
  shtlib_();
  return Qnil;
}

static VALUE
dcl_shtint(self,Vmm,Vjm,Vim,Vq)
    VALUE self,Vmm,Vjm,Vim,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cim,Vim);
  MC_SetFloatArray(Cq,Vq);
  shtint_(&Cmm,&Cjm,&Cim,Cq);
  return Qnil;
}

static VALUE
dcl_shtlap(self,Vmm,Vind,Va,Vb)
    VALUE self,Vmm,Vind,Va,Vb;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cind,Vind);
  MC_SetFloatArray(Ca,Va);
  MC_SetFloatArray(Cb,Vb);
  shtlap_(&Cmm,&Cind,Ca,Cb);
  return Qnil;
}

static VALUE
dcl_shtnml(self,Vmm,Vn,Vm,Vlr,Vli)
    VALUE self,Vmm,Vn,Vm,Vlr,Vli;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cm,Vm);
  MC_SetInt(Clr,Vlr);
  MC_SetInt(Cli,Vli);
  shtnml_(&Cmm,&Cn,&Cm,&Clr,&Cli);
  return Qnil;
}

static VALUE
dcl_shtfun(self,Vmm,Vjm,Vm,Vfun,Vq)
    VALUE self,Vmm,Vjm,Vm,Vfun,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cm,Vm);
  MC_SetFloatArray(Cfun,Vfun);
  MC_SetFloatArray(Cq,Vq);
  shtfun_(&Cmm,&Cjm,&Cm,Cfun,Cq);
  return Qnil;
}

static VALUE
dcl_shtlfw(self,Vmm,Vjm,Vm,Visw,Vwm,Vsm,Vq)
    VALUE self,Vmm,Vjm,Vm,Visw,Vwm,Vsm,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cm,Vm);
  MC_SetInt(Cisw,Visw);
  MC_SetFloatArray(Cwm,Vwm);
  MC_SetFloatArray(Csm,Vsm);
  MC_SetFloatArray(Cq,Vq);
  shtlfw_(&Cmm,&Cjm,&Cm,&Cisw,Cwm,Csm,Cq);
  return Qnil;
}

static VALUE
dcl_shtlbw(self,Vmm,Vjm,Vm,Visw,Vsm,Vwm,Vq)
    VALUE self,Vmm,Vjm,Vm,Visw,Vsm,Vwm,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cm,Vm);
  MC_SetInt(Cisw,Visw);
  MC_SetFloatArray(Csm,Vsm);
  MC_SetFloatArray(Cwm,Vwm);
  MC_SetFloatArray(Cq,Vq);
  shtlbw_(&Cmm,&Cjm,&Cm,&Cisw,Csm,Cwm,Cq);
  return Qnil;
}

static VALUE
dcl_shts2w(self,Vmm,Vjm,Visw,Vs,Vw,Vq)
    VALUE self,Vmm,Vjm,Visw,Vs,Vw,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cisw,Visw);
  MC_SetFloatArray(Cs,Vs);
  MC_SetFloatArray(Cw,Vw);
  MC_SetFloatArray(Cq,Vq);
  shts2w_(&Cmm,&Cjm,&Cisw,Cs,Cw,Cq);
  return Qnil;
}

static VALUE
dcl_shtswa(self,Vmm,Vjm,Visw,Vm1,Vm2,Vs,Vw,Vq)
    VALUE self,Vmm,Vjm,Visw,Vm1,Vm2,Vs,Vw,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cisw,Visw);
  MC_SetInt(Cm1,Vm1);
  MC_SetInt(Cm2,Vm2);
  MC_SetFloatArray(Cs,Vs);
  MC_SetFloatArray(Cw,Vw);
  MC_SetFloatArray(Cq,Vq);
  shtswa_(&Cmm,&Cjm,&Cisw,&Cm1,&Cm2,Cs,Cw,Cq);
  return Qnil;
}

static VALUE
dcl_shtswz(self,Vmm,Vjm,Visw,Vs,Vwz,Vq)
    VALUE self,Vmm,Vjm,Visw,Vs,Vwz,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cisw,Visw);
  MC_SetFloatArray(Cs,Vs);
  MC_SetFloatArray(Cwz,Vwz);
  MC_SetFloatArray(Cq,Vq);
  shtswz_(&Cmm,&Cjm,&Cisw,Cs,Cwz,Cq);
  return Qnil;
}

static VALUE
dcl_shtswm(self,Vmm,Vjm,Vm,Visw,Vs,Vwr,Vwi,Vq)
    VALUE self,Vmm,Vjm,Vm,Visw,Vs,Vwr,Vwi,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cm,Vm);
  MC_SetInt(Cisw,Visw);
  MC_SetFloatArray(Cs,Vs);
  MC_SetFloatArray(Cwr,Vwr);
  MC_SetFloatArray(Cwi,Vwi);
  MC_SetFloatArray(Cq,Vq);
  shtswm_(&Cmm,&Cjm,&Cm,&Cisw,Cs,Cwr,Cwi,Cq);
  return Qnil;
}

static VALUE
dcl_shtswj(self,Vmm,Vjm,Visw,Vj,Vm1,Vm2,Vs,Vwj,Vq)
    VALUE self,Vmm,Vjm,Visw,Vj,Vm1,Vm2,Vs,Vwj,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cisw,Visw);
  MC_SetInt(Cj,Vj);
  MC_SetInt(Cm1,Vm1);
  MC_SetInt(Cm2,Vm2);
  MC_SetFloatArray(Cs,Vs);
  MC_SetFloatArray(Cwj,Vwj);
  MC_SetFloatArray(Cq,Vq);
  shtswj_(&Cmm,&Cjm,&Cisw,&Cj,&Cm1,&Cm2,Cs,Cwj,Cq);
  return Qnil;
}

static VALUE
dcl_shtw2s(self,Vmm,Vjm,Visw,Vs,Vw,Vq)
    VALUE self,Vmm,Vjm,Visw,Vs,Vw,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cisw,Visw);
  MC_SetFloatArray(Cs,Vs);
  MC_SetFloatArray(Cw,Vw);
  MC_SetFloatArray(Cq,Vq);
  shtw2s_(&Cmm,&Cjm,&Cisw,Cs,Cw,Cq);
  return Qnil;
}

static VALUE
dcl_shtw2g(self,Vmm,Vjm,Vim,Vw,Vg,Vq)
    VALUE self,Vmm,Vjm,Vim,Vw,Vg,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cim,Vim);
  MC_SetFloatArray(Cw,Vw);
  MC_SetFloatArray(Cg,Vg);
  MC_SetFloatArray(Cq,Vq);
  shtw2g_(&Cmm,&Cjm,&Cim,Cw,Cg,Cq);
  return Qnil;
}

static VALUE
dcl_shtwga(self,Vmm,Vjm,Vim,Vm1,Vm2,Vw,Vg,Vq)
    VALUE self,Vmm,Vjm,Vim,Vm1,Vm2,Vw,Vg,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cm1,Vm1);
  MC_SetInt(Cm2,Vm2);
  MC_SetFloatArray(Cw,Vw);
  MC_SetFloatArray(Cg,Vg);
  MC_SetFloatArray(Cq,Vq);
  shtwga_(&Cmm,&Cjm,&Cim,&Cm1,&Cm2,Cw,Cg,Cq);
  return Qnil;
}

static VALUE
dcl_shtwgm(self,Vmm,Vjm,Vim,Vm,Vwr,Vwi,Vg,Vq)
    VALUE self,Vmm,Vjm,Vim,Vm,Vwr,Vwi,Vg,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cm,Vm);
  MC_SetFloatArray(Cwr,Vwr);
  MC_SetFloatArray(Cwi,Vwi);
  MC_SetFloatArray(Cg,Vg);
  MC_SetFloatArray(Cq,Vq);
  shtwgm_(&Cmm,&Cjm,&Cim,&Cm,Cwr,Cwi,Cg,Cq);
  return Qnil;
}

static VALUE
dcl_shtwgz(self,Vjm,Vim,Vwz,Vg)
    VALUE self,Vjm,Vim,Vwz,Vg;
{
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cim,Vim);
  MC_SetFloatArray(Cwz,Vwz);
  MC_SetFloatArray(Cg,Vg);
  shtwgz_(&Cjm,&Cim,Cwz,Cg);
  return Qnil;
}

static VALUE
dcl_shtwgj(self,Vmm,Vim,Vm1,Vm2,Vwj,Vgj,Vq)
    VALUE self,Vmm,Vim,Vm1,Vm2,Vwj,Vgj,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cm1,Vm1);
  MC_SetInt(Cm2,Vm2);
  MC_SetFloatArray(Cwj,Vwj);
  MC_SetFloatArray(Cgj,Vgj);
  MC_SetFloatArray(Cq,Vq);
  shtwgj_(&Cmm,&Cim,&Cm1,&Cm2,Cwj,Cgj,Cq);
  return Qnil;
}

static VALUE
dcl_shtg2w(self,Vmm,Vjm,Vim,Vg,Vw,Vq)
    VALUE self,Vmm,Vjm,Vim,Vg,Vw,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cim,Vim);
  MC_SetFloatArray(Cg,Vg);
  MC_SetFloatArray(Cw,Vw);
  MC_SetFloatArray(Cq,Vq);
  shtg2w_(&Cmm,&Cjm,&Cim,Cg,Cw,Cq);
  return Qnil;
}

static VALUE
dcl_shts2g(self,Vmm,Vjm,Vim,Visw,Vs,Vw,Vg,Vq)
    VALUE self,Vmm,Vjm,Vim,Visw,Vs,Vw,Vg,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cisw,Visw);
  MC_SetFloatArray(Cs,Vs);
  MC_SetFloatArray(Cw,Vw);
  MC_SetFloatArray(Cg,Vg);
  MC_SetFloatArray(Cq,Vq);
  shts2g_(&Cmm,&Cjm,&Cim,&Cisw,Cs,Cw,Cg,Cq);
  return Qnil;
}

static VALUE
dcl_shtsga(self,Vmm,Vjm,Vim,Visw,Vm1,Vm2,Vs,Vw,Vg,Vq)
    VALUE self,Vmm,Vjm,Vim,Visw,Vm1,Vm2,Vs,Vw,Vg,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cisw,Visw);
  MC_SetInt(Cm1,Vm1);
  MC_SetInt(Cm2,Vm2);
  MC_SetFloatArray(Cs,Vs);
  MC_SetFloatArray(Cw,Vw);
  MC_SetFloatArray(Cg,Vg);
  MC_SetFloatArray(Cq,Vq);
  shtsga_(&Cmm,&Cjm,&Cim,&Cisw,&Cm1,&Cm2,Cs,Cw,Cg,Cq);
  return Qnil;
}

static VALUE
dcl_shtsgz(self,Vmm,Vjm,Vim,Visw,Vs,Vwz,Vg,Vq)
    VALUE self,Vmm,Vjm,Vim,Visw,Vs,Vwz,Vg,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cisw,Visw);
  MC_SetFloatArray(Cs,Vs);
  MC_SetFloatArray(Cwz,Vwz);
  MC_SetFloatArray(Cg,Vg);
  MC_SetFloatArray(Cq,Vq);
  shtsgz_(&Cmm,&Cjm,&Cim,&Cisw,Cs,Cwz,Cg,Cq);
  return Qnil;
}

static VALUE
dcl_shtsgm(self,Vmm,Vjm,Vim,Vm,Visw,Vs,Vwr,Vwi,Vg,Vq)
    VALUE self,Vmm,Vjm,Vim,Vm,Visw,Vs,Vwr,Vwi,Vg,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cm,Vm);
  MC_SetInt(Cisw,Visw);
  MC_SetFloatArray(Cs,Vs);
  MC_SetFloatArray(Cwr,Vwr);
  MC_SetFloatArray(Cwi,Vwi);
  MC_SetFloatArray(Cg,Vg);
  MC_SetFloatArray(Cq,Vq);
  shtsgm_(&Cmm,&Cjm,&Cim,&Cm,&Cisw,Cs,Cwr,Cwi,Cg,Cq);
  return Qnil;
}

static VALUE
dcl_shtsgj(self,Vmm,Vjm,Vim,Visw,Vj,Vm1,Vm2,Vs,Vwj,Vgj,Vq)
    VALUE self,Vmm,Vjm,Vim,Visw,Vj,Vm1,Vm2,Vs,Vwj,Vgj,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cisw,Visw);
  MC_SetInt(Cj,Vj);
  MC_SetInt(Cm1,Vm1);
  MC_SetInt(Cm2,Vm2);
  MC_SetFloatArray(Cs,Vs);
  MC_SetFloatArray(Cwj,Vwj);
  MC_SetFloatArray(Cgj,Vgj);
  MC_SetFloatArray(Cq,Vq);
  shtsgj_(&Cmm,&Cjm,&Cim,&Cisw,&Cj,&Cm1,&Cm2,Cs,Cwj,Cgj,Cq);
  return Qnil;
}

static VALUE
dcl_shtg2s(self,Vmm,Vjm,Vim,Visw,Vg,Vw,Vs,Vq)
    VALUE self,Vmm,Vjm,Vim,Visw,Vg,Vw,Vs,Vq;
{
  MC_SetInt(Cmm,Vmm);
  MC_SetInt(Cjm,Vjm);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cisw,Visw);
  MC_SetFloatArray(Cg,Vg);
  MC_SetFloatArray(Cw,Vw);
  MC_SetFloatArray(Cs,Vs);
  MC_SetFloatArray(Cq,Vq);
  shtg2s_(&Cmm,&Cjm,&Cim,&Cisw,Cg,Cw,Cs,Cq);
  return Qnil;
}

static VALUE
dcl_vs1int(self,Vwz,Vnw,Vix)
    VALUE self,Vwz,Vnw,Vix;
{
  MC_SetFloatArray(Cwz,Vwz);
  MC_SetIntArray(Cnw,Vnw);
  MC_SetInt(Cix,Vix);
  vs1int_(Cwz,Cnw,&Cix);
  return Qnil;
}

static VALUE
dcl_vs1din(self,Vwz,Vnw,Vix,Vx)
    VALUE self,Vwz,Vnw,Vix,Vx;
{
  MC_SetFloatArray(Cwz,Vwz);
  MC_SetIntArray(Cnw,Vnw);
  MC_SetInt(Cix,Vix);
  MC_SetFloatArray(Cx,Vx);
  vs1din_(Cwz,Cnw,&Cix,Cx);
  return Qnil;
}

static VALUE
dcl_vs1out(self,Vwz,Vnw,Vix)
    VALUE self,Vwz,Vnw,Vix;
{
  MC_SetFloatArray(Cwz,Vwz);
  MC_SetIntArray(Cnw,Vnw);
  MC_SetInt(Cix,Vix);
  vs1out_(Cwz,Cnw,&Cix);
  return Qnil;
}

static VALUE
dcl_vs2int(self,Vwz,Vnw,Vix,Viy)
    VALUE self,Vwz,Vnw,Vix,Viy;
{
  MC_SetFloatArray(Cwz,Vwz);
  MC_SetIntArray(Cnw,Vnw);
  MC_SetInt(Cix,Vix);
  MC_SetInt(Ciy,Viy);
  vs2int_(Cwz,Cnw,&Cix,&Ciy);
  return Qnil;
}

static VALUE
dcl_vs2din(self,Vwz,Vnw,Vix,Viy,Vx,Vy)
    VALUE self,Vwz,Vnw,Vix,Viy,Vx,Vy;
{
  MC_SetFloatArray(Cwz,Vwz);
  MC_SetIntArray(Cnw,Vnw);
  MC_SetInt(Cix,Vix);
  MC_SetInt(Ciy,Viy);
  MC_SetFloatArray(Cx,Vx);
  MC_SetFloatArray(Cy,Vy);
  vs2din_(Cwz,Cnw,&Cix,&Ciy,Cx,Cy);
  return Qnil;
}

static VALUE
dcl_vs2out(self,Vwz,Vnw,Vix,Viy)
    VALUE self,Vwz,Vnw,Vix,Viy;
{
  MC_SetFloatArray(Cwz,Vwz);
  MC_SetIntArray(Cnw,Vnw);
  MC_SetInt(Cix,Vix);
  MC_SetInt(Ciy,Viy);
  vs2out_(Cwz,Cnw,&Cix,&Ciy);
  return Qnil;
}

static VALUE
dcl_bitpci(self,Vcp,Vip)
    VALUE self,Vcp,Vip;
{
  MC_SetString(Ccp,Vcp);
  int   Cip;
  bitpci_(Ccp,&Cip,strlen(Ccp));
  MC_GetInt(Cip,Vip);
  return Qnil;
}

static VALUE
dcl_bitpic(self,Vip,Vcp)
    VALUE self,Vip,Vcp;
{
  MC_SetInt(Cip,Vip);
  char * Ccp="                ";
  bitpic_(&Cip,Ccp,strlen(Ccp));
  MC_GetString(Ccp,Vcp);
  return Qnil;
}

static VALUE
dcl_gbyte(self,Vnpack,Viout,Vibit,Vnbits)
    VALUE self,Vnpack,Viout,Vibit,Vnbits;
{
  MC_SetIntArray(Cnpack,Vnpack);
  MC_SetInt(Ciout,Viout);
  MC_SetInt(Cibit,Vibit);
  MC_SetInt(Cnbits,Vnbits);
  gbyte_(Cnpack,&Ciout,&Cibit,&Cnbits);
  return Qnil;
}

static VALUE
dcl_gbytes(self,Vnpack,Visam,Vibit,Vnbits,Vnskip,Viter)
    VALUE self,Vnpack,Visam,Vibit,Vnbits,Vnskip,Viter;
{
  MC_SetIntArray(Cnpack,Vnpack);
  MC_SetIntArray(Cisam,Visam);
  MC_SetInt(Cibit,Vibit);
  MC_SetInt(Cnbits,Vnbits);
  MC_SetInt(Cnskip,Vnskip);
  MC_SetInt(Citer,Viter);
  gbytes_(Cnpack,Cisam,&Cibit,&Cnbits,&Cnskip,&Citer);
  return Qnil;
}

static VALUE
dcl_sbyte(self,Vnpack,Viout,Vibit,Vnbits)
    VALUE self,Vnpack,Viout,Vibit,Vnbits;
{
  MC_SetIntArray(Cnpack,Vnpack);
  MC_SetInt(Ciout,Viout);
  MC_SetInt(Cibit,Vibit);
  MC_SetInt(Cnbits,Vnbits);
  sbyte_(Cnpack,&Ciout,&Cibit,&Cnbits);
  return Qnil;
}

static VALUE
dcl_sbytes(self,Vnpack,Visam,Vibit,Vnbits,Vnskip,Viter)
    VALUE self,Vnpack,Visam,Vibit,Vnbits,Vnskip,Viter;
{
  MC_SetIntArray(Cnpack,Vnpack);
  MC_SetIntArray(Cisam,Visam);
  MC_SetInt(Cibit,Vibit);
  MC_SetInt(Cnbits,Vnbits);
  MC_SetInt(Cnskip,Vnskip);
  MC_SetInt(Citer,Viter);
  sbytes_(Cnpack,Cisam,&Cibit,&Cnbits,&Cnskip,&Citer);
  return Qnil;
}

static VALUE
dcl_clower(self,Vch)
    VALUE self,Vch;
{
  char * Cch="                ";
  clower_(Cch,strlen(Cch));
  MC_GetString(Cch,Vch);
  return Qnil;
}

static VALUE
dcl_cupper(self,Vch)
    VALUE self,Vch;
{
  char * Cch="                ";
  cupper_(Cch,strlen(Cch));
  MC_GetString(Cch,Vch);
  return Qnil;
}

static VALUE
dcl_lchr(self,Vchar,Vcref)
    VALUE self,Vchar,Vcref;
{
  MC_SetString(Cchar,Vchar);
  MC_SetString(Ccref,Vcref);
  int ret;
  int lchr_();
  ret = lchr_(Cchar,Ccref,strlen(Cchar),strlen(Ccref));
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lchra(self,Vch)
    VALUE self,Vch;
{
  MC_SetString(Cch,Vch);
  int ret;
  int lchra_();
  ret = lchra_(Cch,strlen(Cch));
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lchrb(self,Vch)
    VALUE self,Vch;
{
  MC_SetString(Cch,Vch);
  int ret;
  int lchrb_();
  ret = lchrb_(Cch,strlen(Cch));
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lchrc(self,Vch)
    VALUE self,Vch;
{
  MC_SetString(Cch,Vch);
  int ret;
  int lchrc_();
  ret = lchrc_(Cch,strlen(Cch));
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lchrd(self,Vch)
    VALUE self,Vch;
{
  MC_SetString(Cch,Vch);
  int ret;
  int lchrd_();
  ret = lchrd_(Cch,strlen(Cch));
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lchrf(self,Vch)
    VALUE self,Vch;
{
  MC_SetString(Cch,Vch);
  int ret;
  int lchrf_();
  ret = lchrf_(Cch,strlen(Cch));
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lchrl(self,Vch)
    VALUE self,Vch;
{
  MC_SetString(Cch,Vch);
  int ret;
  int lchrl_();
  ret = lchrl_(Cch,strlen(Cch));
  return MC_NewLogic(ret);;
}

static VALUE
dcl_lchrs(self,Vch)
    VALUE self,Vch;
{
  MC_SetString(Cch,Vch);
  int ret;
  int lchrs_();
  ret = lchrs_(Cch,strlen(Cch));
  return MC_NewLogic(ret);;
}

static VALUE
dcl_chngc(self,Vch,Vca,Vcb)
    VALUE self,Vch,Vca,Vcb;
{
  char * Cch="                ";
  MC_SetString(Cca,Vca);
  MC_SetString(Ccb,Vcb);
  chngc_(Cch,Cca,Ccb,strlen(Cch),strlen(Cca),strlen(Ccb));
  MC_GetString(Cch,Vch);
  return Qnil;
}

static VALUE
dcl_chngi(self,Vch,Vca,Vii,Vcfmt)
    VALUE self,Vch,Vca,Vii,Vcfmt;
{
  MC_SetString(Cch,Vch);
  MC_SetString(Cca,Vca);
  MC_SetInt(Cii,Vii);
  MC_SetString(Ccfmt,Vcfmt);
  chngi_(Cch,Cca,&Cii,Ccfmt,strlen(Cch),strlen(Cca),strlen(Ccfmt));
  return Qnil;
}

static VALUE
dcl_chngr(self,Vch,Vca,Vrr,Vcfmt)
    VALUE self,Vch,Vca,Vrr,Vcfmt;
{
  MC_SetString(Cch,Vch);
  MC_SetString(Cca,Vca);
  MC_SetFloat(Crr,Vrr);
  MC_SetString(Ccfmt,Vcfmt);
  chngr_(Cch,Cca,&Crr,Ccfmt,strlen(Cch),strlen(Cca),strlen(Ccfmt));
  return Qnil;
}

static VALUE
dcl_date12(self,Vidate,Viy,Vitd)
    VALUE self,Vidate,Viy,Vitd;
{
  MC_SetInt(Cidate,Vidate);
  MC_SetInt(Ciy,Viy);
  MC_SetInt(Citd,Vitd);
  date12_(&Cidate,&Ciy,&Citd);
  return Qnil;
}

static VALUE
dcl_date13(self,Vidate,Viy,Vim,Vid)
    VALUE self,Vidate,Viy,Vim,Vid;
{
  MC_SetInt(Cidate,Vidate);
  int   Ciy;
  int   Cim;
  MC_SetInt(Cid,Vid);
  date13_(&Cidate,&Ciy,&Cim,&Cid);
  MC_GetInt(Ciy,Viy);
  MC_GetInt(Cim,Vim);
  return Qnil;
}

static VALUE
dcl_date21(self,Vidate,Viy,Vitd)
    VALUE self,Vidate,Viy,Vitd;
{
  MC_SetInt(Cidate,Vidate);
  MC_SetInt(Ciy,Viy);
  MC_SetInt(Citd,Vitd);
  date21_(&Cidate,&Ciy,&Citd);
  return Qnil;
}

static VALUE
dcl_date23(self,Viy,Vim,Vid,Vitd)
    VALUE self,Viy,Vim,Vid,Vitd;
{
  MC_SetInt(Ciy,Viy);
  int   Cim;
  int   Cid;
  MC_SetInt(Citd,Vitd);
  date23_(&Ciy,&Cim,&Cid,&Citd);
  MC_GetInt(Cim,Vim);
  MC_GetInt(Cid,Vid);
  return Qnil;
}

static VALUE
dcl_date31(self,Vidate,Viy,Vim,Vid)
    VALUE self,Vidate,Viy,Vim,Vid;
{
  MC_SetInt(Cidate,Vidate);
  MC_SetInt(Ciy,Viy);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cid,Vid);
  date31_(&Cidate,&Ciy,&Cim,&Cid);
  return Qnil;
}

static VALUE
dcl_date32(self,Viy,Vim,Vid,Vitd)
    VALUE self,Viy,Vim,Vid,Vitd;
{
  MC_SetInt(Ciy,Viy);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cid,Vid);
  int   Citd;
  date32_(&Ciy,&Cim,&Cid,&Citd);
  MC_GetInt(Citd,Vitd);
  return Qnil;
}

static VALUE
dcl_datec1(self,Vcform,Vidate)
    VALUE self,Vcform,Vidate;
{
  MC_SetString(Ccform,Vcform);
  MC_SetInt(Cidate,Vidate);
  datec1_(Ccform,&Cidate,strlen(Ccform));
  return Qnil;
}

static VALUE
dcl_datec2(self,Vcform,Viy,Vitd)
    VALUE self,Vcform,Viy,Vitd;
{
  MC_SetString(Ccform,Vcform);
  MC_SetInt(Ciy,Viy);
  MC_SetInt(Citd,Vitd);
  datec2_(Ccform,&Ciy,&Citd,strlen(Ccform));
  return Qnil;
}

static VALUE
dcl_datec3(self,Vcform,Viy,Vim,Vid)
    VALUE self,Vcform,Viy,Vim,Vid;
{
  MC_SetString(Ccform,Vcform);
  MC_SetInt(Ciy,Viy);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cid,Vid);
  datec3_(Ccform,&Ciy,&Cim,&Cid,strlen(Ccform));
  return Qnil;
}

static VALUE
dcl_datef1(self,Vn,Vidate,Vndate)
    VALUE self,Vn,Vidate,Vndate;
{
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cidate,Vidate);
  MC_SetInt(Cndate,Vndate);
  datef1_(&Cn,&Cidate,&Cndate);
  return Qnil;
}

static VALUE
dcl_datef2(self,Vn,Viy,Vitd,Vny,Vntd)
    VALUE self,Vn,Viy,Vitd,Vny,Vntd;
{
  MC_SetInt(Cn,Vn);
  MC_SetInt(Ciy,Viy);
  MC_SetInt(Citd,Vitd);
  int   Cny;
  int   Cntd;
  datef2_(&Cn,&Ciy,&Citd,&Cny,&Cntd);
  MC_GetInt(Cny,Vny);
  MC_GetInt(Cntd,Vntd);
  return Qnil;
}

static VALUE
dcl_datef3(self,Vn,Viy,Vim,Vid,Vny,Vnm,Vnd)
    VALUE self,Vn,Viy,Vim,Vid,Vny,Vnm,Vnd;
{
  MC_SetInt(Cn,Vn);
  MC_SetInt(Ciy,Viy);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cid,Vid);
  MC_SetInt(Cny,Vny);
  MC_SetInt(Cnm,Vnm);
  MC_SetInt(Cnd,Vnd);
  datef3_(&Cn,&Ciy,&Cim,&Cid,&Cny,&Cnm,&Cnd);
  return Qnil;
}

static VALUE
dcl_dateg1(self,Vn,Vidate,Vndate)
    VALUE self,Vn,Vidate,Vndate;
{
  MC_SetInt(Cn,Vn);
  MC_SetInt(Cidate,Vidate);
  MC_SetInt(Cndate,Vndate);
  dateg1_(&Cn,&Cidate,&Cndate);
  return Qnil;
}

static VALUE
dcl_dateg2(self,Vn,Viy,Vitd,Vny,Vntd)
    VALUE self,Vn,Viy,Vitd,Vny,Vntd;
{
  int   Cn;
  MC_SetInt(Ciy,Viy);
  MC_SetInt(Citd,Vitd);
  MC_SetInt(Cny,Vny);
  MC_SetInt(Cntd,Vntd);
  dateg2_(&Cn,&Ciy,&Citd,&Cny,&Cntd);
  MC_GetInt(Cn,Vn);
  return Qnil;
}

static VALUE
dcl_dateg3(self,Vn,Viy,Vim,Vid,Vny,Vnm,Vnd)
    VALUE self,Vn,Viy,Vim,Vid,Vny,Vnm,Vnd;
{
  MC_SetInt(Cn,Vn);
  MC_SetInt(Ciy,Viy);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cid,Vid);
  MC_SetInt(Cny,Vny);
  MC_SetInt(Cnm,Vnm);
  MC_SetInt(Cnd,Vnd);
  dateg3_(&Cn,&Ciy,&Cim,&Cid,&Cny,&Cnm,&Cnd);
  return Qnil;
}

static VALUE
dcl_dateq1(self,Vidate)
    VALUE self,Vidate;
{
  MC_SetInt(Cidate,Vidate);
  dateq1_(&Cidate);
  return Qnil;
}

static VALUE
dcl_dateq2(self,Viy,Vitd)
    VALUE self,Viy,Vitd;
{
  MC_SetInt(Ciy,Viy);
  MC_SetInt(Citd,Vitd);
  dateq2_(&Ciy,&Citd);
  return Qnil;
}

static VALUE
dcl_iweek1(self,Vidate)
    VALUE self,Vidate;
{
  MC_SetInt(Cidate,Vidate);
  int ret;
  int iweek1_();
  ret = iweek1_(&Cidate);
  return MC_NewInt(ret);;
}

static VALUE
dcl_iweek2(self,Viy,Vitd)
    VALUE self,Viy,Vitd;
{
  MC_SetInt(Ciy,Viy);
  MC_SetInt(Citd,Vitd);
  int ret;
  int iweek2_();
  ret = iweek2_(&Ciy,&Citd);
  return MC_NewInt(ret);;
}

static VALUE
dcl_iweek3(self,Viy,Vim,Vid)
    VALUE self,Viy,Vim,Vid;
{
  MC_SetInt(Ciy,Viy);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cid,Vid);
  int ret;
  int iweek3_();
  ret = iweek3_(&Ciy,&Cim,&Cid);
  return MC_NewInt(ret);;
}

static VALUE
dcl_ndate1(self,Vidate,Vndate)
    VALUE self,Vidate,Vndate;
{
  MC_SetInt(Cidate,Vidate);
  MC_SetInt(Cndate,Vndate);
  int ret;
  int ndate1_();
  ret = ndate1_(&Cidate,&Cndate);
  return MC_NewInt(ret);;
}

static VALUE
dcl_ndate2(self,Viy,Vitd,Vny,Vntd)
    VALUE self,Viy,Vitd,Vny,Vntd;
{
  MC_SetInt(Ciy,Viy);
  MC_SetInt(Citd,Vitd);
  MC_SetInt(Cny,Vny);
  MC_SetInt(Cntd,Vntd);
  int ret;
  int ndate2_();
  ret = ndate2_(&Ciy,&Citd,&Cny,&Cntd);
  return MC_NewInt(ret);;
}

static VALUE
dcl_ndate3(self,Viy,Vim,Vid,Vny,Vnm,Vnd)
    VALUE self,Viy,Vim,Vid,Vny,Vnm,Vnd;
{
  MC_SetInt(Ciy,Viy);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cid,Vid);
  MC_SetInt(Cny,Vny);
  MC_SetInt(Cnm,Vnm);
  MC_SetInt(Cnd,Vnd);
  int ret;
  int ndate3_();
  ret = ndate3_(&Ciy,&Cim,&Cid,&Cny,&Cnm,&Cnd);
  return MC_NewInt(ret);;
}

static VALUE
dcl_ndmon(self,Viy,Vim)
    VALUE self,Viy,Vim;
{
  MC_SetInt(Ciy,Viy);
  MC_SetInt(Cim,Vim);
  int ret;
  int ndmon_();
  ret = ndmon_(&Ciy,&Cim);
  return MC_NewInt(ret);;
}

static VALUE
dcl_ndyear(self,Viy)
    VALUE self,Viy;
{
  MC_SetInt(Ciy,Viy);
  int ret;
  int ndyear_();
  ret = ndyear_(&Ciy);
  return MC_NewInt(ret);;
}

static VALUE
dcl_fcpack(self)
    VALUE self;
{
  fcpack_();
  return Qnil;
}

static VALUE
dcl_fcslfc(self,Vclx)
    VALUE self,Vclx;
{
  MC_SetString(Cclx,Vclx);
  fcslfc_(Cclx,strlen(Cclx));
  return Qnil;
}

static VALUE
dcl_fcleol(self,Viou,Vleol)
    VALUE self,Viou,Vleol;
{
  MC_SetInt(Ciou,Viou);
  MC_SetLogic(Cleol,Vleol);
  fcleol_(&Ciou,&Cleol);
  return Qnil;
}

static VALUE
dcl_fcopen(self,Viou,Vcdsn,Vnrl,Vcact,Vicon)
    VALUE self,Viou,Vcdsn,Vnrl,Vcact,Vicon;
{
  MC_SetInt(Ciou,Viou);
  MC_SetString(Ccdsn,Vcdsn);
  MC_SetInt(Cnrl,Vnrl);
  MC_SetString(Ccact,Vcact);
  MC_SetInt(Cicon,Vicon);
  fcopen_(&Ciou,Ccdsn,&Cnrl,Ccact,&Cicon,strlen(Ccdsn),strlen(Ccact));
  return Qnil;
}

static VALUE
dcl_fcclos(self,Viou,Vicon)
    VALUE self,Viou,Vicon;
{
  MC_SetInt(Ciou,Viou);
  MC_SetInt(Cicon,Vicon);
  fcclos_(&Ciou,&Cicon);
  return Qnil;
}

static VALUE
dcl_fcnrec(self,Viou,Vnrec)
    VALUE self,Viou,Vnrec;
{
  MC_SetInt(Ciou,Viou);
  MC_SetInt(Cnrec,Vnrec);
  fcnrec_(&Ciou,&Cnrec);
  return Qnil;
}

static VALUE
dcl_fcgetr(self,Viou,Vcbuf,Vicon)
    VALUE self,Viou,Vcbuf,Vicon;
{
  MC_SetInt(Ciou,Viou);
  MC_SetString(Ccbuf,Vcbuf);
  MC_SetInt(Cicon,Vicon);
  fcgetr_(&Ciou,Ccbuf,&Cicon,strlen(Ccbuf));
  return Qnil;
}

static VALUE
dcl_fcputr(self,Viou,Vcbuf,Vicon)
    VALUE self,Viou,Vcbuf,Vicon;
{
  MC_SetInt(Ciou,Viou);
  MC_SetString(Ccbuf,Vcbuf);
  MC_SetInt(Cicon,Vicon);
  fcputr_(&Ciou,Ccbuf,&Cicon,strlen(Ccbuf));
  return Qnil;
}

static VALUE
dcl_fcgets(self,Viou,Vibuf,Vicon)
    VALUE self,Viou,Vibuf,Vicon;
{
  MC_SetInt(Ciou,Viou);
  MC_SetIntArray(Cibuf,Vibuf);
  MC_SetInt(Cicon,Vicon);
  fcgets_(&Ciou,Cibuf,&Cicon);
  return Qnil;
}

static VALUE
dcl_fcputs(self,Viou,Vibuf,Vicon)
    VALUE self,Viou,Vibuf,Vicon;
{
  MC_SetInt(Ciou,Viou);
  MC_SetIntArray(Cibuf,Vibuf);
  MC_SetInt(Cicon,Vicon);
  fcputs_(&Ciou,Cibuf,&Cicon);
  return Qnil;
}

static VALUE
dcl_fcrwnd(self,Viou,Vicon)
    VALUE self,Viou,Vicon;
{
  MC_SetInt(Ciou,Viou);
  MC_SetInt(Cicon,Vicon);
  fcrwnd_(&Ciou,&Cicon);
  return Qnil;
}

static VALUE
dcl_chval(self,Vcfmt,Vval,Vcval)
    VALUE self,Vcfmt,Vval,Vcval;
{
  MC_SetString(Ccfmt,Vcfmt);
  MC_SetFloat(Cval,Vval);
  char * Ccval="                ";
  chval_(Ccfmt,&Cval,Ccval,strlen(Ccfmt),strlen(Ccval));
  MC_GetString(Ccval,Vcval);
  return Qnil;
}

static VALUE
dcl_hexdci(self,Vcp,Vip)
    VALUE self,Vcp,Vip;
{
  MC_SetString(Ccp,Vcp);
  int   Cip;
  hexdci_(Ccp,&Cip,strlen(Ccp));
  MC_GetInt(Cip,Vip);
  return Qnil;
}

static VALUE
dcl_hexdic(self,Vip,Vcp)
    VALUE self,Vip,Vcp;
{
  MC_SetInt(Cip,Vip);
  char * Ccp="                ";
  hexdic_(&Cip,Ccp,strlen(Ccp));
  MC_GetString(Ccp,Vcp);
  return Qnil;
}

static VALUE
dcl_cdblk(self,Vchr)
    VALUE self,Vchr;
{
  char * Cchr="                ";
  cdblk_(Cchr,strlen(Cchr));
  MC_GetString(Cchr,Vchr);
  return Qnil;
}

static VALUE
dcl_cns(self,Vins)
    VALUE self,Vins;
{
  MC_SetInt(Cins,Vins);
  char ret;
  char cns_();
  ret = cns_(&Cins);
  return MC_NewChar(ret);;
}

static VALUE
dcl_rngu1(self,Viseed)
    VALUE self,Viseed;
{
  int   Ciseed;
  float ret;
  float rngu1_();
  ret = rngu1_(&Ciseed);
  MC_GetInt(Ciseed,Viseed);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rngu2(self,Viseed)
    VALUE self,Viseed;
{
  int   Ciseed;
  float ret;
  float rngu2_();
  ret = rngu2_(&Ciseed);
  MC_GetInt(Ciseed,Viseed);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_rngu3(self,Viseed)
    VALUE self,Viseed;
{
  int   Ciseed;
  float ret;
  float rngu3_();
  ret = rngu3_(&Ciseed);
  MC_GetInt(Ciseed,Viseed);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_r4ibm(self,Vii)
    VALUE self,Vii;
{
  MC_SetInt(Cii,Vii);
  float ret;
  float r4ibm_();
  ret = r4ibm_(&Cii);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_r4ieee(self,Vii)
    VALUE self,Vii;
{
  MC_SetInt(Cii,Vii);
  float ret;
  float r4ieee_();
  ret = r4ieee_(&Cii);
  return MC_NewFloat(ret);;
}

static VALUE
dcl_time12(self,Vitime,Vitt)
    VALUE self,Vitime,Vitt;
{
  MC_SetInt(Citime,Vitime);
  MC_SetInt(Citt,Vitt);
  time12_(&Citime,&Citt);
  return Qnil;
}

static VALUE
dcl_time13(self,Vitime,Vih,Vim,Vis)
    VALUE self,Vitime,Vih,Vim,Vis;
{
  MC_SetInt(Citime,Vitime);
  int   Cih;
  int   Cim;
  MC_SetInt(Cis,Vis);
  time13_(&Citime,&Cih,&Cim,&Cis);
  MC_GetInt(Cih,Vih);
  MC_GetInt(Cim,Vim);
  return Qnil;
}

static VALUE
dcl_time21(self,Vitime,Vitt)
    VALUE self,Vitime,Vitt;
{
  MC_SetInt(Citime,Vitime);
  MC_SetInt(Citt,Vitt);
  time21_(&Citime,&Citt);
  return Qnil;
}

static VALUE
dcl_time23(self,Vih,Vim,Vis,Vitt)
    VALUE self,Vih,Vim,Vis,Vitt;
{
  int   Cih;
  int   Cim;
  MC_SetInt(Cis,Vis);
  MC_SetInt(Citt,Vitt);
  time23_(&Cih,&Cim,&Cis,&Citt);
  MC_GetInt(Cih,Vih);
  MC_GetInt(Cim,Vim);
  return Qnil;
}

static VALUE
dcl_time31(self,Vitime,Vih,Vim,Vis)
    VALUE self,Vitime,Vih,Vim,Vis;
{
  MC_SetInt(Citime,Vitime);
  MC_SetInt(Cih,Vih);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cis,Vis);
  time31_(&Citime,&Cih,&Cim,&Cis);
  return Qnil;
}

static VALUE
dcl_time32(self,Vih,Vim,Vis,Vitt)
    VALUE self,Vih,Vim,Vis,Vitt;
{
  MC_SetInt(Cih,Vih);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cis,Vis);
  MC_SetInt(Citt,Vitt);
  time32_(&Cih,&Cim,&Cis,&Citt);
  return Qnil;
}

static VALUE
dcl_timec1(self,Vcform,Vitime)
    VALUE self,Vcform,Vitime;
{
  MC_SetString(Ccform,Vcform);
  MC_SetInt(Citime,Vitime);
  timec1_(Ccform,&Citime,strlen(Ccform));
  return Qnil;
}

static VALUE
dcl_timec2(self,Vcform,Vitt)
    VALUE self,Vcform,Vitt;
{
  MC_SetString(Ccform,Vcform);
  MC_SetInt(Citt,Vitt);
  timec2_(Ccform,&Citt,strlen(Ccform));
  return Qnil;
}

static VALUE
dcl_timec3(self,Vcform,Vih,Vim,Vis)
    VALUE self,Vcform,Vih,Vim,Vis;
{
  MC_SetString(Ccform,Vcform);
  MC_SetInt(Cih,Vih);
  MC_SetInt(Cim,Vim);
  MC_SetInt(Cis,Vis);
  timec3_(Ccform,&Cih,&Cim,&Cis,strlen(Ccform));
  return Qnil;
}

static VALUE
dcl_timeq1(self,Vitime)
    VALUE self,Vitime;
{
  MC_SetInt(Citime,Vitime);
  timeq1_(&Citime);
  return Qnil;
}

static VALUE
dcl_timeq2(self,Vitt)
    VALUE self,Vitt;
{
  MC_SetInt(Citt,Vitt);
  timeq2_(&Citt);
  return Qnil;
}

Init_mcdcl()
{
   VALUE mDcl = rb_define_module("Dcl");

   rb_define_module_function(mDcl, "scplu", dcl_scplu, 4);
   rb_define_module_function(mDcl, "scplv", dcl_scplv, 4);
   rb_define_module_function(mDcl, "scspli", dcl_scspli, 1);
   rb_define_module_function(mDcl, "scqpli", dcl_scqpli, 1);
   rb_define_module_function(mDcl, "scplzu", dcl_scplzu, 5);
   rb_define_module_function(mDcl, "scplzv", dcl_scplzv, 5);
   rb_define_module_function(mDcl, "scpmu", dcl_scpmu, 4);
   rb_define_module_function(mDcl, "scpmv", dcl_scpmv, 4);
   rb_define_module_function(mDcl, "scspmt", dcl_scspmt, 1);
   rb_define_module_function(mDcl, "scqpmt", dcl_scqpmt, 1);
   rb_define_module_function(mDcl, "scspmi", dcl_scspmi, 1);
   rb_define_module_function(mDcl, "scqpmi", dcl_scqpmi, 1);
   rb_define_module_function(mDcl, "scspms", dcl_scspms, 1);
   rb_define_module_function(mDcl, "scqpms", dcl_scqpms, 1);
   rb_define_module_function(mDcl, "scpmzu", dcl_scpmzu, 7);
   rb_define_module_function(mDcl, "scpmzv", dcl_scpmzv, 7);
   rb_define_module_function(mDcl, "scseye", dcl_scseye, 3);
   rb_define_module_function(mDcl, "scqeye", dcl_scqeye, 3);
   rb_define_module_function(mDcl, "scslog", dcl_scslog, 3);
   rb_define_module_function(mDcl, "scqlog", dcl_scqlog, 3);
   rb_define_module_function(mDcl, "scsobj", dcl_scsobj, 3);
   rb_define_module_function(mDcl, "scqobj", dcl_scqobj, 3);
   rb_define_module_function(mDcl, "scsorg", dcl_scsorg, 4);
   rb_define_module_function(mDcl, "scqorg", dcl_scqorg, 4);
   rb_define_module_function(mDcl, "scspln", dcl_scspln, 3);
   rb_define_module_function(mDcl, "scqpln", dcl_scqpln, 3);
   rb_define_module_function(mDcl, "scsprj", dcl_scsprj, 0);
   rb_define_module_function(mDcl, "scstrf", dcl_scstrf, 0);
   rb_define_module_function(mDcl, "scstrn", dcl_scstrn, 1);
   rb_define_module_function(mDcl, "scqtrn", dcl_scqtrn, 1);
   rb_define_module_function(mDcl, "scsvpt", dcl_scsvpt, 6);
   rb_define_module_function(mDcl, "scqvpt", dcl_scqvpt, 6);
   rb_define_module_function(mDcl, "scswnd", dcl_scswnd, 6);
   rb_define_module_function(mDcl, "scqwnd", dcl_scqwnd, 6);
   rb_define_module_function(mDcl, "sctnu", dcl_sctnu, 3);
   rb_define_module_function(mDcl, "sctnv", dcl_sctnv, 3);
   rb_define_module_function(mDcl, "scstnp", dcl_scstnp, 2);
   rb_define_module_function(mDcl, "scqtnp", dcl_scqtnp, 2);
   rb_define_module_function(mDcl, "sctnzu", dcl_sctnzu, 5);
   rb_define_module_function(mDcl, "sctnzv", dcl_sctnzv, 5);
   rb_define_module_function(mDcl, "isgtrc", dcl_isgtrc, 1);
   rb_define_module_function(mDcl, "sglau", dcl_sglau, 4);
   rb_define_module_function(mDcl, "sglav", dcl_sglav, 4);
   rb_define_module_function(mDcl, "sglar", dcl_sglar, 4);
   rb_define_module_function(mDcl, "sgslat", dcl_sgslat, 1);
   rb_define_module_function(mDcl, "sgqlat", dcl_sgqlat, 1);
   rb_define_module_function(mDcl, "sgslai", dcl_sgslai, 1);
   rb_define_module_function(mDcl, "sgqlai", dcl_sgqlai, 1);
   rb_define_module_function(mDcl, "sglazr", dcl_sglazr, 6);
   rb_define_module_function(mDcl, "sglazu", dcl_sglazu, 6);
   rb_define_module_function(mDcl, "sglazv", dcl_sglazv, 6);
   rb_define_module_function(mDcl, "sglnu", dcl_sglnu, 4);
   rb_define_module_function(mDcl, "sglnv", dcl_sglnv, 4);
   rb_define_module_function(mDcl, "sglnr", dcl_sglnr, 4);
   rb_define_module_function(mDcl, "sgslni", dcl_sgslni, 1);
   rb_define_module_function(mDcl, "sgqlni", dcl_sgqlni, 1);
   rb_define_module_function(mDcl, "sglnzr", dcl_sglnzr, 5);
   rb_define_module_function(mDcl, "sglnzu", dcl_sglnzu, 5);
   rb_define_module_function(mDcl, "sglnzv", dcl_sglnzv, 5);
   rb_define_module_function(mDcl, "sgopn", dcl_sgopn, 1);
   rb_define_module_function(mDcl, "sginit", dcl_sginit, 0);
   rb_define_module_function(mDcl, "sgfrm", dcl_sgfrm, 0);
   rb_define_module_function(mDcl, "sgcls", dcl_sgcls, 0);
   rb_define_module_function(mDcl, "sgpget", dcl_sgpget, 2);
   rb_define_module_function(mDcl, "sgiget", dcl_sgiget, 2);
   rb_define_module_function(mDcl, "sgrget", dcl_sgrget, 2);
   rb_define_module_function(mDcl, "sglget", dcl_sglget, 2);
   rb_define_module_function(mDcl, "sgpset", dcl_sgpset, 2);
   rb_define_module_function(mDcl, "sgiset", dcl_sgiset, 2);
   rb_define_module_function(mDcl, "sgrset", dcl_sgrset, 2);
   rb_define_module_function(mDcl, "sglset", dcl_sglset, 2);
   rb_define_module_function(mDcl, "sgpstx", dcl_sgpstx, 2);
   rb_define_module_function(mDcl, "sgistx", dcl_sgistx, 2);
   rb_define_module_function(mDcl, "sgrstx", dcl_sgrstx, 2);
   rb_define_module_function(mDcl, "sglstx", dcl_sglstx, 2);
   rb_define_module_function(mDcl, "sgplu", dcl_sgplu, 3);
   rb_define_module_function(mDcl, "sgplv", dcl_sgplv, 3);
   rb_define_module_function(mDcl, "sgplr", dcl_sgplr, 3);
   rb_define_module_function(mDcl, "sgsplt", dcl_sgsplt, 1);
   rb_define_module_function(mDcl, "sgqplt", dcl_sgqplt, 1);
   rb_define_module_function(mDcl, "sgspli", dcl_sgspli, 1);
   rb_define_module_function(mDcl, "sgqpli", dcl_sgqpli, 1);
   rb_define_module_function(mDcl, "sgplzr", dcl_sgplzr, 5);
   rb_define_module_function(mDcl, "sgplzu", dcl_sgplzu, 5);
   rb_define_module_function(mDcl, "sgplzv", dcl_sgplzv, 5);
   rb_define_module_function(mDcl, "sgpmu", dcl_sgpmu, 3);
   rb_define_module_function(mDcl, "sgpmv", dcl_sgpmv, 3);
   rb_define_module_function(mDcl, "sgpmr", dcl_sgpmr, 3);
   rb_define_module_function(mDcl, "sgspmt", dcl_sgspmt, 1);
   rb_define_module_function(mDcl, "sgqpmt", dcl_sgqpmt, 1);
   rb_define_module_function(mDcl, "sgspmi", dcl_sgspmi, 1);
   rb_define_module_function(mDcl, "sgqpmi", dcl_sgqpmi, 1);
   rb_define_module_function(mDcl, "sgspms", dcl_sgspms, 1);
   rb_define_module_function(mDcl, "sgqpms", dcl_sgqpms, 1);
   rb_define_module_function(mDcl, "sgpmzr", dcl_sgpmzr, 6);
   rb_define_module_function(mDcl, "sgpmzu", dcl_sgpmzu, 6);
   rb_define_module_function(mDcl, "sgpmzv", dcl_sgpmzv, 6);
   rb_define_module_function(mDcl, "sgpqnp", dcl_sgpqnp, 1);
   rb_define_module_function(mDcl, "sgpqid", dcl_sgpqid, 2);
   rb_define_module_function(mDcl, "sgpqcp", dcl_sgpqcp, 2);
   rb_define_module_function(mDcl, "sgpqvl", dcl_sgpqvl, 2);
   rb_define_module_function(mDcl, "sgpsvl", dcl_sgpsvl, 2);
   rb_define_module_function(mDcl, "sgpwsn", dcl_sgpwsn, 0);
   rb_define_module_function(mDcl, "sgsmpl", dcl_sgsmpl, 3);
   rb_define_module_function(mDcl, "sgqmpl", dcl_sgqmpl, 3);
   rb_define_module_function(mDcl, "sgsplc", dcl_sgsplc, 1);
   rb_define_module_function(mDcl, "sgqplc", dcl_sgqplc, 1);
   rb_define_module_function(mDcl, "sgspls", dcl_sgspls, 1);
   rb_define_module_function(mDcl, "sgqpls", dcl_sgqpls, 1);
   rb_define_module_function(mDcl, "sgnplc", dcl_sgnplc, 0);
   rb_define_module_function(mDcl, "sgssim", dcl_sgssim, 3);
   rb_define_module_function(mDcl, "sgqsim", dcl_sgqsim, 3);
   rb_define_module_function(mDcl, "sgstrf", dcl_sgstrf, 0);
   rb_define_module_function(mDcl, "sgstrn", dcl_sgstrn, 1);
   rb_define_module_function(mDcl, "sgqtrn", dcl_sgqtrn, 1);
   rb_define_module_function(mDcl, "sgstxy", dcl_sgstxy, 4);
   rb_define_module_function(mDcl, "sgqtxy", dcl_sgqtxy, 4);
   rb_define_module_function(mDcl, "sgsvpt", dcl_sgsvpt, 4);
   rb_define_module_function(mDcl, "sgqvpt", dcl_sgqvpt, 4);
   rb_define_module_function(mDcl, "sgswnd", dcl_sgswnd, 4);
   rb_define_module_function(mDcl, "sgqwnd", dcl_sgqwnd, 4);
   rb_define_module_function(mDcl, "sgtnu", dcl_sgtnu, 3);
   rb_define_module_function(mDcl, "sgtnv", dcl_sgtnv, 3);
   rb_define_module_function(mDcl, "sgtnr", dcl_sgtnr, 3);
   rb_define_module_function(mDcl, "sgstnp", dcl_sgstnp, 1);
   rb_define_module_function(mDcl, "sgqtnp", dcl_sgqtnp, 1);
   rb_define_module_function(mDcl, "sgtnzr", dcl_sgtnzr, 4);
   rb_define_module_function(mDcl, "sgtnzu", dcl_sgtnzu, 4);
   rb_define_module_function(mDcl, "sgtnzv", dcl_sgtnzv, 4);
   rb_define_module_function(mDcl, "sgtrqf", dcl_sgtrqf, 2);
   rb_define_module_function(mDcl, "sgtrsl", dcl_sgtrsl, 2);
   rb_define_module_function(mDcl, "sgtrsn", dcl_sgtrsn, 2);
   rb_define_module_function(mDcl, "sgtrls", dcl_sgtrls, 2);
   rb_define_module_function(mDcl, "sgtrln", dcl_sgtrln, 2);
   rb_define_module_function(mDcl, "sgtrns", dcl_sgtrns, 2);
   rb_define_module_function(mDcl, "sgtrnl", dcl_sgtrnl, 2);
   rb_define_module_function(mDcl, "sgtxu", dcl_sgtxu, 3);
   rb_define_module_function(mDcl, "sgtxv", dcl_sgtxv, 3);
   rb_define_module_function(mDcl, "sgtxr", dcl_sgtxr, 3);
   rb_define_module_function(mDcl, "sgstxs", dcl_sgstxs, 1);
   rb_define_module_function(mDcl, "sgqtxs", dcl_sgqtxs, 1);
   rb_define_module_function(mDcl, "sgstxr", dcl_sgstxr, 1);
   rb_define_module_function(mDcl, "sgqtxr", dcl_sgqtxr, 1);
   rb_define_module_function(mDcl, "sgstxc", dcl_sgstxc, 1);
   rb_define_module_function(mDcl, "sgqtxc", dcl_sgqtxc, 1);
   rb_define_module_function(mDcl, "sgstxi", dcl_sgstxi, 1);
   rb_define_module_function(mDcl, "sgqtxi", dcl_sgqtxi, 1);
   rb_define_module_function(mDcl, "sgtxzr", dcl_sgtxzr, 7);
   rb_define_module_function(mDcl, "sgtxzu", dcl_sgtxzu, 7);
   rb_define_module_function(mDcl, "sgtxzv", dcl_sgtxzv, 7);
   rb_define_module_function(mDcl, "sldiv", dcl_sldiv, 3);
   rb_define_module_function(mDcl, "sldivz", dcl_sldivz, 0);
   rb_define_module_function(mDcl, "slinit", dcl_slinit, 3);
   rb_define_module_function(mDcl, "slsize", dcl_slsize, 1);
   rb_define_module_function(mDcl, "slform", dcl_slform, 2);
   rb_define_module_function(mDcl, "slmgn", dcl_slmgn, 4);
   rb_define_module_function(mDcl, "slmgnz", dcl_slmgnz, 8);
   rb_define_module_function(mDcl, "slpage", dcl_slpage, 3);
   rb_define_module_function(mDcl, "slpcnr", dcl_slpcnr, 0);
   rb_define_module_function(mDcl, "slpvpc", dcl_slpvpc, 2);
   rb_define_module_function(mDcl, "slpvpr", dcl_slpvpr, 1);
   rb_define_module_function(mDcl, "slpwvc", dcl_slpwvc, 2);
   rb_define_module_function(mDcl, "slpwvr", dcl_slpwvr, 1);
   rb_define_module_function(mDcl, "slpwwc", dcl_slpwwc, 2);
   rb_define_module_function(mDcl, "slpwwr", dcl_slpwwr, 1);
   rb_define_module_function(mDcl, "slqrct", dcl_slqrct, 6);
   rb_define_module_function(mDcl, "slqsiz", dcl_slqsiz, 3);
   rb_define_module_function(mDcl, "slrat", dcl_slrat, 2);
   rb_define_module_function(mDcl, "slratz", dcl_slratz, 6);
   rb_define_module_function(mDcl, "slsttl", dcl_slsttl, 6);
   rb_define_module_function(mDcl, "sldttl", dcl_sldttl, 1);
   rb_define_module_function(mDcl, "slpttl", dcl_slpttl, 0);
   rb_define_module_function(mDcl, "sltlcv", dcl_sltlcv, 3);
   rb_define_module_function(mDcl, "slzttl", dcl_slzttl, 6);
   rb_define_module_function(mDcl, "stfpr3", dcl_stfpr3, 5);
   rb_define_module_function(mDcl, "stspr3", dcl_stspr3, 0);
   rb_define_module_function(mDcl, "stfpr2", dcl_stfpr2, 4);
   rb_define_module_function(mDcl, "stipr2", dcl_stipr2, 4);
   rb_define_module_function(mDcl, "stspr2", dcl_stspr2, 3);
   rb_define_module_function(mDcl, "stepr2", dcl_stepr2, 0);
   rb_define_module_function(mDcl, "strpr2", dcl_strpr2, 0);
   rb_define_module_function(mDcl, "stfrad", dcl_stfrad, 4);
   rb_define_module_function(mDcl, "stirad", dcl_stirad, 4);
   rb_define_module_function(mDcl, "stsrad", dcl_stsrad, 2);
   rb_define_module_function(mDcl, "stfrot", dcl_stfrot, 4);
   rb_define_module_function(mDcl, "stirot", dcl_stirot, 4);
   rb_define_module_function(mDcl, "stsrot", dcl_stsrot, 3);
   rb_define_module_function(mDcl, "stftr3", dcl_stftr3, 6);
   rb_define_module_function(mDcl, "ststr3", dcl_ststr3, 7);
   rb_define_module_function(mDcl, "stsrd3", dcl_stsrd3, 3);
   rb_define_module_function(mDcl, "stslg3", dcl_stslg3, 3);
   rb_define_module_function(mDcl, "stftrf", dcl_stftrf, 4);
   rb_define_module_function(mDcl, "stitrf", dcl_stitrf, 4);
   rb_define_module_function(mDcl, "stqtrf", dcl_stqtrf, 1);
   rb_define_module_function(mDcl, "ststrf", dcl_ststrf, 1);
   rb_define_module_function(mDcl, "stftrn", dcl_stftrn, 4);
   rb_define_module_function(mDcl, "stitrn", dcl_stitrn, 4);
   rb_define_module_function(mDcl, "ststrn", dcl_ststrn, 5);
   rb_define_module_function(mDcl, "stfusr", dcl_stfusr, 4);
   rb_define_module_function(mDcl, "stiusr", dcl_stiusr, 4);
   rb_define_module_function(mDcl, "stsusr", dcl_stsusr, 0);
   rb_define_module_function(mDcl, "stfwtr", dcl_stfwtr, 4);
   rb_define_module_function(mDcl, "stiwtr", dcl_stiwtr, 4);
   rb_define_module_function(mDcl, "stswtr", dcl_stswtr, 0);
   rb_define_module_function(mDcl, "stqwtr", dcl_stqwtr, 0);
   rb_define_module_function(mDcl, "stswrc", dcl_stswrc, 4);
   rb_define_module_function(mDcl, "stqwrc", dcl_stqwrc, 4);
   rb_define_module_function(mDcl, "swcget", dcl_swcget, 2);
   rb_define_module_function(mDcl, "swcset", dcl_swcset, 2);
   rb_define_module_function(mDcl, "swcstx", dcl_swcstx, 2);
   rb_define_module_function(mDcl, "swcqnp", dcl_swcqnp, 1);
   rb_define_module_function(mDcl, "swcqid", dcl_swcqid, 2);
   rb_define_module_function(mDcl, "swcqcp", dcl_swcqcp, 2);
   rb_define_module_function(mDcl, "swcqvl", dcl_swcqvl, 2);
   rb_define_module_function(mDcl, "swcsvl", dcl_swcsvl, 2);
   rb_define_module_function(mDcl, "swdopn", dcl_swdopn, 0);
   rb_define_module_function(mDcl, "swdcls", dcl_swdcls, 0);
   rb_define_module_function(mDcl, "swpopn", dcl_swpopn, 0);
   rb_define_module_function(mDcl, "swpcls", dcl_swpcls, 0);
   rb_define_module_function(mDcl, "swoopn", dcl_swoopn, 2);
   rb_define_module_function(mDcl, "swocls", dcl_swocls, 1);
   rb_define_module_function(mDcl, "swswdi", dcl_swswdi, 1);
   rb_define_module_function(mDcl, "swscli", dcl_swscli, 1);
   rb_define_module_function(mDcl, "swgopn", dcl_swgopn, 0);
   rb_define_module_function(mDcl, "swgmov", dcl_swgmov, 2);
   rb_define_module_function(mDcl, "swgplt", dcl_swgplt, 2);
   rb_define_module_function(mDcl, "swgcls", dcl_swgcls, 0);
   rb_define_module_function(mDcl, "swgton", dcl_swgton, 4);
   rb_define_module_function(mDcl, "swiopn", dcl_swiopn, 4);
   rb_define_module_function(mDcl, "swidat", dcl_swidat, 2);
   rb_define_module_function(mDcl, "swicls", dcl_swicls, 0);
   rb_define_module_function(mDcl, "swqpnt", dcl_swqpnt, 3);
   rb_define_module_function(mDcl, "swfint", dcl_swfint, 4);
   rb_define_module_function(mDcl, "swiint", dcl_swiint, 4);
   rb_define_module_function(mDcl, "swqwdc", dcl_swqwdc, 1);
   rb_define_module_function(mDcl, "swqclc", dcl_swqclc, 1);
   rb_define_module_function(mDcl, "swqtnc", dcl_swqtnc, 1);
   rb_define_module_function(mDcl, "swqimc", dcl_swqimc, 1);
   rb_define_module_function(mDcl, "swqptc", dcl_swqptc, 1);
   rb_define_module_function(mDcl, "swqrct", dcl_swqrct, 5);
   rb_define_module_function(mDcl, "swsrot", dcl_swsrot, 1);
   rb_define_module_function(mDcl, "swpget", dcl_swpget, 2);
   rb_define_module_function(mDcl, "swiget", dcl_swiget, 2);
   rb_define_module_function(mDcl, "swrget", dcl_swrget, 2);
   rb_define_module_function(mDcl, "swlget", dcl_swlget, 2);
   rb_define_module_function(mDcl, "swpset", dcl_swpset, 2);
   rb_define_module_function(mDcl, "swiset", dcl_swiset, 2);
   rb_define_module_function(mDcl, "swrset", dcl_swrset, 2);
   rb_define_module_function(mDcl, "swlset", dcl_swlset, 2);
   rb_define_module_function(mDcl, "swpstx", dcl_swpstx, 2);
   rb_define_module_function(mDcl, "swistx", dcl_swistx, 2);
   rb_define_module_function(mDcl, "swrstx", dcl_swrstx, 2);
   rb_define_module_function(mDcl, "swlstx", dcl_swlstx, 2);
   rb_define_module_function(mDcl, "swpqnp", dcl_swpqnp, 1);
   rb_define_module_function(mDcl, "swpqid", dcl_swpqid, 2);
   rb_define_module_function(mDcl, "swpqcp", dcl_swpqcp, 2);
   rb_define_module_function(mDcl, "swpqvl", dcl_swpqvl, 2);
   rb_define_module_function(mDcl, "swrqvl", dcl_swrqvl, 2);
   rb_define_module_function(mDcl, "swiqvl", dcl_swiqvl, 2);
   rb_define_module_function(mDcl, "swlqvl", dcl_swlqvl, 2);
   rb_define_module_function(mDcl, "swpsvl", dcl_swpsvl, 2);
   rb_define_module_function(mDcl, "swrsvl", dcl_swrsvl, 2);
   rb_define_module_function(mDcl, "swisvl", dcl_swisvl, 2);
   rb_define_module_function(mDcl, "swlsvl", dcl_swlsvl, 2);
   rb_define_module_function(mDcl, "swqfnm", dcl_swqfnm, 2);
   rb_define_module_function(mDcl, "szcltn", dcl_szcltn, 2);
   rb_define_module_function(mDcl, "szfont", dcl_szfont, 6);
   rb_define_module_function(mDcl, "szl3op", dcl_szl3op, 1);
   rb_define_module_function(mDcl, "szl3cl", dcl_szl3cl, 0);
   rb_define_module_function(mDcl, "szl3zu", dcl_szl3zu, 4);
   rb_define_module_function(mDcl, "szl3zv", dcl_szl3zv, 4);
   rb_define_module_function(mDcl, "szlaop", dcl_szlaop, 2);
   rb_define_module_function(mDcl, "szlacl", dcl_szlacl, 0);
   rb_define_module_function(mDcl, "szlazr", dcl_szlazr, 4);
   rb_define_module_function(mDcl, "szlazu", dcl_szlazu, 4);
   rb_define_module_function(mDcl, "szlazv", dcl_szlazv, 4);
   rb_define_module_function(mDcl, "szlnop", dcl_szlnop, 1);
   rb_define_module_function(mDcl, "szlncl", dcl_szlncl, 0);
   rb_define_module_function(mDcl, "szlnzr", dcl_szlnzr, 4);
   rb_define_module_function(mDcl, "szlnzu", dcl_szlnzu, 4);
   rb_define_module_function(mDcl, "szlnzv", dcl_szlnzv, 4);
   rb_define_module_function(mDcl, "szm3op", dcl_szm3op, 3);
   rb_define_module_function(mDcl, "szm3cl", dcl_szm3cl, 0);
   rb_define_module_function(mDcl, "szm3zu", dcl_szm3zu, 4);
   rb_define_module_function(mDcl, "szm3zv", dcl_szm3zv, 4);
   rb_define_module_function(mDcl, "szopl3", dcl_szopl3, 0);
   rb_define_module_function(mDcl, "szmvl3", dcl_szmvl3, 3);
   rb_define_module_function(mDcl, "szpll3", dcl_szpll3, 3);
   rb_define_module_function(mDcl, "szcll3", dcl_szcll3, 0);
   rb_define_module_function(mDcl, "szoplc", dcl_szoplc, 0);
   rb_define_module_function(mDcl, "szmvlc", dcl_szmvlc, 2);
   rb_define_module_function(mDcl, "szpllc", dcl_szpllc, 2);
   rb_define_module_function(mDcl, "szcllc", dcl_szcllc, 0);
   rb_define_module_function(mDcl, "szschz", dcl_szschz, 2);
   rb_define_module_function(mDcl, "szqchz", dcl_szqchz, 2);
   rb_define_module_function(mDcl, "szcrst", dcl_szcrst, 0);
   rb_define_module_function(mDcl, "szopld", dcl_szopld, 0);
   rb_define_module_function(mDcl, "szmvld", dcl_szmvld, 2);
   rb_define_module_function(mDcl, "szplld", dcl_szplld, 2);
   rb_define_module_function(mDcl, "szclld", dcl_szclld, 0);
   rb_define_module_function(mDcl, "szstyz", dcl_szstyz, 1);
   rb_define_module_function(mDcl, "szqtyz", dcl_szqtyz, 1);
   rb_define_module_function(mDcl, "szoplp", dcl_szoplp, 0);
   rb_define_module_function(mDcl, "szmvlp", dcl_szmvlp, 2);
   rb_define_module_function(mDcl, "szpllp", dcl_szpllp, 2);
   rb_define_module_function(mDcl, "szcllp", dcl_szcllp, 0);
   rb_define_module_function(mDcl, "szoplr", dcl_szoplr, 0);
   rb_define_module_function(mDcl, "szmvlr", dcl_szmvlr, 2);
   rb_define_module_function(mDcl, "szpllr", dcl_szpllr, 2);
   rb_define_module_function(mDcl, "szcllr", dcl_szcllr, 0);
   rb_define_module_function(mDcl, "szoplt", dcl_szoplt, 0);
   rb_define_module_function(mDcl, "szmvlt", dcl_szmvlt, 2);
   rb_define_module_function(mDcl, "szpllt", dcl_szpllt, 2);
   rb_define_module_function(mDcl, "szcllt", dcl_szcllt, 0);
   rb_define_module_function(mDcl, "szoplu", dcl_szoplu, 0);
   rb_define_module_function(mDcl, "szmvlu", dcl_szmvlu, 2);
   rb_define_module_function(mDcl, "szpllu", dcl_szpllu, 2);
   rb_define_module_function(mDcl, "szcllu", dcl_szcllu, 0);
   rb_define_module_function(mDcl, "szoplv", dcl_szoplv, 0);
   rb_define_module_function(mDcl, "szmvlv", dcl_szmvlv, 2);
   rb_define_module_function(mDcl, "szpllv", dcl_szpllv, 2);
   rb_define_module_function(mDcl, "szcllv", dcl_szcllv, 0);
   rb_define_module_function(mDcl, "szoplz", dcl_szoplz, 0);
   rb_define_module_function(mDcl, "szmvlz", dcl_szmvlz, 2);
   rb_define_module_function(mDcl, "szpllz", dcl_szpllz, 2);
   rb_define_module_function(mDcl, "szcllz", dcl_szcllz, 0);
   rb_define_module_function(mDcl, "szopsv", dcl_szopsv, 0);
   rb_define_module_function(mDcl, "szmvsv", dcl_szmvsv, 2);
   rb_define_module_function(mDcl, "szplsv", dcl_szplsv, 2);
   rb_define_module_function(mDcl, "szclsv", dcl_szclsv, 0);
   rb_define_module_function(mDcl, "szoptp", dcl_szoptp, 0);
   rb_define_module_function(mDcl, "szsttp", dcl_szsttp, 2);
   rb_define_module_function(mDcl, "szcltp", dcl_szcltp, 0);
   rb_define_module_function(mDcl, "szstmd", dcl_szstmd, 1);
   rb_define_module_function(mDcl, "szqtmd", dcl_szqtmd, 1);
   rb_define_module_function(mDcl, "szoptr", dcl_szoptr, 0);
   rb_define_module_function(mDcl, "szsttr", dcl_szsttr, 2);
   rb_define_module_function(mDcl, "szcltr", dcl_szcltr, 0);
   rb_define_module_function(mDcl, "szopts", dcl_szopts, 0);
   rb_define_module_function(mDcl, "szstts", dcl_szstts, 2);
   rb_define_module_function(mDcl, "szclts", dcl_szclts, 0);
   rb_define_module_function(mDcl, "sztits", dcl_sztits, 1);
   rb_define_module_function(mDcl, "szoptt", dcl_szoptt, 0);
   rb_define_module_function(mDcl, "szsttt", dcl_szsttt, 2);
   rb_define_module_function(mDcl, "szcltt", dcl_szcltt, 0);
   rb_define_module_function(mDcl, "szoptu", dcl_szoptu, 0);
   rb_define_module_function(mDcl, "szsttu", dcl_szsttu, 2);
   rb_define_module_function(mDcl, "szcltu", dcl_szcltu, 0);
   rb_define_module_function(mDcl, "szoptv", dcl_szoptv, 0);
   rb_define_module_function(mDcl, "szsttv", dcl_szsttv, 2);
   rb_define_module_function(mDcl, "szcltv", dcl_szcltv, 0);
   rb_define_module_function(mDcl, "szoptz", dcl_szoptz, 0);
   rb_define_module_function(mDcl, "szsttz", dcl_szsttz, 2);
   rb_define_module_function(mDcl, "szcltz", dcl_szcltz, 0);
   rb_define_module_function(mDcl, "sztitz", dcl_sztitz, 1);
   rb_define_module_function(mDcl, "szpcll", dcl_szpcll, 6);
   rb_define_module_function(mDcl, "szgcll", dcl_szgcll, 5);
   rb_define_module_function(mDcl, "szscll", dcl_szscll, 5);
   rb_define_module_function(mDcl, "szqcll", dcl_szqcll, 5);
   rb_define_module_function(mDcl, "szpclx", dcl_szpclx, 6);
   rb_define_module_function(mDcl, "szgclx", dcl_szgclx, 4);
   rb_define_module_function(mDcl, "szsclx", dcl_szsclx, 2);
   rb_define_module_function(mDcl, "szqclx", dcl_szqclx, 2);
   rb_define_module_function(mDcl, "szpcly", dcl_szpcly, 6);
   rb_define_module_function(mDcl, "szgcly", dcl_szgcly, 3);
   rb_define_module_function(mDcl, "szscly", dcl_szscly, 2);
   rb_define_module_function(mDcl, "szqcly", dcl_szqcly, 2);
   rb_define_module_function(mDcl, "szpipl", dcl_szpipl, 5);
   rb_define_module_function(mDcl, "szgipl", dcl_szgipl, 3);
   rb_define_module_function(mDcl, "szpipt", dcl_szpipt, 5);
   rb_define_module_function(mDcl, "szgipt", dcl_szgipt, 3);
   rb_define_module_function(mDcl, "szpipz", dcl_szpipz, 5);
   rb_define_module_function(mDcl, "szgipz", dcl_szgipz, 5);
   rb_define_module_function(mDcl, "szplop", dcl_szplop, 2);
   rb_define_module_function(mDcl, "szplcl", dcl_szplcl, 0);
   rb_define_module_function(mDcl, "szplzr", dcl_szplzr, 3);
   rb_define_module_function(mDcl, "szplzu", dcl_szplzu, 3);
   rb_define_module_function(mDcl, "szplzv", dcl_szplzv, 3);
   rb_define_module_function(mDcl, "szpmop", dcl_szpmop, 3);
   rb_define_module_function(mDcl, "szpmcl", dcl_szpmcl, 0);
   rb_define_module_function(mDcl, "szpmzr", dcl_szpmzr, 3);
   rb_define_module_function(mDcl, "szpmzu", dcl_szpmzu, 3);
   rb_define_module_function(mDcl, "szpmzv", dcl_szpmzv, 3);
   rb_define_module_function(mDcl, "szqtxw", dcl_szqtxw, 4);
   rb_define_module_function(mDcl, "szsgcl", dcl_szsgcl, 4);
   rb_define_module_function(mDcl, "szqgcy", dcl_szqgcy, 2);
   rb_define_module_function(mDcl, "szqgcx", dcl_szqgcx, 2);
   rb_define_module_function(mDcl, "szsidx", dcl_szsidx, 1);
   rb_define_module_function(mDcl, "szqidx", dcl_szqidx, 1);
   rb_define_module_function(mDcl, "szslti", dcl_szslti, 2);
   rb_define_module_function(mDcl, "szstni", dcl_szstni, 1);
   rb_define_module_function(mDcl, "szqtni", dcl_szqtni, 1);
   rb_define_module_function(mDcl, "szstyp", dcl_szstyp, 1);
   rb_define_module_function(mDcl, "szqtyp", dcl_szqtyp, 1);
   rb_define_module_function(mDcl, "szt3op", dcl_szt3op, 2);
   rb_define_module_function(mDcl, "szt3cl", dcl_szt3cl, 0);
   rb_define_module_function(mDcl, "szt3zu", dcl_szt3zu, 3);
   rb_define_module_function(mDcl, "szt3zv", dcl_szt3zv, 3);
   rb_define_module_function(mDcl, "sztnop", dcl_sztnop, 1);
   rb_define_module_function(mDcl, "sztncl", dcl_sztncl, 0);
   rb_define_module_function(mDcl, "sztnsv", dcl_sztnsv, 7);
   rb_define_module_function(mDcl, "sztnzr", dcl_sztnzr, 3);
   rb_define_module_function(mDcl, "sztnzu", dcl_sztnzu, 3);
   rb_define_module_function(mDcl, "sztnzv", dcl_sztnzv, 3);
   rb_define_module_function(mDcl, "sztxop", dcl_sztxop, 4);
   rb_define_module_function(mDcl, "sztxcl", dcl_sztxcl, 0);
   rb_define_module_function(mDcl, "sztxwv", dcl_sztxwv, 3);
   rb_define_module_function(mDcl, "sztxzr", dcl_sztxzr, 3);
   rb_define_module_function(mDcl, "sztxzu", dcl_sztxzu, 3);
   rb_define_module_function(mDcl, "sztxzv", dcl_sztxzv, 3);
   rb_define_module_function(mDcl, "szxmod", dcl_szxmod, 1);
   rb_define_module_function(mDcl, "grinit", dcl_grinit, 0);
   rb_define_module_function(mDcl, "gropn", dcl_gropn, 1);
   rb_define_module_function(mDcl, "grfrm", dcl_grfrm, 0);
   rb_define_module_function(mDcl, "grfig", dcl_grfig, 0);
   rb_define_module_function(mDcl, "grcls", dcl_grcls, 0);
   rb_define_module_function(mDcl, "grsmpl", dcl_grsmpl, 3);
   rb_define_module_function(mDcl, "grssim", dcl_grssim, 3);
   rb_define_module_function(mDcl, "grstrf", dcl_grstrf, 0);
   rb_define_module_function(mDcl, "grstrn", dcl_grstrn, 1);
   rb_define_module_function(mDcl, "grstxy", dcl_grstxy, 4);
   rb_define_module_function(mDcl, "grsvpt", dcl_grsvpt, 4);
   rb_define_module_function(mDcl, "grswnd", dcl_grswnd, 4);
   rb_define_module_function(mDcl, "nucchr", dcl_nucchr, 2);
   rb_define_module_function(mDcl, "nucday", dcl_nucday, 2);
   rb_define_module_function(mDcl, "ucpget", dcl_ucpget, 2);
   rb_define_module_function(mDcl, "uciget", dcl_uciget, 2);
   rb_define_module_function(mDcl, "ucrget", dcl_ucrget, 2);
   rb_define_module_function(mDcl, "uclget", dcl_uclget, 2);
   rb_define_module_function(mDcl, "ucpset", dcl_ucpset, 2);
   rb_define_module_function(mDcl, "uciset", dcl_uciset, 2);
   rb_define_module_function(mDcl, "ucrset", dcl_ucrset, 2);
   rb_define_module_function(mDcl, "uclset", dcl_uclset, 2);
   rb_define_module_function(mDcl, "ucpstx", dcl_ucpstx, 2);
   rb_define_module_function(mDcl, "ucistx", dcl_ucistx, 2);
   rb_define_module_function(mDcl, "ucrstx", dcl_ucrstx, 2);
   rb_define_module_function(mDcl, "uclstx", dcl_uclstx, 2);
   rb_define_module_function(mDcl, "ucpqnp", dcl_ucpqnp, 1);
   rb_define_module_function(mDcl, "ucpqid", dcl_ucpqid, 2);
   rb_define_module_function(mDcl, "ucpqcp", dcl_ucpqcp, 2);
   rb_define_module_function(mDcl, "ucpqvl", dcl_ucpqvl, 2);
   rb_define_module_function(mDcl, "ucpsvl", dcl_ucpsvl, 2);
   rb_define_module_function(mDcl, "ucxacl", dcl_ucxacl, 3);
   rb_define_module_function(mDcl, "ucxady", dcl_ucxady, 3);
   rb_define_module_function(mDcl, "ucxamn", dcl_ucxamn, 3);
   rb_define_module_function(mDcl, "ucxayr", dcl_ucxayr, 3);
   rb_define_module_function(mDcl, "ucyacl", dcl_ucyacl, 3);
   rb_define_module_function(mDcl, "ucyady", dcl_ucyady, 3);
   rb_define_module_function(mDcl, "ucyamn", dcl_ucyamn, 3);
   rb_define_module_function(mDcl, "ucyayr", dcl_ucyayr, 3);
   rb_define_module_function(mDcl, "ludchk", dcl_ludchk, 5);
   rb_define_module_function(mDcl, "rudlev", dcl_rudlev, 1);
   rb_define_module_function(mDcl, "rudval", dcl_rudval, 2);
   rb_define_module_function(mDcl, "udbclr", dcl_udbclr, 5);
   rb_define_module_function(mDcl, "udbset", dcl_udbset, 5);
   rb_define_module_function(mDcl, "udcntr", dcl_udcntr, 4);
   rb_define_module_function(mDcl, "udcntz", dcl_udcntz, 6);
   rb_define_module_function(mDcl, "udgcla", dcl_udgcla, 3);
   rb_define_module_function(mDcl, "udgclb", dcl_udgclb, 5);
   rb_define_module_function(mDcl, "udgrdn", dcl_udgrdn, 7);
   rb_define_module_function(mDcl, "udiclr", dcl_udiclr, 2);
   rb_define_module_function(mDcl, "udiclv", dcl_udiclv, 0);
   rb_define_module_function(mDcl, "udsclv", dcl_udsclv, 5);
   rb_define_module_function(mDcl, "udqclv", dcl_udqclv, 6);
   rb_define_module_function(mDcl, "udqcln", dcl_udqcln, 1);
   rb_define_module_function(mDcl, "uddclv", dcl_uddclv, 1);
   rb_define_module_function(mDcl, "udsclz", dcl_udsclz, 1);
   rb_define_module_function(mDcl, "udqclz", dcl_udqclz, 1);
   rb_define_module_function(mDcl, "udlabl", dcl_udlabl, 2);
   rb_define_module_function(mDcl, "udsfmt", dcl_udsfmt, 1);
   rb_define_module_function(mDcl, "udqfmt", dcl_udqfmt, 1);
   rb_define_module_function(mDcl, "udline", dcl_udline, 8);
   rb_define_module_function(mDcl, "udpget", dcl_udpget, 2);
   rb_define_module_function(mDcl, "udiget", dcl_udiget, 2);
   rb_define_module_function(mDcl, "udrget", dcl_udrget, 2);
   rb_define_module_function(mDcl, "udlget", dcl_udlget, 2);
   rb_define_module_function(mDcl, "udpset", dcl_udpset, 2);
   rb_define_module_function(mDcl, "udiset", dcl_udiset, 2);
   rb_define_module_function(mDcl, "udrset", dcl_udrset, 2);
   rb_define_module_function(mDcl, "udlset", dcl_udlset, 2);
   rb_define_module_function(mDcl, "udpstx", dcl_udpstx, 2);
   rb_define_module_function(mDcl, "udistx", dcl_udistx, 2);
   rb_define_module_function(mDcl, "udrstx", dcl_udrstx, 2);
   rb_define_module_function(mDcl, "udlstx", dcl_udlstx, 2);
   rb_define_module_function(mDcl, "udpqnp", dcl_udpqnp, 1);
   rb_define_module_function(mDcl, "udpqid", dcl_udpqid, 2);
   rb_define_module_function(mDcl, "udpqcp", dcl_udpqcp, 2);
   rb_define_module_function(mDcl, "udpqvl", dcl_udpqvl, 2);
   rb_define_module_function(mDcl, "udpsvl", dcl_udpsvl, 2);
   rb_define_module_function(mDcl, "uduxuy", dcl_uduxuy, 8);
   rb_define_module_function(mDcl, "iueton", dcl_iueton, 1);
   rb_define_module_function(mDcl, "uearea", dcl_uearea, 9);
   rb_define_module_function(mDcl, "ueaint", dcl_ueaint, 0);
   rb_define_module_function(mDcl, "uegtla", dcl_uegtla, 3);
   rb_define_module_function(mDcl, "uegtlb", dcl_uegtlb, 5);
   rb_define_module_function(mDcl, "ueitlv", dcl_ueitlv, 0);
   rb_define_module_function(mDcl, "uestlv", dcl_uestlv, 3);
   rb_define_module_function(mDcl, "ueqtlv", dcl_ueqtlv, 4);
   rb_define_module_function(mDcl, "ueqntl", dcl_ueqntl, 1);
   rb_define_module_function(mDcl, "uestlz", dcl_uestlz, 1);
   rb_define_module_function(mDcl, "ueqtlz", dcl_ueqtlz, 1);
   rb_define_module_function(mDcl, "uepget", dcl_uepget, 2);
   rb_define_module_function(mDcl, "ueiget", dcl_ueiget, 2);
   rb_define_module_function(mDcl, "uerget", dcl_uerget, 2);
   rb_define_module_function(mDcl, "uelget", dcl_uelget, 2);
   rb_define_module_function(mDcl, "uepset", dcl_uepset, 2);
   rb_define_module_function(mDcl, "ueiset", dcl_ueiset, 2);
   rb_define_module_function(mDcl, "uerset", dcl_uerset, 2);
   rb_define_module_function(mDcl, "uelset", dcl_uelset, 2);
   rb_define_module_function(mDcl, "uepstx", dcl_uepstx, 2);
   rb_define_module_function(mDcl, "ueistx", dcl_ueistx, 2);
   rb_define_module_function(mDcl, "uerstx", dcl_uerstx, 2);
   rb_define_module_function(mDcl, "uelstx", dcl_uelstx, 2);
   rb_define_module_function(mDcl, "uepqnp", dcl_uepqnp, 1);
   rb_define_module_function(mDcl, "uepqid", dcl_uepqid, 2);
   rb_define_module_function(mDcl, "uepqcp", dcl_uepqcp, 2);
   rb_define_module_function(mDcl, "uepqvl", dcl_uepqvl, 2);
   rb_define_module_function(mDcl, "uepsvl", dcl_uepsvl, 2);
   rb_define_module_function(mDcl, "uestln", dcl_uestln, 3);
   rb_define_module_function(mDcl, "uetonc", dcl_uetonc, 4);
   rb_define_module_function(mDcl, "uetone", dcl_uetone, 4);
   rb_define_module_function(mDcl, "uetonf", dcl_uetonf, 4);
   rb_define_module_function(mDcl, "uezchk", dcl_uezchk, 6);
   rb_define_module_function(mDcl, "ugpget", dcl_ugpget, 2);
   rb_define_module_function(mDcl, "ugiget", dcl_ugiget, 2);
   rb_define_module_function(mDcl, "ugrget", dcl_ugrget, 2);
   rb_define_module_function(mDcl, "uglget", dcl_uglget, 2);
   rb_define_module_function(mDcl, "ugpset", dcl_ugpset, 2);
   rb_define_module_function(mDcl, "ugiset", dcl_ugiset, 2);
   rb_define_module_function(mDcl, "ugrset", dcl_ugrset, 2);
   rb_define_module_function(mDcl, "uglset", dcl_uglset, 2);
   rb_define_module_function(mDcl, "ugpstx", dcl_ugpstx, 2);
   rb_define_module_function(mDcl, "ugistx", dcl_ugistx, 2);
   rb_define_module_function(mDcl, "ugrstx", dcl_ugrstx, 2);
   rb_define_module_function(mDcl, "uglstx", dcl_uglstx, 2);
   rb_define_module_function(mDcl, "ugpqnp", dcl_ugpqnp, 1);
   rb_define_module_function(mDcl, "ugpqid", dcl_ugpqid, 2);
   rb_define_module_function(mDcl, "ugpqcp", dcl_ugpqcp, 2);
   rb_define_module_function(mDcl, "ugpqvl", dcl_ugpqvl, 2);
   rb_define_module_function(mDcl, "ugpsvl", dcl_ugpsvl, 2);
   rb_define_module_function(mDcl, "ugsut", dcl_ugsut, 2);
   rb_define_module_function(mDcl, "ugdut", dcl_ugdut, 0);
   rb_define_module_function(mDcl, "ugunit", dcl_ugunit, 0);
   rb_define_module_function(mDcl, "ugvect", dcl_ugvect, 6);
   rb_define_module_function(mDcl, "uhbra", dcl_uhbra, 4);
   rb_define_module_function(mDcl, "uhbraz", dcl_uhbraz, 7);
   rb_define_module_function(mDcl, "uhbrf", dcl_uhbrf, 4);
   rb_define_module_function(mDcl, "uhbrfz", dcl_uhbrfz, 7);
   rb_define_module_function(mDcl, "uhbrl", dcl_uhbrl, 3);
   rb_define_module_function(mDcl, "uhbrlz", dcl_uhbrlz, 6);
   rb_define_module_function(mDcl, "uhbxa", dcl_uhbxa, 4);
   rb_define_module_function(mDcl, "uhbxaz", dcl_uhbxaz, 6);
   rb_define_module_function(mDcl, "uhbxf", dcl_uhbxf, 4);
   rb_define_module_function(mDcl, "uhbxfz", dcl_uhbxfz, 6);
   rb_define_module_function(mDcl, "uhbxl", dcl_uhbxl, 3);
   rb_define_module_function(mDcl, "uhbxlz", dcl_uhbxlz, 5);
   rb_define_module_function(mDcl, "uhdif", dcl_uhdif, 4);
   rb_define_module_function(mDcl, "uhdifz", dcl_uhdifz, 6);
   rb_define_module_function(mDcl, "uherb", dcl_uherb, 4);
   rb_define_module_function(mDcl, "uherbz", dcl_uherbz, 7);
   rb_define_module_function(mDcl, "ulpget", dcl_ulpget, 2);
   rb_define_module_function(mDcl, "uliget", dcl_uliget, 2);
   rb_define_module_function(mDcl, "ulrget", dcl_ulrget, 2);
   rb_define_module_function(mDcl, "ullget", dcl_ullget, 2);
   rb_define_module_function(mDcl, "ulpset", dcl_ulpset, 2);
   rb_define_module_function(mDcl, "uliset", dcl_uliset, 2);
   rb_define_module_function(mDcl, "ulrset", dcl_ulrset, 2);
   rb_define_module_function(mDcl, "ullset", dcl_ullset, 2);
   rb_define_module_function(mDcl, "ulpstx", dcl_ulpstx, 2);
   rb_define_module_function(mDcl, "ulistx", dcl_ulistx, 2);
   rb_define_module_function(mDcl, "ulrstx", dcl_ulrstx, 2);
   rb_define_module_function(mDcl, "ullstx", dcl_ullstx, 2);
   rb_define_module_function(mDcl, "ulpqnp", dcl_ulpqnp, 1);
   rb_define_module_function(mDcl, "ulpqid", dcl_ulpqid, 2);
   rb_define_module_function(mDcl, "ulpqcp", dcl_ulpqcp, 2);
   rb_define_module_function(mDcl, "ulpqvl", dcl_ulpqvl, 2);
   rb_define_module_function(mDcl, "ulpsvl", dcl_ulpsvl, 2);
   rb_define_module_function(mDcl, "ulxlbl", dcl_ulxlbl, 3);
   rb_define_module_function(mDcl, "ulsxbl", dcl_ulsxbl, 2);
   rb_define_module_function(mDcl, "ulqxbl", dcl_ulqxbl, 2);
   rb_define_module_function(mDcl, "ulxlog", dcl_ulxlog, 3);
   rb_define_module_function(mDcl, "ulxsfm", dcl_ulxsfm, 1);
   rb_define_module_function(mDcl, "ulxqfm", dcl_ulxqfm, 1);
   rb_define_module_function(mDcl, "ulylbl", dcl_ulylbl, 3);
   rb_define_module_function(mDcl, "ulsybl", dcl_ulsybl, 2);
   rb_define_module_function(mDcl, "ulqybl", dcl_ulqybl, 2);
   rb_define_module_function(mDcl, "ulylog", dcl_ulylog, 3);
   rb_define_module_function(mDcl, "ulysfm", dcl_ulysfm, 1);
   rb_define_module_function(mDcl, "ulyqfm", dcl_ulyqfm, 1);
   rb_define_module_function(mDcl, "umbndc", dcl_umbndc, 4);
   rb_define_module_function(mDcl, "umbndp", dcl_umbndp, 4);
   rb_define_module_function(mDcl, "umbndr", dcl_umbndr, 0);
   rb_define_module_function(mDcl, "uminit", dcl_uminit, 0);
   rb_define_module_function(mDcl, "umpfit", dcl_umpfit, 0);
   rb_define_module_function(mDcl, "umpget", dcl_umpget, 2);
   rb_define_module_function(mDcl, "umiget", dcl_umiget, 2);
   rb_define_module_function(mDcl, "umrget", dcl_umrget, 2);
   rb_define_module_function(mDcl, "umlget", dcl_umlget, 2);
   rb_define_module_function(mDcl, "umpset", dcl_umpset, 2);
   rb_define_module_function(mDcl, "umiset", dcl_umiset, 2);
   rb_define_module_function(mDcl, "umrset", dcl_umrset, 2);
   rb_define_module_function(mDcl, "umlset", dcl_umlset, 2);
   rb_define_module_function(mDcl, "umpstx", dcl_umpstx, 2);
   rb_define_module_function(mDcl, "umistx", dcl_umistx, 2);
   rb_define_module_function(mDcl, "umrstx", dcl_umrstx, 2);
   rb_define_module_function(mDcl, "umlstx", dcl_umlstx, 2);
   rb_define_module_function(mDcl, "umpglb", dcl_umpglb, 0);
   rb_define_module_function(mDcl, "umpgrd", dcl_umpgrd, 0);
   rb_define_module_function(mDcl, "umplim", dcl_umplim, 0);
   rb_define_module_function(mDcl, "umpmap", dcl_umpmap, 1);
   rb_define_module_function(mDcl, "umpqnp", dcl_umpqnp, 1);
   rb_define_module_function(mDcl, "umpqid", dcl_umpqid, 2);
   rb_define_module_function(mDcl, "umpqcp", dcl_umpqcp, 2);
   rb_define_module_function(mDcl, "umpqvl", dcl_umpqvl, 2);
   rb_define_module_function(mDcl, "umpsvl", dcl_umpsvl, 2);
   rb_define_module_function(mDcl, "umqfnm", dcl_umqfnm, 2);
   rb_define_module_function(mDcl, "umqtxy", dcl_umqtxy, 4);
   rb_define_module_function(mDcl, "umscnt", dcl_umscnt, 3);
   rb_define_module_function(mDcl, "umqcnt", dcl_umqcnt, 3);
   rb_define_module_function(mDcl, "umscom", dcl_umscom, 0);
   rb_define_module_function(mDcl, "umscwd", dcl_umscwd, 3);
   rb_define_module_function(mDcl, "umqcwd", dcl_umqcwd, 3);
   rb_define_module_function(mDcl, "umsgrd", dcl_umsgrd, 0);
   rb_define_module_function(mDcl, "umspct", dcl_umspct, 0);
   rb_define_module_function(mDcl, "umspcw", dcl_umspcw, 0);
   rb_define_module_function(mDcl, "umspdf", dcl_umspdf, 0);
   rb_define_module_function(mDcl, "umspnt", dcl_umspnt, 3);
   rb_define_module_function(mDcl, "umqpnt", dcl_umqpnt, 3);
   rb_define_module_function(mDcl, "umqptn", dcl_umqptn, 1);
   rb_define_module_function(mDcl, "umrpnt", dcl_umrpnt, 0);
   rb_define_module_function(mDcl, "umsppt", dcl_umsppt, 0);
   rb_define_module_function(mDcl, "umspwd", dcl_umspwd, 0);
   rb_define_module_function(mDcl, "umstvz", dcl_umstvz, 0);
   rb_define_module_function(mDcl, "csblbl", dcl_csblbl, 3);
   rb_define_module_function(mDcl, "uscget", dcl_uscget, 2);
   rb_define_module_function(mDcl, "uscset", dcl_uscset, 2);
   rb_define_module_function(mDcl, "uscstx", dcl_uscstx, 2);
   rb_define_module_function(mDcl, "uschvl", dcl_uschvl, 2);
   rb_define_module_function(mDcl, "uscqnp", dcl_uscqnp, 1);
   rb_define_module_function(mDcl, "uscqid", dcl_uscqid, 2);
   rb_define_module_function(mDcl, "uscqcp", dcl_uscqcp, 2);
   rb_define_module_function(mDcl, "uscqvl", dcl_uscqvl, 2);
   rb_define_module_function(mDcl, "uscsvl", dcl_uscsvl, 2);
   rb_define_module_function(mDcl, "usdaxs", dcl_usdaxs, 0);
   rb_define_module_function(mDcl, "usgrph", dcl_usgrph, 3);
   rb_define_module_function(mDcl, "usinit", dcl_usinit, 0);
   rb_define_module_function(mDcl, "uspfit", dcl_uspfit, 0);
   rb_define_module_function(mDcl, "uspget", dcl_uspget, 2);
   rb_define_module_function(mDcl, "usiget", dcl_usiget, 2);
   rb_define_module_function(mDcl, "usrget", dcl_usrget, 2);
   rb_define_module_function(mDcl, "uslget", dcl_uslget, 2);
   rb_define_module_function(mDcl, "uspset", dcl_uspset, 2);
   rb_define_module_function(mDcl, "usiset", dcl_usiset, 2);
   rb_define_module_function(mDcl, "usrset", dcl_usrset, 2);
   rb_define_module_function(mDcl, "uslset", dcl_uslset, 2);
   rb_define_module_function(mDcl, "uspstx", dcl_uspstx, 2);
   rb_define_module_function(mDcl, "usistx", dcl_usistx, 2);
   rb_define_module_function(mDcl, "usrstx", dcl_usrstx, 2);
   rb_define_module_function(mDcl, "uslstx", dcl_uslstx, 2);
   rb_define_module_function(mDcl, "uspqnp", dcl_uspqnp, 1);
   rb_define_module_function(mDcl, "uspqid", dcl_uspqid, 2);
   rb_define_module_function(mDcl, "uspqcp", dcl_uspqcp, 2);
   rb_define_module_function(mDcl, "uspqvl", dcl_uspqvl, 2);
   rb_define_module_function(mDcl, "uspsvl", dcl_uspsvl, 2);
   rb_define_module_function(mDcl, "usspnt", dcl_usspnt, 3);
   rb_define_module_function(mDcl, "ussttl", dcl_ussttl, 4);
   rb_define_module_function(mDcl, "usurdl", dcl_usurdl, 4);
   rb_define_module_function(mDcl, "usurdt", dcl_usurdt, 5);
   rb_define_module_function(mDcl, "ususcl", dcl_ususcl, 5);
   rb_define_module_function(mDcl, "ususcu", dcl_ususcu, 6);
   rb_define_module_function(mDcl, "uswapz", dcl_uswapz, 3);
   rb_define_module_function(mDcl, "usxaxl", dcl_usxaxl, 1);
   rb_define_module_function(mDcl, "usxaxs", dcl_usxaxs, 1);
   rb_define_module_function(mDcl, "usxaxu", dcl_usxaxu, 1);
   rb_define_module_function(mDcl, "usxoff", dcl_usxoff, 1);
   rb_define_module_function(mDcl, "usxsub", dcl_usxsub, 4);
   rb_define_module_function(mDcl, "usyaxl", dcl_usyaxl, 1);
   rb_define_module_function(mDcl, "usyaxs", dcl_usyaxs, 1);
   rb_define_module_function(mDcl, "usyaxu", dcl_usyaxu, 1);
   rb_define_module_function(mDcl, "usyoff", dcl_usyoff, 1);
   rb_define_module_function(mDcl, "usysub", dcl_usysub, 4);
   rb_define_module_function(mDcl, "uszdgt", dcl_uszdgt, 0);
   rb_define_module_function(mDcl, "uuinit", dcl_uuinit, 0);
   rb_define_module_function(mDcl, "uulin", dcl_uulin, 3);
   rb_define_module_function(mDcl, "uulinz", dcl_uulinz, 5);
   rb_define_module_function(mDcl, "uumrk", dcl_uumrk, 3);
   rb_define_module_function(mDcl, "uumrkz", dcl_uumrkz, 6);
   rb_define_module_function(mDcl, "uupget", dcl_uupget, 2);
   rb_define_module_function(mDcl, "uuiget", dcl_uuiget, 2);
   rb_define_module_function(mDcl, "uurget", dcl_uurget, 2);
   rb_define_module_function(mDcl, "uulget", dcl_uulget, 2);
   rb_define_module_function(mDcl, "uupset", dcl_uupset, 2);
   rb_define_module_function(mDcl, "uuiset", dcl_uuiset, 2);
   rb_define_module_function(mDcl, "uurset", dcl_uurset, 2);
   rb_define_module_function(mDcl, "uulset", dcl_uulset, 2);
   rb_define_module_function(mDcl, "uupstx", dcl_uupstx, 2);
   rb_define_module_function(mDcl, "uuistx", dcl_uuistx, 2);
   rb_define_module_function(mDcl, "uurstx", dcl_uurstx, 2);
   rb_define_module_function(mDcl, "uulstx", dcl_uulstx, 2);
   rb_define_module_function(mDcl, "uupqnp", dcl_uupqnp, 1);
   rb_define_module_function(mDcl, "uupqid", dcl_uupqid, 2);
   rb_define_module_function(mDcl, "uupqcp", dcl_uupqcp, 2);
   rb_define_module_function(mDcl, "uupqvl", dcl_uupqvl, 2);
   rb_define_module_function(mDcl, "uupsvl", dcl_uupsvl, 2);
   rb_define_module_function(mDcl, "uusarp", dcl_uusarp, 2);
   rb_define_module_function(mDcl, "uuqarp", dcl_uuqarp, 2);
   rb_define_module_function(mDcl, "uusbrs", dcl_uusbrs, 1);
   rb_define_module_function(mDcl, "uuqbrs", dcl_uuqbrs, 1);
   rb_define_module_function(mDcl, "uusebt", dcl_uusebt, 1);
   rb_define_module_function(mDcl, "uuqebt", dcl_uuqebt, 1);
   rb_define_module_function(mDcl, "uusebi", dcl_uusebi, 1);
   rb_define_module_function(mDcl, "uuqebi", dcl_uuqebi, 1);
   rb_define_module_function(mDcl, "uusebs", dcl_uusebs, 1);
   rb_define_module_function(mDcl, "uuqebs", dcl_uuqebs, 1);
   rb_define_module_function(mDcl, "uusfrt", dcl_uusfrt, 1);
   rb_define_module_function(mDcl, "uuqfrt", dcl_uuqfrt, 1);
   rb_define_module_function(mDcl, "uusfri", dcl_uusfri, 1);
   rb_define_module_function(mDcl, "uuqfri", dcl_uuqfri, 1);
   rb_define_module_function(mDcl, "uusidv", dcl_uusidv, 2);
   rb_define_module_function(mDcl, "uuqidv", dcl_uuqidv, 2);
   rb_define_module_function(mDcl, "uuslnt", dcl_uuslnt, 1);
   rb_define_module_function(mDcl, "uuqlnt", dcl_uuqlnt, 1);
   rb_define_module_function(mDcl, "uuslni", dcl_uuslni, 1);
   rb_define_module_function(mDcl, "uuqlni", dcl_uuqlni, 1);
   rb_define_module_function(mDcl, "uusmkt", dcl_uusmkt, 1);
   rb_define_module_function(mDcl, "uuqmkt", dcl_uuqmkt, 1);
   rb_define_module_function(mDcl, "uusmki", dcl_uusmki, 1);
   rb_define_module_function(mDcl, "uuqmki", dcl_uuqmki, 1);
   rb_define_module_function(mDcl, "uusmks", dcl_uusmks, 1);
   rb_define_module_function(mDcl, "uuqmks", dcl_uuqmks, 1);
   rb_define_module_function(mDcl, "uvbra", dcl_uvbra, 4);
   rb_define_module_function(mDcl, "uvbraz", dcl_uvbraz, 7);
   rb_define_module_function(mDcl, "uvbrf", dcl_uvbrf, 4);
   rb_define_module_function(mDcl, "uvbrfz", dcl_uvbrfz, 7);
   rb_define_module_function(mDcl, "uvbrl", dcl_uvbrl, 3);
   rb_define_module_function(mDcl, "uvbrlz", dcl_uvbrlz, 6);
   rb_define_module_function(mDcl, "uvbxa", dcl_uvbxa, 4);
   rb_define_module_function(mDcl, "uvbxaz", dcl_uvbxaz, 6);
   rb_define_module_function(mDcl, "uvbxf", dcl_uvbxf, 4);
   rb_define_module_function(mDcl, "uvbxfz", dcl_uvbxfz, 6);
   rb_define_module_function(mDcl, "uvbxl", dcl_uvbxl, 3);
   rb_define_module_function(mDcl, "uvbxlz", dcl_uvbxlz, 5);
   rb_define_module_function(mDcl, "uvdif", dcl_uvdif, 4);
   rb_define_module_function(mDcl, "uvdifz", dcl_uvdifz, 6);
   rb_define_module_function(mDcl, "uverb", dcl_uverb, 4);
   rb_define_module_function(mDcl, "uverbz", dcl_uverbz, 7);
   rb_define_module_function(mDcl, "iuwgx", dcl_iuwgx, 1);
   rb_define_module_function(mDcl, "iuwgy", dcl_iuwgy, 1);
   rb_define_module_function(mDcl, "ruwgx", dcl_ruwgx, 1);
   rb_define_module_function(mDcl, "ruwgy", dcl_ruwgy, 1);
   rb_define_module_function(mDcl, "uwdflt", dcl_uwdflt, 2);
   rb_define_module_function(mDcl, "uwqgxi", dcl_uwqgxi, 3);
   rb_define_module_function(mDcl, "uwigxi", dcl_uwigxi, 0);
   rb_define_module_function(mDcl, "uwqgyi", dcl_uwqgyi, 3);
   rb_define_module_function(mDcl, "uwigyi", dcl_uwigyi, 0);
   rb_define_module_function(mDcl, "uwsgxa", dcl_uwsgxa, 2);
   rb_define_module_function(mDcl, "uwqgxa", dcl_uwqgxa, 2);
   rb_define_module_function(mDcl, "uwsgxb", dcl_uwsgxb, 3);
   rb_define_module_function(mDcl, "uwqgxb", dcl_uwqgxb, 3);
   rb_define_module_function(mDcl, "uwsgxz", dcl_uwsgxz, 1);
   rb_define_module_function(mDcl, "uwqgxz", dcl_uwqgxz, 1);
   rb_define_module_function(mDcl, "uwsgya", dcl_uwsgya, 2);
   rb_define_module_function(mDcl, "uwqgya", dcl_uwqgya, 2);
   rb_define_module_function(mDcl, "uwsgyb", dcl_uwsgyb, 3);
   rb_define_module_function(mDcl, "uwqgyb", dcl_uwqgyb, 3);
   rb_define_module_function(mDcl, "uwsgyz", dcl_uwsgyz, 1);
   rb_define_module_function(mDcl, "uwqgyz", dcl_uwqgyz, 1);
   rb_define_module_function(mDcl, "luxchk", dcl_luxchk, 1);
   rb_define_module_function(mDcl, "uxaxdv", dcl_uxaxdv, 3);
   rb_define_module_function(mDcl, "uxaxlb", dcl_uxaxlb, 7);
   rb_define_module_function(mDcl, "uxaxnm", dcl_uxaxnm, 5);
   rb_define_module_function(mDcl, "uxmttl", dcl_uxmttl, 3);
   rb_define_module_function(mDcl, "uxpaxs", dcl_uxpaxs, 2);
   rb_define_module_function(mDcl, "uxplba", dcl_uxplba, 10);
   rb_define_module_function(mDcl, "uxplbb", dcl_uxplbb, 0);
   rb_define_module_function(mDcl, "uxplbl", dcl_uxplbl, 6);
   rb_define_module_function(mDcl, "uxpnum", dcl_uxpnum, 4);
   rb_define_module_function(mDcl, "uxsfmt", dcl_uxsfmt, 1);
   rb_define_module_function(mDcl, "uxqfmt", dcl_uxqfmt, 1);
   rb_define_module_function(mDcl, "uxptmk", dcl_uxptmk, 4);
   rb_define_module_function(mDcl, "uxptmz", dcl_uxptmz, 6);
   rb_define_module_function(mDcl, "uxpttl", dcl_uxpttl, 4);
   rb_define_module_function(mDcl, "uxsaxs", dcl_uxsaxs, 1);
   rb_define_module_function(mDcl, "uxsaxz", dcl_uxsaxz, 2);
   rb_define_module_function(mDcl, "uxsoff", dcl_uxsoff, 0);
   rb_define_module_function(mDcl, "uxroff", dcl_uxroff, 0);
   rb_define_module_function(mDcl, "uxsttl", dcl_uxsttl, 3);
   rb_define_module_function(mDcl, "luychk", dcl_luychk, 1);
   rb_define_module_function(mDcl, "uyaxdv", dcl_uyaxdv, 3);
   rb_define_module_function(mDcl, "uyaxlb", dcl_uyaxlb, 7);
   rb_define_module_function(mDcl, "uyaxnm", dcl_uyaxnm, 5);
   rb_define_module_function(mDcl, "uymttl", dcl_uymttl, 3);
   rb_define_module_function(mDcl, "uypaxs", dcl_uypaxs, 2);
   rb_define_module_function(mDcl, "uyplba", dcl_uyplba, 10);
   rb_define_module_function(mDcl, "uyplbb", dcl_uyplbb, 0);
   rb_define_module_function(mDcl, "uyplbl", dcl_uyplbl, 6);
   rb_define_module_function(mDcl, "uypnum", dcl_uypnum, 4);
   rb_define_module_function(mDcl, "uysfmt", dcl_uysfmt, 1);
   rb_define_module_function(mDcl, "uyqfmt", dcl_uyqfmt, 1);
   rb_define_module_function(mDcl, "uyptmk", dcl_uyptmk, 4);
   rb_define_module_function(mDcl, "uyptmz", dcl_uyptmz, 6);
   rb_define_module_function(mDcl, "uypttl", dcl_uypttl, 4);
   rb_define_module_function(mDcl, "uysaxs", dcl_uysaxs, 1);
   rb_define_module_function(mDcl, "uysaxz", dcl_uysaxz, 2);
   rb_define_module_function(mDcl, "uysoff", dcl_uysoff, 0);
   rb_define_module_function(mDcl, "uyroff", dcl_uyroff, 0);
   rb_define_module_function(mDcl, "uysttl", dcl_uysttl, 3);
   rb_define_module_function(mDcl, "uzfact", dcl_uzfact, 1);
   rb_define_module_function(mDcl, "uzinit", dcl_uzinit, 0);
   rb_define_module_function(mDcl, "uzpget", dcl_uzpget, 2);
   rb_define_module_function(mDcl, "uziget", dcl_uziget, 2);
   rb_define_module_function(mDcl, "uzrget", dcl_uzrget, 2);
   rb_define_module_function(mDcl, "uzlget", dcl_uzlget, 2);
   rb_define_module_function(mDcl, "uzpset", dcl_uzpset, 2);
   rb_define_module_function(mDcl, "uziset", dcl_uziset, 2);
   rb_define_module_function(mDcl, "uzrset", dcl_uzrset, 2);
   rb_define_module_function(mDcl, "uzlset", dcl_uzlset, 2);
   rb_define_module_function(mDcl, "uzpstx", dcl_uzpstx, 2);
   rb_define_module_function(mDcl, "uzistx", dcl_uzistx, 2);
   rb_define_module_function(mDcl, "uzrstx", dcl_uzrstx, 2);
   rb_define_module_function(mDcl, "uzlstx", dcl_uzlstx, 2);
   rb_define_module_function(mDcl, "uzpqnp", dcl_uzpqnp, 1);
   rb_define_module_function(mDcl, "uzpqid", dcl_uzpqid, 2);
   rb_define_module_function(mDcl, "uzpqcp", dcl_uzpqcp, 2);
   rb_define_module_function(mDcl, "uzpqvl", dcl_uzpqvl, 2);
   rb_define_module_function(mDcl, "uzpsvl", dcl_uzpsvl, 2);
   rb_define_module_function(mDcl, "uzpsav", dcl_uzpsav, 0);
   rb_define_module_function(mDcl, "uzprst", dcl_uzprst, 0);
   rb_define_module_function(mDcl, "iblkge", dcl_iblkge, 3);
   rb_define_module_function(mDcl, "iblkgt", dcl_iblkgt, 3);
   rb_define_module_function(mDcl, "iblkle", dcl_iblkle, 3);
   rb_define_module_function(mDcl, "iblklt", dcl_iblklt, 3);
   rb_define_module_function(mDcl, "cladj", dcl_cladj, 1);
   rb_define_module_function(mDcl, "cradj", dcl_cradj, 1);
   rb_define_module_function(mDcl, "crvrs", dcl_crvrs, 1);
   rb_define_module_function(mDcl, "lenb", dcl_lenb, 1);
   rb_define_module_function(mDcl, "lenc", dcl_lenc, 1);
   rb_define_module_function(mDcl, "leny", dcl_leny, 1);
   rb_define_module_function(mDcl, "lenz", dcl_lenz, 1);
   rb_define_module_function(mDcl, "cr2c", dcl_cr2c, 5);
   rb_define_module_function(mDcl, "cr3c", dcl_cr3c, 9);
   rb_define_module_function(mDcl, "cr3s", dcl_cr3s, 7);
   rb_define_module_function(mDcl, "ct2bc", dcl_ct2bc, 4);
   rb_define_module_function(mDcl, "ct2ch", dcl_ct2ch, 4);
   rb_define_module_function(mDcl, "ct2cp", dcl_ct2cp, 4);
   rb_define_module_function(mDcl, "ct2ec", dcl_ct2ec, 4);
   rb_define_module_function(mDcl, "ct2hc", dcl_ct2hc, 4);
   rb_define_module_function(mDcl, "ct2pc", dcl_ct2pc, 4);
   rb_define_module_function(mDcl, "ct3cs", dcl_ct3cs, 6);
   rb_define_module_function(mDcl, "ct3sc", dcl_ct3sc, 6);
   rb_define_module_function(mDcl, "igus", dcl_igus, 1);
   rb_define_module_function(mDcl, "imod", dcl_imod, 2);
   rb_define_module_function(mDcl, "rd2r", dcl_rd2r, 1);
   rb_define_module_function(mDcl, "rexp", dcl_rexp, 3);
   rb_define_module_function(mDcl, "rfpi", dcl_rfpi, 0);
   rb_define_module_function(mDcl, "rmod", dcl_rmod, 2);
   rb_define_module_function(mDcl, "rr2d", dcl_rr2d, 1);
   rb_define_module_function(mDcl, "gnsave", dcl_gnsave, 0);
   rb_define_module_function(mDcl, "gnrset", dcl_gnrset, 0);
   rb_define_module_function(mDcl, "gnsblk", dcl_gnsblk, 2);
   rb_define_module_function(mDcl, "gnqblk", dcl_gnqblk, 2);
   rb_define_module_function(mDcl, "gnlt", dcl_gnlt, 3);
   rb_define_module_function(mDcl, "gnle", dcl_gnle, 3);
   rb_define_module_function(mDcl, "gngt", dcl_gngt, 3);
   rb_define_module_function(mDcl, "gnge", dcl_gnge, 3);
   rb_define_module_function(mDcl, "rgnge", dcl_rgnge, 1);
   rb_define_module_function(mDcl, "rgngt", dcl_rgngt, 1);
   rb_define_module_function(mDcl, "rgnle", dcl_rgnle, 1);
   rb_define_module_function(mDcl, "rgnlt", dcl_rgnlt, 1);
   rb_define_module_function(mDcl, "imax", dcl_imax, 3);
   rb_define_module_function(mDcl, "imax0", dcl_imax0, 3);
   rb_define_module_function(mDcl, "imax1", dcl_imax1, 3);
   rb_define_module_function(mDcl, "imin", dcl_imin, 3);
   rb_define_module_function(mDcl, "imin0", dcl_imin0, 3);
   rb_define_module_function(mDcl, "imin1", dcl_imin1, 3);
   rb_define_module_function(mDcl, "isum", dcl_isum, 3);
   rb_define_module_function(mDcl, "isum0", dcl_isum0, 3);
   rb_define_module_function(mDcl, "isum1", dcl_isum1, 3);
   rb_define_module_function(mDcl, "indxcf", dcl_indxcf, 4);
   rb_define_module_function(mDcl, "indxcl", dcl_indxcl, 4);
   rb_define_module_function(mDcl, "indxif", dcl_indxif, 4);
   rb_define_module_function(mDcl, "indxil", dcl_indxil, 4);
   rb_define_module_function(mDcl, "indxmf", dcl_indxmf, 4);
   rb_define_module_function(mDcl, "indxml", dcl_indxml, 4);
   rb_define_module_function(mDcl, "indxnf", dcl_indxnf, 4);
   rb_define_module_function(mDcl, "indxnl", dcl_indxnl, 4);
   rb_define_module_function(mDcl, "indxrf", dcl_indxrf, 4);
   rb_define_module_function(mDcl, "indxrl", dcl_indxrl, 4);
   rb_define_module_function(mDcl, "nindxc", dcl_nindxc, 4);
   rb_define_module_function(mDcl, "nindxi", dcl_nindxi, 4);
   rb_define_module_function(mDcl, "nindxm", dcl_nindxm, 4);
   rb_define_module_function(mDcl, "nindxn", dcl_nindxn, 4);
   rb_define_module_function(mDcl, "nindxr", dcl_nindxr, 4);
   rb_define_module_function(mDcl, "irge", dcl_irge, 1);
   rb_define_module_function(mDcl, "irgt", dcl_irgt, 1);
   rb_define_module_function(mDcl, "irle", dcl_irle, 1);
   rb_define_module_function(mDcl, "irlt", dcl_irlt, 1);
   rb_define_module_function(mDcl, "lreq", dcl_lreq, 2);
   rb_define_module_function(mDcl, "lreq0", dcl_lreq0, 2);
   rb_define_module_function(mDcl, "lreq1", dcl_lreq1, 2);
   rb_define_module_function(mDcl, "lreqa", dcl_lreqa, 3);
   rb_define_module_function(mDcl, "lrge", dcl_lrge, 2);
   rb_define_module_function(mDcl, "lrge0", dcl_lrge0, 2);
   rb_define_module_function(mDcl, "lrge1", dcl_lrge1, 2);
   rb_define_module_function(mDcl, "lrgea", dcl_lrgea, 3);
   rb_define_module_function(mDcl, "lrgt", dcl_lrgt, 2);
   rb_define_module_function(mDcl, "lrgt0", dcl_lrgt0, 2);
   rb_define_module_function(mDcl, "lrgt1", dcl_lrgt1, 2);
   rb_define_module_function(mDcl, "lrgta", dcl_lrgta, 3);
   rb_define_module_function(mDcl, "lrle", dcl_lrle, 2);
   rb_define_module_function(mDcl, "lrle0", dcl_lrle0, 2);
   rb_define_module_function(mDcl, "lrle1", dcl_lrle1, 2);
   rb_define_module_function(mDcl, "lrlea", dcl_lrlea, 3);
   rb_define_module_function(mDcl, "lrlt", dcl_lrlt, 2);
   rb_define_module_function(mDcl, "lrlt0", dcl_lrlt0, 2);
   rb_define_module_function(mDcl, "lrlt1", dcl_lrlt1, 2);
   rb_define_module_function(mDcl, "lrlta", dcl_lrlta, 3);
   rb_define_module_function(mDcl, "lrne", dcl_lrne, 2);
   rb_define_module_function(mDcl, "lrne0", dcl_lrne0, 2);
   rb_define_module_function(mDcl, "lrne1", dcl_lrne1, 2);
   rb_define_module_function(mDcl, "lrnea", dcl_lrnea, 3);
   rb_define_module_function(mDcl, "mpfaza", dcl_mpfaza, 4);
   rb_define_module_function(mDcl, "mpiaza", dcl_mpiaza, 4);
   rb_define_module_function(mDcl, "mpfazm", dcl_mpfazm, 4);
   rb_define_module_function(mDcl, "mpiazm", dcl_mpiazm, 4);
   rb_define_module_function(mDcl, "mpfbon", dcl_mpfbon, 4);
   rb_define_module_function(mDcl, "mpibon", dcl_mpibon, 4);
   rb_define_module_function(mDcl, "mpsbon", dcl_mpsbon, 1);
   rb_define_module_function(mDcl, "mpfcoa", dcl_mpfcoa, 4);
   rb_define_module_function(mDcl, "mpicoa", dcl_mpicoa, 4);
   rb_define_module_function(mDcl, "mpscoa", dcl_mpscoa, 1);
   rb_define_module_function(mDcl, "mpfcoc", dcl_mpfcoc, 4);
   rb_define_module_function(mDcl, "mpicoc", dcl_mpicoc, 4);
   rb_define_module_function(mDcl, "mpscoc", dcl_mpscoc, 2);
   rb_define_module_function(mDcl, "mpfcon", dcl_mpfcon, 4);
   rb_define_module_function(mDcl, "mpicon", dcl_mpicon, 4);
   rb_define_module_function(mDcl, "mpscon", dcl_mpscon, 1);
   rb_define_module_function(mDcl, "mpfcyl", dcl_mpfcyl, 4);
   rb_define_module_function(mDcl, "mpicyl", dcl_mpicyl, 4);
   rb_define_module_function(mDcl, "mpfek6", dcl_mpfek6, 4);
   rb_define_module_function(mDcl, "mpiek6", dcl_mpiek6, 4);
   rb_define_module_function(mDcl, "mpfhmr", dcl_mpfhmr, 4);
   rb_define_module_function(mDcl, "mpihmr", dcl_mpihmr, 4);
   rb_define_module_function(mDcl, "mpfktd", dcl_mpfktd, 4);
   rb_define_module_function(mDcl, "mpiktd", dcl_mpiktd, 4);
   rb_define_module_function(mDcl, "mpfmer", dcl_mpfmer, 4);
   rb_define_module_function(mDcl, "mpimer", dcl_mpimer, 4);
   rb_define_module_function(mDcl, "mpfmwd", dcl_mpfmwd, 4);
   rb_define_module_function(mDcl, "mpimwd", dcl_mpimwd, 4);
   rb_define_module_function(mDcl, "mpfmwl", dcl_mpfmwl, 4);
   rb_define_module_function(mDcl, "mpimwl", dcl_mpimwl, 4);
   rb_define_module_function(mDcl, "mpfotg", dcl_mpfotg, 4);
   rb_define_module_function(mDcl, "mpiotg", dcl_mpiotg, 4);
   rb_define_module_function(mDcl, "mpsotg", dcl_mpsotg, 1);
   rb_define_module_function(mDcl, "mpfpst", dcl_mpfpst, 4);
   rb_define_module_function(mDcl, "mpipst", dcl_mpipst, 4);
   rb_define_module_function(mDcl, "mpzek6", dcl_mpzek6, 4);
   rb_define_module_function(mDcl, "mpzktd", dcl_mpzktd, 4);
   rb_define_module_function(mDcl, "mpzmwd", dcl_mpzmwd, 4);
   rb_define_module_function(mDcl, "mpznwt", dcl_mpznwt, 3);
   rb_define_module_function(mDcl, "xmplon", dcl_xmplon, 1);
   rb_define_module_function(mDcl, "ramp", dcl_ramp, 3);
   rb_define_module_function(mDcl, "ramp0", dcl_ramp0, 3);
   rb_define_module_function(mDcl, "ramp1", dcl_ramp1, 3);
   rb_define_module_function(mDcl, "rave", dcl_rave, 3);
   rb_define_module_function(mDcl, "rave0", dcl_rave0, 3);
   rb_define_module_function(mDcl, "rave1", dcl_rave1, 3);
   rb_define_module_function(mDcl, "rmax", dcl_rmax, 3);
   rb_define_module_function(mDcl, "rmax0", dcl_rmax0, 3);
   rb_define_module_function(mDcl, "rmax1", dcl_rmax1, 3);
   rb_define_module_function(mDcl, "rmin", dcl_rmin, 3);
   rb_define_module_function(mDcl, "rmin0", dcl_rmin0, 3);
   rb_define_module_function(mDcl, "rmin1", dcl_rmin1, 3);
   rb_define_module_function(mDcl, "rrms", dcl_rrms, 3);
   rb_define_module_function(mDcl, "rrms0", dcl_rrms0, 3);
   rb_define_module_function(mDcl, "rrms1", dcl_rrms1, 3);
   rb_define_module_function(mDcl, "rstd", dcl_rstd, 3);
   rb_define_module_function(mDcl, "rstd0", dcl_rstd0, 3);
   rb_define_module_function(mDcl, "rstd1", dcl_rstd1, 3);
   rb_define_module_function(mDcl, "rsum", dcl_rsum, 3);
   rb_define_module_function(mDcl, "rsum0", dcl_rsum0, 3);
   rb_define_module_function(mDcl, "rsum1", dcl_rsum1, 3);
   rb_define_module_function(mDcl, "rvar", dcl_rvar, 3);
   rb_define_module_function(mDcl, "rvar0", dcl_rvar0, 3);
   rb_define_module_function(mDcl, "rvar1", dcl_rvar1, 3);
   rb_define_module_function(mDcl, "rvmax", dcl_rvmax, 5);
   rb_define_module_function(mDcl, "rvmax0", dcl_rvmax0, 5);
   rb_define_module_function(mDcl, "rvmax1", dcl_rvmax1, 5);
   rb_define_module_function(mDcl, "rvmin", dcl_rvmin, 5);
   rb_define_module_function(mDcl, "rvmin0", dcl_rvmin0, 5);
   rb_define_module_function(mDcl, "rvmin1", dcl_rvmin1, 5);
   rb_define_module_function(mDcl, "rcor", dcl_rcor, 5);
   rb_define_module_function(mDcl, "rcov", dcl_rcov, 5);
   rb_define_module_function(mDcl, "rprd", dcl_rprd, 5);
   rb_define_module_function(mDcl, "dxfloc", dcl_dxfloc, 4);
   rb_define_module_function(mDcl, "dxiloc", dcl_dxiloc, 4);
   rb_define_module_function(mDcl, "vignn", dcl_vignn, 3);
   rb_define_module_function(mDcl, "vrgnn", dcl_vrgnn, 3);
   rb_define_module_function(mDcl, "cfsrch", dcl_cfsrch, 5);
   rb_define_module_function(mDcl, "glcget", dcl_glcget, 2);
   rb_define_module_function(mDcl, "glcset", dcl_glcset, 2);
   rb_define_module_function(mDcl, "glcstx", dcl_glcstx, 2);
   rb_define_module_function(mDcl, "glpget", dcl_glpget, 2);
   rb_define_module_function(mDcl, "gliget", dcl_gliget, 2);
   rb_define_module_function(mDcl, "glrget", dcl_glrget, 2);
   rb_define_module_function(mDcl, "gllget", dcl_gllget, 2);
   rb_define_module_function(mDcl, "glpset", dcl_glpset, 2);
   rb_define_module_function(mDcl, "gliset", dcl_gliset, 2);
   rb_define_module_function(mDcl, "glrset", dcl_glrset, 2);
   rb_define_module_function(mDcl, "gllset", dcl_gllset, 2);
   rb_define_module_function(mDcl, "glpstx", dcl_glpstx, 2);
   rb_define_module_function(mDcl, "glistx", dcl_glistx, 2);
   rb_define_module_function(mDcl, "glrstx", dcl_glrstx, 2);
   rb_define_module_function(mDcl, "gllstx", dcl_gllstx, 2);
   rb_define_module_function(mDcl, "glqfnm", dcl_glqfnm, 2);
   rb_define_module_function(mDcl, "iufopn", dcl_iufopn, 0);
   rb_define_module_function(mDcl, "lchreq", dcl_lchreq, 2);
   rb_define_module_function(mDcl, "msgdmp", dcl_msgdmp, 3);
   rb_define_module_function(mDcl, "mszdmp", dcl_mszdmp, 3);
   rb_define_module_function(mDcl, "rtcenv", dcl_rtcenv, 3);
   rb_define_module_function(mDcl, "rtcget", dcl_rtcget, 4);
   rb_define_module_function(mDcl, "rtcopt", dcl_rtcopt, 3);
   rb_define_module_function(mDcl, "rtcxfl", dcl_rtcxfl, 3);
   rb_define_module_function(mDcl, "rtpenv", dcl_rtpenv, 3);
   rb_define_module_function(mDcl, "rtpget", dcl_rtpget, 4);
   rb_define_module_function(mDcl, "rtpopt", dcl_rtpopt, 3);
   rb_define_module_function(mDcl, "rtpxfl", dcl_rtpxfl, 3);
   rb_define_module_function(mDcl, "iadd", dcl_iadd, 4);
   rb_define_module_function(mDcl, "iadd0", dcl_iadd0, 4);
   rb_define_module_function(mDcl, "iadd1", dcl_iadd1, 4);
   rb_define_module_function(mDcl, "imlt", dcl_imlt, 4);
   rb_define_module_function(mDcl, "imlt0", dcl_imlt0, 4);
   rb_define_module_function(mDcl, "imlt1", dcl_imlt1, 4);
   rb_define_module_function(mDcl, "iset", dcl_iset, 4);
   rb_define_module_function(mDcl, "iset0", dcl_iset0, 4);
   rb_define_module_function(mDcl, "iset1", dcl_iset1, 4);
   rb_define_module_function(mDcl, "vicon", dcl_vicon, 6);
   rb_define_module_function(mDcl, "vicon0", dcl_vicon0, 6);
   rb_define_module_function(mDcl, "vicon1", dcl_vicon1, 6);
   rb_define_module_function(mDcl, "vifct", dcl_vifct, 6);
   rb_define_module_function(mDcl, "vifct0", dcl_vifct0, 6);
   rb_define_module_function(mDcl, "vifct1", dcl_vifct1, 6);
   rb_define_module_function(mDcl, "vifna", dcl_vifna, 6);
   rb_define_module_function(mDcl, "vifna0", dcl_vifna0, 6);
   rb_define_module_function(mDcl, "vifna1", dcl_vifna1, 6);
   rb_define_module_function(mDcl, "viinc", dcl_viinc, 6);
   rb_define_module_function(mDcl, "viinc0", dcl_viinc0, 6);
   rb_define_module_function(mDcl, "viinc1", dcl_viinc1, 6);
   rb_define_module_function(mDcl, "viset", dcl_viset, 5);
   rb_define_module_function(mDcl, "viset0", dcl_viset0, 5);
   rb_define_module_function(mDcl, "viset1", dcl_viset1, 5);
   rb_define_module_function(mDcl, "viadd", dcl_viadd, 7);
   rb_define_module_function(mDcl, "viadd0", dcl_viadd0, 7);
   rb_define_module_function(mDcl, "viadd1", dcl_viadd1, 7);
   rb_define_module_function(mDcl, "vidiv", dcl_vidiv, 7);
   rb_define_module_function(mDcl, "vidiv0", dcl_vidiv0, 7);
   rb_define_module_function(mDcl, "vidiv1", dcl_vidiv1, 7);
   rb_define_module_function(mDcl, "vifnb", dcl_vifnb, 8);
   rb_define_module_function(mDcl, "vifnb0", dcl_vifnb0, 8);
   rb_define_module_function(mDcl, "vifnb1", dcl_vifnb1, 8);
   rb_define_module_function(mDcl, "vimlt", dcl_vimlt, 7);
   rb_define_module_function(mDcl, "vimlt0", dcl_vimlt0, 7);
   rb_define_module_function(mDcl, "vimlt1", dcl_vimlt1, 7);
   rb_define_module_function(mDcl, "visub", dcl_visub, 7);
   rb_define_module_function(mDcl, "visub0", dcl_visub0, 7);
   rb_define_module_function(mDcl, "visub1", dcl_visub1, 7);
   rb_define_module_function(mDcl, "radd", dcl_radd, 4);
   rb_define_module_function(mDcl, "radd0", dcl_radd0, 4);
   rb_define_module_function(mDcl, "radd1", dcl_radd1, 4);
   rb_define_module_function(mDcl, "rmlt", dcl_rmlt, 4);
   rb_define_module_function(mDcl, "rmlt0", dcl_rmlt0, 4);
   rb_define_module_function(mDcl, "rmlt1", dcl_rmlt1, 4);
   rb_define_module_function(mDcl, "rset", dcl_rset, 4);
   rb_define_module_function(mDcl, "rset0", dcl_rset0, 4);
   rb_define_module_function(mDcl, "rset1", dcl_rset1, 4);
   rb_define_module_function(mDcl, "vrcon", dcl_vrcon, 6);
   rb_define_module_function(mDcl, "vrcon0", dcl_vrcon0, 6);
   rb_define_module_function(mDcl, "vrcon1", dcl_vrcon1, 6);
   rb_define_module_function(mDcl, "vrfct", dcl_vrfct, 6);
   rb_define_module_function(mDcl, "vrfct0", dcl_vrfct0, 6);
   rb_define_module_function(mDcl, "vrfct1", dcl_vrfct1, 6);
   rb_define_module_function(mDcl, "vrfna", dcl_vrfna, 6);
   rb_define_module_function(mDcl, "vrfna0", dcl_vrfna0, 6);
   rb_define_module_function(mDcl, "vrfna1", dcl_vrfna1, 6);
   rb_define_module_function(mDcl, "vrinc", dcl_vrinc, 6);
   rb_define_module_function(mDcl, "vrinc0", dcl_vrinc0, 6);
   rb_define_module_function(mDcl, "vrinc1", dcl_vrinc1, 6);
   rb_define_module_function(mDcl, "vrset", dcl_vrset, 5);
   rb_define_module_function(mDcl, "vrset0", dcl_vrset0, 5);
   rb_define_module_function(mDcl, "vrset1", dcl_vrset1, 5);
   rb_define_module_function(mDcl, "vradd", dcl_vradd, 7);
   rb_define_module_function(mDcl, "vradd0", dcl_vradd0, 7);
   rb_define_module_function(mDcl, "vradd1", dcl_vradd1, 7);
   rb_define_module_function(mDcl, "vrdiv", dcl_vrdiv, 7);
   rb_define_module_function(mDcl, "vrdiv0", dcl_vrdiv0, 7);
   rb_define_module_function(mDcl, "vrdiv1", dcl_vrdiv1, 7);
   rb_define_module_function(mDcl, "vrfnb", dcl_vrfnb, 8);
   rb_define_module_function(mDcl, "vrfnb0", dcl_vrfnb0, 8);
   rb_define_module_function(mDcl, "vrfnb1", dcl_vrfnb1, 8);
   rb_define_module_function(mDcl, "vrmlt", dcl_vrmlt, 7);
   rb_define_module_function(mDcl, "vrmlt0", dcl_vrmlt0, 7);
   rb_define_module_function(mDcl, "vrmlt1", dcl_vrmlt1, 7);
   rb_define_module_function(mDcl, "vrsub", dcl_vrsub, 7);
   rb_define_module_function(mDcl, "vrsub0", dcl_vrsub0, 7);
   rb_define_module_function(mDcl, "vrsub1", dcl_vrsub1, 7);
   rb_define_module_function(mDcl, "ffromc", dcl_ffromc, 1);
   rb_define_module_function(mDcl, "ifromc", dcl_ifromc, 1);
   rb_define_module_function(mDcl, "jfromc", dcl_jfromc, 1);
   rb_define_module_function(mDcl, "lfromc", dcl_lfromc, 1);
   rb_define_module_function(mDcl, "rfromc", dcl_rfromc, 1);
   rb_define_module_function(mDcl, "cfftb", dcl_cfftb, 3);
   rb_define_module_function(mDcl, "cfftb1", dcl_cfftb1, 5);
   rb_define_module_function(mDcl, "cfftf", dcl_cfftf, 3);
   rb_define_module_function(mDcl, "cfftf1", dcl_cfftf1, 5);
   rb_define_module_function(mDcl, "cffti", dcl_cffti, 2);
   rb_define_module_function(mDcl, "cffti1", dcl_cffti1, 3);
   rb_define_module_function(mDcl, "cosqb", dcl_cosqb, 3);
   rb_define_module_function(mDcl, "cosqb1", dcl_cosqb1, 4);
   rb_define_module_function(mDcl, "cosqf", dcl_cosqf, 3);
   rb_define_module_function(mDcl, "cosqf1", dcl_cosqf1, 4);
   rb_define_module_function(mDcl, "cosqi", dcl_cosqi, 2);
   rb_define_module_function(mDcl, "cost", dcl_cost, 3);
   rb_define_module_function(mDcl, "costi", dcl_costi, 2);
   rb_define_module_function(mDcl, "ezfft1", dcl_ezfft1, 3);
   rb_define_module_function(mDcl, "ezfftb", dcl_ezfftb, 6);
   rb_define_module_function(mDcl, "ezfftf", dcl_ezfftf, 6);
   rb_define_module_function(mDcl, "ezffti", dcl_ezffti, 2);
   rb_define_module_function(mDcl, "passb", dcl_passb, 11);
   rb_define_module_function(mDcl, "passb2", dcl_passb2, 5);
   rb_define_module_function(mDcl, "passb3", dcl_passb3, 6);
   rb_define_module_function(mDcl, "passb4", dcl_passb4, 7);
   rb_define_module_function(mDcl, "passb5", dcl_passb5, 8);
   rb_define_module_function(mDcl, "passf", dcl_passf, 11);
   rb_define_module_function(mDcl, "passf2", dcl_passf2, 5);
   rb_define_module_function(mDcl, "passf3", dcl_passf3, 6);
   rb_define_module_function(mDcl, "passf4", dcl_passf4, 7);
   rb_define_module_function(mDcl, "passf5", dcl_passf5, 8);
   rb_define_module_function(mDcl, "radb2", dcl_radb2, 5);
   rb_define_module_function(mDcl, "radb3", dcl_radb3, 6);
   rb_define_module_function(mDcl, "radb4", dcl_radb4, 7);
   rb_define_module_function(mDcl, "radb5", dcl_radb5, 8);
   rb_define_module_function(mDcl, "radbg", dcl_radbg, 10);
   rb_define_module_function(mDcl, "radf2", dcl_radf2, 5);
   rb_define_module_function(mDcl, "radf3", dcl_radf3, 6);
   rb_define_module_function(mDcl, "radf4", dcl_radf4, 7);
   rb_define_module_function(mDcl, "radf5", dcl_radf5, 8);
   rb_define_module_function(mDcl, "radfg", dcl_radfg, 10);
   rb_define_module_function(mDcl, "rfftb", dcl_rfftb, 3);
   rb_define_module_function(mDcl, "rfftb1", dcl_rfftb1, 5);
   rb_define_module_function(mDcl, "rfftf", dcl_rfftf, 3);
   rb_define_module_function(mDcl, "rfftf1", dcl_rfftf1, 5);
   rb_define_module_function(mDcl, "rffti", dcl_rffti, 2);
   rb_define_module_function(mDcl, "rffti1", dcl_rffti1, 3);
   rb_define_module_function(mDcl, "sinqb", dcl_sinqb, 3);
   rb_define_module_function(mDcl, "sinqf", dcl_sinqf, 3);
   rb_define_module_function(mDcl, "sinqi", dcl_sinqi, 2);
   rb_define_module_function(mDcl, "sint", dcl_sint, 3);
   rb_define_module_function(mDcl, "sint1", dcl_sint1, 6);
   rb_define_module_function(mDcl, "sinti", dcl_sinti, 2);
   rb_define_module_function(mDcl, "vcintr", dcl_vcintr, 3);
   rb_define_module_function(mDcl, "vrintr", dcl_vrintr, 3);
   rb_define_module_function(mDcl, "odpget", dcl_odpget, 2);
   rb_define_module_function(mDcl, "odiget", dcl_odiget, 2);
   rb_define_module_function(mDcl, "odrget", dcl_odrget, 2);
   rb_define_module_function(mDcl, "odlget", dcl_odlget, 2);
   rb_define_module_function(mDcl, "odpset", dcl_odpset, 2);
   rb_define_module_function(mDcl, "odiset", dcl_odiset, 2);
   rb_define_module_function(mDcl, "odrset", dcl_odrset, 2);
   rb_define_module_function(mDcl, "odlset", dcl_odlset, 2);
   rb_define_module_function(mDcl, "odpstx", dcl_odpstx, 2);
   rb_define_module_function(mDcl, "odistx", dcl_odistx, 2);
   rb_define_module_function(mDcl, "odrstx", dcl_odrstx, 2);
   rb_define_module_function(mDcl, "odlstx", dcl_odlstx, 2);
   rb_define_module_function(mDcl, "odpqnp", dcl_odpqnp, 1);
   rb_define_module_function(mDcl, "odpqid", dcl_odpqid, 2);
   rb_define_module_function(mDcl, "odpqcp", dcl_odpqcp, 2);
   rb_define_module_function(mDcl, "odpqvl", dcl_odpqvl, 2);
   rb_define_module_function(mDcl, "odpsvl", dcl_odpsvl, 2);
   rb_define_module_function(mDcl, "odrk1", dcl_odrk1, 8);
   rb_define_module_function(mDcl, "odrk2", dcl_odrk2, 8);
   rb_define_module_function(mDcl, "odrk4", dcl_odrk4, 8);
   rb_define_module_function(mDcl, "odrk4r", dcl_odrk4r, 7);
   rb_define_module_function(mDcl, "odrk4s", dcl_odrk4s, 7);
   rb_define_module_function(mDcl, "odrkdu", dcl_odrkdu, 8);
   rb_define_module_function(mDcl, "odrkdv", dcl_odrkdv, 8);
   rb_define_module_function(mDcl, "odrkg", dcl_odrkg, 8);
   rb_define_module_function(mDcl, "odrkgr", dcl_odrkgr, 7);
   rb_define_module_function(mDcl, "odrkgs", dcl_odrkgs, 7);
   rb_define_module_function(mDcl, "vrrnm", dcl_vrrnm, 6);
   rb_define_module_function(mDcl, "vrrnm0", dcl_vrrnm0, 6);
   rb_define_module_function(mDcl, "vrrnm1", dcl_vrrnm1, 6);
   rb_define_module_function(mDcl, "shfftb", dcl_shfftb, 3);
   rb_define_module_function(mDcl, "shfftf", dcl_shfftf, 3);
   rb_define_module_function(mDcl, "shfg2w", dcl_shfg2w, 7);
   rb_define_module_function(mDcl, "shfw2g", dcl_shfw2g, 7);
   rb_define_module_function(mDcl, "shfwga", dcl_shfwga, 9);
   rb_define_module_function(mDcl, "shfwgj", dcl_shfwgj, 8);
   rb_define_module_function(mDcl, "shfwgm", dcl_shfwgm, 8);
   rb_define_module_function(mDcl, "shfwgz", dcl_shfwgz, 4);
   rb_define_module_function(mDcl, "shinic", dcl_shinic, 4);
   rb_define_module_function(mDcl, "shinif", dcl_shinif, 2);
   rb_define_module_function(mDcl, "shinip", dcl_shinip, 5);
   rb_define_module_function(mDcl, "shinir", dcl_shinir, 2);
   rb_define_module_function(mDcl, "shinit", dcl_shinit, 15);
   rb_define_module_function(mDcl, "shinix", dcl_shinix, 5);
   rb_define_module_function(mDcl, "shiniy", dcl_shiniy, 4);
   rb_define_module_function(mDcl, "shiniz", dcl_shiniz, 4);
   rb_define_module_function(mDcl, "shlbwj", dcl_shlbwj, 11);
   rb_define_module_function(mDcl, "shlbwl", dcl_shlbwl, 6);
   rb_define_module_function(mDcl, "shlbwm", dcl_shlbwm, 10);
   rb_define_module_function(mDcl, "shlbwu", dcl_shlbwu, 12);
   rb_define_module_function(mDcl, "shlfwl", dcl_shlfwl, 7);
   rb_define_module_function(mDcl, "shlfwm", dcl_shlfwm, 13);
   rb_define_module_function(mDcl, "shlfwu", dcl_shlfwu, 15);
   rb_define_module_function(mDcl, "shlsds", dcl_shlsds, 6);
   rb_define_module_function(mDcl, "shlssd", dcl_shlssd, 6);
   rb_define_module_function(mDcl, "shly2x", dcl_shly2x, 7);
   rb_define_module_function(mDcl, "shmdxj", dcl_shmdxj, 2);
   rb_define_module_function(mDcl, "shmdxm", dcl_shmdxm, 3);
   rb_define_module_function(mDcl, "shms2w", dcl_shms2w, 11);
   rb_define_module_function(mDcl, "shmsri", dcl_shmsri, 4);
   rb_define_module_function(mDcl, "shmswa", dcl_shmswa, 13);
   rb_define_module_function(mDcl, "shmswj", dcl_shmswj, 14);
   rb_define_module_function(mDcl, "shmswm", dcl_shmswm, 13);
   rb_define_module_function(mDcl, "shmswz", dcl_shmswz, 11);
   rb_define_module_function(mDcl, "shmw2s", dcl_shmw2s, 14);
   rb_define_module_function(mDcl, "shmwjm", dcl_shmwjm, 14);
   rb_define_module_function(mDcl, "shmwjz", dcl_shmwjz, 12);
   rb_define_module_function(mDcl, "shnm2l", dcl_shnm2l, 5);
   rb_define_module_function(mDcl, "sholap", dcl_sholap, 4);
   rb_define_module_function(mDcl, "shpfun", dcl_shpfun, 9);
   rb_define_module_function(mDcl, "shppma", dcl_shppma, 7);
   rb_define_module_function(mDcl, "shppmj", dcl_shppmj, 8);
   rb_define_module_function(mDcl, "shtlib", dcl_shtlib, 0);
   rb_define_module_function(mDcl, "shtint", dcl_shtint, 4);
   rb_define_module_function(mDcl, "shtlap", dcl_shtlap, 4);
   rb_define_module_function(mDcl, "shtnml", dcl_shtnml, 5);
   rb_define_module_function(mDcl, "shtfun", dcl_shtfun, 5);
   rb_define_module_function(mDcl, "shtlfw", dcl_shtlfw, 7);
   rb_define_module_function(mDcl, "shtlbw", dcl_shtlbw, 7);
   rb_define_module_function(mDcl, "shts2w", dcl_shts2w, 6);
   rb_define_module_function(mDcl, "shtswa", dcl_shtswa, 8);
   rb_define_module_function(mDcl, "shtswz", dcl_shtswz, 6);
   rb_define_module_function(mDcl, "shtswm", dcl_shtswm, 8);
   rb_define_module_function(mDcl, "shtswj", dcl_shtswj, 9);
   rb_define_module_function(mDcl, "shtw2s", dcl_shtw2s, 6);
   rb_define_module_function(mDcl, "shtw2g", dcl_shtw2g, 6);
   rb_define_module_function(mDcl, "shtwga", dcl_shtwga, 8);
   rb_define_module_function(mDcl, "shtwgm", dcl_shtwgm, 8);
   rb_define_module_function(mDcl, "shtwgz", dcl_shtwgz, 4);
   rb_define_module_function(mDcl, "shtwgj", dcl_shtwgj, 7);
   rb_define_module_function(mDcl, "shtg2w", dcl_shtg2w, 6);
   rb_define_module_function(mDcl, "shts2g", dcl_shts2g, 8);
   rb_define_module_function(mDcl, "shtsga", dcl_shtsga, 10);
   rb_define_module_function(mDcl, "shtsgz", dcl_shtsgz, 8);
   rb_define_module_function(mDcl, "shtsgm", dcl_shtsgm, 10);
   rb_define_module_function(mDcl, "shtsgj", dcl_shtsgj, 11);
   rb_define_module_function(mDcl, "shtg2s", dcl_shtg2s, 8);
   rb_define_module_function(mDcl, "vs1int", dcl_vs1int, 3);
   rb_define_module_function(mDcl, "vs1din", dcl_vs1din, 4);
   rb_define_module_function(mDcl, "vs1out", dcl_vs1out, 3);
   rb_define_module_function(mDcl, "vs2int", dcl_vs2int, 4);
   rb_define_module_function(mDcl, "vs2din", dcl_vs2din, 6);
   rb_define_module_function(mDcl, "vs2out", dcl_vs2out, 4);
   rb_define_module_function(mDcl, "bitpci", dcl_bitpci, 2);
   rb_define_module_function(mDcl, "bitpic", dcl_bitpic, 2);
   rb_define_module_function(mDcl, "gbyte", dcl_gbyte, 4);
   rb_define_module_function(mDcl, "gbytes", dcl_gbytes, 6);
   rb_define_module_function(mDcl, "sbyte", dcl_sbyte, 4);
   rb_define_module_function(mDcl, "sbytes", dcl_sbytes, 6);
   rb_define_module_function(mDcl, "clower", dcl_clower, 1);
   rb_define_module_function(mDcl, "cupper", dcl_cupper, 1);
   rb_define_module_function(mDcl, "lchr", dcl_lchr, 2);
   rb_define_module_function(mDcl, "lchra", dcl_lchra, 1);
   rb_define_module_function(mDcl, "lchrb", dcl_lchrb, 1);
   rb_define_module_function(mDcl, "lchrc", dcl_lchrc, 1);
   rb_define_module_function(mDcl, "lchrd", dcl_lchrd, 1);
   rb_define_module_function(mDcl, "lchrf", dcl_lchrf, 1);
   rb_define_module_function(mDcl, "lchrl", dcl_lchrl, 1);
   rb_define_module_function(mDcl, "lchrs", dcl_lchrs, 1);
   rb_define_module_function(mDcl, "chngc", dcl_chngc, 3);
   rb_define_module_function(mDcl, "chngi", dcl_chngi, 4);
   rb_define_module_function(mDcl, "chngr", dcl_chngr, 4);
   rb_define_module_function(mDcl, "date12", dcl_date12, 3);
   rb_define_module_function(mDcl, "date13", dcl_date13, 4);
   rb_define_module_function(mDcl, "date21", dcl_date21, 3);
   rb_define_module_function(mDcl, "date23", dcl_date23, 4);
   rb_define_module_function(mDcl, "date31", dcl_date31, 4);
   rb_define_module_function(mDcl, "date32", dcl_date32, 4);
   rb_define_module_function(mDcl, "datec1", dcl_datec1, 2);
   rb_define_module_function(mDcl, "datec2", dcl_datec2, 3);
   rb_define_module_function(mDcl, "datec3", dcl_datec3, 4);
   rb_define_module_function(mDcl, "datef1", dcl_datef1, 3);
   rb_define_module_function(mDcl, "datef2", dcl_datef2, 5);
   rb_define_module_function(mDcl, "datef3", dcl_datef3, 7);
   rb_define_module_function(mDcl, "dateg1", dcl_dateg1, 3);
   rb_define_module_function(mDcl, "dateg2", dcl_dateg2, 5);
   rb_define_module_function(mDcl, "dateg3", dcl_dateg3, 7);
   rb_define_module_function(mDcl, "dateq1", dcl_dateq1, 1);
   rb_define_module_function(mDcl, "dateq2", dcl_dateq2, 2);
   rb_define_module_function(mDcl, "iweek1", dcl_iweek1, 1);
   rb_define_module_function(mDcl, "iweek2", dcl_iweek2, 2);
   rb_define_module_function(mDcl, "iweek3", dcl_iweek3, 3);
   rb_define_module_function(mDcl, "ndate1", dcl_ndate1, 2);
   rb_define_module_function(mDcl, "ndate2", dcl_ndate2, 4);
   rb_define_module_function(mDcl, "ndate3", dcl_ndate3, 6);
   rb_define_module_function(mDcl, "ndmon", dcl_ndmon, 2);
   rb_define_module_function(mDcl, "ndyear", dcl_ndyear, 1);
   rb_define_module_function(mDcl, "fcpack", dcl_fcpack, 0);
   rb_define_module_function(mDcl, "fcslfc", dcl_fcslfc, 1);
   rb_define_module_function(mDcl, "fcleol", dcl_fcleol, 2);
   rb_define_module_function(mDcl, "fcopen", dcl_fcopen, 5);
   rb_define_module_function(mDcl, "fcclos", dcl_fcclos, 2);
   rb_define_module_function(mDcl, "fcnrec", dcl_fcnrec, 2);
   rb_define_module_function(mDcl, "fcgetr", dcl_fcgetr, 3);
   rb_define_module_function(mDcl, "fcputr", dcl_fcputr, 3);
   rb_define_module_function(mDcl, "fcgets", dcl_fcgets, 3);
   rb_define_module_function(mDcl, "fcputs", dcl_fcputs, 3);
   rb_define_module_function(mDcl, "fcrwnd", dcl_fcrwnd, 2);
   rb_define_module_function(mDcl, "chval", dcl_chval, 3);
   rb_define_module_function(mDcl, "hexdci", dcl_hexdci, 2);
   rb_define_module_function(mDcl, "hexdic", dcl_hexdic, 2);
   rb_define_module_function(mDcl, "cdblk", dcl_cdblk, 1);
   rb_define_module_function(mDcl, "cns", dcl_cns, 1);
   rb_define_module_function(mDcl, "rngu1", dcl_rngu1, 1);
   rb_define_module_function(mDcl, "rngu2", dcl_rngu2, 1);
   rb_define_module_function(mDcl, "rngu3", dcl_rngu3, 1);
   rb_define_module_function(mDcl, "r4ibm", dcl_r4ibm, 1);
   rb_define_module_function(mDcl, "r4ieee", dcl_r4ieee, 1);
   rb_define_module_function(mDcl, "time12", dcl_time12, 2);
   rb_define_module_function(mDcl, "time13", dcl_time13, 4);
   rb_define_module_function(mDcl, "time21", dcl_time21, 2);
   rb_define_module_function(mDcl, "time23", dcl_time23, 4);
   rb_define_module_function(mDcl, "time31", dcl_time31, 4);
   rb_define_module_function(mDcl, "time32", dcl_time32, 4);
   rb_define_module_function(mDcl, "timec1", dcl_timec1, 2);
   rb_define_module_function(mDcl, "timec2", dcl_timec2, 2);
   rb_define_module_function(mDcl, "timec3", dcl_timec3, 4);
   rb_define_module_function(mDcl, "timeq1", dcl_timeq1, 1);
   rb_define_module_function(mDcl, "timeq2", dcl_timeq2, 1);
}

/* I don't know why this is neccessary */
MAIN__()
{
}
